@@ -9,6 +9,7 @@
 #endif
 
 #include "guiutils.h"
+#include "pulist.h"
 #include "cfg.h"
 #include "edv_types.h"
 #include "archive_options_dlg.h"
@@ -27,13 +28,13 @@
 
 
 /*
- *      Dialog Common:
+ *	Dialog Common:
  */
 typedef struct {
 	GtkWidget	*toplevel;
 	GtkAccelGroup	*accelgrp;
 	gint		freeze_count;
-	edv_core_struct	*core;   
+	edv_core_struct	*core;
 	GtkWidget	*main_vbox,
 			*client_vbox,
 			*ok_btn,
@@ -51,9 +52,9 @@ typedef struct {
 	GtkWidget	*recursive_check,
 			*compression_scale,
 			*compression_label,
-			*compression_combo,
 			*dereference_links_check;
 	GtkAdjustment	*compression_adj;
+	pulistbox_struct	*compression_pulistbox;
 } AddDlg;
 #define ADD_DLG(p)		((AddDlg *)(p))
 
@@ -79,8 +80,8 @@ static void EDVDlgCancelCB(GtkWidget *widget, gpointer data);
 static void EDVArchOptsDlgAddCompressionValueChangedCB(
 	GtkAdjustment *adj, gpointer data
 );
-static void EDVArchOptsDlgAddCompressionComboChangedCB(
-	GtkWidget *w, gpointer data, GList *glist
+static void EDVArchOptsDlgAddCompressionPUListChangedCB(
+	pulistbox_struct *pulistbox, gint i, gpointer data
 );
 
 /* Dialog Common */
@@ -115,16 +116,16 @@ gboolean EDVArchExtractOptsGetResponse(
 );
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -173,11 +174,12 @@ static void EDVArchOptsDlgAddCompressionValueChangedCB(
 	GtkAdjustment *adj, gpointer data
 )
 {
+	gint nitems;
 	gfloat v;
 	gchar *s;
-	GList *glist;
 	GtkLabel *label;
-	GtkCombo *combo;
+	pulist_struct *pulist;
+	pulistbox_struct *pulistbox;
 	AddDlg *d = ADD_DLG(data);
 	if((adj == NULL) || (d == NULL))
 	    return;
@@ -189,48 +191,43 @@ static void EDVArchOptsDlgAddCompressionValueChangedCB(
 
 	v = adj->value;
 	label = GTK_LABEL(d->compression_label);
-	combo = GTK_COMBO(d->compression_combo);
+	pulistbox = d->compression_pulistbox;
+	pulist = PUListBoxGetPUList(pulistbox);
+	nitems = PUListGetTotalItems(pulist);
 
-	/* Update label */
+	/* Update the label */
 	s = g_strdup_printf("%i%%", (gint)v);
 	gtk_label_set_text(label, s);
 	g_free(s);
 
-	/* Set combo */
-	glist = GUIComboGetList(GTK_WIDGET(combo));
-	if(glist != NULL)
-	{
-	    gint n_highest = MAX(g_list_length(glist) - 1, 0);
-	    const gchar *s = (const gchar *)g_list_nth_data(
-		glist,
+	/* Update the popup list box */
+	if(nitems > 1)
+	    PUListBoxSelect(
+		pulistbox,
 		(gint)rint(
-		    (v / 100.0f) * (gfloat)n_highest
+		    (v / 100.0f) * (gfloat)(nitems - 1)
 		)
 	    );
-	    if(s == NULL)
-		s = (const gchar *)g_list_nth_data(glist, 0);
-	    if(s != NULL)
-		gtk_entry_set_text(GTK_ENTRY(combo->entry), s);
-	}
 
 	DLG(d)->freeze_count--;
 }
 
 /*
- *	Add Options Dialog compression GtkCombo changed signal callback.
+ *	Add Options Dialog compression popup list box changed signal
+ *	callback.
  */
-static void EDVArchOptsDlgAddCompressionComboChangedCB(
-	GtkWidget *w, gpointer data, GList *glist
+static void EDVArchOptsDlgAddCompressionPUListChangedCB(
+	pulistbox_struct *pulistbox, gint i, gpointer data
 )
 {
 	float v = 0.0f;
-	gint items;
+	gint nitems;
 	gchar *s;
 	GtkAdjustment *adj;
 	GtkLabel *label;
-	GtkCombo *combo;
+	pulist_struct *pulist;
 	AddDlg *d = ADD_DLG(data);
-	if((glist == NULL) || (d == NULL))
+	if((pulistbox == NULL) || (d == NULL))
 	    return;
 
 	if(DLG(d)->freeze_count > 0)
@@ -240,41 +237,24 @@ static void EDVArchOptsDlgAddCompressionComboChangedCB(
 
 	adj = d->compression_adj;
 	label = GTK_LABEL(d->compression_label);
-	combo = GTK_COMBO(d->compression_combo);
-	items = g_list_length(glist);
+	pulist = PUListBoxGetPUList(pulistbox);
+	nitems = PUListGetTotalItems(pulist);
 
-	/* Get current value from compression combo */
-	s = gtk_entry_get_text(GTK_ENTRY(combo->entry));
-	if(s != NULL)
-	{
-	    gint i = 0, n_highest = MAX(items - 1, 0);
-	    const gchar *s2;
-	    GList *glist_ptr = glist;
+	/* Calculate the compression value from 0.0 to 100.0 */
+	if(nitems > 1)
+	    v = MIN(
+		((gfloat)i / (gfloat)(nitems - 1)),
+		1.0f
+	    ) * 100.0f;
+	else
+	    v = 0.0f;
 
-	    while(glist_ptr != NULL)
-	    {
-		s2 = (const gchar *)glist_ptr->data;
-		if((s2 != NULL) ? !strcmp(s, s2) : FALSE)
-		    break;
-
-		i++;
-		glist_ptr = g_list_next(glist_ptr);
-	    }
-
-	    if(n_highest > 0)
-		v = MIN(
-		    (gfloat)i / (gfloat)n_highest, 1.0f
-		) * 100.0f;
-	    else
-		v = 0.0f;
-	}
-
-	/* Update label */
+	/* Update the label */
 	s = g_strdup_printf("%i%%", (gint)v);
 	gtk_label_set_text(label, s);
 	g_free(s);
 
-	/* Update scale */
+	/* Update the scale */
 	gtk_adjustment_set_value(adj, v);
 
 	DLG(d)->freeze_count--;
@@ -315,8 +295,8 @@ static Dlg *EDVDlgNew(
 	    GTK_WINDOW(w), "dialog", PROG_NAME
 	);
 	gtk_widget_realize(w);
-	window = w->window;   
-	if(window != NULL)   
+	window = w->window;
+	if(window != NULL)
 	{
 	    gdk_window_set_decorations(
 		window,
@@ -329,6 +309,10 @@ static Dlg *EDVDlgNew(
 	    );
 	    GUISetWMIcon(window, icon_data);
 	}
+	gtk_widget_add_events(
+	    w,
+	    GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
+	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "delete_event",
 	    GTK_SIGNAL_FUNC(EDVDlgDeleteEventCB), d
@@ -348,17 +332,17 @@ static Dlg *EDVDlgNew(
 	/* Main vbox */
 	d->main_vbox = w = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(parent), w);
-	gtk_widget_show(w);   
+	gtk_widget_show(w);
 	parent = w;
 
 	/* Client vbox */
 	d->client_vbox = w = gtk_vbox_new(FALSE, border_major);
-	gtk_container_border_width(GTK_CONTAINER(w), border_major);  
+	gtk_container_border_width(GTK_CONTAINER(w), border_major);
 	gtk_box_pack_start(GTK_BOX(parent), w, TRUE, TRUE, 0);
 	gtk_widget_show(w);
 
 	w = gtk_hseparator_new();
-	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);  
+	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 
 	/* Buttons hbox */
@@ -387,7 +371,7 @@ static Dlg *EDVDlgNew(
 	/* Cancel button */
 	d->cancel_btn = w = GUIButtonPixmapLabelH(
 	    cancel_icon_data, cancel_label, NULL
-	);                          
+	);
 	GTK_WIDGET_SET_FLAGS(w, GTK_CAN_DEFAULT);
 	gtk_widget_set_usize(
 	    w,
@@ -484,9 +468,9 @@ gboolean EDVArchAddOptsGetResponse(
 "Fgen Sie Zu Archiv Optionen Hinzu"
 #elif defined(PROG_LANGUAGE_ITALIAN)
 "Aggiungere Alle Opzioni Di Archivio"
-#elif defined(PROG_LANGUAGE_DUTCH)                                     
+#elif defined(PROG_LANGUAGE_DUTCH)
 "Voeg Aan archief Opties toe"
-#elif defined(PROG_LANGUAGE_PORTUGUESE)                                    
+#elif defined(PROG_LANGUAGE_PORTUGUESE)
 "Adicione A Opes de Arquivo"
 #elif defined(PROG_LANGUAGE_NORWEGIAN)
 "Tilfy To Archive Options"
@@ -547,15 +531,16 @@ gboolean EDVArchAddOptsGetResponse(
 	client_vbox = DLG(d)->client_vbox;
 	style = gtk_widget_get_style(toplevel);
 
-	/* Create options widgets */
+	/* Create the option widgets */
 	if(client_vbox != NULL)
 	{
-	    gpointer combo_rtn;
-	    GList *glist;
+	    gint i;
 	    GtkStateType state;
 	    GtkRcStyle *rcstyle;
 	    GtkAdjustment *adj;
 	    GtkWidget *w, *parent = client_vbox, *parent2, *parent3;
+	    pulist_struct *pulist;
+	    pulistbox_struct *pulistbox;
 
 	    w = DLG(d)->ok_btn;
 	    gtk_accel_group_add(
@@ -564,7 +549,7 @@ gboolean EDVArchAddOptsGetResponse(
 	    );
 	    GUIButtonLabelUnderline(w, GDK_a);
 	    w = DLG(d)->cancel_btn;
-	    gtk_accel_group_add(   
+	    gtk_accel_group_add(
 		accelgrp, GDK_Escape, 0, GTK_ACCEL_VISIBLE,
 		GTK_OBJECT(w), "clicked"
 	    );
@@ -813,83 +798,75 @@ archive formats and therefore do not apply."
 	    gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	    gtk_widget_show(w);
 
-	    /* Compression combo */
-	    glist = NULL;
-#if defined(PROG_LANGUAGE_SPANISH)
-	    glist = g_list_append(glist, "Ninguno");
-	    glist = g_list_append(glist, "Bajo");
-	    glist = g_list_append(glist, "Estndar");
-	    glist = g_list_append(glist, "Alto");
-	    glist = g_list_append(glist, "Mximo");
-#elif defined(PROG_LANGUAGE_FRENCH)
-	    glist = g_list_append(glist, "Aucun");
-	    glist = g_list_append(glist, "Niveau Bas");
-	    glist = g_list_append(glist, "Norme");
-	    glist = g_list_append(glist, "Haut");
-	    glist = g_list_append(glist, "Maximum");
-#elif defined(PROG_LANGUAGE_GERMAN)
-	    glist = g_list_append(glist, "Keiner");
-	    glist = g_list_append(glist, "Niedrig");
-	    glist = g_list_append(glist, "Standard");
-	    glist = g_list_append(glist, "Hoch");
-	    glist = g_list_append(glist, "Maximum");
-#elif defined(PROG_LANGUAGE_ITALIAN)
-	    glist = g_list_append(glist, "Nessuno");
-	    glist = g_list_append(glist, "Basso");
-	    glist = g_list_append(glist, "Norma");
-	    glist = g_list_append(glist, "Alto");
-	    glist = g_list_append(glist, "Massimo");
-#elif defined(PROG_LANGUAGE_DUTCH)
-	    glist = g_list_append(glist, "Geen");
-	    glist = g_list_append(glist, "Laag");
-	    glist = g_list_append(glist, "Standaard");
-	    glist = g_list_append(glist, "Hoog");
-	    glist = g_list_append(glist, "Maximum");
-#elif defined(PROG_LANGUAGE_PORTUGUESE)
-	    glist = g_list_append(glist, "Nenhum");
-	    glist = g_list_append(glist, "Baixo");
-	    glist = g_list_append(glist, "Padro");
-	    glist = g_list_append(glist, "Alto");
-	    glist = g_list_append(glist, "Mximo");
-#elif defined(PROG_LANGUAGE_NORWEGIAN)
-	    glist = g_list_append(glist, "Ingen");
-	    glist = g_list_append(glist, "Lav");
-	    glist = g_list_append(glist, "Standard");
-	    glist = g_list_append(glist, "Hy");
-	    glist = g_list_append(glist, "Maksimum");
-#elif defined(PROG_LANGUAGE_POLISH)
-	    glist = g_list_append(glist, "Brak");
-	    glist = g_list_append(glist, "Niska");
-	    glist = g_list_append(glist, "Normalna");
-	    glist = g_list_append(glist, "Wysoka");
-	    glist = g_list_append(glist, "Maksymalna");
-
-#else
-	    glist = g_list_append(glist, "None");
-	    glist = g_list_append(glist, "Low");
-	    glist = g_list_append(glist, "Standard");
-	    glist = g_list_append(glist, "High");
-	    glist = g_list_append(glist, "Maximum");
-#endif
-	    w = GUIComboCreate(
-		NULL,			/* No label */
-		NULL,			/* No value (set later) */
-		glist,			/* List of values */
-		g_list_length(glist),	/* Size of list */
-		&combo_rtn,
-		d,
-		NULL,
-		EDVArchOptsDlgAddCompressionComboChangedCB
+	    /* Compression popup list box */
+	    d->compression_pulistbox = pulistbox = PUListBoxNew(
+		parent3,
+		90, -1
 	    );
-	    g_list_free(glist);
-	    gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
-	    gtk_widget_show(w);
-	    d->compression_combo = w = (GtkWidget *)combo_rtn;
-	    w = GTK_COMBO(w)->entry;
-	    gtk_widget_set_usize(w, 70, -1);
-	    gtk_entry_set_editable(GTK_ENTRY(w), FALSE);
+	    pulist = PUListBoxGetPUList(pulistbox);
+	    PUListBoxSetChangedCB(
+		pulistbox,
+		EDVArchOptsDlgAddCompressionPUListChangedCB, d
+	    );
+	    PUListBoxMap(pulistbox);
+#if defined(PROG_LANGUAGE_SPANISH)
+	    i = PUListAddItem(pulist, "Ninguno");
+	    i = PUListAddItem(pulist, "Bajo");
+	    i = PUListAddItem(pulist, "Estndar");
+	    i = PUListAddItem(pulist, "Alto");
+	    i = PUListAddItem(pulist, "Mximo");
+#elif defined(PROG_LANGUAGE_FRENCH)
+	    i = PUListAddItem(pulist, "Aucun");
+	    i = PUListAddItem(pulist, "Niveau Bas");
+	    i = PUListAddItem(pulist, "Norme");
+	    i = PUListAddItem(pulist, "Haut");
+	    i = PUListAddItem(pulist, "Maximum");
+#elif defined(PROG_LANGUAGE_GERMAN)
+	    i = PUListAddItem(pulist, "Keiner");
+	    i = PUListAddItem(pulist, "Niedrig");
+	    i = PUListAddItem(pulist, "Standard");
+	    i = PUListAddItem(pulist, "Hoch");
+	    i = PUListAddItem(pulist, "Maximum");
+#elif defined(PROG_LANGUAGE_ITALIAN)
+	    i = PUListAddItem(pulist, "Nessuno");
+	    i = PUListAddItem(pulist, "Basso");
+	    i = PUListAddItem(pulist, "Norma");
+	    i = PUListAddItem(pulist, "Alto");
+	    i = PUListAddItem(pulist, "Massimo");
+#elif defined(PROG_LANGUAGE_DUTCH)
+	    i = PUListAddItem(pulist, "Geen");
+	    i = PUListAddItem(pulist, "Laag");
+	    i = PUListAddItem(pulist, "Standaard");
+	    i = PUListAddItem(pulist, "Hoog");
+	    i = PUListAddItem(pulist, "Maximum");
+#elif defined(PROG_LANGUAGE_PORTUGUESE)
+	    i = PUListAddItem(pulist, "Nenhum");
+	    i = PUListAddItem(pulist, "Baixo");
+	    i = PUListAddItem(pulist, "Padro");
+	    i = PUListAddItem(pulist, "Alto");
+	    i = PUListAddItem(pulist, "Mximo");
+#elif defined(PROG_LANGUAGE_NORWEGIAN)
+	    i = PUListAddItem(pulist, "Ingen");
+	    i = PUListAddItem(pulist, "Lav");
+	    i = PUListAddItem(pulist, "Standard");
+	    i = PUListAddItem(pulist, "Hy");
+	    i = PUListAddItem(pulist, "Maksimum");
+#elif defined(PROG_LANGUAGE_POLISH)
+	    i = PUListAddItem(pulist, "Brak");
+	    i = PUListAddItem(pulist, "Niska");
+	    i = PUListAddItem(pulist, "Normalna");
+	    i = PUListAddItem(pulist, "Wysoka");
+	    i = PUListAddItem(pulist, "Maksymalna");
+#else
+	    i = PUListAddItem(pulist, "None");
+	    i = PUListAddItem(pulist, "Low");
+	    i = PUListAddItem(pulist, "Standard");
+	    i = PUListAddItem(pulist, "High");
+	    i = PUListAddItem(pulist, "Maximum");
+#endif
+	    PUListBoxSetLinesVisible(pulistbox, i + 1);
 
-	    /* Update value */
+	    /* Update the compression value */
 	    EDVArchOptsDlgAddCompressionValueChangedCB(adj, d);
 
 	    /* Dereference links check */
@@ -1007,6 +984,7 @@ archive formats and therefore do not apply."
 	}
 
 	/* Delete the Dialog */
+	PUListBoxDelete(d->compression_pulistbox);
 	EDVDlgDelete(DLG(d));
 
 	return(got_response);
@@ -1188,7 +1166,7 @@ gboolean EDVArchExtractOptsGetResponse(
 
 		w = gtk_hbox_new(FALSE, border_major);
 		gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
-		gtk_widget_show(w);                                   
+		gtk_widget_show(w);
 		parent3 = w;
 
 		w = EDVNewPixmapWidget(
@@ -1216,7 +1194,7 @@ gboolean EDVArchExtractOptsGetResponse(
 
 		w = gtk_hbox_new(FALSE, border_major);
 		gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
-		gtk_widget_show(w);                                   
+		gtk_widget_show(w);
 		parent3 = w;
 		w = gtk_label_new(
 "Specify the options for extracting objects from this\n\
@@ -1410,5 +1388,5 @@ archive formats and therefore do not apply."
 	/* Delete the Dialog */
 	EDVDlgDelete(DLG(d));
 
-	return(got_response);  
+	return(got_response);
 }
