@@ -8,21 +8,22 @@
 
 #include "guiutils.h"
 #include "toolbar.h"
+#include "cdialog.h"
 
-#include "edvtypes.h"
-#include "edvlistcb.h"
+#include "edv_types.h"
+#include "edv_list_cb.h"
 #include "cfg.h"
-#include "statusbar.h"
+#include "edv_status_bar.h"
 #include "archiver.h"
-#include "archivercb.h"
-#include "archiveropcb.h"
-#include "archivercontents.h"
-#include "archiverdnd.h"
-#include "endeavour.h"
-#include "edvcb.h"
-#include "edvutils.h"
-#include "edvutilsgtk.h"
-#include "edvcfglist.h"
+#include "archiver_cb.h"
+#include "archiver_op_cb.h"
+#include "archiver_contents_list.h"
+#include "archiver_dnd.h"
+#include "endeavour2.h"
+#include "edv_cb.h"
+#include "edv_utils.h"
+#include "edv_utils_gtk.h"
+#include "edv_cfg_list.h"
 #include "config.h"
 
 #include "images/icon_hsep_20x20.xpm"
@@ -36,6 +37,8 @@
 #include "images/icon_exit_20x20.xpm"
 #include "images/icon_archive_add_20x20.xpm"
 #include "images/icon_archive_extract_20x20.xpm"
+#include "images/icon_aid_20x20.xpm"
+#include "images/icon_archive_check_20x20.xpm"
 #include "images/icon_security_20x20.xpm"
 #include "images/icon_cancel_20x20.xpm"
 #include "images/icon_select_all_20x20.xpm"
@@ -48,6 +51,7 @@
 #include "images/icon_properties2_20x20.xpm"
 #include "images/icon_tool_bar_20x20.xpm"
 #include "images/icon_status_bar_20x20.xpm"
+#include "images/icon_wildcards_20x20.xpm"
 #include "images/icon_options2_20x20.xpm"
 #include "images/icon_customize_20x20.xpm"
 #include "images/icon_insecure_20x20.xpm"
@@ -60,6 +64,7 @@
 #include "images/archiver_20x20.xpm"
 #include "images/icon_trash_20x20.xpm"
 #include "images/icon_trash_empty_20x20.xpm"
+#include "images/icon_purge_20x20.xpm"
 #include "images/archiver_48x48.xpm"
 
 
@@ -97,8 +102,8 @@ void EDVArchiverContentsMenuRegenerate(edv_archiver_struct *archiver);
 /* Sync Configuration */
 void EDVArchiverSyncConfiguration(edv_archiver_struct *archiver);
 
-/* Select Archive */
-void EDVArchiverSelectArchive(
+/* Open Archive */
+void EDVArchiverOpenArchive(
 	edv_archiver_struct *archiver, const gchar *arch_obj,
 	const gchar *password
 );
@@ -114,7 +119,7 @@ cfg_accelkey_list_struct *EDVArchiverAccelkeysListNewDefault(void);
 static void EDVArchiverCreateMenuBar(
 	edv_archiver_struct *archiver, GtkWidget *parent
 );
-edv_archiver_struct *EDVArchiverNew(gpointer core_ptr);
+edv_archiver_struct *EDVArchiverNew(edv_core_struct *core);
 void EDVArchiverSyncData(edv_archiver_struct *archiver);
 void EDVArchiverUpdateMenus(edv_archiver_struct *archiver);
 void EDVArchiverUpdateContentsHeadings(
@@ -128,16 +133,16 @@ void EDVArchiverUnmap(edv_archiver_struct *archiver);
 void EDVArchiverDelete(edv_archiver_struct *archiver);
 
 
-#define ATOI(s)         (((s) != NULL) ? atoi(s) : 0)
-#define ATOL(s)         (((s) != NULL) ? atol(s) : 0)
-#define ATOF(s)         (((s) != NULL) ? atof(s) : 0.0f)
-#define STRDUP(s)       (((s) != NULL) ? g_strdup(s) : NULL)
+#define ATOI(s)		(((s) != NULL) ? atoi(s) : 0)
+#define ATOL(s)		(((s) != NULL) ? atol(s) : 0)
+#define ATOF(s)		(((s) != NULL) ? atof(s) : 0.0f)
+#define STRDUP(s)	(((s) != NULL) ? g_strdup(s) : NULL)
 
-#define MAX(a,b)        (((a) > (b)) ? (a) : (b))
-#define MIN(a,b)        (((a) < (b)) ? (a) : (b))
-#define CLIP(a,l,h)     (MIN(MAX((a),(l)),(h)))
-#define STRLEN(s)       (((s) != NULL) ? strlen(s) : 0)
-#define STRISEMPTY(s)   (((s) != NULL) ? (*(s) == '\0') : TRUE)
+#define MAX(a,b)	(((a) > (b)) ? (a) : (b))
+#define MIN(a,b)	(((a) < (b)) ? (a) : (b))
+#define CLIP(a,l,h)	(MIN(MAX((a),(l)),(h)))
+#define STRLEN(s)	(((s) != NULL) ? strlen(s) : 0)
+#define STRISEMPTY(s)	(((s) != NULL) ? (*(s) == '\0') : TRUE)
 
 
 /*
@@ -183,21 +188,21 @@ void EDVArchiverSetTitle(
 	gchar *title;
 	GtkWidget *w;
 	const cfg_item_struct *cfg_list;
-	edv_core_struct *core_ptr;
+	edv_core_struct *core;
 
 	if(archiver == NULL)
 	    return;
 
 	w = archiver->toplevel;
-	core_ptr = EDV_CORE(archiver->core_ptr);
-	if((w == NULL) || (core_ptr == NULL))
+	core = archiver->core;
+	if((w == NULL) || (core == NULL))
 	    return;
 
-	cfg_list = core_ptr->cfg_list;
+	cfg_list = core->cfg_list;
 
 	/* Use user defined title? */
-	if(!STRISEMPTY(core_ptr->title))
-	    prog_name = core_ptr->title;
+	if(!STRISEMPTY(core->title))
+	    prog_name = core->title;
 
 	/* Get title bar customization */
 	include_user_name = EDV_GET_B(EDV_CFG_PARM_ARCHIVER_TITLE_WITH_USER);
@@ -209,7 +214,7 @@ void EDVArchiverSetTitle(
 	)
 	    title = g_strdup_printf(
 		"%s: %s %s",
-		prog_name, core_ptr->effective_user_id_host_str,
+		prog_name, core->effective_user_id_host_str,
 		path
 	    );
 	else if(include_location && (path != NULL))
@@ -220,7 +225,7 @@ void EDVArchiverSetTitle(
 	else if(include_user_name)
 	    title = g_strdup_printf(
 		"%s: %s",
-		prog_name, core_ptr->effective_user_id_host_str
+		prog_name, core->effective_user_id_host_str
 	    );
 	else
 	    title = STRDUP(prog_name);
@@ -294,7 +299,7 @@ void EDVArchiverSetLocation(
 /*
  *	Updates the Archiver Location Bar's icon.
  *
- *      If the given path is NULL then the icon will be set as unknown.
+ *	If the given path is NULL then the icon will be set as unknown.
  */
 void EDVArchiverUpdateLocationIcon(
 	edv_archiver_struct *archiver, const gchar *path
@@ -304,14 +309,14 @@ void EDVArchiverUpdateLocationIcon(
 	GdkPixmap *pixmap, *pixmap_hid;
 	GdkBitmap *mask, *mask_hid;
 	GtkWidget *parent, *w;
-	edv_core_struct *core_ptr;
+	edv_core_struct *core;
 
 	if(archiver == NULL)
 	    return;
 
-	core_ptr = EDV_CORE(archiver->core_ptr);
+	core = archiver->core;
 	parent = archiver->location_icon_fixed;
-	if((core_ptr == NULL) || (parent == NULL))
+	if((core == NULL) || (parent == NULL))
 	    return;
 
 	if(!STRISEMPTY(path))
@@ -347,8 +352,8 @@ void EDVArchiverUpdateLocationIcon(
 
 	/* Get pixmap and mask */
 	EDVMatchObjectIcon(
-	    core_ptr->device, core_ptr->total_devices,
-	    core_ptr->mimetype, core_ptr->total_mimetypes,
+	    core->device, core->total_devices,
+	    core->mimetype, core->total_mimetypes,
 	    obj->type,
 	    obj->full_path,
 	    EDV_OBJECT_IS_LINK_VALID(obj),
@@ -439,20 +444,19 @@ void EDVArchiverAccelkeysRegenerate(edv_archiver_struct *archiver)
 	GtkAccelGroup *accelgrp = NULL;
 	cfg_accelkey_list_struct *ak_list;
 	const cfg_item_struct *cfg_list;
-	edv_core_struct *core_ptr;
+	edv_core_struct *core;
 
 	if(archiver == NULL)
 	    return;
 
-	core_ptr = EDV_CORE(archiver->core_ptr);
-	if(core_ptr == NULL)
+	core = archiver->core;
+	if(core == NULL)
 	    return;
 		   
-	cfg_list = core_ptr->cfg_list;
+	cfg_list = core->cfg_list;
 
-	ak_list = 
-EDV_GET_ACCELKEY_LIST(EDV_CFG_PARM_BROWSER_ACCELERATOR_KEYS);
-	if(ak_list == NULL)                   
+	ak_list = EDV_GET_ACCELKEY_LIST(EDV_CFG_PARM_ARCHIVER_ACCELERATOR_KEYS);
+	if(ak_list == NULL)
 	    return;
 
 #define UPDATE_ACCELKEY(_w_,_opid_)	{	\
@@ -519,6 +523,16 @@ EDV_GET_ACCELKEY_LIST(EDV_CFG_PARM_BROWSER_ACCELERATOR_KEYS);
 	    archiver->edit_delete_mi,
 	    EDV_ARCHIVER_OP_DELETE
 	);
+
+	UPDATE_ACCELKEY(
+	    archiver->check_mi,
+	    EDV_ARCHIVER_OP_CHECK
+	);
+	UPDATE_ACCELKEY(
+	    archiver->fix_mi,
+	    EDV_ARCHIVER_OP_FIX
+	);
+
 	UPDATE_ACCELKEY(
 	    archiver->select_all_mi,
 	    EDV_ARCHIVER_OP_SELECT_ALL
@@ -568,6 +582,10 @@ EDV_GET_ACCELKEY_LIST(EDV_CFG_PARM_BROWSER_ACCELERATOR_KEYS);
 	    archiver->show_status_bar_micheck,
 	    EDV_ARCHIVER_OP_SHOW_STATUS_BAR
 	);
+	UPDATE_ACCELKEY(
+	    archiver->contents_list_filter_mi,
+	    EDV_ARCHIVER_OP_CONTENTS_LIST_FILTER
+	);
 	UPDATE_ACCELKEY(
 	    archiver->mime_types_mi,
 	    EDV_ARCHIVER_OP_MIME_TYPES
@@ -577,6 +595,14 @@ EDV_GET_ACCELKEY_LIST(EDV_CFG_PARM_BROWSER_ACCELERATOR_KEYS);
 	    archiver->write_protect_mi,
 	    EDV_ARCHIVER_OP_WRITE_PROTECT
 	);
+	UPDATE_ACCELKEY(
+	    archiver->delete_method_recycle_micheck,
+	    EDV_ARCHIVER_OP_DELETE_METHOD_RECYCLE
+	);
+	UPDATE_ACCELKEY(
+	    archiver->delete_method_purge_micheck,
+	    EDV_ARCHIVER_OP_DELETE_METHOD_PURGE
+	);
 	UPDATE_ACCELKEY(
 	    archiver->options_mi,
 	    EDV_ARCHIVER_OP_OPTIONS
@@ -644,6 +670,14 @@ EDV_GET_ACCELKEY_LIST(EDV_CFG_PARM_BROWSER_ACCELERATOR_KEYS);
 	    archiver->contents_clist_comment_and_statistics_mi,
 	    EDV_ARCHIVER_OP_COMMENT_AND_STATISTICS
 	);
+	UPDATE_ACCELKEY(
+	    archiver->contents_clist_check_mi,
+	    EDV_ARCHIVER_OP_COMMENT_AND_STATISTICS
+	);
+	UPDATE_ACCELKEY(
+	    archiver->contents_clist_fix_mi,
+	    EDV_ARCHIVER_OP_COMMENT_AND_STATISTICS
+	);
 	UPDATE_ACCELKEY(
 	    archiver->contents_clist_properties_mi,
 	    EDV_ARCHIVER_OP_PROPERTIES
@@ -667,17 +701,17 @@ void EDVArchiverToolBarRegenerate(edv_archiver_struct *archiver)
 	edv_archiver_opid_struct *opid;
 	toolbar_struct *toolbar;
 	toolbar_item_struct **item, *item_ptr;
-	edv_core_struct *core_ptr;
+	edv_core_struct *core;
 
 	if(archiver == NULL)
 	    return;
 
 	parent = archiver->tool_bar_handle;
-	core_ptr = EDV_CORE(archiver->core_ptr);
-	if((parent == NULL) || (core_ptr == NULL))
+	core = archiver->core;
+	if((parent == NULL) || (core == NULL))
 	    return;
 
-	cfg_list = core_ptr->cfg_list;
+	cfg_list = core->cfg_list;
 
 	/* Get Tool Bar configuration */
 	tb_display = (toolbar_display)EDV_GET_I(
@@ -833,6 +867,16 @@ void EDVArchiverContentsMenuRegenerate(edv_archiver_struct *archiver)
 
 	DO_ADD_MENU_SEP
 
+	op = EDV_ARCHIVER_OP_CHECK;
+	DO_ADD_MENU_ITEM_LABEL
+	archiver->contents_clist_check_mi = w;
+
+	op = EDV_ARCHIVER_OP_FIX;
+	DO_ADD_MENU_ITEM_LABEL
+	archiver->contents_clist_fix_mi = w;
+
+	DO_ADD_MENU_SEP
+
 	op = EDV_ARCHIVER_OP_PROPERTIES;
 	DO_ADD_MENU_ITEM_LABEL
 	archiver->contents_clist_properties_mi = w;
@@ -848,17 +892,17 @@ void EDVArchiverContentsMenuRegenerate(edv_archiver_struct *archiver)
 void EDVArchiverSyncConfiguration(edv_archiver_struct *archiver)
 {
 	GtkWidget *w;
-	edv_core_struct *core_ptr;
+	edv_core_struct *core;
 	cfg_item_struct *cfg_list;
 
 	if(archiver == NULL)
 	    return;
 
-	core_ptr = EDV_CORE(archiver->core_ptr);
-	if(core_ptr == NULL)
+	core = archiver->core;
+	if(core == NULL)
 	    return;
 
-	cfg_list = core_ptr->cfg_list;
+	cfg_list = core->cfg_list;
 
 	/* Location history */
 	w = archiver->location_combo;
@@ -894,35 +938,70 @@ void EDVArchiverSyncConfiguration(edv_archiver_struct *archiver)
 	/* EDV_CFG_PARM_ARCHIVER_CONTENTS_COLUMN parameter is updated
 	 * when the configuration list is changed directly
 	 */
+
+	/* Contents list filter */
+	if(STRISEMPTY(archiver->contents_list_filter))
+	{
+	    EDV_SET_S(
+		EDV_CFG_PARM_ARCHIVER_CONTENTS_LIST_FILTER,
+		"*"
+	    );
+	}
+	else
+	{
+	    EDV_SET_S(
+		EDV_CFG_PARM_ARCHIVER_CONTENTS_LIST_FILTER,
+		archiver->contents_list_filter
+	    );
+	}
 }
 
 /*
- *	Sets the Archiver's Location Bar to refer to the archive
- *	specified by arch_obj and updates the Contents List to reflect
- *	the contents of the archive.
+ *	Opens the archive.
+ *
+ *	The arch_obj specifies the archive to open.
+ *
+ *	The password specifies the password needed to open the archive
+ *	or NULL if none is specified.
+ *
+ *	All the objects in the specified archive will be opened to the
+ *	Archiver's Contents List, any existing items in the Contents
+ *	List will be cleared first.
+ *
+ *	The Archiver's title, location, and password will be updated
+ *	to reflect the opened archive.
+ *
+ *	The location's history will be recorded prior to setting the
+ *	new location.
+ *
+ *	The Archive Comments & Statistics Dialog will be mapped as
+ *	appropriate.
  */
-void EDVArchiverSelectArchive(
+void EDVArchiverOpenArchive(
 	edv_archiver_struct *archiver, const gchar *arch_obj,
 	const gchar *password
 )
 {
 	gboolean show_info_on_open;
 	gulong size;
-	gchar *darch_obj, *dpassword;
+	gchar *darch_obj, *dpassword, *get_listing_error_msg;
 	GtkCList *clist;
 	const cfg_item_struct *cfg_list;
-	edv_core_struct *core_ptr;
+	edv_core_struct *core;
 	struct stat stat_buf;
 
 	if((archiver == NULL) || STRISEMPTY(arch_obj))
 	    return;
 
 	clist = (GtkCList *)archiver->contents_clist;
-	core_ptr = EDV_CORE(archiver->core_ptr);
-	if((clist == NULL) || (core_ptr == NULL))
+	core = archiver->core;
+	if((clist == NULL) || (core == NULL))
 	    return;
 
-	cfg_list = core_ptr->cfg_list;
+	EDVArchiverSetBusy(archiver, TRUE);
+	GUIBlockInput(archiver->toplevel, TRUE);
+
+	cfg_list = core->cfg_list;
 
 	/* Get configuration */
 	show_info_on_open = EDV_GET_B(
@@ -937,27 +1016,33 @@ void EDVArchiverSelectArchive(
 	    size = 0l;
 #ifdef S_ISREG
 	else if(S_ISREG(stat_buf.st_mode))
-	    size = stat_buf.st_size;
+	    size = (gulong)stat_buf.st_size;
 #endif
 	else
 	    size = 0l;
 
-	/* Update title and Location Bar */
+	/* Update the title, location, and password */
 	EDVArchiverSetTitle(archiver, darch_obj);
 	EDVArchiverSetLocation(archiver, darch_obj, TRUE);
 	EDVArchiverSetPassword(archiver, dpassword);
 	EDVArchiverUpdateLocationIcon(archiver, darch_obj);
 
-	/* Clear contents list and update it with the list of objects
-	 * found in the archive
+	/* Clear the Contents List and open the archive's objects
+	 * to it
 	 */
 	gtk_clist_freeze(clist);
 	EDVArchiverContentsGetListing(
 	    archiver,
 	    EDV_GET_B(EDV_CFG_PARM_LISTS_ANIMATE_UPDATES)
 	);
+	get_listing_error_msg = STRDUP(EDVArchiverContentsGetError(archiver));
 	gtk_clist_thaw(clist);
 
+	EDVArchiverUpdateMenus(archiver);
+
+	GUIBlockInput(archiver->toplevel, FALSE);
+	EDVArchiverSetBusy(archiver, FALSE);
+
 	/* Does the archive have a non-zero size (implying it is not
 	 * an empty new archive) and we should show the archive info
 	 * on open?
@@ -965,8 +1050,44 @@ void EDVArchiverSelectArchive(
 	if((size > 0l) && show_info_on_open)
 	    EDVArchiverOPCommentAndStatistics(archiver);
 
+	if(TRUE)
+	{
+	    gchar *s = g_strdup_printf(
+"Archive \"%s\" opened (%s %s)",
+		g_basename(darch_obj),
+		EDVGetObjectSizeStr(core, size),
+		(size == 1l) ? "byte" : "bytes"
+	    );
+	    EDVStatusBarMessage(archiver->status_bar, s, FALSE);
+	    g_free(s);
+	}
+
+	/* Did an error occure while getting the listing? */
+	if(!STRISEMPTY(get_listing_error_msg) && !CDialogIsQuery() &&
+	   (size > 0l)
+	)
+	{
+	    gchar *s = g_strdup_printf(
+"%s.",
+		get_listing_error_msg
+	    );
+	    EDVPlaySoundWarning(core);
+	    CDialogSetTransientFor(archiver->toplevel);
+	    CDialogGetResponse(
+		"Open Archive Warning",
+		s,
+		NULL,
+		CDIALOG_ICON_WARNING,
+		CDIALOG_BTNFLAG_OK,
+		CDIALOG_BTNFLAG_OK
+	    );
+	    CDialogSetTransientFor(NULL);
+	    g_free(s);
+	}
+
 	g_free(darch_obj);
 	g_free(dpassword);
+	g_free(get_listing_error_msg);
 }
 
 
@@ -1120,8 +1241,8 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 	menu_icon_data = button_icon_data;
 
 #if defined(PROG_LANGUAGE_SPANISH)
-	button_name = "Discos Sincro";
-	menu_name = "Discos Sincro";
+	button_name = "Sincronizar Discos";
+	menu_name = "Sincronizar Discos";
 	tooltip = "Limpan cualquiera transferencias pendientes de datos al disco";
 #elif defined(PROG_LANGUAGE_FRENCH)
 	button_name = "Disq Syn";
@@ -1225,8 +1346,8 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 	menu_icon_data = button_icon_data;
 #if defined(PROG_LANGUAGE_SPANISH)
 	button_name = "Proteja";
-	menu_name = "Escriba Proteja";
-	tooltip = "Habilite/incapacita escribe protege";
+	menu_name = "Proteja contra escritura";
+	tooltip = "Habilite/inhabilita la proteccion contra escritura";
 #elif defined(PROG_LANGUAGE_FRENCH)
 	button_name = "Protge";
 	menu_name = "Protge En criture";
@@ -1244,6 +1365,30 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 	accel_mods = GDK_CONTROL_MASK;
 	DO_APPEND_OPID
 
+	op = EDV_ARCHIVER_OP_DELETE_METHOD_RECYCLE;
+	tb_item_type = TOOLBAR_ITEM_TOGGLE_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_trash_20x20_xpm;
+	menu_icon_data = button_icon_data;
+	button_name = "Recycle";
+	menu_name = "Delete Method: Recycle";
+	tooltip = "Set the delete method to recycle";
+	accel_key = 0;
+	accel_mods = 0;
+	DO_APPEND_OPID
+
+	op = EDV_ARCHIVER_OP_DELETE_METHOD_PURGE;
+	tb_item_type = TOOLBAR_ITEM_TOGGLE_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_purge_20x20_xpm;
+	menu_icon_data = button_icon_data;
+	button_name = "Purge";
+	menu_name = "Delete Method: Purge";
+	tooltip = "Set the delete method to purge";
+	accel_key = 0;
+	accel_mods = 0;
+	DO_APPEND_OPID
+
 
 	op = EDV_ARCHIVER_OP_NEW;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
@@ -1277,8 +1422,8 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 	button_icon_data = (guint8 **)icon_open_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #if defined(PROG_LANGUAGE_SPANISH)
-	button_name = "Abierto";
-	menu_name = "Abierto...";
+	button_name = "Abrir";
+	menu_name = "Abrir...";
 	tooltip = "Abre un archivo";
 #elif defined(PROG_LANGUAGE_FRENCH)
 	button_name = "Ouvert";
@@ -1329,9 +1474,9 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 	button_icon_data = (guint8 **)icon_archive_extract_20x20_xpm;
 	menu_icon_data = button_icon_data;
 #if defined(PROG_LANGUAGE_SPANISH)
-	button_name = "Extracto";
-	menu_name = "El Extracto...";
-	tooltip = "El Extracto escogi se opone(s) del archivo";
+	button_name = "Extraer";
+	menu_name = "Extraer...";
+	tooltip = "Extraer los objetos escogidos del archivo";
 #elif defined(PROG_LANGUAGE_FRENCH)
 	button_name = "L'Extrait";
 	menu_name = "L'Extrait...";
@@ -1357,7 +1502,7 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 #if defined(PROG_LANGUAGE_SPANISH)
 	button_name = "ExtrTodo";
 	menu_name = "Extraiga Todo...";
-	tooltip = "Extrae todo se opone del archivo";
+	tooltip = "Extrae todo del archivo";
 #elif defined(PROG_LANGUAGE_FRENCH)
 	button_name = "ExtrTout";
 	menu_name = "Extraire Tout...";
@@ -1383,7 +1528,7 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 #if defined(PROG_LANGUAGE_SPANISH)
 	button_name = "Borre";
 	menu_name = "Borre";
-	tooltip = "Borre escogido se opone(s) del archivo";
+	tooltip = "Borre los objeto(s) escogido(s) del archivo";
 #elif defined(PROG_LANGUAGE_FRENCH)
 	button_name = "Effacer";
 	menu_name = "Effacer";
@@ -1401,6 +1546,30 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 	accel_mods = 0;
 	DO_APPEND_OPID
 
+	op = EDV_ARCHIVER_OP_CHECK;
+	tb_item_type = TOOLBAR_ITEM_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_archive_check_20x20_xpm;
+	menu_icon_data = button_icon_data;
+	button_name = "Check";
+	menu_name = "Check";
+	tooltip = "Check the archive for problems";
+	accel_key = GDK_c;
+	accel_mods = GDK_SHIFT_MASK | GDK_CONTROL_MASK;
+	DO_APPEND_OPID
+
+	op = EDV_ARCHIVER_OP_FIX;
+	tb_item_type = TOOLBAR_ITEM_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_aid_20x20_xpm;
+	menu_icon_data = button_icon_data;
+	button_name = "Fix";
+	menu_name = "Fix";
+	tooltip = "Attempt to fix any problems with the archive";
+	accel_key = GDK_f;
+	accel_mods = GDK_SHIFT_MASK | GDK_CONTROL_MASK;
+	DO_APPEND_OPID
+
 	op = EDV_ARCHIVER_OP_PROPERTIES;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
 	flags = 0;
@@ -1436,7 +1605,7 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 #if defined(PROG_LANGUAGE_SPANISH)
 	button_name = "SelAll";
 	menu_name = "Escoja Todo";
-	tooltip = "Escoge todo se opone";
+	tooltip = "Escoge todo";
 #elif defined(PROG_LANGUAGE_FRENCH)
 	button_name = "SelAll";
 	menu_name = "Choisir Tout";
@@ -1462,7 +1631,7 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 #if defined(PROG_LANGUAGE_SPANISH)
 	button_name = "UnSelAll";
 	menu_name = "Unescoja Todo";
-	tooltip = "Unescoge todo se opone";
+	tooltip = "Unescoge todo";
 #elif defined(PROG_LANGUAGE_FRENCH)
 	button_name = "UnSelAll";
 	menu_name = "Unchoisir Tout";
@@ -1516,9 +1685,9 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 	button_icon_data = (guint8 **)icon_search_20x20_xpm;;
 	menu_icon_data = button_icon_data;
 #if defined(PROG_LANGUAGE_SPANISH)
-	button_name = "Hallazgo";
-	menu_name = "El Hallazgo";
-	tooltip = "El Hallazgo se opone (s) por atributos especificados";
+	button_name = "Buscar";
+	menu_name = "Buscar";
+	tooltip = "Buscar objeto(s) por atributos especificados";
 #elif defined(PROG_LANGUAGE_FRENCH)
 	button_name = "Dcouverte";
 	menu_name = "La Dcouverte";
@@ -1741,6 +1910,18 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 	accel_mods = 0;
 	DO_APPEND_OPID
 
+	op = EDV_ARCHIVER_OP_CONTENTS_LIST_FILTER;
+	tb_item_type = TOOLBAR_ITEM_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_wildcards_20x20_xpm;
+	menu_icon_data = button_icon_data;
+	button_name = "Filter";
+	menu_name = "Set Filter...";
+	tooltip = "Set the name filter for listing objects";
+	accel_key = 0;
+	accel_mods = 0;
+	DO_APPEND_OPID
+
 
 	op = EDV_ARCHIVER_OP_MIME_TYPES;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
@@ -1776,8 +1957,8 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 	menu_icon_data = button_icon_data;
 #if defined(PROG_LANGUAGE_SPANISH)
 	button_name = "FBrowser";
-	menu_name = "El Examinador Nuevo Del Archivo";
-	tooltip = "Crea a un examinador nuevo del archivo";
+	menu_name = "Nuevo Examinador De Archivos";
+	tooltip = "Muestra un nuevo examinador de archivos";
 #elif defined(PROG_LANGUAGE_FRENCH)
 	button_name = "FBrowser";
 	menu_name = "Nouveau Browser de Fichier";
@@ -1802,8 +1983,8 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 	menu_icon_data = button_icon_data;
 #if defined(PROG_LANGUAGE_SPANISH)
 	button_name = "IBrowser";
-	menu_name = "El Examinador Nuevo De La Imagen";
-	tooltip = "Crea a un examinador nuevo de la imagen";
+	menu_name = "Nuevo Examinador De Imagenes";
+	tooltip = "Muestra un nuevo examinador de imagenes";
 #elif defined(PROG_LANGUAGE_FRENCH)
 	button_name = "IBrowser";
 	menu_name = "Nouveau Browser D'Image";
@@ -1828,8 +2009,8 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 	menu_icon_data = button_icon_data;
 #if defined(PROG_LANGUAGE_SPANISH)
 	button_name = "Archiver";
-	menu_name = "Archiver Nuevo";
-	tooltip = "Crea un archiver nuevo";
+	menu_name = "Nuevo Compresor De Archivos";
+	tooltip = "Muestra un archivo comprimido nuevo";
 #elif defined(PROG_LANGUAGE_FRENCH)
 	button_name = "Archiver";
 	menu_name = "Nouveau Archiver";
@@ -1854,8 +2035,8 @@ GList *EDVArchiverOPIDListNew(edv_archiver_struct *archiver)
 	menu_icon_data = button_icon_data;
 #if defined(PROG_LANGUAGE_SPANISH)
 	button_name = "RecBin";
-	menu_name = "El Cajn De La Recirculacin";
-	tooltip = "Cajn de Recirculacin (basura puede)";
+	menu_name = "El Cajn De Reciclaje";
+	tooltip = "Abrir Cajn de Reciclaje (basura)";
 #elif defined(PROG_LANGUAGE_FRENCH)
 	button_name = "RecBin";
 	menu_name = "Recycler L'Huche";
@@ -2115,7 +2296,7 @@ void EDVArchiverOPIDListDelete(GList *glist)
 
 
 /*
- *      Creates a new Accel Key List with default values.
+ *	Creates a new Accel Key List with default values.
  */
 cfg_accelkey_list_struct *EDVArchiverAccelkeysListNewDefault(void)
 {
@@ -2331,6 +2512,16 @@ static void EDVArchiverCreateMenuBar(
 
 	    DO_ADD_MENU_SEP
 
+	    op = EDV_ARCHIVER_OP_CHECK;
+	    DO_ADD_MENU_ITEM_LABEL
+	    archiver->check_mi = w;
+
+	    op = EDV_ARCHIVER_OP_FIX;
+	    DO_ADD_MENU_ITEM_LABEL
+	    archiver->fix_mi = w;
+
+	    DO_ADD_MENU_SEP
+
 	    op = EDV_ARCHIVER_OP_SELECT_ALL;
 	    DO_ADD_MENU_ITEM_LABEL
 	    archiver->select_all_mi = w;
@@ -2343,6 +2534,8 @@ static void EDVArchiverCreateMenuBar(
 	    DO_ADD_MENU_ITEM_LABEL
 	    archiver->invert_selection_mi = w;
 
+	    DO_ADD_MENU_SEP
+
 	    op = EDV_ARCHIVER_OP_FIND;
 	    DO_ADD_MENU_ITEM_LABEL
 	    archiver->find_mi = w;
@@ -2356,7 +2549,7 @@ static void EDVArchiverCreateMenuBar(
 	GUIMenuAddToMenuBar(
 	    menu_bar, menu,
 #if defined(PROG_LANGUAGE_SPANISH)
-"Redacte"
+"Editar"
 #elif defined(PROG_LANGUAGE_FRENCH)
 "Editer"
 #elif defined(PROG_LANGUAGE_GERMAN)
@@ -2415,6 +2608,12 @@ static void EDVArchiverCreateMenuBar(
 
 	    DO_ADD_MENU_SEP
 
+	    op = EDV_ARCHIVER_OP_CONTENTS_LIST_FILTER;
+	    DO_ADD_MENU_ITEM_LABEL
+	    archiver->contents_list_filter_mi = w;
+
+	    DO_ADD_MENU_SEP
+
 	    op = EDV_ARCHIVER_OP_MIME_TYPES;
 	    DO_ADD_MENU_ITEM_LABEL
 	    archiver->mime_types_mi = w;
@@ -2451,6 +2650,14 @@ static void EDVArchiverCreateMenuBar(
 	    DO_ADD_MENU_ITEM_LABEL
 	    archiver->write_protect_mi = w;
 
+	    op = EDV_ARCHIVER_OP_DELETE_METHOD_RECYCLE;
+	    DO_ADD_MENU_ITEM_CHECK
+	    archiver->delete_method_recycle_micheck = w;
+
+	    op = EDV_ARCHIVER_OP_DELETE_METHOD_PURGE;
+	    DO_ADD_MENU_ITEM_CHECK
+	    archiver->delete_method_purge_micheck = w;
+
 	    DO_ADD_MENU_SEP
 
 	    op = EDV_ARCHIVER_OP_OPTIONS;
@@ -2464,7 +2671,7 @@ static void EDVArchiverCreateMenuBar(
 	GUIMenuAddToMenuBar(
 	    menu_bar, menu,
 #if defined(PROG_LANGUAGE_SPANISH)
-"Escenarios"
+"Configuracion"
 #elif defined(PROG_LANGUAGE_FRENCH)
 "Montages"
 #elif defined(PROG_LANGUAGE_GERMAN)
@@ -2592,35 +2799,28 @@ static void EDVArchiverCreateMenuBar(
 /*
  *	Creates a new Archiver.
  */
-edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
+edv_archiver_struct *EDVArchiverNew(edv_core_struct *core)
 {
+	const gint	border_major = 5;
+	gint	toplevel_x, toplevel_y,
+		toplevel_width, toplevel_height;
+	gboolean	tool_bar_map_state,
+			location_bar_map_state,
+			find_bar_map_state,
+			status_bar_map_state;
+	const gchar *location_history_file;
+	const gchar *wm_name, *wm_class;
 	gint i;
-	const gchar	*location_history_file = NULL;
-	gint		border_major = 5;
-	gint		toplevel_x = 0,
-			toplevel_y = 0,
-			toplevel_width = EDV_DEF_ARCHIVER_WIDTH,
-			toplevel_height = EDV_DEF_ARCHIVER_HEIGHT;
-	gboolean	tool_bar_map_state = TRUE,
-			location_bar_map_state = TRUE,
-			find_bar_map_state = TRUE,
-			status_bar_map_state = TRUE;
-	const gchar	*wm_name = NULL,
-			*wm_class = NULL;
 	gpointer entry_rtn, combo_rtn;
 	GList *glist;
-	const cfg_item_struct *cfg_list = (core_ptr != NULL) ?
-	    EDV_CORE(core_ptr)->cfg_list : NULL;
 	GdkCursor *cursor;
 	GdkWindow *window;
-	GtkRcStyle	*standard_rcstyle = NULL,
-			*lists_rcstyle = NULL;
+	GtkRcStyle *standard_rcstyle, *lists_rcstyle;
 	GtkStyle *style;
 	GtkWidget *w, *parent, *parent2, *parent3, *parent4;
 	GtkEntry *entry;
 	GtkCombo *combo;
 	GtkCList *clist;
-	edv_statusbar_struct *status_bar;
 	const GtkTargetEntry dnd_tar_types[] = {
 {"text/plain",				0,	EDV_DND_TYPE_INFO_TEXT_PLAIN},
 {"text/uri-list",			0,	EDV_DND_TYPE_INFO_TEXT_URI_LIST},
@@ -2629,62 +2829,62 @@ edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
 	const GtkTargetEntry dnd_src_types[] = {
 {EDV_DND_TYPE_STRING_ARCHIVE_OBJECT,	0,	EDV_DND_TYPE_INFO_ARCHIVE_OBJECT}
 	};
+	const cfg_item_struct *cfg_list;
+	edv_status_bar_struct *status_bar;
 	edv_archiver_struct *archiver = EDV_ARCHIVER(
 	    g_malloc0(sizeof(edv_archiver_struct))
 	);
-	if(archiver == NULL)
-	    return(archiver);
-
-
-	/* Get configuration */
-	if(cfg_list != NULL)
+	if((archiver == NULL) || (core == NULL))
 	{
-	    edv_core_struct *c_ptr = EDV_CORE(core_ptr);
-
-	    standard_rcstyle = c_ptr->standard_rcstyle;
-	    lists_rcstyle = c_ptr->lists_rcstyle;
-
-	    wm_name = c_ptr->wm_name;
-	    wm_class = c_ptr->wm_class;
-
-	    location_history_file = EDV_GET_S(
-		EDV_CFG_PARM_FILE_ARCHIVER_LOCATION_HISTORY
-	    );
-
-	    if(c_ptr->geometry_set)
-	    {
-		GdkRectangle *rect = &c_ptr->geometry;
-		toplevel_x = rect->x;
-		toplevel_y = rect->y;
-		toplevel_width = rect->width;
-		toplevel_height = rect->height;
-	    }
-	    else
-	    {
-		toplevel_x = EDV_GET_I(EDV_CFG_PARM_ARCHIVER_X);
-		toplevel_y = EDV_GET_I(EDV_CFG_PARM_ARCHIVER_Y);
-		toplevel_width = EDV_GET_I(EDV_CFG_PARM_ARCHIVER_WIDTH);
-		toplevel_height = EDV_GET_I(EDV_CFG_PARM_ARCHIVER_HEIGHT);
-	    }
-
-	    tool_bar_map_state = EDV_GET_B(
-		EDV_CFG_PARM_ARCHIVER_SHOW_TOOL_BAR
-	    );
-	    location_bar_map_state = EDV_GET_B(
-		EDV_CFG_PARM_ARCHIVER_SHOW_LOCATION_BAR
-	    );
-	    find_bar_map_state = EDV_GET_B(
-		EDV_CFG_PARM_ARCHIVER_SHOW_FIND_BAR
-	    );
-	    status_bar_map_state = EDV_GET_B(
-		EDV_CFG_PARM_ARCHIVER_SHOW_STATUS_BAR
-	    );
+	    g_free(archiver);
+	    return(NULL);
 	}
 
+	cfg_list = core->cfg_list;
+
+	standard_rcstyle = core->standard_rcstyle;
+	lists_rcstyle = core->lists_rcstyle;
+
+	wm_name = core->wm_name;
+	wm_class = core->wm_class;
+
+	location_history_file = EDV_GET_S(
+	    EDV_CFG_PARM_FILE_ARCHIVER_LOCATION_HISTORY
+	);
+
+	if(core->geometry_set)
+	{
+	    const GdkRectangle *rect = &core->geometry;
+	    toplevel_x = rect->x;
+	    toplevel_y = rect->y;
+	    toplevel_width = rect->width;
+	    toplevel_height = rect->height;
+	}
+	else
+	{
+	    toplevel_x = EDV_GET_I(EDV_CFG_PARM_ARCHIVER_X);
+	    toplevel_y = EDV_GET_I(EDV_CFG_PARM_ARCHIVER_Y);
+	    toplevel_width = EDV_GET_I(EDV_CFG_PARM_ARCHIVER_WIDTH);
+	    toplevel_height = EDV_GET_I(EDV_CFG_PARM_ARCHIVER_HEIGHT);
+	}
+
+	tool_bar_map_state = EDV_GET_B(
+	    EDV_CFG_PARM_ARCHIVER_SHOW_TOOL_BAR
+	);
+	location_bar_map_state = EDV_GET_B(
+	    EDV_CFG_PARM_ARCHIVER_SHOW_LOCATION_BAR
+	);
+	find_bar_map_state = EDV_GET_B(
+	    EDV_CFG_PARM_ARCHIVER_SHOW_FIND_BAR
+	);
+	status_bar_map_state = EDV_GET_B(
+	    EDV_CFG_PARM_ARCHIVER_SHOW_STATUS_BAR
+	);
+
 	archiver->processing = FALSE;
 	archiver->busy_count = 0;
-	archiver->freeze_count = 0;  
-	archiver->core_ptr = core_ptr;
+	archiver->freeze_count = 0;
+	archiver->core = core;
 
 	archiver->opid_list = EDVArchiverOPIDListNew(archiver);
 
@@ -2692,6 +2892,9 @@ edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
 	archiver->location_bar_map_state = location_bar_map_state;
 	archiver->find_bar_map_state = find_bar_map_state;
 	archiver->status_bar_map_state = status_bar_map_state;
+	archiver->contents_list_filter = STRDUP(EDV_GET_S(
+	    EDV_CFG_PARM_ARCHIVER_CONTENTS_LIST_FILTER
+	));
 	archiver->contents_clist_selected_row = -1;
 	archiver->last_recbin_items = -1;
 	archiver->last_write_protect_state = -1;
@@ -2861,7 +3064,7 @@ edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
 	);
 	gtk_widget_realize(w);
 	cursor = EDVGetCursor(
-	    EDV_CORE(core_ptr), EDV_CURSOR_CODE_HAND
+	    core, EDV_CURSOR_CODE_HAND
 	);
 	gdk_window_set_cursor(w->window, cursor);
 	GUISetWidgetTip(w,
@@ -2936,9 +3139,9 @@ edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
 	{
 	    /* Need to set different dnd_src_types for the drag source */
 	    const GtkTargetEntry dnd_src_types[] = {
-{"text/plain",                          0,      EDV_DND_TYPE_INFO_TEXT_PLAIN},
-{"text/uri-list",                       0,      EDV_DND_TYPE_INFO_TEXT_URI_LIST},
-{"STRING",                              0,      EDV_DND_TYPE_INFO_STRING}
+{"text/plain",				0,	EDV_DND_TYPE_INFO_TEXT_PLAIN},
+{"text/uri-list",			0,	EDV_DND_TYPE_INFO_TEXT_URI_LIST},
+{"STRING",				0,	EDV_DND_TYPE_INFO_STRING}
 	    };
 	    GUIDNDSetSrc(
 		archiver->location_icon_fixed,
@@ -2954,8 +3157,8 @@ edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
 		combo
 	    );
 	}
-	EDVEntrySetDND(EDV_CORE(core_ptr), combo->entry);
-	EDVEntrySetCompletePath(EDV_CORE(core_ptr), combo->entry);
+	EDVEntrySetDND(core, combo->entry);
+	EDVEntrySetCompletePath(core, combo->entry);
 
 	/* VBox for password prompt */
 	w = gtk_vbox_new(TRUE, 0);
@@ -3041,14 +3244,14 @@ edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
 
 	/* Create the Find Bar */
 	archiver->find_bar = EDVFindBarNew(
-	    core_ptr, parent2,
+	    core, parent2,
 	    EDV_FINDBAR_ROLE_ARCHIVE_OBJECT,
 	    EDVArchiverFindBarLocationCB,
 	    EDVArchiverFindBarStartCB,
 	    EDVArchiverFindBarEndCB,
 	    EDVArchiverFindBarMatchCB,
-            EDVArchiverStatusMessageCB,
-            EDVArchiverStatusProgressCB,
+	    EDVArchiverStatusMessageCB,
+	    EDVArchiverStatusProgressCB,
 	    archiver
 	);
 	EDVFindBarMap(archiver->find_bar);
@@ -3079,23 +3282,23 @@ edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
 	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "key_press_event",
-	    GTK_SIGNAL_FUNC(EDVCListKeyEventCB), core_ptr
+	    GTK_SIGNAL_FUNC(EDVCListKeyEventCB), core
 	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "key_release_event",
-	    GTK_SIGNAL_FUNC(EDVCListKeyEventCB), core_ptr
+	    GTK_SIGNAL_FUNC(EDVCListKeyEventCB), core
 	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "button_press_event",
-	    GTK_SIGNAL_FUNC(EDVCListButtonEventCB), core_ptr
+	    GTK_SIGNAL_FUNC(EDVCListButtonEventCB), core
 	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "button_release_event",
-	    GTK_SIGNAL_FUNC(EDVCListButtonEventCB), core_ptr
+	    GTK_SIGNAL_FUNC(EDVCListButtonEventCB), core
 	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "motion_notify_event",
-	    GTK_SIGNAL_FUNC(EDVCListMotionEventCB), core_ptr
+	    GTK_SIGNAL_FUNC(EDVCListMotionEventCB), core
 	);
 	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "key_press_event",
@@ -3172,7 +3375,7 @@ edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
 
 	/* Create the Status Bar */
 	archiver->status_bar = status_bar = EDVStatusBarNew(
-	    core_ptr, archiver->main_vbox
+	    core, archiver->main_vbox
 	);
 	if(status_bar != NULL)
 	{
@@ -3211,8 +3414,8 @@ edv_archiver_struct *EDVArchiverNew(gpointer core_ptr)
 }
 
 /*
- *      Syncronizes all data in the archiver's widgets to internal data
- *      on the archiver.
+ *	Syncronizes all data in the archiver's widgets to internal data
+ *	on the archiver.
  */
 void EDVArchiverSyncData(edv_archiver_struct *archiver)
 {
@@ -3225,12 +3428,13 @@ void EDVArchiverSyncData(edv_archiver_struct *archiver)
 }
 
 /*
- *      Updates all widgets on the given archiver to reflect the current
- *      data.
+ *	Updates all widgets on the given archiver to reflect the current
+ *	data.
  */
 void EDVArchiverUpdateMenus(edv_archiver_struct *archiver)
 {
 	gboolean write_protect, write_protect_changed = FALSE;
+	edv_delete_method delete_method;
 	gboolean sensitive, state;
 	guint8 **icon_data, **recbin_icon_data;
 	const gchar *location;
@@ -3239,17 +3443,16 @@ void EDVArchiverUpdateMenus(edv_archiver_struct *archiver)
 	GtkCList *clist;
 	const cfg_item_struct *cfg_list;
 	toolbar_struct *tb;
-	edv_core_struct *core_ptr;
-
+	edv_core_struct *core;
 
 	if(archiver == NULL)
 	    return;
 
-	core_ptr = EDV_CORE(archiver->core_ptr);
-	if(core_ptr == NULL)
+	core = archiver->core;
+	if(core == NULL)
 	    return;
 
-	cfg_list = core_ptr->cfg_list;
+	cfg_list = core->cfg_list;
 	tb = archiver->tool_bar;
 
 #define DO_SHOW			\
@@ -3274,6 +3477,11 @@ void EDVArchiverUpdateMenus(edv_archiver_struct *archiver)
 	}
 	archiver->last_write_protect_state = write_protect ? 1 : 0;
 
+	/* Delete method */
+	delete_method = (edv_delete_method)EDV_GET_I(
+	    EDV_CFG_PARM_DELETE_METHOD
+	);
+
 	/* Get last selected row on the contents clist */
 	clist = (GtkCList *)archiver->contents_clist;
 	selected_obj_row = EDVCListGetSelectedLast(clist, NULL);
@@ -3285,7 +3493,7 @@ void EDVArchiverUpdateMenus(edv_archiver_struct *archiver)
 	icon_data = NULL;
 	if(archiver->last_recbin_items < 0)
 	{
-	    if(core_ptr->last_recbin_items > 0)
+	    if(core->last_recbin_items > 0)
 		icon_data = (guint8 **)icon_trash_20x20_xpm;
 	    else
 		icon_data = (guint8 **)icon_trash_empty_20x20_xpm;
@@ -3293,15 +3501,15 @@ void EDVArchiverUpdateMenus(edv_archiver_struct *archiver)
 	else
 	{
 	    if(!archiver->last_recbin_items &&
-	       core_ptr->last_recbin_items
+	       core->last_recbin_items
 	    )
 		icon_data = (guint8 **)icon_trash_20x20_xpm;
 	    else if(archiver->last_recbin_items &&
-		    !core_ptr->last_recbin_items
+		    !core->last_recbin_items
 	    )
 		icon_data = (guint8 **)icon_trash_empty_20x20_xpm;
 	}
-	archiver->last_recbin_items = core_ptr->last_recbin_items;
+	archiver->last_recbin_items = core->last_recbin_items;
 	recbin_icon_data = icon_data;
 
 	/* Get current location */
@@ -3402,6 +3610,29 @@ void EDVArchiverUpdateMenus(edv_archiver_struct *archiver)
 	    );
 	}
 
+	/* Delete Method: Recycle */
+	w = archiver->delete_method_recycle_micheck;
+	GUIMenuItemSetPixmap(w, recbin_icon_data);
+	state = (delete_method == EDV_DELETE_METHOD_RECYCLE) ?
+	    TRUE : FALSE;
+	DO_SET_CHECK_STATE
+	ToolBarItemUpdateByID(
+	    tb, EDV_ARCHIVER_OP_DELETE_METHOD_RECYCLE,
+	    NULL, recbin_icon_data, NULL
+	);
+	ToolBarItemSetToggleID(
+	    tb, EDV_ARCHIVER_OP_DELETE_METHOD_RECYCLE, state
+	);
+
+	/* Delete Method: Purge */
+	w = archiver->delete_method_purge_micheck;
+	state = (delete_method == EDV_DELETE_METHOD_PURGE) ?
+	    TRUE : FALSE;
+	DO_SET_CHECK_STATE
+	ToolBarItemSetToggleID(
+	    tb, EDV_ARCHIVER_OP_DELETE_METHOD_PURGE, state
+	);
+
 
 	/* Windows */
 	if(recbin_icon_data != NULL)
@@ -3448,20 +3679,20 @@ void EDVArchiverUpdateMenus(edv_archiver_struct *archiver)
 }
 
 /*
- *      Marks the archiver as busy or ready.
+ *	Marks the archiver as busy or ready.
  */
 void EDVArchiverSetBusy(edv_archiver_struct *archiver, gboolean busy)
 {
 	GdkCursor *cur;
 	GtkWidget *w;
-	edv_core_struct *core_ptr;
+	edv_core_struct *core;
 
 	if(archiver == NULL)
 	    return;
 
 	w = archiver->toplevel;
-	core_ptr = EDV_CORE(archiver->core_ptr);
-	if((w == NULL) || (core_ptr == NULL))
+	core = archiver->core;
+	if((w == NULL) || (core == NULL))
 	    return;
 
 	if(busy)
@@ -3470,7 +3701,7 @@ void EDVArchiverSetBusy(edv_archiver_struct *archiver, gboolean busy)
 	    if(archiver->busy_count > 1)
 		return;
 
-	    cur = EDVGetCursor(core_ptr, EDV_CURSOR_CODE_BUSY);
+	    cur = EDVGetCursor(core, EDV_CURSOR_CODE_BUSY);
 	}
 	else
 	{
@@ -3539,7 +3770,7 @@ void EDVArchiverDelete(edv_archiver_struct *archiver)
 	archiver->contents_clist_selected_row = -1;
 
 
-        EDVArchiveInfoDelete(archiver->arch_info);
+	EDVArchiveInfoDelete(archiver->arch_info);
 
 	GTK_WIDGET_DESTROY(archiver->contents_clist_menu);
 
@@ -3566,5 +3797,7 @@ void EDVArchiverDelete(edv_archiver_struct *archiver)
 	/* Delete all Operation IDs */
 	EDVArchiverOPIDListDelete(archiver->opid_list);
 
+	g_free(archiver->contents_list_filter);
+
 	g_free(archiver);
 }
