@@ -1,5 +1,5 @@
 /*
-			  Endeavour Archiver
+			       Endeavour Archiver
  */
 
 #ifndef ARCHIVER_H
@@ -7,15 +7,17 @@
 
 #include <gtk/gtk.h>
 #include "cfg.h"
-#include "edvtypes.h"
 #include "toolbar.h"
-#include "findbar.h"
-#include "statusbar.h"
-#include "archiveinfo.h"
+#include "edv_types.h"
+#include "edv_find_bar.h"
+#include "edv_status_bar.h"
+#include "archive_info_dlg.h"
 
 
-typedef struct _edv_archiver_struct		edv_archiver_struct;
+typedef struct _edv_archiver_struct	edv_archiver_struct;
+#define EDV_ARCHIVER(p)			((edv_archiver_struct *)(p))
 typedef struct _edv_archiver_opid_struct	edv_archiver_opid_struct;
+#define EDV_ARCHIVER_OPID(p)		((edv_archiver_opid_struct *)(p))
 
 
 /*
@@ -60,6 +62,8 @@ typedef enum {
 	EDV_ARCHIVER_OP_RUN			= 31,
 	EDV_ARCHIVER_OP_RUN_TERMINAL		= 32,
 	EDV_ARCHIVER_OP_WRITE_PROTECT		= 35,
+	EDV_ARCHIVER_OP_DELETE_METHOD_RECYCLE	= 38,
+	EDV_ARCHIVER_OP_DELETE_METHOD_PURGE	= 39,
 
 	EDV_ARCHIVER_OP_NEW			= 60,
 	EDV_ARCHIVER_OP_OPEN			= 61,
@@ -67,6 +71,8 @@ typedef enum {
 	EDV_ARCHIVER_OP_EXTRACT			= 63,
 	EDV_ARCHIVER_OP_EXTRACT_ALL		= 64,
 	EDV_ARCHIVER_OP_DELETE			= 65,
+	EDV_ARCHIVER_OP_CHECK			= 67,
+	EDV_ARCHIVER_OP_FIX			= 68,
 	EDV_ARCHIVER_OP_SELECT_ALL		= 70,
 	EDV_ARCHIVER_OP_UNSELECT_ALL		= 71,
 	EDV_ARCHIVER_OP_INVERT_SELECTION	= 72,
@@ -83,6 +89,8 @@ typedef enum {
 	EDV_ARCHIVER_OP_SHOW_FIND_BAR		= 92,
 	EDV_ARCHIVER_OP_SHOW_STATUS_BAR		= 93,
 
+	EDV_ARCHIVER_OP_CONTENTS_LIST_FILTER	= 97,
+
 	EDV_ARCHIVER_OP_MIME_TYPES		= 100,
 
 	EDV_ARCHIVER_OP_NEW_BROWSER		= 110,
@@ -145,7 +153,6 @@ struct _edv_archiver_opid_struct {
 		**menu_icon_data;	/* Shared */
 
 };
-#define EDV_ARCHIVER_OPID(p)	((edv_archiver_opid_struct *)(p))
 
 
 /*
@@ -157,7 +164,7 @@ struct _edv_archiver_struct {
 	gboolean	processing;
 	gint		busy_count,
 			freeze_count;
-	gpointer	core_ptr;
+	edv_core_struct	*core;
 
 	GList		*opid_list;
 
@@ -201,6 +208,8 @@ struct _edv_archiver_struct {
 			*edit_extract_mi,
 			*edit_extract_all_mi,
 			*edit_delete_mi,
+			*check_mi,
+			*fix_mi,
 			*select_all_mi,
 			*unselect_all_mi,
 			*invert_selection_mi,
@@ -214,9 +223,12 @@ struct _edv_archiver_struct {
 			*show_location_bar_micheck,
 			*show_find_bar_micheck,
 			*show_status_bar_micheck,
+			*contents_list_filter_mi,
 			*mime_types_mi,
 
 			*write_protect_mi,
+			*delete_method_recycle_micheck,
+			*delete_method_purge_micheck,
 			*options_mi,
 			*customize_mi,
 
@@ -238,8 +250,12 @@ struct _edv_archiver_struct {
 			*contents_clist_extract_all_mi,
 			*contents_clist_delete_mi,
 			*contents_clist_comment_and_statistics_mi,
+			*contents_clist_check_mi,
+			*contents_clist_fix_mi,
 			*contents_clist_properties_mi;
 
+	gchar		*contents_list_filter;
+
 	/* Last selected row on the clist, can be -1. Note that
 	 * this does not reflect other selected rows since multiple
 	 * selections are allowed
@@ -262,13 +278,12 @@ struct _edv_archiver_struct {
 
 
 	/* Status Bar */
-	edv_statusbar_struct	*status_bar;
+	edv_status_bar_struct	*status_bar;
 
 	/* Archive Info Dialog */
-	edv_archive_info_struct	*arch_info;
+	edv_archive_info_dlg_struct	*arch_info;
 
 };
-#define EDV_ARCHIVER(p)	((edv_archiver_struct *)(p))
 
 
 /* Utilities */
@@ -306,7 +321,7 @@ extern void EDVArchiverContentsMenuRegenerate(edv_archiver_struct *archiver);
 extern void EDVArchiverSyncConfiguration(edv_archiver_struct *archiver);
 
 /* Select Archive */
-extern void EDVArchiverSelectArchive(
+extern void EDVArchiverOpenArchive(
 	edv_archiver_struct *archiver, const gchar *arch_obj,
 	const gchar *password
 );
@@ -321,7 +336,7 @@ extern void EDVArchiverOPIDListDelete(GList *glist);
 extern cfg_accelkey_list_struct *EDVArchiverAccelkeysListNewDefault(void);
 
 /* Archiver */
-extern edv_archiver_struct *EDVArchiverNew(gpointer core_ptr);
+extern edv_archiver_struct *EDVArchiverNew(edv_core_struct *core);
 extern void EDVArchiverSyncData(edv_archiver_struct *archiver);
 extern void EDVArchiverUpdateMenus(edv_archiver_struct *archiver);
 extern void EDVArchiverUpdateContentsHeadings(
