@@ -750,7 +750,7 @@ void EDVArchiverClickColumnCB(
 	    GtkCListCompareFunc cmp_func_str =
 		 (GtkCListCompareFunc)EDVCListColumnSortStringCB;
 	    GtkCListCompareFunc cmp_func_num =
-		(GtkCListCompareFunc)EDVCListColumnSortNumericCB;
+		(GtkCListCompareFunc)EDVCListColumnSortNumberCB;
 
 
 	    EDVArchiverSetBusy(archiver, TRUE);
