@@ -1064,9 +1064,19 @@ static void EDVArchiverContentsSetCellMethod(
 	const gint row, const gint column
 )
 {
-	const gchar *method = obj->method;
-	if(method == NULL)
-	    method = "";
+	gchar *method;
+
+	if((obj->method != NULL) && (obj->encryption != NULL))
+	    method = g_strconcat(
+		obj->method,
+		" + ",
+		obj->encryption,
+		NULL
+	    );
+	else if(obj->method != NULL)
+	    method = STRDUP(obj->method);
+	else
+	    method = STRDUP("");
 
 	/* Set cell */
 	gtk_clist_set_text(clist, row, column, method);
@@ -1074,6 +1084,8 @@ static void EDVArchiverContentsSetCellMethod(
 	gtk_clist_set_shift(
 	    clist, row, column, 0, 0
 	);
+
+	g_free(method);
 }
 
 /*
