@@ -559,13 +559,17 @@ void EDVArchiverOPNew(edv_archiver_struct *archiver)
 		&ftype, &total_ftypes,
 		ext_list[i], ext_list[i + 1]
 	    );
+	FileBrowserTypeListNew(
+            &ftype, &total_ftypes,
+            "*.*", "All Files"
+        );
 
 	/* Query user for new archive */
 	FileBrowserSetTransientFor(toplevel);
 	status = FileBrowserGetResponse(
 	    "Create Archive",
 	    "Create", "Cancel",
-	    NULL,			/* Startup path */
+	    NULL,			/* Use the last location */
 	    ftype, total_ftypes,
 	    &path_rtn, &total_path_rtns,
 	    &ftype_rtn
@@ -748,7 +752,7 @@ void EDVArchiverOPOpen(edv_archiver_struct *archiver)
 	if(core == NULL)
 	    return;
 
-	/* Create file types list */
+	/* Create the file types list */
 	if(ext_list != NULL)
 	{
 	    gint i;
@@ -770,7 +774,7 @@ void EDVArchiverOPOpen(edv_archiver_struct *archiver)
 	    }
 	    FileBrowserTypeListNew(
 		&ftype, &total_ftypes,
-		s, "All archives"
+		s, "All Archives"
 	    );
 	    g_free(s);
 
@@ -782,7 +786,7 @@ void EDVArchiverOPOpen(edv_archiver_struct *archiver)
 	}
 	FileBrowserTypeListNew(
 	    &ftype, &total_ftypes,
-	    "*.*", "All files"
+	    "*.*", "All Files"
 	);
 
 
@@ -985,7 +989,7 @@ void EDVArchiverOPAdd(edv_archiver_struct *archiver)
 	/* Create file types list */
 	FileBrowserTypeListNew(
 	    &ftype, &total_ftypes,
-	    "*.*", "All files"
+	    "*.*", "All Files"
 	);
 
 	/* Query user for extract destination */
@@ -1240,7 +1244,7 @@ void EDVArchiverOPExtract(edv_archiver_struct *archiver)
 	/* Generate file types list */
 	FileBrowserTypeListNew(
 	    &ftype, &total_ftypes,
-	    "*.*", "All files"
+	    "*.*", "All Files"
 	);
 
 	/* Query user for extract destination */
@@ -1518,7 +1522,7 @@ void EDVArchiverOPExtractAll(edv_archiver_struct *archiver)
 	/* Create file types list */
 	FileBrowserTypeListNew(
 	    &ftype, &total_ftypes,
-	    "*.*", "All files"
+	    "*.*", "All Files"
 	);
 
 	/* Query user for extract destination */
@@ -1717,15 +1721,15 @@ void EDVArchiverOPDelete(edv_archiver_struct *archiver)
 	if(EDVCheckWriteProtect(core, TRUE, toplevel))
 	    return;
 
-#define DO_FREE_LOCALS	{		\
- src_path = NULL;			\
-					\
- g_list_foreach(obj_list, (GFunc)EDVArchObjectDelete, NULL); \
- g_list_free(obj_list);			\
- obj_list = NULL;			\
-					\
- g_free(arch_obj);			\
- arch_obj = NULL;			\
+#define DO_FREE_LOCALS	{			\
+ if(obj_list != NULL) {				\
+  g_list_foreach(				\
+   obj_list, (GFunc)EDVArchObjectDelete, NULL	\
+  );						\
+  g_list_free(obj_list);			\
+ }						\
+						\
+ g_free(arch_obj);				\
 }
 
 	/* Get the current archive's path */
@@ -1784,9 +1788,7 @@ void EDVArchiverOPDelete(edv_archiver_struct *archiver)
 	    toplevel, TRUE, TRUE, &yes_to_all
 	);
 
-	/* Get error message (if any) that might have occured in
-	 * the above operation
-	 */
+	/* Check for and report and errors */
 	error_msg = EDVArchDeleteGetError();
 	if(!STRISEMPTY(error_msg))
 	{
