@@ -1388,7 +1388,7 @@ void EDVBrowserClickColumnCB(
 	    GtkCListCompareFunc cmp_func_str =
 		 (GtkCListCompareFunc)EDVCListColumnSortStringCB;
 	    GtkCListCompareFunc cmp_func_num =
-		(GtkCListCompareFunc)EDVCListColumnSortNumericCB;
+		(GtkCListCompareFunc)EDVCListColumnSortNumberCB;
 
 
 	    EDVBrowserSetBusy(browser, TRUE);
@@ -1441,10 +1441,10 @@ void EDVBrowserClickColumnCB(
 		  case EDV_BROWSER_COLUMN_TYPE_LINKED_TO:
 		    cmp_func = cmp_func_str;
 		    break;
-		  case EDV_BROWSER_COLUMN_TYPE_DEVICE:
+		  case EDV_BROWSER_COLUMN_TYPE_DEVICE_INDEX:
 		    cmp_func = cmp_func_num;
 		    break;
-		  case EDV_BROWSER_COLUMN_TYPE_INODE:
+		  case EDV_BROWSER_COLUMN_TYPE_INDEX:
 		    cmp_func = cmp_func_num;
 		    break;
 		  case EDV_BROWSER_COLUMN_TYPE_DEVICE_TYPE:
