@@ -107,9 +107,21 @@ void EDVBrowserDirTreeSelectPath(
 );
 
 /* Finding */
+static void EDVBrowserDirTreeFindNodeByIndexIterate(
+	GtkCTree *ctree,
+	GtkCTreeNode *node,
+	const gulong device_index, const gulong index,
+	GtkCTreeNode **matched_node
+);
+GtkCTreeNode *EDVBrowserDirTreeFindNodeByIndex(
+	edv_browser_struct *browser,
+	const gulong device_index, const gulong index
+);
 static void EDVBrowserDirTreeFindNodeByPathIterate(
-	GtkCTree *ctree, GtkCTreeNode *node,
-	const gchar *path, GtkCTreeNode **matched_node_ptr
+	GtkCTree *ctree,
+	GtkCTreeNode *node,
+	const gchar *path,
+	GtkCTreeNode **matched_node
 );
 GtkCTreeNode *EDVBrowserDirTreeFindNodeByPath(
 	edv_browser_struct *browser, const gchar *path
@@ -134,8 +146,8 @@ void EDVBrowserDirTreeObjectAddedNotify(
 	const struct stat *lstat_buf
 );
 void EDVBrowserDirTreeObjectModifiedNotify(
-	edv_browser_struct *browser, const gchar *path,
-	const gchar *new_name,
+	edv_browser_struct *browser,
+	const gchar *path, const gchar *new_path,
 	const struct stat *lstat_buf
 );
 void EDVBrowserDirTreeObjectRemovedNotify(
@@ -756,7 +768,7 @@ void EDVBrowserDirTreeCreateToplevels(edv_browser_struct *browser)
 	/* Get the origin path as the path for the toplevel node */
 	path = browser->directory_ctree_origin_path;
 	if(STRISEMPTY(path))
-#if defined(__WIN32)
+#if defined(_WIN32)
 	    path = "C:\\";
 #else
 	    path = "/";
@@ -968,15 +980,13 @@ static void EDVBrowserDirTreeRealizeListingIterate(
 		    );
 	    }
 
+	    /* Get the next sibling node (which may be NULL) */
+	    next_node = row_ptr->sibling;
+
 	    /* Get this node's object */
 	    obj = EDV_OBJECT(
 		gtk_ctree_node_get_row_data(ctree, node)
 	    );
-
-	    /* Get next sibling node (which may be NULL) */
-	    next_node = row_ptr->sibling;
-
-	    /* Got Object and its full path is specified? */
 	    if((obj != NULL) ? !STRISEMPTY(obj->full_path) : FALSE)
 	    {
 		struct stat lstat_buf;
@@ -1232,29 +1242,129 @@ void EDVBrowserDirTreeSelectPath(
 	g_free(full_path);
 }
 
+
 /*
- *	Called by EDVBrowserDirTreeFindNodeByPath() or itself to check
- *	child nodes of the given node, recursing if a path prefix match
- *	is made
+ *	Performs one iteration of finding the Directory Tree node by
+ *	location index.
+ */
+static void EDVBrowserDirTreeFindNodeByIndexIterate(
+	GtkCTree *ctree, 
+	GtkCTreeNode *node,
+	const gulong device_index, const gulong index,
+	GtkCTreeNode **matched_node
+)
+{
+	edv_object_struct *obj;
+
+	if((*matched_node != NULL) || (node == NULL))
+	    return;
+
+	obj = EDV_OBJECT(
+	    gtk_ctree_node_get_row_data(ctree, node)
+	);
+	if(obj == NULL)
+	    return;
+
+	/* Does this object's index location match the specified index
+	 * location?
+	 */
+	if((obj->device_index == device_index) &&
+	   (obj->index == index)
+	)
+	{
+	    *matched_node = node;
+	    return;
+	}
+	else
+	{
+	    /* No match, now check if any of this node's child nodes
+	     * match
+	     */
+	    GtkCTreeRow *row_ptr = GTK_CTREE_ROW(node);
+	    if(row_ptr == NULL)
+		return;
+
+	    node = row_ptr->children;
+	    while(node != NULL)
+	    {
+		EDVBrowserDirTreeFindNodeByIndexIterate(
+		    ctree,
+		    node,
+		    device_index, index,
+		    matched_node
+		);
+		if(*matched_node != NULL)
+		    return;
+
+		/* Get the sibling */
+		row_ptr = GTK_CTREE_ROW(node);
+		if(row_ptr == NULL)
+		    break;
+
+		node = row_ptr->sibling;
+	    }
+	}
+}
+
+/*
+ *	Matches the Directory Tree node who's object matches the
+ *	location index.
  *
- *	If a perfect match is made *matched_node_ptr will be set to TRUE
+ *	The device_index specifies the index of the device that the
+ *	object reside son.
+ *
+ *	The index specifies the index on the device that the object
+ *	resides at.
+ *
+ *	Returns the matched node or NULL on error.
+ */
+GtkCTreeNode *EDVBrowserDirTreeFindNodeByIndex(
+	edv_browser_struct *browser,                  
+	const gulong device_index, const gulong index
+)
+{
+	GtkCTreeNode *node, *matched_node;
+	GtkCTree *ctree;
+
+	if(browser == NULL)
+	    return(NULL);
+
+	ctree = (GtkCTree *)browser->directory_ctree;
+	if(ctree == NULL)
+	    return(NULL);
+
+	/* Get the toplevel node to start the search at */
+	node = EDVBrowserDirTreeGetToplevel(browser);
+
+	/* Begin the search */
+	matched_node = NULL;
+	EDVBrowserDirTreeFindNodeByIndexIterate(
+	    ctree,
+	    node,
+	    device_index, index,
+	    &matched_node
+	);
+
+	return(matched_node);
+}
+
+/*
+ *	Performs one iteration of finding the Directory Tree node by
+ *	path.
  */
 static void EDVBrowserDirTreeFindNodeByPathIterate(
-	GtkCTree *ctree, GtkCTreeNode *node,
-	const gchar *path, GtkCTreeNode **matched_node_ptr
+	GtkCTree *ctree,
+	GtkCTreeNode *node,
+	const gchar *path,
+	GtkCTreeNode **matched_node
 )
 {
 	const gchar *cur_path;
 	edv_object_struct *obj;
 
-	/* Already matched node? */
-	if((matched_node_ptr != NULL) ? (*matched_node_ptr != NULL) : TRUE)
+	if((*matched_node != NULL) || (node == NULL))
 	    return;
 
-	if(node == NULL)
-	    return;
-
-	/* Get the node's Object */
 	obj = EDV_OBJECT(
 	    gtk_ctree_node_get_row_data(ctree, node)
 	);
@@ -1270,38 +1380,25 @@ static void EDVBrowserDirTreeFindNodeByPathIterate(
 	    /* Yes it is, now check if it is a complete match */
 	    if(!strcmp(path, cur_path))
 	    {
-		/* Node's path and specified path match completely, so
-		 * mark that we found the node
-		 */
-		if(matched_node_ptr != NULL)
-		    *matched_node_ptr = node;
+		*matched_node = node;
 		return;
 	    }
 	    else
 	    {
-		/* Not a complete match but the node's path is a prefix
-		 * of the specified path, so this means we are on the
-		 * right track
-		 *
-	         * Recurse into this node's children and continue the 
-		 * search
-		 */
-
-		/* Get child node of this node and continue search */
+		/* Not a complete match, check the child nodes */
 		node = EDVNodeGetChild(node);
 		while(node != NULL)
 		{
-		    /* Check this node, recurse if it is a match */
 		    EDVBrowserDirTreeFindNodeByPathIterate(
-			ctree, node, path, matched_node_ptr
+			ctree,
+			node,
+			path,
+			matched_node
 		    );
-		    /* Got match? If so then we should not continue further */
-		    if((matched_node_ptr != NULL) ?
-			(*matched_node_ptr != NULL) : TRUE
-		    )
+		    if(*matched_node != NULL)
 		        return;
 
-		    /* Get this child node's sibling */
+		    /* Get the sibling */
 		    node = EDVNodeGetSibling(node);
 		}
 	    }
@@ -1309,19 +1406,19 @@ static void EDVBrowserDirTreeFindNodeByPathIterate(
 }
 
 /*
- *	Searches for a node on the browser's directory ctree that matches
- *	the full path specified by path.
+ *	Matches the Directory Tree node who's object matches the
+ *	path.
  *
- *	Will not expand or modify any nodes.
+ *	The path specifies the full path of the object.
  *
- *	Can return NULL on failed match.
+ *	Returns the matched node or NULL on error.
  */
 GtkCTreeNode *EDVBrowserDirTreeFindNodeByPath(
 	edv_browser_struct *browser, const gchar *path
 )
 {
 	gchar *full_path;
-	GtkCTreeNode *node, **matched_node_ptr, *matched_node;
+	GtkCTreeNode *node, *matched_node;
 	GtkCTree *ctree;
 	GtkWidget *w = (browser != NULL) ? browser->directory_ctree : NULL;
 	if((w == NULL) || STRISEMPTY(path))
@@ -1341,12 +1438,6 @@ GtkCTreeNode *EDVBrowserDirTreeFindNodeByPath(
 	/* Strip tailing deliminators */
 	StripPath(full_path);
 
-	/* Allocate matched node marker to pass around so we can tell
-	 * when we got a matched node
-	 */
-	matched_node_ptr = (GtkCTreeNode **)g_malloc(sizeof(GtkCTreeNode *));
-	*matched_node_ptr = NULL;
-
 	/* Get the toplevel node to start search from */
 	node = EDVBrowserDirTreeGetToplevel(browser);
 
@@ -1356,14 +1447,14 @@ GtkCTreeNode *EDVBrowserDirTreeFindNodeByPath(
 	 * matched_node_ptr will point to the matched node if a match
 	 * was made
 	 */
+	matched_node = NULL;
 	EDVBrowserDirTreeFindNodeByPathIterate(
-	    ctree, node, full_path, matched_node_ptr
+	    ctree,
+	    node,
+	    full_path,
+	    &matched_node
 	);
 
-	/* Get matched node (if any) */
-	matched_node = *matched_node_ptr;
-
-	g_free(matched_node_ptr);
 	g_free(full_path);
 
 	return(matched_node);
@@ -1502,16 +1593,18 @@ static void EDVBrowserDirTreeFPromptRenameApplyCB(
 	    if((obj != NULL) ? (obj->full_path != NULL) : FALSE)
 	    {
 		gboolean yes_to_all = FALSE;
-		gint status;
 		const gchar *error_msg;
-		gchar	*old_full_path = STRDUP(obj->full_path),
-			*new_obj = NULL;
+		gchar *old_full_path = STRDUP(obj->full_path);
+		GList *modified_paths_list;
 
-		/* Perform rename */
-		status = EDVObjectOPRename(
-		    core, old_full_path, value,
-		    &new_obj, toplevel,
-		    FALSE, TRUE,
+		/* Rename */
+		EDVObjectOPRename(
+		    core,
+		    old_full_path, value,
+		    &modified_paths_list,
+		    toplevel,
+		    FALSE,			/* Do not show progress */
+		    TRUE,			/* Interactive */
 		    &yes_to_all
 		);
 
@@ -1536,49 +1629,56 @@ static void EDVBrowserDirTreeFPromptRenameApplyCB(
 		    );
 		}
 
-		/* Got new object full path name (implying success)? */
-		if((new_obj != NULL) && (old_full_path != NULL))
+		/* Report the modified objects */
+		if(modified_paths_list != NULL)
 		{
 		    struct stat lstat_buf;
-		    const gchar	*new_child = g_basename(new_obj),
-				*old_child = g_basename(old_full_path);
+		    const gchar *modified_path;
+		    GList *glist;
 
-		    /* Get new local statistics for the renamed object */
-		    if(!lstat(new_obj, &lstat_buf))
+		    for(glist = modified_paths_list;
+			glist != NULL;
+			glist = g_list_next(glist)
+		    )
 		    {
-			gchar *buf = g_strdup_printf(
-			    "Object \"%s\" renamed to \"%s\"",
-			    old_child, new_child
-			);
-			EDVStatusBarMessage(
-			    browser->status_bar, buf, FALSE
-			);
-			g_free(buf);
+			modified_path = (const gchar *)glist->data;
+			if(modified_path == NULL)
+			    continue;
 
-			/* Emit object modified signal to all windows */
-			EDVObjectModifiedEmit(
-			    core, old_full_path,
-			    new_obj, &lstat_buf
-			);
+			if(!lstat(modified_path, &lstat_buf))
+			{
+			    gchar *s = g_strdup_printf(
+				"Object \"%s\" renamed to \"%s\"",
+				g_basename(old_full_path),
+				g_basename(modified_path)
+			    );
+			    EDVStatusBarMessage(browser->status_bar, s, FALSE);
+			    g_free(s);
+
+			    EDVObjectModifiedEmit(
+				core,
+				old_full_path,
+				modified_path,
+				&lstat_buf
+			    );
+			}
 		    }
+
+		    g_list_foreach(modified_paths_list, (GFunc)g_free, NULL);
+		    g_list_free(modified_paths_list);
 		}
 		else
 		{
-		    /* Did not get new object path new_obj, implying failed */
+		    /* Did not get the modified object path so this
+		     * implies failure
+		     */
 		    EDVStatusBarMessage(
-			browser->status_bar, "Rename object failed", FALSE
+			browser->status_bar,
+			"Rename object failed",
+			FALSE
 		    );
 		}
 
-#if 0
-		/* The disk object structure may now be invalid if the
-		 * object modified signal was emitted
-		 */
-		object = NULL;
-#endif
-
-		/* Delete coppies of paths */
-		g_free(new_obj);
 		g_free(old_full_path);
 	    }
 	}
@@ -1709,7 +1809,7 @@ void EDVBrowserDirTreeObjectAddedNotify(
 	const struct stat *lstat_buf
 )
 {
-	struct stat stat_buf;
+	struct stat stat_buf, parent_stat_buf;
 	gchar *parent_path;
 	GtkCList *clist;
 	GtkCTreeNode *node, *parent_node;
@@ -1726,11 +1826,11 @@ void EDVBrowserDirTreeObjectAddedNotify(
 
 	clist = GTK_CLIST(ctree);
 
-	/* Get the destination stats of the added path */
+	/* Get the added object's destination statistics */
 	if(stat(path, &stat_buf))
 	    return;
 
-	/* Skip if it is not a directory */
+	/* Skip if the added object's destination is not a directory */
 #ifdef S_ISDIR
 	if(!S_ISDIR(stat_buf.st_mode))
 #else
@@ -1738,43 +1838,70 @@ void EDVBrowserDirTreeObjectAddedNotify(
 #endif
 	    return;
 
-	/* Get the parent of the added path */
+	/* Check if the added object is already listed */
+	node = EDVBrowserDirTreeFindNodeByIndex(
+	    browser,
+	    (gulong)lstat_buf->st_dev,
+	    (gulong)lstat_buf->st_ino
+	);
+	if(node != NULL)
+	{
+	    /* A node for the added object already exists, update
+	     * this node and its object
+	     */
+	    edv_object_struct *obj = EDV_OBJECT(
+		gtk_ctree_node_get_row_data(ctree, node)
+	    );
+	    if(obj != NULL)
+	    {
+		EDVObjectSetPath(obj, path);
+		EDVObjectSetStat(obj, lstat_buf);
+		EDVObjectUpdateLinkFlags(obj);
+
+		gtk_clist_freeze(clist);
+
+		/* Update the node */
+		EDVBrowserDirTreeSetNode(
+		    core, browser, ctree,
+		    node,
+		    obj
+		);
+
+		/* Get new listing of child objects for the updated
+		 * node, recurse no more than 2 levels
+		 */
+		EDVBrowserDirTreeDoGetChildrenList(
+		    core, browser, ctree,
+		    node,			/* Parent node */
+		    TRUE, TRUE
+		);
+
+		gtk_clist_thaw(clist);
+	    }
+	    return;
+	}
+
+	/* Get the added object's parent */
 	parent_path = g_dirname(path);
 	if(parent_path == NULL)
 	    return;
 
-	/* Find the parent node that matches the parent of the specified
-	 * path
-	 */
-	parent_node = EDVBrowserDirTreeFindNodeByPath(browser, parent_path);
-	if(parent_node == NULL)
+	/* Get the parent's local statistics */
+	if(lstat(parent_path, &parent_stat_buf))
 	{
-	    /* Unable to find the parent node, there is no way to
-	     * create the node to represent this new object
-	     */
 	    g_free(parent_path);
 	    return;
 	}
 
-	/* Check if the node for the added path already exists */
-	node = EDVBrowserDirTreeFindNodeByPath(browser, path);
-	if(node != NULL)
+	/* Get the parent node of the added object */
+	parent_node = EDVBrowserDirTreeFindNodeByIndex(
+	    browser,
+	    (gulong)parent_stat_buf.st_dev,
+	    (gulong)parent_stat_buf.st_ino
+	);
+	if(parent_node != NULL)
 	{
-	    /* The node already exists, so just update the node by
-	     * regetting its child nodes and recursing no more than
-	     * 2 levels
-	     */
-	    gtk_clist_freeze(clist);
-	    EDVBrowserDirTreeDoGetChildrenList(
-		core, browser, ctree,
-		node,				/* Parent node */
-		TRUE, TRUE
-	    );
-	    gtk_clist_thaw(clist);
-	}
-	else
-	{
-	    /* Add a new node for the new directory */
+	    /* Create the new node for the added object */
 	    edv_object_struct *obj = EDVObjectNew();
 	    if(obj != NULL)
 	    {
@@ -1819,8 +1946,8 @@ void EDVBrowserDirTreeObjectAddedNotify(
  *	be NULL if there was no name change.
  */
 void EDVBrowserDirTreeObjectModifiedNotify(
-	edv_browser_struct *browser, const gchar *path,
-	const gchar *new_path,
+	edv_browser_struct *browser,
+	const gchar *path, const gchar *new_path,
 	const struct stat *lstat_buf
 )
 {
@@ -1843,35 +1970,37 @@ void EDVBrowserDirTreeObjectModifiedNotify(
 
 	clist = GTK_CLIST(ctree);
 
-	/* Get the destination stats of the modified path */
+	/* Get the modified object's destination statistics */
 	stat_result = (gint)stat((const char *)new_path, &stat_buf);
 
+	/* Find the node who's object matches the modified object */
+	node = EDVBrowserDirTreeFindNodeByIndex(
+	    browser,
+	    (gulong)lstat_buf->st_dev,
+	    (gulong)lstat_buf->st_ino
+	);
+
+#ifdef S_ISDIR
 	/* Is the destination invalid or it does not lead to a
 	 * directory?
 	 */
-#ifdef S_ISDIR
 	if((stat_result == 0) ? !S_ISDIR(stat_buf.st_mode) : TRUE)
-#else
-	if(stat_result != 0)
-#endif
 	{
 	    /* The destination either no longer exists or is not
-	     * a directory, remove any nodes that refer to this
-	     * object
+	     * a directory, remove the node that refer to this
+	     * object (if any)
 	     */
-	    node = EDVBrowserDirTreeFindNodeByPath(browser, path);
 	    if(node != NULL)
 	    {
 		gtk_clist_freeze(clist);
 		gtk_ctree_remove_node(ctree, node);
 		gtk_clist_thaw(clist);
 	    }
-
 	    return;
 	}
+#endif	/* S_ISDIR */
 
-	/* Find the node that matches the old path */
-	node = EDVBrowserDirTreeFindNodeByPath(browser, path);
+	/* Is there a node that refers to the modified object? */
 	if(node != NULL)
 	{
 	    /* Update the object */
@@ -1898,7 +2027,7 @@ void EDVBrowserDirTreeObjectModifiedNotify(
 		 */
 		EDVBrowserDirTreeDoGetChildrenList(
 		    core, browser, ctree,
-		    node,			/* Parent node */
+		    node,
 		    TRUE, TRUE
 		);
 
@@ -1910,51 +2039,52 @@ void EDVBrowserDirTreeObjectModifiedNotify(
 	    /* No existing node matches the old path so check if an
 	     * existing node matches the parent of the new path
 	     */
+	    struct stat parent_stat_buf;
 	    gchar *new_parent_path = g_dirname(new_path);
-
-	    /* Find node that matches the path of the parent of
-	     * the new path
-	     */
-	    GtkCTreeNode *parent_node = EDVBrowserDirTreeFindNodeByPath(
-		browser, new_parent_path
-	    );
-	    if(parent_node != NULL)
+	    if((new_parent_path != NULL) ?
+		!stat(new_parent_path, &parent_stat_buf) : FALSE
+	    )
 	    {
-		/* Modified node does not exist but its parent does,
-		 * which implies we need to create a new child node for
-		 * the matched parent_node
-		 */
-		edv_object_struct *obj = EDVObjectNew();
-		if(obj != NULL)
+		GtkCTreeNode *parent_node = EDVBrowserDirTreeFindNodeByIndex(
+		    browser,
+		    (gulong)parent_stat_buf.st_dev,
+		    (gulong)parent_stat_buf.st_ino
+		);
+		if(parent_node != NULL)
 		{
-		    EDVObjectSetPath(obj, new_path);
-		    EDVObjectSetStat(obj, lstat_buf);
-		    EDVObjectUpdateLinkFlags(obj);
-
-		    gtk_clist_freeze(clist);
-
-		    /* Add/transfer the object to the tree */
-		    node = EDVBrowserDirTreeInsertNode(
-			core, browser, ctree,
-			parent_node, NULL,
-			obj
-		    );
-		    if(node != NULL)
+		    /* Create a node for the modified object */
+		    edv_object_struct *obj = EDVObjectNew();
+		    if(obj != NULL)
 		    {
-			/* Get new listing of child disk objects for
-			 * the new node, recurse no more than 2 levels
-			 */
-			EDVBrowserDirTreeDoGetChildrenList(
-			    core, browser, ctree,
-			    node,		/* Parent node */
-			    TRUE, TRUE
-			);
-		    }
+			EDVObjectSetPath(obj, new_path);
+			EDVObjectSetStat(obj, lstat_buf);
+			EDVObjectUpdateLinkFlags(obj);
 
-		    gtk_clist_thaw(clist);
+			gtk_clist_freeze(clist);
+
+			/* Add/transfer the object to the tree */
+			node = EDVBrowserDirTreeInsertNode(
+			    core, browser, ctree,
+			    parent_node, NULL,
+			    obj
+			);
+			if(node != NULL)
+			{
+			    /* Get new listing of child disk objects
+			     * for the new node, recurse no more than 2
+			     * levels
+			     */
+			    EDVBrowserDirTreeDoGetChildrenList(
+				core, browser, ctree,
+				node,		/* Parent node */
+				TRUE, TRUE
+			    );
+			}
+
+			gtk_clist_thaw(clist);
+		    }
 		}
 	    }
-
 	    g_free(new_parent_path);
 	}
 }
