@@ -1,5 +1,6 @@
 #include <stdlib.h>
 #include <string.h>
+#include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <gtk/gtk.h>
@@ -261,13 +262,13 @@ static void EDVBrowserDragDataReceivedNexus(
 
 #define DO_FREE_LOCALS	{		\
  g_free(parent_path);			\
- parent_path = NULL;			\
 					\
- g_list_foreach(			\
-  url_list, (GFunc)URLDelete, NULL	\
- );					\
- g_list_free(url_list);			\
- url_list = NULL;			\
+ if(url_list != NULL) {			\
+  g_list_foreach(			\
+   url_list, (GFunc)URLDelete, NULL	\
+  );					\
+  g_list_free(url_list);		\
+ }					\
 }
 
 	/* Get copy of parent_path as the object's full path if the
@@ -346,7 +347,7 @@ static void EDVBrowserDragDataReceivedNexus(
 	    gboolean yes_to_all = FALSE;
 	    gint objects_processed = 0;
 	    gchar *new_path;
-	    const gchar *error_title, *error_msg;
+	    const gchar *path, *error_title, *error_msg;
 	    GList *glist;
 	    struct stat lstat_buf;
 
@@ -363,7 +364,8 @@ static void EDVBrowserDragDataReceivedNexus(
 		if(url == NULL)
 		    continue;
 
-		if(STRISEMPTY(parent_path) || STRISEMPTY(url->path))
+		path = url->path;
+		if(STRISEMPTY(path))
 		    continue;
 
 		/* Handle by drag action type */
@@ -374,7 +376,7 @@ static void EDVBrowserDragDataReceivedNexus(
 		{
 		  case GDK_ACTION_COPY:
 		    status = EDVObjectOPCopy(
-			core, url->path, parent_path,
+			core, path, parent_path,
 			&new_path, toplevel,
 			TRUE, TRUE,
 			&yes_to_all
@@ -383,7 +385,7 @@ static void EDVBrowserDragDataReceivedNexus(
 		    break;
 		  case GDK_ACTION_MOVE:
 		    status = EDVObjectOPMove(
-			core, url->path, parent_path,
+			core, path, parent_path,
 			&new_path, toplevel,
 			TRUE, TRUE,
 			&yes_to_all
@@ -392,7 +394,7 @@ static void EDVBrowserDragDataReceivedNexus(
 		    break;
 		  case GDK_ACTION_LINK:
 		    status = EDVObjectOPLink(
-			core, parent_path, url->path,
+			core, parent_path, path,
 			&new_path, toplevel,
 			TRUE, TRUE,
 			&yes_to_all
@@ -405,9 +407,7 @@ static void EDVBrowserDragDataReceivedNexus(
 		    break;
 		}
 
-		/* Get error message (if any) describing the error that
-		 * might have occured in the above operation
-		 */
+		/* Check for and report any errors */
 		if(error_msg == NULL)
 		    error_msg = EDVObjectOPGetError();
 		if(!STRISEMPTY(error_msg))
@@ -416,27 +416,44 @@ static void EDVBrowserDragDataReceivedNexus(
 		    EDVMessageObjectOPError(
 			error_title,
 			error_msg,
-			url->path,
+			path,
 			toplevel
 		    );
 		}
 
-		/* Report the new object being added? */
-		if((new_path != NULL) ?
-		    !lstat(new_path, &lstat_buf) : FALSE
-		)
+		/* Get the source object's statistics for reporting */
+		if(lstat(path, &lstat_buf))
 		{
-		    objects_processed++;
-
-		    browser->processing = FALSE;
-		    EDVObjectAddedEmit(
-			core, new_path, &lstat_buf
-		    );
-		    browser->processing = TRUE;
+#ifdef ENOENT
+		    /* Report the source object being removed */
+		    const gint error_code = (gint)errno;
+		    if(error_code == ENOENT)
+		    {
+			browser->processing = FALSE;
+			EDVObjectRemovedEmit(core, path);
+			browser->processing = TRUE;
+		    }
+#endif
 		}
 
-		/* Delete the path of the new object */
-		g_free(new_path);
+		/* Report the new object being added? */
+		if(new_path != NULL)
+		{
+		    if(!lstat(new_path, &lstat_buf))
+		    {
+			objects_processed++;
+
+			browser->processing = FALSE;
+			EDVObjectAddedEmit(
+			    core,
+			    new_path,
+			    &lstat_buf
+			);
+			browser->processing = TRUE;
+		    }
+
+		    g_free(new_path);
+		}
 
 		/* User aborted? */
 		if(status == -4)
@@ -488,8 +505,7 @@ static void EDVBrowserDragDataReceivedNexus(
 		if(url == NULL)
 		    continue;
 
-		if(STRISEMPTY(url->path))
-		    continue;
+		index = (guint)ATOI(url->path);
 
 		/* Handle by drag action type */
 		status = -1;
@@ -501,7 +517,6 @@ static void EDVBrowserDragDataReceivedNexus(
 		    error_msg = "Recycled objects may not be coppied";
 		    break;
 		  case GDK_ACTION_MOVE:
-		    index = (guint)ATOI(url->path);
 		    status = EDVRecBinRecover(
 			core,
 			index,		/* Recycled object to recover */
@@ -519,9 +534,7 @@ static void EDVBrowserDragDataReceivedNexus(
 		    break;
 		}
 
-		/* Get error message (if any) describing the error that
-		 * might have occured in the above operation
-		 */ 
+		/* Check for and report any errors */
 		if(error_msg == NULL)
 		    error_msg = EDVRecBinRecoverGetError();
 		if(!STRISEMPTY(error_msg))
@@ -536,22 +549,25 @@ static void EDVBrowserDragDataReceivedNexus(
 		}
 
 		/* Object recovered? */
-		if((new_path != NULL) ?
-		    !lstat(new_path, &lstat_buf) : FALSE
-		)
+		if(new_path != NULL)
 		{
-		    objects_recovered++;
+		    if(!lstat(new_path, &lstat_buf))
+		    {
+			objects_recovered++;
 
-		    browser->processing = FALSE;
-		    EDVObjectAddedEmit(
-			core, new_path, &lstat_buf
-		    );
-		    browser->processing = TRUE;
+			browser->processing = FALSE;
+			EDVRecycledObjectRemovedEmit(core, index);
+			EDVObjectAddedEmit(
+			    core,
+			    new_path,
+			    &lstat_buf
+			);
+			browser->processing = TRUE;
+		    }
+
+		    g_free(new_path);
 		}
 
-		/* Delete the path of the new object */
-		g_free(new_path);
-
 		/* User aborted? */
 		if(status == -4)
 		    break;
@@ -672,7 +688,7 @@ static void EDVBrowserDragDataReceivedNexus(
 		);
 	    }
 
-	    /* Report the extracted objects */
+	    /* Report the extracted objects being added */
 	    if(new_paths_list != NULL)
 	    {
 		const gchar *path;
@@ -691,18 +707,19 @@ static void EDVBrowserDragDataReceivedNexus(
 			continue;
 
 		    EDVObjectAddedEmit(
-			core, path, &lstat_buf
+			core,
+			path,
+			&lstat_buf
 		    );
 		    objects_extracted++;
 		}
 
 		browser->processing = TRUE;
-	    }
 
-	    /* Delete the list of the extracted object paths */
-	    g_list_foreach(new_paths_list, (GFunc)g_free, NULL);
-	    g_list_free(new_paths_list);
-	    new_paths_list = NULL;
+		/* Delete the list of the extracted object paths */
+		g_list_foreach(new_paths_list, (GFunc)g_free, NULL);
+		g_list_free(new_paths_list);
+	    }
 
 	    /* Update the status bar message */
 	    EDVBrowserDNDUpdateStatusBar(
@@ -1037,69 +1054,7 @@ void EDVBrowserDirTreeDragDataDeleteCB(
 	GtkWidget *widget, GdkDragContext *dc, gpointer data
 )
 {
-	const gchar *path;
-	gchar **strv;
-	gint i, strc;
-	GList *glist;
-	GtkWidget *w;
-	GtkCList *clist;
-	GtkCTree *ctree;
-	GtkCListRow *row_ptr;
-	edv_object_struct *obj;
-	struct stat lstat_buf;
-	edv_core_struct *core;
-	edv_browser_struct *browser = EDV_BROWSER(data);
-	if((dc == NULL) || (browser == NULL))
-	    return;
 
-	w = browser->directory_ctree;
-	core = browser->core;
-	if((w == NULL) || (core == NULL))
-	    return;
-
-	ctree = GTK_CTREE(w);
-	clist = GTK_CLIST(w);
-
-	/* Generate a list of object paths from the selected nodes */
-	strv = NULL;
-	strc = 0;
-	for(glist = clist->selection;
-	    glist != NULL;
-	    glist = g_list_next(glist)
-	)
-	{
-	    row_ptr = (GtkCListRow *)glist->data;
-	    obj = EDV_OBJECT(
-		gtk_ctree_node_get_row_data(ctree, (GtkCTreeNode *)row_ptr)
-	    );
-	    if((obj != NULL) ? !STRISEMPTY(obj->full_path) : FALSE)
-	    {
-		i = strc;
-		strc = i + 1;
-		strv = (gchar **)g_realloc(
-		    strv, strc * sizeof(gchar *)
-		);
-		if(strv == NULL)
-		{
-		    strc = 0;
-		    break;
-		}
-		strv[i] = STRDUP(obj->full_path);
-	    }
-	}
-
-	/* Emit object delete signal and delete list of paths */
-	for(i = 0; i < strc; i++)
-	{
-	    path = strv[i];
-	    if(!STRISEMPTY(path))
-	    {
-		if(lstat(path, &lstat_buf))
-		    EDVObjectRemovedEmit(core, path);
-	    }
-	    g_free(strv[i]);
-	}
-	g_free(strv);
 }
 
 
@@ -1334,62 +1289,5 @@ void EDVBrowserContentsDragDataDeleteCB(
 	GtkWidget *widget, GdkDragContext *dc, gpointer data
 )
 {
-	const gchar *path;
-	gchar **strv;
-	gint i, strc, row;
-	edv_core_struct *core;
-	GList *glist;
-	GtkWidget *w;
-	GtkCList *clist;
-	edv_object_struct *obj;
-	struct stat lstat_buf;
-	edv_browser_struct *browser = EDV_BROWSER(data);
-	if((dc == NULL) || (browser == NULL))
-	    return;
 
-	w = browser->contents_clist;
-	core = browser->core;
-	if((w == NULL) || (core == NULL))
-	    return;
-
-	clist = GTK_CLIST(w);
-
-	/* Generate a list of object paths from the selected rows */
-	strv = NULL;
-	strc = 0;
-	for(glist = clist->selection;
-	    glist != NULL;
-	    glist = g_list_next(glist)
-	)
-	{
-	    row = (gint)glist->data;
-	    obj = EDV_OBJECT(gtk_clist_get_row_data(clist, row));
-	    if((obj != NULL) ? !STRISEMPTY(obj->full_path) : FALSE)
-	    {
-		i = strc;
-		strc = i + 1;
-		strv = (gchar **)g_realloc(
-		    strv, strc * sizeof(gchar *)
-		);
-		if(strv == NULL)
-		{
-		    strc = 0;
-		    break;
-		}
-		strv[i] = STRDUP(obj->full_path);
-	    }
-	}
-
-	/* Emit object delete signal and delete list of paths */
-	for(i = 0; i < strc; i++)
-	{
-	    path = strv[i];
-	    if(!STRISEMPTY(path))
-	    {
-		if(lstat(path, &lstat_buf))
-		    EDVObjectRemovedEmit(core, path);
-	    }
-	    g_free(strv[i]);
-	}
-	g_free(strv);
 }
