@@ -1795,12 +1795,11 @@ void EDVBrowserOPChTime(edv_browser_struct *browser)
  */
 void EDVBrowserOPDelete(edv_browser_struct *browser)
 {
+	struct stat lstat_buf;
 	gboolean yes_to_all = FALSE;
-	gint i, status;
+	gint status, npaths, objects_deleted = 0;
 	const gchar *path, *error_msg;
-	gchar **object_path = NULL;
-	gint total_object_paths = 0, objects_deleted = 0;
-	GList *index_list;
+	GList *glist, *paths_list = NULL, *index_list;
 	GtkWidget *toplevel;
 	edv_core_struct *core;
 
@@ -1808,9 +1807,12 @@ void EDVBrowserOPDelete(edv_browser_struct *browser)
 	    return;
 
 #define DO_FREE_LOCALS	{			\
- strlistfree(object_path, total_object_paths);	\
- object_path = NULL;				\
- total_object_paths = 0;			\
+ if(paths_list != NULL)	{			\
+  g_list_foreach(				\
+   paths_list, (GFunc)g_free, NULL		\
+  );						\
+  g_list_free(paths_list);			\
+ }						\
 }
 
 	toplevel = browser->toplevel;
@@ -1831,88 +1833,65 @@ void EDVBrowserOPDelete(edv_browser_struct *browser)
 	/* Contents List was last selected? */
 	if(browser->contents_clist_selected_row > -1)
 	{
-	    edv_object_struct *obj;
+	    GtkCList *clist = GTK_CLIST(browser->contents_clist);
 	    gint row;
-	    GtkCList *clist = (GtkCList *)browser->contents_clist;
-	    GList *glist = (clist != NULL) ? clist->selection : NULL;
-	    while(glist != NULL)
+	    edv_object_struct *obj;
+
+	    for(glist = clist->selection;
+		glist != NULL;
+		glist = g_list_next(glist)
+	    )
 	    {
 		row = (gint)glist->data;
 		obj = EDV_OBJECT(
 		    gtk_clist_get_row_data(clist, row)
 		);
 		if((obj != NULL) ? (obj->full_path != NULL) : FALSE)
-		{
-		    i = total_object_paths;
-		    total_object_paths = i + 1;
-		    object_path = (gchar **)g_realloc(
-			object_path,
-			total_object_paths * sizeof(gchar *)
+		    paths_list = g_list_append(
+			paths_list,
+			STRDUP(obj->full_path)
 		    );
-		    if(object_path == NULL)
-		    {
-			total_object_paths = 0;
-			break;
-		    }
-		    else
-		    {
-			object_path[i] = STRDUP(obj->full_path);
-		    }
-		}
-
-		glist = g_list_next(glist);
 	    }
 	}
 	/* Directory Tree was last selected? */
 	else if(browser->directory_ctree_selected_node != NULL)
 	{
-	    GtkCList *clist = (GtkCList *)browser->directory_ctree;
-	    GtkCTree *ctree = (GtkCTree *)clist;
+	    GtkCTree *ctree = GTK_CTREE(browser->directory_ctree);
+	    GtkCList *clist = GTK_CLIST(ctree);
 	    GtkCTreeNode *node;
 	    edv_object_struct *obj;
 
-	    GList *glist = (clist != NULL) ? clist->selection : NULL;
-	    while(glist != NULL)
+	    for(glist = clist->selection;
+		glist != NULL;
+		glist = g_list_next(glist)
+	    )
 	    {
 		node = (GtkCTreeNode *)glist->data;
 		obj = EDV_OBJECT(
 		    gtk_ctree_node_get_row_data(ctree, node)
 		);
 		if((obj != NULL) ? (obj->full_path != NULL) : FALSE)
-		{
-		    i = total_object_paths;
-		    total_object_paths = i + 1;
-		    object_path = (gchar **)g_realloc(
-			object_path,
-			total_object_paths * sizeof(gchar *)
+		    paths_list = g_list_append(
+			paths_list,
+			STRDUP(obj->full_path)
 		    );
-		    if(object_path == NULL)
-		    {
-			total_object_paths = 0;
-			break;
-		    }
-		    else
-		    {
-			object_path[i] = STRDUP(obj->full_path);
-		    }
-		}
-
-		glist = g_list_next(glist);
 	    }
 	}
 
-	/* No disk objects selected? */
-	if(total_object_paths <= 0)
+	/* No objects selected? */
+	if(paths_list == NULL)
 	{
 	    DO_FREE_LOCALS
 	    return;
 	}
 
+	npaths = g_list_length(paths_list);
+
 	/* Confirm delete */
 	status = EDVConfirmDelete(
 	    core, toplevel,
-	    (total_object_paths == 1) ? object_path[0] : NULL,
-	    total_object_paths
+	    (npaths == 1) ? (const gchar *)paths_list->data : NULL,
+	    npaths
 	);
 	switch(status)
 	{
@@ -1934,9 +1913,12 @@ void EDVBrowserOPDelete(edv_browser_struct *browser)
 
 	/* Iterate through the list of object paths */
 	status = 0;
-	for(i = 0; i < total_object_paths; i++)
+	for(glist = paths_list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
-	    path = object_path[i];
+	    path = (const gchar *)glist->data;
 	    if(path == NULL)
 		continue;
 
@@ -1949,9 +1931,7 @@ void EDVBrowserOPDelete(edv_browser_struct *browser)
 		TRUE, TRUE, &yes_to_all
 	    );
 
-	    /* Get error message (if any) describing the error that
-	     * might have occured in the above operation
-	     */
+	    /* Check for and report any errors */
 	    error_msg = EDVRecBinDeleteObjectGetError();
 	    if(!STRISEMPTY(error_msg))
 	    {
@@ -1964,10 +1944,20 @@ void EDVBrowserOPDelete(edv_browser_struct *browser)
 		);
 	    }
 
-	    /* Any objects delected? */
+	    /* Check if the object still exists */
+	    if(lstat(path, &lstat_buf))
+	    {
+#ifdef ENOENT
+		/* Report the object being removed */
+		const gint error_code = (gint)errno;
+		if(error_code == ENOENT)
+		    EDVObjectRemovedEmit(core, path);
+#endif
+	    }
+
+	    /* Any objects deleted? */
 	    if(index_list != NULL)
 	    {
-		struct stat lstat_buf;
 		guint index;
 		GList *glist;
 
@@ -1979,10 +1969,6 @@ void EDVBrowserOPDelete(edv_browser_struct *browser)
 
 		    objects_deleted++;
 		}
-
-		/* Report the object removed? */
-		if(lstat(path, &lstat_buf))
-		    EDVObjectRemovedEmit(core, path);
 	    }
 
 	    /* Delete the recycle objects index list */
@@ -2010,7 +1996,7 @@ void EDVBrowserOPDelete(edv_browser_struct *browser)
 	    else
 		s = g_strdup_printf(
 		    "Unable to delete %s",
-		    (total_object_paths == 1) ? "object" : "objects"
+		    (npaths == 1) ? "object" : "objects"
 		);
 	    EDVStatusBarMessage(browser->status_bar, s, FALSE);
 	    g_free(s);
