@@ -2,10 +2,11 @@
 #include <stdlib.h>
 #include <string.h>
 #include <sys/types.h>
+#include <sys/stat.h>
 #include <fcntl.h>
-#include <unistd.h>
 #include <gtk/gtk.h>
 #include <gdk/gdkkeysyms.h>
+#include <unistd.h>
 
 #include "../include/disk.h"
 #include "guiutils.h"
@@ -653,7 +654,7 @@ gint ConMsgInit(
 	}
 	else
 	{
-	    const gchar *s = getenv("COLUMNS");
+	    const gchar *s = g_getenv("COLUMNS");
 	    if(s != NULL)
 		terminal_columns = ATOI(s);
 	}
@@ -663,7 +664,7 @@ gint ConMsgInit(
 	}
 	else
 	{
-	    const gchar *s = getenv("LINES");
+	    const gchar *s = g_getenv("LINES");
 	    if(s != NULL)
 		terminal_lines = ATOI(s);
 	}
@@ -733,7 +734,7 @@ gint ConMsgReset(
 	}
 	else
 	{   
-	    const gchar *s = getenv("COLUMNS");
+	    const gchar *s = g_getenv("COLUMNS");
 	    if(s != NULL)
 		terminal_columns = ATOI(s);
 	}
@@ -743,7 +744,7 @@ gint ConMsgReset(
 	}
 	else
 	{   
-	    const gchar *s = getenv("LINES");
+	    const gchar *s = g_getenv("LINES");
 	    if(s != NULL)
 		terminal_lines = ATOI(s);
 	}
