@@ -756,20 +756,20 @@ void EDVCustomizeBrowserCreateContentsListPage(
 	);
 	StackListAppend(
 	    slist,
-"Device",
-"Device that the object exists on",
+"Device Index",
+"Index of the device that the object resides on",
 	    NULL,               /* No icon data */
 	    NULL,               /* No client data */
-	    EDV_BROWSER_COLUMN_TYPE_DEVICE,
+	    EDV_BROWSER_COLUMN_TYPE_DEVICE_INDEX,
 	    FALSE, FALSE        /* No multiple, no stay on target */
 	);
 	StackListAppend(
 	    slist,
-"INode",
-"Index location on the media that the object exists on",
+"Index",
+"Index on the device that the object resides at",
  	    NULL,               /* No icon data */
 	    NULL,               /* No client data */
-	    EDV_BROWSER_COLUMN_TYPE_INODE,
+	    EDV_BROWSER_COLUMN_TYPE_INDEX,
 	    FALSE, FALSE        /* No multiple, no stay on target */
 	);
 	StackListAppend(
