@@ -56,9 +56,16 @@
 #include "config.h"
 
 
+typedef enum {
+	EDV_SORT_TYPE_TEXT,
+	EDV_SORT_TYPE_NUMBER
+} edv_sort_type;
+
+
 typedef struct _interps_idle_data_struct	interps_idle_data_struct;
 #define INTERPS_IDLE_DATA(p)		((interps_idle_data_struct *)(p))
 
+
 /* UNIX Signal Callbacks */
 void EDVSignalCB(int s);
 
@@ -80,12 +87,12 @@ void EDVCustomizeCB(GtkWidget *widget, gpointer data);
 /* GtkCList Sort Callbacks */
 static gint EDVCListColumnSortNexus(
 	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2,
-	gint sort_code
+	const edv_sort_type sort_type
 );
 gint EDVCListColumnSortStringCB(
 	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
 );
-gint EDVCListColumnSortNumericCB(
+gint EDVCListColumnSortNumberCB(
 	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
 );
 
@@ -177,21 +184,21 @@ void EDVReconfiguredEmit(edv_core_struct *core);
 
 /* MIME Type Emitters */
 void EDVMimeTypeAddedEmitCB(
-	gpointer data, const gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt, gpointer data
 );
 void EDVMimeTypeAddedEmit(
 	edv_core_struct *core,
 	const gint mt_num, edv_mime_type_struct *mt
 );
 void EDVMimeTypeModifiedEmitCB(
-	gpointer data, const gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt, gpointer data
 );
 void EDVMimeTypeModifiedEmit(
 	edv_core_struct *core,
 	const gint mt_num, edv_mime_type_struct *mt
 );
 void EDVMimeTypeRemovedEmitCB(
-	gpointer data, const gint mt_num
+	const gint mt_num, gpointer data
 );
 void EDVMimeTypeRemovedEmit(
 	edv_core_struct *core, const gint mt_num
@@ -252,6 +259,7 @@ void EDVSignalCB(int s)
 {
 	edv_core_struct *core = edv_core;
 
+	/* If the core was not initialized then ignore the signal */
 	if(core == NULL)
 	    return;
 
@@ -261,6 +269,8 @@ void EDVSignalCB(int s)
 	  case SIGHUP:
 	    core->pending_flags |= EDV_CORE_PENDING_RESET;
 	    break;
+#else
+#warning SIGHUP is not defined, reset signaling will not function
 #endif
 #ifdef SIGINT
 	  case SIGINT:
@@ -287,6 +297,8 @@ void EDVSignalCB(int s)
 	    /* Increment InterPS signal count */
 	    core->interps_signal_count++;
 	    break;
+#else
+#warning SIGUSR1 is not defined, InterPS signaling will not function
 #endif
 
 #ifdef SIGUSR2
@@ -1049,15 +1061,23 @@ void EDVCustomizeCB(GtkWidget *widget, gpointer data)
 /*
  *	GtkCList column sort callback nexus.
  *
- *	These only take the text value from the cell that corresesponds
- *	to the sort column of the given rows. The row data is ignored.
+ *	This function only sorts by the cell's text value and not the
+ *	row's data. Only cells of type GTK_CELL_TEXT and
+ *	GTK_CELL_PIXTEXT will be sorted, all other types will
+ *	reutrn -1.
  *
- *	Only cells of type text and pixtext are supported, all other 
- *	cell types will return -1.
+ *	The clist specifies the GtkCList.
+ *
+ *	The ptr1 specifies the first GtkCListRow.
+ *
+ *	The ptr2 specifies the second GtkCListRow.
+ *
+ *	The sort_type specifies what the text value describes (string,
+ *	number, etc).
  */
 static gint EDVCListColumnSortNexus(
 	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2,
-	gint sort_code
+	const edv_sort_type sort_type
 )
 {
 	gint sort_column;
@@ -1076,7 +1096,7 @@ static gint EDVCListColumnSortNexus(
 	if((sort_column < 0) || (sort_column >= clist->columns))
 	    return(-1);
 
-	/* Get the pointer to the text of the first cell */
+	/* Get the first cell's text value */
 	switch(row1->cell[sort_column].type)
 	{
 	  case GTK_CELL_TEXT:
@@ -1089,7 +1109,7 @@ static gint EDVCListColumnSortNexus(
 	    break;
 	}
 
-	/* Get the pointer to the text of the second cell */
+	/* Get the second cell's text value */
 	switch(row2->cell[sort_column].type)
 	{
 	  case GTK_CELL_TEXT:
@@ -1107,22 +1127,25 @@ static gint EDVCListColumnSortNexus(
 	if(text1 == NULL)
 	    return(-1);
 
-	/* Sort by the given sort_code */
-	switch(sort_code)
+	/* Sort by the text value's descriptive type */
+	switch(sort_type)
 	{
-	  case 0:	/* By text */
+	  case EDV_SORT_TYPE_TEXT:
+	    /* The text value is plain text, sort alphabetically */
 	    return(strcmp(text1, text2));
 	    break;
 
-	  case 1:	/* By numeric */
+	  case EDV_SORT_TYPE_NUMBER:
+	    /* The text value is a number, sort numerically */
 	    {
-		/* Number strings may contain ',' characters, need
-		 * to copy them to tempory strings and strip them
+		/* Number strings may contain notation characters such
+		 * as ',', '#', or '$', so copy them to tempory strings
+		 * and then remove those characters them
 		 */
 		gchar	ns1[80], ns2[80];
 		gint	n1, n2;
 
-		/* Copy strings to tempory and modifyable number
+		/* Copy the strings to tempory and modifyable number
 		 * strings
 		 */
 		strncpy(ns1, text1, sizeof(ns1));
@@ -1130,7 +1153,7 @@ static gint EDVCListColumnSortNexus(
 		strncpy(ns2, text2, sizeof(ns2));
 		ns2[sizeof(ns2) - 1] = '\0';
 
-		/* Remove ',', '#', and '$' characters */
+		/* Remove any notation characters */
 		substr(ns1, ",", "");
 		substr(ns1, "#", "");
 		substr(ns1, "$", "");
@@ -1161,17 +1184,21 @@ gint EDVCListColumnSortStringCB(
 	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
 )
 {
-	return(EDVCListColumnSortNexus(clist, ptr1, ptr2, 0));
+	return(EDVCListColumnSortNexus(
+	    clist, ptr1, ptr2, EDV_SORT_TYPE_TEXT
+	));
 }
 
 /*
  *	GtkCList column sort by numeric callback.
  */
-gint EDVCListColumnSortNumericCB(
+gint EDVCListColumnSortNumberCB(
 	GtkCList *clist, gconstpointer ptr1, gconstpointer ptr2
 )
 {
-	return(EDVCListColumnSortNexus(clist, ptr1, ptr2, 1));
+	return(EDVCListColumnSortNexus(
+	    clist, ptr1, ptr2, EDV_SORT_TYPE_NUMBER
+	));
 }
 
 
@@ -1193,10 +1220,10 @@ void EDVPurgeAllRecycledObjectsCB(GtkWidget *widget, gpointer data)
 	if(core == NULL)
 	    return;
 
-	/* Map Recycle Bin */
+	/* Map the Recycle Bin */
 	EDVMapRecBin(core);
 
-	/* Purge all objects in the Recycle Bin */
+	/* Purge all the objects from the Recycle Bin */
 	EDVRecBinOPPurgeAll(core->recbin);
 }
 
@@ -2071,24 +2098,32 @@ void EDVReconfiguredEmit(edv_core_struct *core)
 
 	cfg_list = core->cfg_list;
 
-	/* Update RC styles */
+	/* Update the RC styles */
 	EDVUpdateRCStyles(core);
 	standard_rcstyle = core->standard_rcstyle;
 	lists_rcstyle = core->lists_rcstyle;
 
-	/* Update global Tool Tips state */
+	/* Update the global Tool Tips state */
 	GUISetGlobalTipsState(EDV_GET_B(EDV_CFG_PARM_SHOW_TOOLTIPS));
 
 
 	/* Update the popup lists */
 
 	/* Users & Groups popup lists */
+	PUListDelete(core->users_pulist);
+	core->users_pulist = NULL;
+	PUListDelete(core->groups_pulist);
+	core->groups_pulist = NULL;
 	EDVUpdateIDPULists(core);
 
 	/* Devices popup list */
+	PUListDelete(core->devices_pulist);
+	core->devices_pulist = NULL;
 	EDVUpdateDevicesPUList(core);
 
 	/* Open With popup list */
+	PUListDelete(core->open_with_pulist);
+	core->open_with_pulist = NULL;
 	EDVUpdateOpenWithPUList(core);
 
 
@@ -2154,7 +2189,7 @@ void EDVReconfiguredEmit(edv_core_struct *core)
  *	Emits a MIME Type added signal.
  */
 void EDVMimeTypeAddedEmitCB(
-	gpointer data, const gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt, gpointer data
 )
 {
 	EDVMimeTypeAddedEmit(EDV_CORE(data), mt_num, mt);
@@ -2215,7 +2250,7 @@ void EDVMimeTypeAddedEmit(
  *	Emits a MIME Type modified signal.
  */
 void EDVMimeTypeModifiedEmitCB(
-	gpointer data, const gint mt_num, edv_mime_type_struct *mt
+	const gint mt_num, edv_mime_type_struct *mt, gpointer data
 )
 {
 	EDVMimeTypeModifiedEmit(EDV_CORE(data), mt_num, mt);
@@ -2277,7 +2312,7 @@ void EDVMimeTypeModifiedEmit(
  *	are interested.
  */
 void EDVMimeTypeRemovedEmitCB(
-	gpointer data, const gint mt_num
+	const gint mt_num, gpointer data
 )
 {
 	EDVMimeTypeRemovedEmit(EDV_CORE(data), mt_num);
