@@ -502,10 +502,10 @@ static cfg_item_struct *EDVNewDefaultConfigurationList(
 	    EDV_BROWSER_COLUMN_TYPE_LINKED_TO, (gpointer)150
 	);
 	g_list_set_nth_data(glist,
-	    EDV_BROWSER_COLUMN_TYPE_DEVICE, (gpointer)60
+	    EDV_BROWSER_COLUMN_TYPE_DEVICE_INDEX, (gpointer)60
 	);
 	g_list_set_nth_data(glist,
-	    EDV_BROWSER_COLUMN_TYPE_INODE, (gpointer)70
+	    EDV_BROWSER_COLUMN_TYPE_INDEX, (gpointer)70
 	);
 	g_list_set_nth_data(glist,
 	    EDV_BROWSER_COLUMN_TYPE_DEVICE_TYPE, (gpointer)90
@@ -1286,7 +1286,7 @@ edv_core_struct *EDVNew(gint argc, gchar *argv[], gint *error_rtn)
 
 	core->mimetype = NULL;
 	core->total_mimetypes = 0;
-	core->openwith_pulist = NULL;
+	core->open_with_pulist = NULL;
 
 	core->mimetype_system_index_first = -1;
 	core->mimetype_system_index_last = -1;
@@ -2501,8 +2501,8 @@ void EDVDelete(
 
 
 	/* Delete the Open With popup list */
-	PUListDelete(core->openwith_pulist);
-	core->openwith_pulist = NULL;
+	PUListDelete(core->open_with_pulist);
+	core->open_with_pulist = NULL;
 
 	/* Delete the MIME Types list */
 	for(i = 0; i < core->total_mimetypes; i++)
