@@ -5,6 +5,7 @@
 #include <gdk/gdkkeysyms.h>
 
 #include "guiutils.h"
+#include "pulist.h"
 
 #include "cfg.h"
 #include "edv_types.h"
@@ -510,35 +511,19 @@ void EDVFindBarSetSearch(
  */
 edv_findbar_operation EDVFindBarCurrentFindOP(edv_findbar_struct *fb)
 {
-	edv_findbar_operation i;
-	const gchar *value, *value2;
-	GList *glist;
-	GtkCombo *combo;
+	pulist_struct *pulist;
 
 	if(fb == NULL)
 	    return(EDV_FINDBAR_FIND_OBJECT_NAME);
 
-	combo = (GtkCombo *)fb->find_op_combo;
-	if(combo == NULL)
+	pulist = PUListBoxGetPUList(fb->find_op_pulistbox);
+	if(pulist == NULL)
 	    return(EDV_FINDBAR_FIND_OBJECT_NAME);
 
-	value = gtk_entry_get_text(GTK_ENTRY(combo->entry));
-	glist = GUIComboGetList(GTK_WIDGET(combo));
-	if((value == NULL) || (glist == NULL))
-	    return(EDV_FINDBAR_FIND_OBJECT_NAME);
-
-	i = 0;
-	while(glist != NULL)
-	{
-	    value2 = (const gchar *)glist->data;
-	    if((value2 != NULL) ? !g_strcasecmp(value2, value) : FALSE)
-		return(i);
-
-	    i++;
-	    glist = g_list_next(glist);
-	}
-
-	return(EDV_FINDBAR_FIND_OBJECT_NAME);
+	return((edv_findbar_operation)PUListGetItemData(
+	    pulist,
+	    PUListGetSelectedLast(pulist)
+	));
 }
 
 
@@ -569,23 +554,23 @@ edv_findbar_struct *EDVFindBarNew(
 )
 {
 	const gint border_minor = 2;
+	gint i;
 	gpointer combo_rtn;
 	GList *glist;
-	GtkWidget *w, *parent2;
+	GtkWidget *w, *parent2, *parent3;
 	GtkCombo *combo;
+	pulist_struct *pulist;
+	pulistbox_struct *pulistbox;
 	edv_findbar_struct *fb = EDV_FINDBAR(
 	    g_malloc0(sizeof(edv_findbar_struct))
 	);
 	if(fb == NULL)
 	    return(fb);
 
-	/* Reset values */
 	fb->freeze_count = 0;
 	fb->stop_count = 0;
 	fb->core = core;
-
 	fb->role = role;
-
 	fb->get_location_cb = get_location_cb;
 	fb->start_cb = start_cb;
 	fb->end_cb = end_cb;
@@ -594,47 +579,19 @@ edv_findbar_struct *EDVFindBarNew(
 	fb->status_progress_cb = status_progress_cb;
 	fb->data = data;
 
-
-	/* Create toplevel */
+	/* Create the toplevel GtkHBox */
 	fb->toplevel = w = gtk_hbox_new(FALSE, border_minor);
 	gtk_container_border_width(GTK_CONTAINER(w), 2);
 	gtk_container_add(GTK_CONTAINER(parent), w);
 	parent2 = w;
 
+	/* GtkHBox for the find operation */
+	w = gtk_hbox_new(FALSE, border_minor);
+	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
+	gtk_widget_show(w);
+	parent3 = w;
 
-	/* Create glist containing a list of find operation names, where
-	 * the index of each name corresponds to one of
-	 * EDV_FINDBAR_FIND_*
-	 */
-	glist = NULL;
-#if defined(PROG_LANGUAGE_SPANISH)
-	glist = g_list_append(glist, "Por Nombre de archivo");
-	glist = g_list_append(glist, "Por Contenido");
-#elif defined(PROG_LANGUAGE_FRENCH)
-	glist = g_list_append(glist, "Nom D'Objet");
-	glist = g_list_append(glist, "Contenu D'Objet");
-#elif defined(PROG_LANGUAGE_GERMAN)
-	glist = g_list_append(glist, "Wenden Sie Gegen Namen Ein");
-	glist = g_list_append(glist, "Wenden Sie Gegen Inhalt Ein");
-#elif defined(PROG_LANGUAGE_ITALIAN)
-	glist = g_list_append(glist, "Il Nome Di Oggetto");
-	glist = g_list_append(glist, "Il Contenuto Di Oggetto");
-#elif defined(PROG_LANGUAGE_DUTCH)
-	glist = g_list_append(glist, "Heb Bezwaar Naam");
-	glist = g_list_append(glist, "Heb Bezwaar Inhoud");
-#elif defined(PROG_LANGUAGE_PORTUGUESE)
-	glist = g_list_append(glist, "O Nome De Objeto");
-	glist = g_list_append(glist, "O Contedo De Objeto");
-#elif defined(PROG_LANGUAGE_NORWEGIAN)
-	glist = g_list_append(glist, "Protester Navn");
-	glist = g_list_append(glist, "Protester Innhold");
-#else
-	glist = g_list_append(glist, "Object Name");
-	glist = g_list_append(glist, "Object Content");
-#endif
-
-	/* Find operation combo */
-	w = GUIComboCreate(
+	w = gtk_label_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Buscar"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -652,33 +609,58 @@ edv_findbar_struct *EDVFindBarNew(
 #else
 "Find"
 #endif
-	    ":",
-	    "",				/* Initial Value */
-	    glist,			/* List */
-	    g_list_length(glist),	/* Items in list */
-	    &combo_rtn,
-	    fb,
-	    EDVFindBarFindCB,
-	    NULL
 	);
-	fb->find_op_combo = (GtkWidget *)combo_rtn;
-	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 
-	w = fb->find_op_combo;
-	combo = GTK_COMBO(w);
-	gtk_widget_set_usize(w, 150, -1);
-
-	g_list_free(glist);
-
-	w = combo->entry;
-	gtk_entry_set_editable(GTK_ENTRY(w), FALSE);
-#if 0
-	glist = GUIComboGetList(combo);
-	glist = g_list_nth(glist, find_op);
-	if((glist != NULL) ? (glist->data != NULL) : FALSE)
-	    gtk_entry_set_text(GTK_ENTRY(w), (const gchar *)glist->data);
+	fb->find_op_pulistbox = pulistbox = PUListBoxNew(
+	    parent3,
+	    150, -1
+	);
+	pulist = PUListBoxGetPUList(pulistbox);
+	PUListBoxMap(pulistbox);
+#if defined(PROG_LANGUAGE_SPANISH)
+	i = PUListAddItem(pulist, "Por Nombre de archivo");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_NAME);
+	i = PUListAddItem(pulist, "Por Contenido");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_CONTENT);
+#elif defined(PROG_LANGUAGE_FRENCH)
+	i = PUListAddItem(pulist, "Nom D'Objet");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_NAME);
+	i = PUListAddItem(pulist, "Contenu D'Objet");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_CONTENT);
+#elif defined(PROG_LANGUAGE_GERMAN)
+	i = PUListAddItem(pulist, "Wenden Sie Gegen Namen Ein");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_NAME);
+	i = PUListAddItem(pulist, "Wenden Sie Gegen Inhalt Ein");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_CONTENT);
+#elif defined(PROG_LANGUAGE_ITALIAN)
+	i = PUListAddItem(pulist, "Il Nome Di Oggetto");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_NAME);
+	i = PUListAddItem(pulist, "Il Contenuto Di Oggetto");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_CONTENT);
+#elif defined(PROG_LANGUAGE_DUTCH)
+	i = PUListAddItem(pulist, "Heb Bezwaar Naam");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_NAME);
+	i = PUListAddItem(pulist, "Heb Bezwaar Inhoud");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_CONTENT);
+#elif defined(PROG_LANGUAGE_PORTUGUESE)
+	i = PUListAddItem(pulist, "O Nome De Objeto");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_NAME);
+	i = PUListAddItem(pulist, "O Contedo De Objeto");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_CONTENT);
+#elif defined(PROG_LANGUAGE_NORWEGIAN)
+	i = PUListAddItem(pulist, "Protester Navn");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_NAME);
+	i = PUListAddItem(pulist, "Protester Innhold");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_CONTENT);
+#else
+	i = PUListAddItem(pulist, "Object Name");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_NAME);
+	i = PUListAddItem(pulist, "Object Content");
+	PUListSetItemData(pulist, i, (gpointer)EDV_FINDBAR_FIND_OBJECT_CONTENT);
 #endif
+	PUListBoxSetLinesVisible(pulistbox, i + 1);
 
 	/* Search string combo */
 	glist = NULL;
@@ -854,9 +836,12 @@ void EDVFindBarUpdateMenus(edv_findbar_struct *fb)
 	GTK_WIDGET_SET_SENSITIVE(fb->stop_btn, sensitive)
 
 	sensitive = (fb->freeze_count == 0) ? TRUE : FALSE;
-	GTK_WIDGET_SET_SENSITIVE(fb->search_combo, sensitive)
-	GTK_WIDGET_SET_SENSITIVE(fb->case_sensitive_check, sensitive)
-	GTK_WIDGET_SET_SENSITIVE(fb->find_op_combo, sensitive)
+	GTK_WIDGET_SET_SENSITIVE(fb->search_combo, sensitive);
+	GTK_WIDGET_SET_SENSITIVE(fb->case_sensitive_check, sensitive);
+	GTK_WIDGET_SET_SENSITIVE(
+	    PUListBoxGetToplevel(fb->find_op_pulistbox),
+	    sensitive
+	);
 
 #undef DO_SHOW
 #undef DO_HIDE
@@ -896,16 +881,10 @@ void EDVFindBarDelete(edv_findbar_struct *fb)
 	if(fb == NULL)
 	    return;
 
-	GTK_WIDGET_DESTROY(fb->find_op_combo)
-	fb->find_op_combo = NULL;
-	GTK_WIDGET_DESTROY(fb->search_combo)
-	fb->search_combo = NULL;
-	GTK_WIDGET_DESTROY(fb->case_sensitive_check)
-	fb->case_sensitive_check = NULL;
-	GTK_WIDGET_DESTROY(fb->stop_btn)
-	fb->stop_btn = NULL;
-	GTK_WIDGET_DESTROY(fb->toplevel)
-	fb->toplevel = NULL;
-
+	PUListBoxDelete(fb->find_op_pulistbox);
+	GTK_WIDGET_DESTROY(fb->search_combo);
+	GTK_WIDGET_DESTROY(fb->case_sensitive_check);
+	GTK_WIDGET_DESTROY(fb->stop_btn);
+	GTK_WIDGET_DESTROY(fb->toplevel);
 	g_free(fb);
 }
