@@ -30,7 +30,7 @@ void EDVMimeTypesListSystemFileOpen(
 	const gint insert_index,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
 	gpointer progress_data,
-	void (*added_cb)(gpointer, const gint, edv_mime_type_struct *),
+	void (*added_cb)(const gint, edv_mime_type_struct *, gpointer),
 	gpointer added_data,
 	const gboolean mark_all_loaded_read_only
 );
@@ -42,9 +42,9 @@ void EDVMimeTypesListFileOpen(
 	const gboolean update, const gboolean only_newer,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
 	gpointer progress_data,
-	void (*added_cb)(gpointer, const gint, edv_mime_type_struct *),
+	void (*added_cb)(const gint, edv_mime_type_struct *, gpointer),
 	gpointer added_data,
-	void (*modified_cb)(gpointer, const gint, edv_mime_type_struct *),
+	void (*modified_cb)(const gint, edv_mime_type_struct *, gpointer),
 	gpointer modified_data,
 	const gboolean mark_all_loaded_read_only
 );
@@ -227,7 +227,7 @@ void EDVMimeTypesListSystemFileOpen(
 	const gint insert_index,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
 	gpointer progress_data,
-	void (*added_cb)(gpointer, const gint, edv_mime_type_struct *),
+	void (*added_cb)(const gint, edv_mime_type_struct *, gpointer),
 	gpointer added_data,
 	const gboolean mark_all_loaded_read_only
 )
@@ -311,7 +311,7 @@ void EDVMimeTypesListSystemFileOpen(
    ));						\
 						\
    if(added_cb != NULL)				\
-    added_cb(added_data, mt_num, m);		\
+    added_cb(mt_num, m, added_data);		\
   }						\
  }						\
 }
@@ -593,9 +593,9 @@ void EDVMimeTypesListFileOpen(
 	const gboolean update, const gboolean only_newer,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
 	gpointer progress_data,
-	void (*added_cb)(gpointer, const gint, edv_mime_type_struct *),
+	void (*added_cb)(const gint, edv_mime_type_struct *, gpointer),
 	gpointer added_data,
-	void (*modified_cb)(gpointer, const gint, edv_mime_type_struct *),
+	void (*modified_cb)(const gint, edv_mime_type_struct *, gpointer),
 	gpointer modified_data,
 	const gboolean mark_all_loaded_read_only
 )
@@ -1043,7 +1043,7 @@ void EDVMimeTypesListFileOpen(
 			(*list)[mt_num] = mt;
 
 			if(modified_cb != NULL)
-			    modified_cb(modified_data, mt_num, mt);
+			    modified_cb(mt_num, mt, modified_data);
 		    }
 		    /* Add this MIME Type to the list? */
 		    else if(mt != NULL)
@@ -1104,7 +1104,7 @@ void EDVMimeTypesListFileOpen(
 
 			/* Report this MIME Type as added */
 			if(added_cb != NULL)
-			    added_cb(added_data, mt_num, mt);
+			    added_cb(mt_num, mt, added_data);
 		    }
 		}
 
