@@ -22,9 +22,9 @@ void EDVMimeTypesListMailcapImport(
 	const gboolean update, const gboolean only_newer,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
 	gpointer progress_data,
-	void (*added_cb)(gpointer, gint, edv_mime_type_struct *),
+	void (*added_cb)(const gint, edv_mime_type_struct *, gpointer),
 	gpointer added_data,
-	void (*modified_cb)(gpointer, gint, edv_mime_type_struct *),
+	void (*modified_cb)(const gint, edv_mime_type_struct *, gpointer),
 	gpointer modified_data
 );
 void EDVMimeTypesListMailcapExport(
@@ -147,9 +147,9 @@ void EDVMimeTypesListMailcapImport(
 	const gboolean update, const gboolean only_newer,
 	gint (*progress_cb)(gpointer, const gulong, const gulong),
 	gpointer progress_data,
-	void (*added_cb)(gpointer, gint, edv_mime_type_struct *),
+	void (*added_cb)(const gint, edv_mime_type_struct *, gpointer),
 	gpointer added_data,
-	void (*modified_cb)(gpointer, gint, edv_mime_type_struct *),
+	void (*modified_cb)(const gint, edv_mime_type_struct *, gpointer),
 	gpointer modified_data
 )
 {
@@ -860,12 +860,12 @@ void EDVMimeTypesListMailcapImport(
 		if(mt_exists)
 		{
 		    if(modified_cb != NULL)
-			modified_cb(modified_data, mt_num, m);
+			modified_cb(mt_num, m, modified_data);
 		}
 		else
 		{
 		    if(added_cb != NULL)
-			added_cb(added_data, mt_num, m);
+			added_cb(mt_num, m, added_data);
 		}
 
 #undef ADD_COMMAND
