@@ -598,8 +598,8 @@ static gint EDVMountBarStatsEventCB(
  */
 static void EDVMountBarMapPUListCB(GtkWidget *widget, gpointer data)
 {
+	gint dev_num, nitems, nitems_visible;
 	const gchar *value;
-	gint dev_num;
 	edv_device_struct *dev;
 	pulist_struct *pulist;
 	edv_core_struct *core;
@@ -614,14 +614,19 @@ static void EDVMountBarMapPUListCB(GtkWidget *widget, gpointer data)
 	if(PUListIsQuery(pulist))
 	    return;
 
+	nitems = PUListGetTotalItems(pulist);
+	nitems_visible = MIN(10, nitems);
+
 	/* Block input and get value */
 	value = PUListMapQuery(
-	    pulist, mb->dev_text,
-	    10,
+	    pulist,
+	    mb->dev_text,
+	    nitems_visible,
 	    PULIST_RELATIVE_BELOW,
 	    mb->dev_da,			/* Relative widget */
 	    widget			/* Map widget */
 	);
+
 	/* User canceled? */
 	if(value == NULL)
 	    return;
