@@ -2259,9 +2259,9 @@ void EDVUpdateOpenWithPUList(edv_core_struct *core)
 	    return;
 
 	/* Get the Open With popup list, create it as needed */
-	pulist = core->openwith_pulist;
+	pulist = core->open_with_pulist;
 	if(pulist == NULL)
-	    core->openwith_pulist = pulist = PUListNew();
+	    core->open_with_pulist = pulist = PUListNew();
 	if(pulist == NULL)
 	    return;
 
@@ -2323,7 +2323,7 @@ void EDVRefresh(edv_core_struct *core)
 	if(core == NULL)
 	    return;
 
-	/* Refresh device mount states and stats */
+	/* Update the Device mount states and stats */
 	EDVDevicesListUpdateMountStates(
 	    core->device, core->total_devices
 	);
@@ -2331,7 +2331,7 @@ void EDVRefresh(edv_core_struct *core)
 	    core->device, core->total_devices
 	);
 
-	/* Refresh File Browsers */
+	/* Refresh the File Browsers */
 	for(i = 0; i < core->total_browsers; i++)
 	{
 	    browser = core->browser[i];
@@ -2341,7 +2341,7 @@ void EDVRefresh(edv_core_struct *core)
 	    EDVBrowserOPRefresh(browser);
 	}
 
-	/* Refresh Image Browsers */
+	/* Refresh the Image Browsers */
 	for(i = 0; i < core->total_imbrs; i++)
 	{
 	    imbr = core->imbr[i];
@@ -2351,7 +2351,7 @@ void EDVRefresh(edv_core_struct *core)
 	    EDVImbrOPRefresh(imbr);
 	}
 
-	/* Refresh Archivers */
+	/* Refresh the Archivers */
 	for(i = 0; i < core->total_archivers; i++)
 	{
 	    archiver = core->archiver[i];
@@ -2361,7 +2361,7 @@ void EDVRefresh(edv_core_struct *core)
 	    EDVArchiverOPRefresh(archiver);
 	}
 
-	/* Refresh Recycle Bin */
+	/* Refresh the Recycle Bin */
 	recbin = core->recbin;
 	if(recbin != NULL)
 	{
@@ -2404,6 +2404,8 @@ void EDVRefresh(edv_core_struct *core)
  *	refreshes resources.
  *
  *	Any unsaved configuration in memory will be discarded.
+ *
+ *	EDVRefresh() will be automatically called at the end.
  */
 void EDVReset(edv_core_struct *core)
 {
@@ -2506,17 +2508,23 @@ void EDVReset(edv_core_struct *core)
 	    NULL, core,
 	    TRUE		/* Read only */
 	);
-	/* Update MIME Types class list index hints */
+	/* Update the MIME Types class list index hints */
 	EDVUpdateMIMETypeHintIndices(core);
 
-	/* Notify all resources about the reset and the change in
-	 * the configuration by emitting a reconfigured, write
-	 * protect changed, and refresh signal
+	/* Notify all resources about the reset
+	 *
+	 * This will cause all the windows to update their
+	 * customizable attributes based on the just reloaded
+	 * configuration
 	 */
 	EDVReconfiguredEmit(core);
+
+	/* Notify about the updated global write protect state */
 	EDVWriteProtectChangedEmit(
 	    core, EDV_GET_B(EDV_CFG_PARM_WRITE_PROTECT)
 	);
+
+	/* Refresh all the windows */
 	EDVRefresh(core);
 }
 
