@@ -1330,7 +1330,7 @@ gint EDVOpenWith(
 	    return(-1);
 
 	/* Get the Open With Popup List */
-	pulist = core->openwith_pulist;
+	pulist = core->open_with_pulist;
 	if(pulist == NULL)
 	    return(-1);
 	if(PUListIsQuery(pulist))
@@ -1339,8 +1339,8 @@ gint EDVOpenWith(
 	/* Map the Open With Popup List */
 	value = PUListMapQuery(
 	    pulist,
-	    NULL,		/* No initial value, use last value */
-	    -1,			/* Default number of visible lines */
+	    NULL,		/* Use the last value */
+	    -1,			/* Default number of items visible */
 	    PULIST_RELATIVE_DOWN,
 	    NULL,		/* No relative widget, meaning use pointer coordinates */
 	    NULL		/* No map widget */
