@@ -1009,22 +1009,8 @@ static guint EDVRecBinDeleteObjectIterate(
 #ifdef S_ISLNK
 	    if(S_ISLNK(m))
 	    {
-		gchar link_value[PATH_MAX + NAME_MAX + 1];
-		const gint bytes_read = readlink(
-		    path,
-		    link_value,
-		    PATH_MAX + NAME_MAX
-		);
-		if(bytes_read >= 0)
-		{
-		    if(bytes_read <= (PATH_MAX + NAME_MAX))
-			link_value[bytes_read] = '\0';
-		    else
-			link_value[PATH_MAX + NAME_MAX] = '\0';
-
-		    g_free(obj->link_value);
-		    obj->link_value = STRDUP(link_value);
-		}
+		g_free(obj->link_value);
+		obj->link_value = EDVGetLinkValue(path);
 	    }
 #endif
 
