@@ -1394,8 +1394,7 @@ gint EDVRecBinDiskObjectDelete(
 	/* Link? */
 	else if(S_ISLNK(in_lstat_buf.st_mode))
 	{
-	    gint bytes_read;
-	    gchar buf[PATH_MAX + NAME_MAX + 1];
+	    gchar *v;
 
 	    /* Report the initial progress */
 	    if((progress_cb != NULL) && (status == 0))
@@ -1407,20 +1406,14 @@ gint EDVRecBinDiskObjectDelete(
 		}
 	    }
 
-	    /* Read the link's destination value */
-	    bytes_read = (gint)readlink(
-		(const char *)in_path, (char *)buf, sizeof(buf)
-	    );
-	    if(bytes_read < 0)
+	    /* Get the link's destination value */
+	    v = EDVGetLinkValue(in_path);
+	    if(v == NULL)
 	    {
-		last_error = "Unable to read the link's value";
+		last_error = "Unable to get the link's destination value";
 		DO_FREE_LOCALS
-		return(-1);
+                return(-1);
 	    }
-	    if(bytes_read < sizeof(buf))
-		buf[bytes_read] = '\0';
-	    else
-		buf[sizeof(buf) - 1] = '\0';
 
 	    /* Report progress */
 	    if((progress_cb != NULL) && (status == 0))
@@ -1436,16 +1429,18 @@ gint EDVRecBinDiskObjectDelete(
 		if(out_fp == NULL)
 		{
 		    last_error = "Unable to open the recycled file for writing";
+		    g_free(v);
 		    DO_FREE_LOCALS
 		    return(-1);
 		}
 
-		/* Write the link destination */
-		if(fputs((const char *)buf, out_fp) == EOF)
+		/* Write the link's destination */
+		if(fputs((const char *)v, out_fp) == EOF)
 		{
 		    last_error =
 "An error occured while writing to the recycled file";
 		    fclose(out_fp);
+		    g_free(v);
 		    DO_FREE_LOCALS
 		    return(-1);
 		}
@@ -1454,6 +1449,9 @@ gint EDVRecBinDiskObjectDelete(
 		fclose(out_fp);
 	    }
 
+	    /* Delete the link's value */
+	    g_free(v);
+
 	    /* Report the final progress */
 	    if((progress_cb != NULL) && (status == 0))
 	    {
