@@ -45,12 +45,14 @@ guint EDVGetUMask(void);
 void EDVSetUMask(const guint m);
 gchar *EDVTmpName(const gchar *dir);
 gchar *EDVWhich(const gchar *name);
+gchar *EDVGetLinkValue(const gchar *path);
+gchar *EDVGetLinkValueFull(const gchar *path);
 gboolean EDVIsLinkInfinatelyRecursive(const gchar *path);
 
 void EDVGetDeviceNumbers(gint rdev, gint *major, gint *minor);
-gint EDVFormatDeviceNumbers(gint major, gint minor);
+gint EDVFormatDeviceNumbers(const gint major, const gint minor);
 
-gboolean EDVProcessIsRunning(gint pid);
+gboolean EDVProcessIsRunning(const gint pid);
 
 static void EDVSystemWaitCB(gint s);
 static gpointer EDVSystemAddSignal(gint signum, void (*handler)(gint));
@@ -406,7 +408,10 @@ gchar *EDVEvaluatePath(const gchar *parent, const gchar *path)
 	gchar *eval_path;
 
 	if(path == NULL)
+	{
+	    errno = EINVAL;
 	    return(NULL);
+	}
 
 	if(parent == NULL)
 #if defined(_WIN32)
@@ -491,7 +496,10 @@ gchar *EDVGetCWD(void)
 gint EDVSetCWD(const gchar *path)
 {
 	if(STRISEMPTY(path))
+	{
+	    errno = EINVAL;
 	    return(-2);
+	}
 
 	return(chdir(path));
 }
@@ -540,7 +548,10 @@ gchar *EDVTmpName(const gchar *dir)
 	    PROG_NAME "XXXXXX"
 	));
 	if(path == NULL)
+	{
+	    errno = ENOMEM;
 	    return(NULL);
+	}
 
 	/* Create tempory file and modify the template path */
 	fd = (gint)mkstemp((char *)path);
@@ -604,6 +615,102 @@ gchar *EDVWhich(const gchar *name)
 	return(matched_path);
 }
 
+/*
+ *	Gets the link's destination value.
+ *
+ *	The path specifies the full path to the link.
+ *
+ *	Returns a dynamically allocated string containing the link's
+ *	destination value or NULL on error. The global errno will be        
+ *	set if an error has occured.
+ */                  
+gchar *EDVGetLinkValue(const gchar *path)
+{
+	struct stat lstat_buf;
+	gint len, bytes_read;
+	gchar *v;
+
+	if(STRISEMPTY(path))
+	{
+	    errno = EINVAL;
+	    return(NULL);
+	}
+
+	if(lstat(path, &lstat_buf))
+	    return(NULL);
+
+#ifdef S_ISLNK
+	if(!S_ISLNK(lstat_buf.st_mode))
+#else
+	if(TRUE)
+#endif
+	{
+	    errno = EINVAL;
+	    return(NULL);
+	}
+
+	len = (gint)lstat_buf.st_size;
+	v = (gchar *)g_malloc((len + 1) * sizeof(gchar));
+	if(v == NULL)
+	{
+	    errno = ENOMEM;
+	    return(NULL);
+	}
+
+	if(len > 0)
+	{
+	    bytes_read = readlink(
+		(const char *)path,		/* Link */
+		v,				/* Value return */
+		(size_t)len			/* Value allocation */
+	    );
+	    if(bytes_read != len)
+	    {
+		g_free(v);
+		return(NULL);
+	    }
+	}
+
+	v[len] = '\0';
+
+	return(v);
+}
+
+/*
+ *	Same as EDVGetLinkValue() except that it appends the parent
+ *	of the path to the link's destination value if the link's
+ *	destination value is a relative path.
+ */
+gchar *EDVGetLinkValueFull(const gchar *path)
+{
+	gchar	*parent,
+		*full_path,
+		*v = EDVGetLinkValue(path);
+	if(v == NULL)
+	    return(NULL);
+
+	if(g_path_is_absolute(v))
+	    return(v);
+
+	parent = g_dirname(path);
+	if(parent == NULL)
+	    return(v); 
+
+	full_path = g_strconcat(
+	    parent,
+	    G_DIR_SEPARATOR_S,
+	    v,
+	    NULL
+	);
+
+	g_free(parent);
+	g_free(v);
+
+	SimplifyPath(full_path);
+
+	return(full_path);
+}
+
 /*
  *	Checks if the link specified by path has a destination that
  *	may possibly be infinately recursive.
@@ -690,7 +797,7 @@ void EDVGetDeviceNumbers(gint rdev, gint *major, gint *minor)
  *	Returns the (dev_t)rdev value (obtained from stat()) parsed
  *	from the specified device major and minor numbers.
  */
-gint EDVFormatDeviceNumbers(gint major, gint minor)
+gint EDVFormatDeviceNumbers(const gint major, const gint minor)
 {
 	return((gint)(
 	    ((dev_t)major << 8) | ((dev_t)minor << 0)
@@ -701,7 +808,7 @@ gint EDVFormatDeviceNumbers(gint major, gint minor)
 /*
  *	Checks if the process speecified by pid is still running.
  */
-gboolean EDVProcessIsRunning(gint pid)
+gboolean EDVProcessIsRunning(const gint pid)
 {
 #if defined(__linux__)
 	gchar path[PATH_MAX + NAME_MAX];
@@ -711,7 +818,10 @@ gboolean EDVProcessIsRunning(gint pid)
 	struct sched_param sp;
 
 	if(pid <= 0)
+	{
+	    errno = EINVAL;
 	    return(FALSE);
+	}
 
 	if(sched_getparam(
 	    (pid_t)pid,
