@@ -8,6 +8,7 @@
 #include "../include/disk.h"
 
 #include "guiutils.h"
+#include "pulist.h"
 
 #include "cfg.h"
 #include "edv_types.h"
@@ -207,34 +208,19 @@ void EDVFindWinSetLocation(
  */
 edv_findwin_operation EDVFindWinCurrentOperation(edv_find_win_struct *fw)
 {
-	gint i;
-	const gchar *value, *value2;
-	GList *glist;
-	GtkEntry *entry;
-	GtkCombo *combo = (GtkCombo *)((fw != NULL) ?
-	    fw->find_op_combo : NULL
-	);
-	if(combo == NULL)
+	pulist_struct *pulist;
+
+	if(fw == NULL)
 	    return(EDV_FIND_WIN_FIND_OBJECT_NAME);
 
-	entry = GTK_ENTRY(combo->entry);
-	value = gtk_entry_get_text(entry);
-	glist = GUIComboGetList(GTK_WIDGET(combo));
-	if(STRISEMPTY(value) || (glist == NULL))
-	    return(EDV_FIND_WIN_FIND_OBJECT_NAME);
+        pulist = PUListBoxGetPUList(fw->find_op_pulistbox);
+        if(pulist == NULL)
+            return(EDV_FIND_WIN_FIND_OBJECT_NAME);
 
-	i = 0;
-	while(glist != NULL)
-	{
-	    value2 = (const gchar *)glist->data;
-	    if((value2 != NULL) ? !g_strcasecmp(value2, value) : FALSE)
-		return((edv_findwin_operation)i);
-
-	    i++;
-	    glist = g_list_next(glist);
-	}
-
-	return(EDV_FIND_WIN_FIND_OBJECT_NAME);
+        return((edv_findwin_operation)PUListGetItemData(
+            pulist,
+            PUListGetSelectedLast(pulist)
+        ));
 }
 
 /*
@@ -850,7 +836,8 @@ edv_find_win_struct *EDVFindWinNew(edv_core_struct *core)
 {
 	const gint	border_major = 5,
 			border_minor = 2;
-	gint	toplevel_x = 0,
+	gint	i,
+		toplevel_x = 0,
 		toplevel_y = 0,
 		toplevel_width = EDV_DEF_FINDWIN_WIDTH,
 		toplevel_height = EDV_DEF_FINDWIN_HEIGHT;
@@ -861,12 +848,14 @@ edv_find_win_struct *EDVFindWinNew(edv_core_struct *core)
 	edv_status_bar_struct *status_bar;
 	GList *glist;
 	GtkRcStyle *standard_rcstyle, *lists_rcstyle;
-	GtkWidget *w, *parent, *parent2, *parent3, *parent4;
+	GtkWidget *w, *parent, *parent2, *parent3, *parent4, *parent5;
 	gpointer combo_rtn;
 	GtkCombo *combo;
 	GtkCList *clist;
 	GdkWindow *window;
 	GtkAccelGroup *accelgrp;
+        pulist_struct *pulist;
+        pulistbox_struct *pulistbox;
 	const cfg_item_struct *cfg_list;
 	edv_find_win_struct *fw = EDV_FIND_WIN(
 	    g_malloc0(sizeof(edv_find_win_struct))
@@ -984,45 +973,19 @@ edv_find_win_struct *EDVFindWinNew(edv_core_struct *core)
 	gtk_widget_show(w);
 	parent4 = w;
 
-	/* Hbox for search string combo and find operation combo */
+	/* GtkHBox for find operation and search string */
 	w = gtk_hbox_new(FALSE, border_minor);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
 
-	/* Create glist containing a list of find operation names,
-	 * where the enumerated value corresponds to one of
-	 * EDV_FIND_WIN_FIND_*
-	 */
-	glist = NULL;
-#if defined(PROG_LANGUAGE_SPANISH)
-	glist = g_list_append(glist, "Por Nombre de archivo");
-	glist = g_list_append(glist, "Por Contenido");
-#elif defined(PROG_LANGUAGE_FRENCH)
-	glist = g_list_append(glist, "Nom D'Objet");
-	glist = g_list_append(glist, "Contenu D'Objet");
-#elif defined(PROG_LANGUAGE_GERMAN)
-	glist = g_list_append(glist, "Wenden Sie Gegen Namen Ein");
-	glist = g_list_append(glist, "Wenden Sie Gegen Inhalt Ein");
-#elif defined(PROG_LANGUAGE_ITALIAN)
-	glist = g_list_append(glist, "Il Nome Di Oggetto");
-	glist = g_list_append(glist, "Il Contenuto Di Oggetto");
-#elif defined(PROG_LANGUAGE_DUTCH)
-	glist = g_list_append(glist, "Heb Bezwaar Naam");
-	glist = g_list_append(glist, "Heb Bezwaar Inhoud");
-#elif defined(PROG_LANGUAGE_PORTUGUESE)
-	glist = g_list_append(glist, "O Nome De Objeto");
-	glist = g_list_append(glist, "O Contedo De Objeto");
-#elif defined(PROG_LANGUAGE_NORWEGIAN)
-	glist = g_list_append(glist, "Protester Navn");
-	glist = g_list_append(glist, "Protester Innhold");
-#else
-	glist = g_list_append(glist, "Object Name");
-	glist = g_list_append(glist, "Object Content");
-#endif
+	/* GtkHBox for the find operation */
+        w = gtk_hbox_new(FALSE, border_minor);
+        gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
+        gtk_widget_show(w);
+        parent5 = w;
 
-	/* Find operation combo */
-	w = GUIComboCreate(
+        w = gtk_label_new(
 #if defined(PROG_LANGUAGE_SPANISH)
 "Buscar"
 #elif defined(PROG_LANGUAGE_FRENCH)
@@ -1040,31 +1003,59 @@ edv_find_win_struct *EDVFindWinNew(edv_core_struct *core)
 #else
 "Find"
 #endif
-	    ":",
-	    "",
-	    glist,			/* List */
-	    g_list_length(glist),	/* Items in list */
-	    &combo_rtn,
-	    fw,
-	    EDVFindWinComboActivateCB,
-	    NULL
+	    ":"
 	);
-	fw->find_op_combo = (GtkWidget *)combo_rtn;
-	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
-	gtk_widget_show(w);
+        gtk_box_pack_start(GTK_BOX(parent5), w, FALSE, FALSE, 0);
+        gtk_widget_show(w);
 
-	w = fw->find_op_combo;
-	combo = GTK_COMBO(w);
-	gtk_widget_set_usize(w, 150, -1);
-
-	g_list_free(glist);
-
-	w = combo->entry;
-	gtk_entry_set_editable(GTK_ENTRY(w), FALSE);
-	glist = GUIComboGetList(GTK_WIDGET(combo));
-	glist = g_list_nth(glist, find_op);
-	if((glist != NULL) ? (glist->data != NULL) : FALSE)
-	    gtk_entry_set_text(GTK_ENTRY(w), (gchar *)glist->data);
+        fw->find_op_pulistbox = pulistbox = PUListBoxNew(
+            parent5,
+            150, -1
+        );
+        pulist = PUListBoxGetPUList(pulistbox);
+        PUListBoxMap(pulistbox);
+#if defined(PROG_LANGUAGE_SPANISH)
+	i = PUListAddItem(pulist, "Por Nombre de archivo");
+        PUListSetItemData(pulist, i, (gpointer)EDV_FIND_WIN_FIND_OBJECT_NAME);
+	i = PUListAddItem(pulist, "Por Contenido");
+        PUListSetItemData(pulist, i, (gpointer)EDV_FIND_WIN_FIND_OBJECT_CONTENT);
+#elif defined(PROG_LANGUAGE_FRENCH)
+	i = PUListAddItem(pulist, "Nom D'Objet");
+        PUListSetItemData(pulist, i, (gpointer)EDV_FIND_WIN_FIND_OBJECT_NAME);
+	i = PUListAddItem(pulist, "Contenu D'Objet");
+        PUListSetItemData(pulist, i, (gpointer)EDV_FIND_WIN_FIND_OBJECT_CONTENT);
+#elif defined(PROG_LANGUAGE_GERMAN)
+	i = PUListAddItem(pulist, "Wenden Sie Gegen Namen Ein");
+        PUListSetItemData(pulist, i, (gpointer)EDV_FIND_WIN_FIND_OBJECT_NAME);
+	i = PUListAddItem(pulist, "Wenden Sie Gegen Inhalt Ein");
+        PUListSetItemData(pulist, i, (gpointer)EDV_FIND_WIN_FIND_OBJECT_CONTENT);
+#elif defined(PROG_LANGUAGE_ITALIAN)
+	i = PUListAddItem(pulist, "Il Nome Di Oggetto");
+        PUListSetItemData(pulist, i, (gpointer)EDV_FIND_WIN_FIND_OBJECT_NAME);
+	i = PUListAddItem(pulist, "Il Contenuto Di Oggetto");
+        PUListSetItemData(pulist, i, (gpointer)EDV_FIND_WIN_FIND_OBJECT_CONTENT);
+#elif defined(PROG_LANGUAGE_DUTCH)
+	i = PUListAddItem(pulist, "Heb Bezwaar Naam");
+        PUListSetItemData(pulist, i, (gpointer)EDV_FIND_WIN_FIND_OBJECT_NAME);
+	i = PUListAddItem(pulist, "Heb Bezwaar Inhoud");
+        PUListSetItemData(pulist, i, (gpointer)EDV_FIND_WIN_FIND_OBJECT_CONTENT);
+#elif defined(PROG_LANGUAGE_PORTUGUESE)
+	i = PUListAddItem(pulist, "O Nome De Objeto");
+        PUListSetItemData(pulist, i, (gpointer)EDV_FIND_WIN_FIND_OBJECT_NAME);
+	i = PUListAddItem(pulist, "O Contedo De Objeto");
+        PUListSetItemData(pulist, i, (gpointer)EDV_FIND_WIN_FIND_OBJECT_CONTENT);
+#elif defined(PROG_LANGUAGE_NORWEGIAN)
+	i = PUListAddItem(pulist, "Protester Navn");
+        PUListSetItemData(pulist, i, (gpointer)EDV_FIND_WIN_FIND_OBJECT_NAME);
+	i = PUListAddItem(pulist, "Protester Innhold");
+        PUListSetItemData(pulist, i, (gpointer)EDV_FIND_WIN_FIND_OBJECT_CONTENT);
+#else
+	i = PUListAddItem(pulist, "Object Name");
+        PUListSetItemData(pulist, i, (gpointer)EDV_FIND_WIN_FIND_OBJECT_NAME);
+	i = PUListAddItem(pulist, "Object Content");
+        PUListSetItemData(pulist, i, (gpointer)EDV_FIND_WIN_FIND_OBJECT_CONTENT);
+#endif
+        PUListBoxSetLinesVisible(pulistbox, i + 1);
 
 
 	/* Search string combo */
@@ -2033,31 +2024,34 @@ void EDVFindWinUpdateMenus(edv_find_win_struct *fw)
 	    sensitive = FALSE;
 	else
 	    sensitive = TRUE;
-	GTK_WIDGET_SET_SENSITIVE(fw->location_combo, sensitive)
+	GTK_WIDGET_SET_SENSITIVE(fw->location_combo, sensitive);
 
 
 	/* Update buttons */
 	sensitive = fw->processing;
-	GTK_WIDGET_SET_SENSITIVE(fw->stop_btn, sensitive)
+	GTK_WIDGET_SET_SENSITIVE(fw->stop_btn, sensitive);
 
 	sensitive = !fw->processing;
-	GTK_WIDGET_SET_SENSITIVE(fw->search_combo, sensitive)
-	GTK_WIDGET_SET_SENSITIVE(fw->case_sensitive_check, sensitive)
-	GTK_WIDGET_SET_SENSITIVE(fw->recursive_check, sensitive)
-	GTK_WIDGET_SET_SENSITIVE(fw->find_op_combo, sensitive)
-	GTK_WIDGET_SET_SENSITIVE(fw->search_btn, sensitive)
-	GTK_WIDGET_SET_SENSITIVE(fw->clear_btn, sensitive)
-	GTK_WIDGET_SET_SENSITIVE(fw->close_btn, sensitive)
+	GTK_WIDGET_SET_SENSITIVE(fw->search_combo, sensitive);
+	GTK_WIDGET_SET_SENSITIVE(fw->case_sensitive_check, sensitive);
+	GTK_WIDGET_SET_SENSITIVE(fw->recursive_check, sensitive);
+	GTK_WIDGET_SET_SENSITIVE(
+	    PUListBoxGetToplevel(fw->find_op_pulistbox),
+	    sensitive
+	);
+	GTK_WIDGET_SET_SENSITIVE(fw->search_btn, sensitive);
+	GTK_WIDGET_SET_SENSITIVE(fw->clear_btn, sensitive);
+	GTK_WIDGET_SET_SENSITIVE(fw->close_btn, sensitive);
 
 	sensitive = (!fw->processing && (sel_row > -1)) ? TRUE : FALSE;
-	GTK_WIDGET_SET_SENSITIVE(fw->open_btn, sensitive)
-	GTK_WIDGET_SET_SENSITIVE(fw->results_clist_open_mi, sensitive)
-	GTK_WIDGET_SET_SENSITIVE(fw->open_with_btn, sensitive)
-	GTK_WIDGET_SET_SENSITIVE(fw->results_clist_open_with_mi, sensitive)
+	GTK_WIDGET_SET_SENSITIVE(fw->open_btn, sensitive);
+	GTK_WIDGET_SET_SENSITIVE(fw->results_clist_open_mi, sensitive);
+	GTK_WIDGET_SET_SENSITIVE(fw->open_with_btn, sensitive);
+	GTK_WIDGET_SET_SENSITIVE(fw->results_clist_open_with_mi, sensitive);
 
 	sensitive = (!fw->processing && (sel_row > -1)) ? TRUE : FALSE;
-	GTK_WIDGET_SET_SENSITIVE(fw->goto_btn, sensitive)
-	GTK_WIDGET_SET_SENSITIVE(fw->results_clist_goto_mi, sensitive)
+	GTK_WIDGET_SET_SENSITIVE(fw->goto_btn, sensitive);
+	GTK_WIDGET_SET_SENSITIVE(fw->results_clist_goto_mi, sensitive);
 
 
 	/* Update status bar */
@@ -2166,49 +2160,29 @@ void EDVFindWinDelete(edv_find_win_struct *fw)
 	if(fw == NULL)
 	    return;
 
-	/* Delete status bar */
 	EDVStatusBarDelete(fw->status_bar);
-	fw->status_bar = NULL;
 
-	/* Destroy right-click menu */
-	GTK_WIDGET_DESTROY(fw->results_clist_menu)
-	fw->results_clist_menu = NULL;
+	GTK_WIDGET_DESTROY(fw->results_clist_menu);
 
-	GTK_WIDGET_DESTROY(fw->find_op_combo)
-	fw->find_op_combo = NULL;
-	GTK_WIDGET_DESTROY(fw->search_combo)
-	fw->search_combo = NULL;
-	GTK_WIDGET_DESTROY(fw->location_combo)
-	fw->location_combo = NULL;
-	GTK_WIDGET_DESTROY(fw->case_sensitive_check)
-	fw->case_sensitive_check = NULL;
-	GTK_WIDGET_DESTROY(fw->recursive_check)
-	fw->recursive_check = NULL;
+	PUListBoxDelete(fw->find_op_pulistbox);
+	GTK_WIDGET_DESTROY(fw->search_combo);
+	GTK_WIDGET_DESTROY(fw->location_combo);
+	GTK_WIDGET_DESTROY(fw->case_sensitive_check);
+	GTK_WIDGET_DESTROY(fw->recursive_check);
 
-	GTK_WIDGET_DESTROY(fw->search_btn)
-	fw->search_btn = NULL;
-	GTK_WIDGET_DESTROY(fw->stop_btn)
-	fw->stop_btn = NULL;
-	GTK_WIDGET_DESTROY(fw->clear_btn)
-	fw->clear_btn = NULL;
-	GTK_WIDGET_DESTROY(fw->close_btn)
-	fw->close_btn = NULL;
-	GTK_WIDGET_DESTROY(fw->results_clist)
-	fw->results_clist = NULL;
-	GTK_WIDGET_DESTROY(fw->open_btn)
-	fw->open_btn = NULL;
-	GTK_WIDGET_DESTROY(fw->open_with_btn)
-	fw->open_with_btn = NULL;
-	GTK_WIDGET_DESTROY(fw->goto_btn)
-	fw->goto_btn = NULL;
+	GTK_WIDGET_DESTROY(fw->search_btn);
+	GTK_WIDGET_DESTROY(fw->stop_btn);
+	GTK_WIDGET_DESTROY(fw->clear_btn);
+	GTK_WIDGET_DESTROY(fw->close_btn);
+	GTK_WIDGET_DESTROY(fw->results_clist);
+	GTK_WIDGET_DESTROY(fw->open_btn);
+	GTK_WIDGET_DESTROY(fw->open_with_btn);
+	GTK_WIDGET_DESTROY(fw->goto_btn);
 
-	GTK_WIDGET_DESTROY(fw->main_vbox)
-	fw->main_vbox = NULL;
-	GTK_WIDGET_DESTROY(fw->toplevel)
-	fw->toplevel = NULL;
+	GTK_WIDGET_DESTROY(fw->main_vbox);
+	GTK_WIDGET_DESTROY(fw->toplevel);
 
-	GTK_ACCEL_GROUP_UNREF(fw->accelgrp)
-	fw->accelgrp = NULL;
+	GTK_ACCEL_GROUP_UNREF(fw->accelgrp);
 
 	g_free(fw);
 }
