@@ -489,17 +489,17 @@ static void FormatManagerDoStart(
 )
 {
 	const gchar *s, *capacity_str;
-	gint capacity = 1440;
+	gulong capacity = 1440l;
 	gboolean	quick_format = FALSE,
 			verbose = FALSE;
-	const gchar	*fs_type = EDV_FS_TYPE_MSDOS_NAME,
-			*volume_label = NULL;
+	gchar *fs_type = EDV_FS_TYPE_MSDOS_NAME;
+	const gchar *volume_label = NULL;
 	GtkWidget *toplevel;
 	GtkEntry *entry;
-	GtkCombo *combo;
 	pid_t p;
 	guint toid;
 	gchar *cmd, *prog, *prog_name, *startup_message;
+	pulist_struct *pulist;
 	edv_device_struct *dev;
 
 	if(fm == NULL)
@@ -512,23 +512,22 @@ static void FormatManagerDoStart(
 	   fm->quick_format_check
 	);
 
-	combo = (GtkCombo *)fm->capacity_combo;
-	if(combo != NULL)
-	{
-	    s = gtk_entry_get_text(GTK_ENTRY(combo->entry));
-	    if(s != NULL)
-	    {
-		/* All capacity strings start with a number and
-		 * are in units of kb
-		 */
-		capacity = atoi(s);
-	    }
-	}
+	/* Get the capacity */
+	pulist = PUListBoxGetPUList(fm->capacity_pulistbox);
+	capacity = (gulong)PUListGetItemData(
+	    pulist,
+	    PUListGetSelectedLast(pulist)
+	);
 
-	combo = (GtkCombo *)fm->file_system_type_combo;
-	if(combo != NULL)
-	    fs_type = gtk_entry_get_text(GTK_ENTRY(combo->entry));
-	/* Set aliases for fs types */
+	/* Get the filesystem type */
+	pulist = PUListBoxGetPUList(fm->filesystem_type_pulistbox);
+	PUListGetItemText(
+	    pulist,
+	    PUListGetSelectedLast(pulist),
+	    &fs_type
+	);
+
+	/* Set aliases for filesystem types */
 	if(!strcmp(fs_type, EDV_FS_TYPE_VFAT_NAME))
 	    fs_type = EDV_FS_TYPE_MSDOS_NAME;
 
@@ -649,7 +648,7 @@ already running.",
 	switch(fm->format_stage)
 	{
 	  case FORMAT_STAGE_FORMAT:
-	    /* Get capacity string */
+	    /* Get the capacity string */
 	    switch(capacity)
 	    {
 	      case 1440:
