@@ -6,7 +6,7 @@
 #define FORMATCB_H
 
 #include <gtk/gtk.h>
-#include "../edvtypes.h"
+#include "../edv_types.h"
 #include "formatmanager.h"
 
 
