@@ -11,6 +11,7 @@
 #include "../../include/prochandle.h"
 
 #include "../guiutils.h"
+#include "../pulist.h"
 
 #include "../lib/endeavour2.h"
 
@@ -276,21 +277,21 @@ format_manager_struct *FormatManagerNew(edv_context_struct *ctx)
 	const gint	border_major = 5,
 			border_minor = 2;
 	gint i;
-	GList *glist;
+	gpointer entry_rtn;
 	GdkColor *c;
 	GdkColormap *colormap;
 	GtkAdjustment *adj;
 	GdkWindow *window;
 	GtkStyle *style;
-	gpointer entry_rtn, combo_rtn;
 	GtkWidget	*w, *parent, *parent2, *parent3, *parent4,
-			*parent5, *main_vbox;
+			*parent5, *parent6, *main_vbox;
 	GtkAccelGroup *accelgrp;
 	GtkEditable *editable;
 	GtkText *text;
 	GtkCList *clist;
-	GtkCombo *combo;
 	gchar *heading[4];
+	pulist_struct *pulist;
+	pulistbox_struct *pulistbox;
 	format_manager_struct *fm = FORMAT_MANAGER(
 	    g_malloc0(sizeof(format_manager_struct))
 	);
@@ -570,54 +571,51 @@ format_manager_struct *FormatManagerNew(edv_context_struct *ctx)
 	GTK_TOGGLE_BUTTON(w)->active = FALSE;
 
 
-	/* List of supported file system types */
-	glist = NULL;
-	glist = g_list_append(glist, "360 kb");
-	glist = g_list_append(glist, "720 kb");
-	glist = g_list_append(glist, "1200 kb");
-	glist = g_list_append(glist, "1440 kb");
-	/* File system type combo */
-	w = GUIComboCreate(
-#ifdef PROG_LANGUAGE_ENGLISH
-	    "Capacity:",
+	/* GtkHBox for the capacity */
+	w = gtk_hbox_new(FALSE, border_minor);
+        gtk_box_pack_start(GTK_BOX(parent5), w, FALSE, FALSE, 0);
+        gtk_widget_show(w);
+        parent6 = w;
+
+	w = gtk_label_new(
+#if defined(PROG_LANGUAGE_SPANISH)
+	    "Capacidad:"
+#elif defined(PROG_LANGUAGE_FRENCH)
+	    "Capacit:"
+#else
+	    "Capacity:"
 #endif
-#ifdef PROG_LANGUAGE_SPANISH
-	    "Capacidad:",
-#endif
-#ifdef PROG_LANGUAGE_FRENCH
-	    "Capacit:",
-#endif
-	    "",
-	    glist,
-	    4,		/* Maximum items */
-	    &combo_rtn,
-	    fm, NULL, NULL
 	);
-	fm->capacity_combo = (GtkWidget *)combo_rtn;
-	gtk_box_pack_start(GTK_BOX(parent5), w, FALSE, FALSE, 0);
-	gtk_widget_show(w);
+	gtk_box_pack_start(GTK_BOX(parent6), w, FALSE, FALSE, 0);
+        gtk_widget_show(w);
 
-	w = fm->capacity_combo;
-	combo = GTK_COMBO(w);
-	gtk_widget_set_usize(w, 80, -1);
-
-	g_list_free(glist);
-
-	w = combo->entry;
-	gtk_entry_set_editable(GTK_ENTRY(w), FALSE);
-	gtk_entry_set_text(GTK_ENTRY(w), "1440 kb");
+	fm->capacity_pulistbox = pulistbox = PUListBoxNew(
+	    parent6,
+	    80, -1
+	);
 	GUISetWidgetTip(
-	    w,
-#ifdef PROG_LANGUAGE_ENGLISH
+	    pulistbox->da,
+#if defined(PROG_LANGUAGE_SPANISH)
+""
+#elif defined(PROG_LANGUAGE_FRENCH)
+"Choisir la capacit actuelle du disque"
+#else
 "Select the actual capacity of the drive"
-#endif
-#ifdef PROG_LANGUAGE_SPANISH
-""
-#endif
-#ifdef PROG_LANGUAGE_FRENCH
-"Choisir la capacit actuelle du disque"
 #endif
 	);
+	PUListBoxMap(pulistbox);
+	pulist = PUListBoxGetPUList(pulistbox);
+	i = PUListAddItem(pulist, "360 kb");
+	PUListSetItemData(pulist, i, (gpointer)360);
+	i = PUListAddItem(pulist, "720 kb");
+	PUListSetItemData(pulist, i, (gpointer)720);
+	i = PUListAddItem(pulist, "1200 kb");
+	PUListSetItemData(pulist, i, (gpointer)1200);
+	i = PUListAddItem(pulist, "1440 kb");
+	PUListSetItemData(pulist, i, (gpointer)1440);
+	PUListBoxSelect(pulistbox, i);
+	PUListBoxSetLinesVisible(pulistbox, i + 1);
+
 
 	/* Volume label entry */
 	w = GUIPromptBar(
@@ -658,53 +656,46 @@ format_manager_struct *FormatManagerNew(edv_context_struct *ctx)
 	gtk_widget_show(w);
 	parent5 = w;
 
-	/* List of supported file system types */
-	glist = NULL;
-	glist = g_list_append(glist, EDV_FS_TYPE_MSDOS_NAME);
-	glist = g_list_append(glist, EDV_FS_TYPE_EXT2_NAME);
-	glist = g_list_append(glist, EDV_FS_TYPE_MINIX_NAME);
-	/* File system type combo */
-	w = GUIComboCreate(
-#ifdef PROG_LANGUAGE_ENGLISH
-	    "File System Type:",
+
+	/* GtkHBox for filesystem types list */
+	w = gtk_hbox_new(FALSE, border_minor);
+        gtk_box_pack_start(GTK_BOX(parent5), w, FALSE, FALSE, 0);
+        gtk_widget_show(w);
+        parent6 = w;
+
+	w = gtk_label_new(
+#if defined(PROG_LANGUAGE_SPANISH)
+	    "Archive El Tipo De Sistema:"
+#elif defined(PROG_LANGUAGE_FRENCH)
+	    "Type de Systme de fichier:"
+#else PROG_LANGUAGE_ENGLISH
+	    "File System Type:"
 #endif
-#ifdef PROG_LANGUAGE_SPANISH
-	    "Archive El Tipo De Sistema:",
-#endif
-#ifdef PROG_LANGUAGE_FRENCH
-	    "Type de Systme de fichier:",
-#endif
-	    "",
-	    glist,
-	    3,		/* Maximum items */
-	    &combo_rtn,
-	    fm, NULL, NULL
 	);
-	fm->file_system_type_combo = (GtkWidget *)combo_rtn;
-	gtk_box_pack_start(GTK_BOX(parent5), w, FALSE, FALSE, 0);
-	gtk_widget_show(w);
+	gtk_box_pack_start(GTK_BOX(parent6), w, FALSE, FALSE, 0);
+        gtk_widget_show(w);
 
-	w = fm->file_system_type_combo;
-	combo = GTK_COMBO(w);
-	gtk_widget_set_usize(w, 80, -1);
-
-	g_list_free(glist);
-
-	w = combo->entry;
-	gtk_entry_set_editable(GTK_ENTRY(w), FALSE);
-	gtk_entry_set_text(GTK_ENTRY(w), EDV_FS_TYPE_MSDOS_NAME);
-	GUISetWidgetTip(
-	    w,
-#ifdef PROG_LANGUAGE_ENGLISH
+        fm->filesystem_type_pulistbox = pulistbox = PUListBoxNew(
+            parent6,
+            80, -1  
+        );
+        GUISetWidgetTip(
+            pulistbox->da,
+#if defined(PROG_LANGUAGE_SPANISH)
+"Escoja el tipo de sistema de archivo para ser creado en los medios"
+#elif defined(PROG_LANGUAGE_FRENCH)
+"Choisir le type du systme de fichier pour ce support"
+#else
 "Select the type of file system to be created on the media"
 #endif
-#ifdef PROG_LANGUAGE_SPANISH
-"Escoja el tipo de sistema de archivo para ser creado en los medios"
-#endif
-#ifdef PROG_LANGUAGE_FRENCH
-"Choisir le type du systme de fichier pour ce support"
-#endif
-	);
+        );
+        PUListBoxMap(pulistbox);
+        pulist = PUListBoxGetPUList(pulistbox);
+	i = PUListAddItem(pulist, EDV_FS_TYPE_MSDOS_NAME);
+	PUListBoxSelect(pulistbox, i);
+	i = PUListAddItem(pulist, EDV_FS_TYPE_EXT2_NAME);
+	i = PUListAddItem(pulist, EDV_FS_TYPE_MINIX_NAME);
+	PUListBoxSetLinesVisible(pulistbox, i + 1);
 
 
 	/* Verbose */
@@ -1414,53 +1405,33 @@ void FormatManagerDelete(format_manager_struct *fm)
 	fm->devices_menu = NULL;
 
 	GTK_WIDGET_DESTROY(fm->devices_clist);
-	fm->devices_clist = NULL;
 	GTK_WIDGET_DESTROY(fm->quick_format_check);
-	fm->quick_format_check = NULL;
-	GTK_WIDGET_DESTROY(fm->capacity_combo);
-	fm->capacity_combo = NULL;
+	PUListBoxDelete(fm->capacity_pulistbox);
 	GTK_WIDGET_DESTROY(fm->volume_label_entry);
-	fm->volume_label_entry = NULL;
-	GTK_WIDGET_DESTROY(fm->file_system_type_combo);
-	fm->file_system_type_combo = NULL;
+	PUListBoxDelete(fm->filesystem_type_pulistbox);
 	GTK_WIDGET_DESTROY(fm->verbose_check);
-	fm->verbose_check = NULL;
 	GTK_WIDGET_DESTROY(fm->output_text);
-	fm->output_text = NULL;
 	GTK_WIDGET_DESTROY(fm->progress_bar);
-	fm->progress_bar = NULL;
 
 	GTK_WIDGET_DESTROY(fm->disk_anim_da);
-	fm->disk_anim_da = NULL;
 	GDK_PIXMAP_UNREF(fm->disk_anim_pm);
-	fm->disk_anim_pm = NULL;
 
 	GTK_WIDGET_DESTROY(fm->start_btn);
-	fm->start_btn = NULL;
 	GTK_WIDGET_DESTROY(fm->stop_btn);
-	fm->stop_btn = NULL;
 	GTK_WIDGET_DESTROY(fm->clear_btn);
-	fm->clear_btn = NULL;
 	GTK_WIDGET_DESTROY(fm->close_btn);
-	fm->close_btn = NULL;
 
 	GTK_WIDGET_DESTROY(fm->toplevel);
-	fm->toplevel = NULL;
 
 	GTK_ACCEL_GROUP_UNREF(fm->accelgrp);
-	fm->accelgrp = NULL;
 
 	GDK_GC_UNREF(fm->gc);
-	fm->gc = NULL;
 
 	GDK_COLORMAP_FREE_COLOR(colormap, &fm->error_color);
 	GDK_COLORMAP_UNREF(colormap);
-	fm->colormap = colormap = NULL;
 
 	GDK_CURSOR_DESTROY(fm->busy_cur);
-	fm->busy_cur = NULL;
 	GDK_CURSOR_DESTROY(fm->text_cur);
-	fm->text_cur = NULL;
 
 	GDK_FONT_UNREF(fm->text_font);
 	fm->text_font = NULL;
@@ -1468,8 +1439,6 @@ void FormatManagerDelete(format_manager_struct *fm)
 	for(i = 0; i < fm->total_devices; i++)
 	    EDVDeviceDelete(fm->device[i]);
 	g_free(fm->device);
-	fm->device = NULL;
-	fm->total_devices = 0;
 
 	g_free(fm);
 }
