@@ -6,7 +6,7 @@
 #define FSCKCB_H
 
 #include <gtk/gtk.h>
-#include "../edvtypes.h"
+#include "../edv_types.h"
 #include "fsckmanager.h"
 
 
