@@ -397,9 +397,9 @@ fsck_manager_struct *FSCKManagerNew(edv_context_struct *ctx)
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 	heading[0] = "Nom";
-	heading[1] = "Sentier D'appareil";
-	heading[2] = "Monter Le Sentier";
-	heading[3] = "Classer Le Systme";
+	heading[1] = "Composant";
+	heading[2] = "Rpertoire de montage";
+	heading[3] = "Systme de fichier";
 #endif
 	fm->devices_clist = w = gtk_clist_new_with_titles(4, heading);
 	clist = GTK_CLIST(w);
@@ -469,7 +469,7 @@ fsck_manager_struct *FSCKManagerNew(edv_context_struct *ctx)
 	    label = "Comienzo";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	    label = "Dbut";
+	    label = "Dmarrer";
 #endif
 	    accel_key = 0;
 	    accel_mods = 0;
@@ -556,8 +556,8 @@ fsck_manager_struct *FSCKManagerNew(edv_context_struct *ctx)
 tiempo que verifica)"
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	    "Le chque pour les mauvais blocs, (ceci peut augmenter \
-le temps qui vrifiant"
+	    "La vrifications des mauvais blocs augemente le temps de la vrification"
+
 #endif
 	);
 	gtk_widget_show(w);
@@ -572,7 +572,7 @@ le temps qui vrifiant"
 	    "Detallado"
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	    "Verbose"
+	    "Dtails"
 #endif
 	);
 	gtk_box_pack_start(GTK_BOX(parent5), w, FALSE, FALSE, 0);
@@ -585,7 +585,7 @@ le temps qui vrifiant"
 	    "Sea detallado"
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	    "Etre verbose"
+	    "Plus d'information sur le compte rendu"
 #endif
 	);
 	gtk_widget_show(w);
@@ -639,7 +639,7 @@ le temps qui vrifiant"
 	    "Comienzo",
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	    "Dbut",
+	    "Dmarrer",
 #endif
 	    NULL
 	);
@@ -659,7 +659,7 @@ le temps qui vrifiant"
 	    "El comienzo verificando el artefacto escogido"
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	    "Le dbut pour vrifier l'appareil choisi"
+	    "Dmarrer le programme de vrification"
 #endif
 	);
 	gtk_signal_connect(
@@ -707,7 +707,7 @@ le temps qui vrifiant"
 	    "Pare la corriente el proceso que verifica"
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	    "Arrter le courant procd qui vrifiant"
+	    "Arrter le procd de vrification en cours"
 #endif
 	);
 	gtk_signal_connect(
@@ -833,7 +833,7 @@ le temps qui vrifiant"
 	    "Claro",
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	    "Clair",
+	    "Effacer",
 #endif
 	    NULL
 	);
@@ -853,7 +853,7 @@ le temps qui vrifiant"
 	    "Los resultados claros"
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	    "Rsultats clairs"
+	    "Effacer le compte-rendu"
 #endif
 	);
 	gtk_signal_connect(
@@ -883,7 +883,7 @@ le temps qui vrifiant"
 	    "Cierre",
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
-	    "Proche",
+	    "Quitter",
 #endif
 	    NULL
 	);
