@@ -9,7 +9,7 @@
 #include "../cdialog.h"
 
 #include "../lib/endeavour2.h"
-#include "../lib/edvdevicesfio.h"
+#include "../lib/edv_devices_list.h"
 
 #include "fsckmanager.h"
 #include "fsckcb.h"
@@ -66,9 +66,8 @@ int main(int argc, char *argv[])
 	gint total_devices = 0;
 	edv_context_struct *ctx;
 
-
-	/* Set up time zone */
-	tzset();
+#define DO_FREE_LOCALS	{		\
+}
 
 	/* Set up signal callbacks */
 	signal(SIGINT, FSCKManagerSignalCB);
@@ -88,40 +87,81 @@ int main(int argc, char *argv[])
 		continue;
 
 	    /* Help */
-	    if(!strcasecmp(arg, "--help") ||
-	       !strcasecmp(arg, "-help") ||
-	       !strcasecmp(arg, "--h") ||
-	       !strcasecmp(arg, "-h") ||
-	       !strcasecmp(arg, "-?")
+	    if(!g_strcasecmp(arg, "--help") ||
+	       !g_strcasecmp(arg, "-help") ||
+	       !g_strcasecmp(arg, "--h") ||
+	       !g_strcasecmp(arg, "-h") ||
+	       !g_strcasecmp(arg, "-?")
 	    )
 	    {
 		printf("%s", PROG_HELP_MESG);
+		DO_FREE_LOCALS
 		return(0);
 	    }
 	    /* Version */
-	    else if(!strcasecmp(arg, "--version") ||
-		    !strcasecmp(arg, "-version") ||
-		    !strcasecmp(arg, "--v") ||
-		    !strcasecmp(arg, "-v")
+	    else if(!g_strcasecmp(arg, "--version") ||
+		    !g_strcasecmp(arg, "-version")
 	    )
 	    {
 		printf("%s %s\n%s", PROG_NAME, PROG_VERSION, PROG_COPYRIGHT);
+		DO_FREE_LOCALS
 		return(0);
 	    }
 	    /* Auto start */
-	    else if(!strcasecmp(arg, "--start") ||
-		    !strcasecmp(arg, "-start") ||
-		    !strcasecmp(arg, "--s") ||
-		    !strcasecmp(arg, "-s")
+	    else if(!g_strcasecmp(arg, "--start") ||
+		    !g_strcasecmp(arg, "-start") ||
+		    !strcmp(arg, "--s") ||
+		    !strcmp(arg, "-s")
 	    )
 	    {
 		auto_start = TRUE;
 	    }
-	    /* All else assume startup device */
-	    else
+	    /* Skip these arguments so that gtk_window_apply_args()
+	     * handles them
+	     */
+	    else if(gtk_is_window_arg(arg))
+	    {
+		i++;
+	    }
+	    /* Single character argument? */
+	    else if((*arg == '-') ? (arg[1] != '-') : FALSE)
+	    {
+		const gchar *v = arg + 1;
+		gchar c;
+
+		while(*v != '\0')
+		{
+		    c = *v;
+		    if(c == 's')
+		    {
+			auto_start = TRUE;
+		    }
+		    else
+		    {
+			g_printerr(
+"-%c: Unsupported argument.\n",
+			    c
+			);
+			DO_FREE_LOCALS
+			return(2);
+		    }
+		    v++;
+		}
+	    }
+	    /* Non-option argument? */
+	    else if((*arg != '-') && (*arg != '+'))
 	    {
 		startup_device = arg;
 	    }
+	    else
+	    {   
+		g_printerr(
+"%s: Unsupported argument.\n",
+		    arg        
+		);
+		DO_FREE_LOCALS
+		return(2);
+	    }
 	}
 
 
@@ -132,6 +172,7 @@ int main(int argc, char *argv[])
 	    if(!gtk_init_check(&argc, &argv))
 	    {
 		g_printerr("Unable to initialize GTK.\n");
+		DO_FREE_LOCALS
 		return(1);
 	    }
 	    initialized_gtk = TRUE;
@@ -151,11 +192,11 @@ int main(int argc, char *argv[])
 
 	/* Load devices */
 	devices_ini_file = STRDUP(EDVGetS(ctx, EDV_CFG_PARM_FILE_DEVICES));
-	device = EDVDevicesListLoadFromFile(devices_ini_file, &total_devices);
+	device = EDVDevicesListFileOpen(devices_ini_file, &total_devices);
 
-        /* Update device mount states and stats */
-        EDVDevicesListUpdateMountStates(device, total_devices);
-        EDVDevicesListUpdateStats(device, total_devices);
+	/* Update device mount states and stats */
+	EDVDevicesListUpdateMountStates(device, total_devices);
+	EDVDevicesListUpdateStats(device, total_devices);
 
 	/* Check if no devices have been loaded, suggesting that
 	 * either no device references exist in the devices.ini or
@@ -287,8 +328,11 @@ program again.",
 	/* Shutdown dialogs */
 	CDialogShutdown();
 
-        /* Reset the DND Icon */
-        GUIDNDSetDragIcon(NULL, NULL, 0, 0);
+	/* Reset the DND Icon */
+	GUIDNDSetDragIcon(NULL, NULL, 0, 0);
+
+	DO_FREE_LOCALS
 
 	return(0);
+#undef DO_FREE_LOCALS
 }
