@@ -1,14 +1,21 @@
 #ifdef HAVE_LIBGIF
+/* This version of the gif module is taken from IV, please update the
+ * IV version and then copy it to here instead of updating this
+ * one
+ */
 #include <stdlib.h>
 #include <string.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 #include <gif_lib.h>
+
 #include "rgba_to_cidx.h"
 #include "gif.h"
 
 
 /* Last error message pointer */
-static const char *imgio_last_open_error;
-static const char *imgio_last_save_error;
+const char *imgio_last_load_error;
+const char *imgio_last_write_error;
 
 
 /*
@@ -33,6 +40,7 @@ typedef struct {
 /* GIF Library Version */
 void ImgGIFVersion(int *major, int *minor, int *release); 
 
+mode_t ImgGIFGetFileMode(const char *filename);
 
 /* GIF Reading */
 int ImgGIFReadRGBA(
@@ -209,6 +217,37 @@ void ImgGIFVersion(int *major, int *minor, int *release)
 }
 
 
+/*
+ *	Returns the permissions of the specified file.
+ *
+ *	If the file does not exist then the default permissions are
+ *	returned.
+ *
+ *	This is needed for the GIF write functions since they do not
+ *	set the file permissions on a newly created file.
+ */
+mode_t ImgGIFGetFileMode(const char *filename)
+{
+	struct stat stat_buf;
+
+	if(stat(filename, &stat_buf))
+	{
+	    const mode_t m = umask(0);
+	    umask(m);
+	    return(
+		(~m) &
+		    (S_IRUSR | S_IWUSR |
+		     S_IRGRP | S_IWGRP |
+		     S_IROTH | S_IWOTH)
+	    );
+	}
+	else
+	{
+	    return(stat_buf.st_mode);
+	}
+}
+
+
 /*
  *	Reads the GIF file.
  *
@@ -255,12 +294,12 @@ int ImgGIFReadRGBA(
 	GifRecordType rt;
 
 	/* Reset last load error */
-	imgio_last_open_error = NULL;
+	imgio_last_load_error = NULL;
 
 	/* Skip if user aborted */
 	if(*user_aborted)
 	{
-	    imgio_last_open_error = "User aborted operation";
+	    imgio_last_load_error = "User aborted operation";
 	    return(-4);
 	}
 
@@ -268,7 +307,7 @@ int ImgGIFReadRGBA(
 	ft = DGifOpenFileName(filename);
 	if(ft == NULL)
 	{
-	    imgio_last_open_error = "Unable to open the file for reading";
+	    imgio_last_load_error = "Unable to open the file for reading";
 	    return(-1);
 	}
 
@@ -306,7 +345,7 @@ printf(
 	if(scr_buf == NULL)
 	{
 	    DGifCloseFile(ft);
-	    imgio_last_open_error = "Memory allocation error";
+	    imgio_last_load_error = "Memory allocation error";
 	    return(-3);
 	}
 
@@ -709,7 +748,7 @@ printf(
 
 	if(*user_aborted)
 	{
-	    imgio_last_open_error = "User aborted operation";
+	    imgio_last_load_error = "User aborted operation";
 	    return(-4);
 	}
 	else
@@ -820,7 +859,7 @@ static int ImgGIFDitherRGBA(
 	{
 	    free(cidx);
 	    free(colors_list);
-	    imgio_last_save_error = "User aborted operation";
+	    imgio_last_write_error = "User aborted operation";
 	    return(-4);
 	}
 
@@ -829,7 +868,7 @@ static int ImgGIFDitherRGBA(
 	if(data == NULL)
 	{
 	    free(colors_list);
-	    imgio_last_save_error =
+	    imgio_last_write_error =
 		"Unable to generate color index image";
 	    return(-1);
 	}
@@ -838,7 +877,7 @@ static int ImgGIFDitherRGBA(
 	if(colors_list == NULL)
 	{
 	    free(data);
-	    imgio_last_save_error =
+	    imgio_last_write_error =
 		"Unable to generate color palette";
 	    return(-1);
 	}
@@ -855,7 +894,7 @@ static int ImgGIFDitherRGBA(
 	    if(colors_list == NULL)
 	    {
 		free(data);
-		imgio_last_save_error = "Memory allocation error";
+		imgio_last_write_error = "Memory allocation error";
 		return(-3);
 	    }
 	    c = &colors_list[i];
@@ -885,7 +924,7 @@ static int ImgGIFDitherRGBA(
 	    );
 	    if(colors_list == NULL)
 	    {
-		imgio_last_save_error = "Memory allocation error";
+		imgio_last_write_error = "Memory allocation error";
 		return(-3);
 	    }
 	    c = &colors_list[i];
@@ -900,7 +939,7 @@ static int ImgGIFDitherRGBA(
 	{
 	    const int	cidx_bpp = sizeof(GifByteType),
 			cidx_bpl = width * cidx_bpp;
-	    const GifByteType	v = (GifByteType)*trans_color_num;
+	    const GifByteType v = (GifByteType)(*trans_color_num);
 	    int y;
 	    const u_int8_t alpha_threshold = 0x80;
 	    const u_int8_t *rgba_ptr, *rgba_end;
@@ -940,7 +979,7 @@ static int ImgGIFDitherRGBA(
 	{
 	    free(data);
 	    free(colors_list);
-	    imgio_last_save_error = "Memory allocation error";
+	    imgio_last_write_error = "Memory allocation error";
 	    return(-3);
 	}
 
@@ -996,6 +1035,7 @@ static int ImgWriteGIFFileRGBAToColor(
 	char user_input = 0;
 	unsigned long delay;
 	u_int8_t *rgba_cur;
+	const mode_t mode = ImgGIFGetFileMode(filename);
 	ColorMapObject *colormap = NULL;
 	GifByteType *cidx = NULL;
 	GifFileType *ft;
@@ -1004,7 +1044,7 @@ static int ImgWriteGIFFileRGBAToColor(
 	ft = EGifOpenFileName(filename, 0);
 	if(ft == NULL)
 	{
-	    imgio_last_save_error = "Unable to open the file for writing";
+	    imgio_last_write_error = "Unable to open the file for writing";
 	    return(-1);
 	}
 
@@ -1077,7 +1117,7 @@ static int ImgWriteGIFFileRGBAToColor(
 				user_input_flag = (1 << 1),
 				disposal_method_mask = (1 << 0) |
 				    (1 << 1) | (1 << 2);
-	        u_int8_t buf[] = {
+		const u_int8_t buf[] = {
 		    /* Flags */
 		    (transparency ? transparency_flag : 0) |
 		    (user_input ? user_input_flag : 0) |
@@ -1108,7 +1148,7 @@ static int ImgWriteGIFFileRGBAToColor(
 	    /* Delete the GIF colormap */
 	    FreeMapObject(colormap);
 
-	    /* Write image data */
+	    /* Write the image data for this frame */
 	    if(interlaced)
 	    {
 		const int	po = height,
@@ -1196,9 +1236,12 @@ static int ImgWriteGIFFileRGBAToColor(
 	/* Close the GIF file */
 	EGifCloseFile(ft);
 
+	/* Set/restore the file permissions */
+	chmod(filename, mode);
+
 	if(*user_aborted)
 	{
-	    imgio_last_save_error = "User aborted operation";
+	    imgio_last_write_error = "User aborted operation";
 	    return(-4);
 	}
 	else
@@ -1231,12 +1274,13 @@ static int ImgWriteGIFFileRGBAToGreyscale(
 {
 	int	frame_num, disposal_method,
 		color_resolution = 8,
-		colormap_ncolors_set = 256,
+		colormap_ncolors_set = 256,	/* Must be 256 or else fails */
 		bg_color_num = 0,
 		trans_color_num = -1;
 	char user_input = 0;
 	unsigned long delay;
 	u_int8_t *rgba_cur;
+	const mode_t mode = ImgGIFGetFileMode(filename);
 	ColorMapObject *colormap;
 	GifByteType *cidx;
 	GifFileType *ft;
@@ -1291,7 +1335,7 @@ static int ImgWriteGIFFileRGBAToGreyscale(
 	if(cidx == NULL)
 	{
 	    FreeMapObject(colormap);
-	    imgio_last_save_error = "Memory allocation error";
+	    imgio_last_write_error = "Memory allocation error";
 	    return(-3);
 	}
 
@@ -1301,7 +1345,7 @@ static int ImgWriteGIFFileRGBAToGreyscale(
 	{
 	    FreeMapObject(colormap);
 	    free(cidx);
-	    imgio_last_save_error = "Unable to open the file for writing";
+	    imgio_last_write_error = "Unable to open the file for writing";
 	    return(-1);
 	}
 	 
@@ -1481,16 +1525,19 @@ static int ImgWriteGIFFileRGBAToGreyscale(
 	    }
 	}
 
-	/* Write comments */ 
+	/* Write the comments */
 	if(!STRISEMPTY(comments) && !(*user_aborted))
 	    EGifPutExtension(
 		ft, COMMENT_EXT_FUNC_CODE,
 		STRLEN(comments) + 1, comments
 	    );
 
-	/* Close GIF file */ 
+	/* Close the GIF file */ 
 	EGifCloseFile(ft);
 
+	/* Set/restore file permissions */
+	chmod(filename, mode);
+
 	/* Delete the GIF colormap */
 	FreeMapObject(colormap);
 
@@ -1499,7 +1546,7 @@ static int ImgWriteGIFFileRGBAToGreyscale(
 
 	if(*user_aborted)
 	{
-	    imgio_last_save_error = "User aborted operation";
+	    imgio_last_write_error = "User aborted operation";
 	    return(-4);
 	}
 	else
@@ -1532,12 +1579,13 @@ static int ImgWriteGIFFileRGBAToBW(
 {
 	int	frame_num, disposal_method,
 		color_resolution = 8,
-		colormap_ncolors_set = 256,
+		colormap_ncolors_set = 256,	/* Must be 256 or else fails */
 		bg_color_num = 0,
 		trans_color_num = -1;
 	char user_input = 0;
 	unsigned long delay;
 	u_int8_t *rgba_cur;
+	const mode_t mode = ImgGIFGetFileMode(filename);
 	ColorMapObject *colormap;
 	GifByteType *cidx;
 	GifFileType *ft;
@@ -1572,7 +1620,7 @@ static int ImgWriteGIFFileRGBAToBW(
 		    c->Red = c->Green = c->Blue = (GifByteType)0xff;
 		}
 
-		/* Set color 2 to (transparent) to white */
+		/* Set color 2 (transparent) to black */
 		trans_color_num = i = 2;
 		if(i < m)
 		{
@@ -1580,8 +1628,8 @@ static int ImgWriteGIFFileRGBAToBW(
 		    c->Red = c->Green = c->Blue = (GifByteType)0x00;
 		}
 
-		/* Set rest of colors to black */
-		for(i = 3; i < m; i++)
+		/* Set the rest of the colors to black */
+		for(i++; i < m; i++)
 		{
 		    c = &colormap->Colors[i];
 		    c->Red = c->Green = c->Blue = (GifByteType)0x00;
@@ -1589,11 +1637,6 @@ static int ImgWriteGIFFileRGBAToBW(
 	    }
 	    else
 	    {
-		/* Generate 3 colors; black, white, and the rest
-		 * are black (including color 255 for the transparent
-		 * pixel)
-		 */
-		   
 		/* Set color 0 to black */
 		int i = 0, m = colormap->ColorCount;
 		GifColorType *c = &colormap->Colors[i];
@@ -1607,8 +1650,8 @@ static int ImgWriteGIFFileRGBAToBW(
 		    c->Red = c->Green = c->Blue = (GifByteType)0xff;
 		}
 
-		/* Set rest of colors to black */
-		for(i = 2; i < m; i++)
+		/* Set the rest of the colors to black */
+		for(i++; i < m; i++)
 		{
 		    c = &colormap->Colors[i];
 		    c->Red = c->Green = c->Blue = (GifByteType)0x00;
@@ -1623,7 +1666,7 @@ static int ImgWriteGIFFileRGBAToBW(
 	if(cidx == NULL)
 	{
 	    FreeMapObject(colormap);
-	    imgio_last_save_error = "Memory allocation error";
+	    imgio_last_write_error = "Memory allocation error";
 	    return(-3);
 	}
 
@@ -1633,7 +1676,7 @@ static int ImgWriteGIFFileRGBAToBW(
 	{
 	    FreeMapObject(colormap);
 	    free(cidx);
-	    imgio_last_save_error = "Unable to open the file for writing";
+	    imgio_last_write_error = "Unable to open the file for writing";
 	    return(-1);
 	}
 
@@ -1821,9 +1864,12 @@ static int ImgWriteGIFFileRGBAToBW(
 		STRLEN(comments) + 1, comments
 	    );
 
-	/* Close GIF file */
+	/* Close the GIF file */
 	EGifCloseFile(ft);
 
+	/* Set/restore file permissions */
+	chmod(filename, mode);
+
 	/* Delete the GIF colormap */
 	FreeMapObject(colormap);
 
@@ -1832,7 +1878,7 @@ static int ImgWriteGIFFileRGBAToBW(
 
 	if(*user_aborted)
 	{
-	    imgio_last_save_error = "User aborted operation";
+	    imgio_last_write_error = "User aborted operation";
 	    return(-4);
 	}
 	else
@@ -1877,14 +1923,14 @@ int ImgWriteGIFFileRGBA(
 	int user_aborted = 0;
 
 	/* Reset global last write error message pointer */
-	imgio_last_save_error = NULL;
+	imgio_last_write_error = NULL;
 
 	if(STRISEMPTY(filename) || (rgba == NULL) || (nframes <= 0) ||
 	   (width <= 0) || (height <= 0) ||
 	   (bpp != 4)
 	)
 	{
-	    imgio_last_save_error = "Invalid value used to describe image";
+	    imgio_last_write_error = "Invalid value used to describe image";
 	    return(-2);
 	}
 
@@ -1948,7 +1994,7 @@ int ImgWriteGIFFileRGBA(
 	    break;
 
 	  default:
-	    imgio_last_save_error = "Unsupported GIF color format";
+	    imgio_last_write_error = "Unsupported GIF color format";
 	    status = -2;
 	    break;
 	}
@@ -1968,11 +2014,11 @@ int ImgWriteGIFFileRGBA(
 
 	if(user_aborted)
 	{
-	    imgio_last_save_error = "User aborted operation";
+	    imgio_last_write_error = "User aborted operation";
 	    return(-4);
 	}
 	else
 	    return(status);
 }
 
-#endif
+#endif	/* HAVE_LIBGIF */
