@@ -1,8 +1,7 @@
 #include <gtk/gtk.h>
 
-#if defined(WIN32)
+#if defined(_WIN32)
 # include <gdk/gdkwin32.h>
-# define HAVE_WIN32
 #else
 # include <gdk/gdkx.h>
 # define HAVE_X
@@ -55,7 +54,7 @@ gboolean gdk_video_mode_is_supported(void)
 	 */
 	if(gui_vidmode_supported < 0)
 	{
-#if defined(HAVE_WIN32)
+#if defined(_WIN32)
 	    gui_vidmode_supported = 1;
 #elif defined(HAVE_X) && defined(HAVE_XF86_VIDMODE)
 	    Display *dpy = GDK_DISPLAY();
@@ -107,7 +106,7 @@ void gdk_video_mode_delete(GdkVideoModeInfo *m)
  */
 GList *gdk_video_modes_get(void)
 {
-#if defined(HAVE_WIN32)
+#if defined(_WIN32)
 	int i;
 	gboolean is_dup;
 	DWORD dwFields;
@@ -275,7 +274,7 @@ void gdk_video_modes_delete(GList *glist)
  */
 GdkVideoModeInfo *gdk_video_mode_get_current(GList *glist)
 {
-#if defined(HAVE_WIN32)
+#if defined(_WIN32)
 	DWORD dwFields;
 	DEVMODE dmSettings;
 	static GdkVideoModeInfo mode_info;
