@@ -15,6 +15,7 @@
 #include "../pdialog.h"
 #include "../lib/endeavour2.h"
 #include "../hview.h"
+#include "ascii_chart_dlg.h"
 #include "config.h"
 
 #include "../images/icon_edit_48x48.xpm"
@@ -22,13 +23,14 @@
 #include "../images/icon_open_20x20.xpm"
 #include "../images/icon_save_20x20.xpm"
 #include "../images/icon_save_as_20x20.xpm"
-#include "../images/icon_exit_20x20.xpm"
+#include "../images/icon_close_20x20.xpm"
 #include "../images/icon_cut_20x20.xpm"
 #include "../images/icon_copy_20x20.xpm"
 #include "../images/icon_paste_20x20.xpm"
 #include "../images/icon_add_20x20.xpm"
 #include "../images/icon_cancel_20x20.xpm"
 #include "../images/icon_search_20x20.xpm"
+#include "../images/icon_calculator_20x20.xpm"
 #include "../images/icon_about_20x20.xpm"
 
 
@@ -39,13 +41,19 @@ typedef struct {
 
 	GtkWidget	*toplevel;
 	GtkAccelGroup	*accelgrp;
+	gint		freeze_count;
 
 	GtkWidget	*main_vbox,
 			*menu_bar_handle,
 			*cut_mi,
 			*copy_mi,
 			*delete_mi,
-			*edit_mode;
+			*edit_mode_hex_mi,
+			*edit_mode_ascii_mi,
+			*select_all_mi,
+			*unselect_all_mi,
+			*find_mi,
+			*find_next_mi;
 
 	hview_struct	*hv;
 
@@ -54,6 +62,8 @@ typedef struct {
 	guint8		*last_find_needle;
 	gint		last_find_needle_len;
 
+	ascii_chart_dlg_struct	*ac_dlg;
+
 	edv_context_struct *ctx;
 
 } hedit_struct;
@@ -61,7 +71,14 @@ typedef struct {
 
 
 static void HViewSignalCB(int s);
+static gint HEditCloseCB(GtkWidget *widget, GdkEvent *event, gpointer data);
 static void HEditHViewChangedCB(hview_struct *hv, gpointer data);
+static void HEditHViewSelectCB(
+	hview_struct *hv, int start_pos, int end_pos, gpointer data
+);
+static void HEditHViewEditModeChangedCB(
+	hview_struct *hv, hview_edit_mode edit_mode, gpointer data
+);
 static void HEditDNDDragReceivedCB(
 	GtkWidget *widget, GdkDragContext *dc, gint x, gint y,
 	GtkSelectionData *selection_data, guint info, guint t,
@@ -77,12 +94,23 @@ static void HEditCopyCB(GtkWidget *widget, gpointer data);
 static void HEditPasteCB(GtkWidget *widget, gpointer data);
 static void HEditInsertCB(GtkWidget *widget, gpointer data);
 static void HEditDeleteCB(GtkWidget *widget, gpointer data);
+static void HEditSelectAllCB(GtkWidget *widget, gpointer data);
+static void HEditUnselectAllCB(GtkWidget *widget, gpointer data);
 static void HEditFindCB(GtkWidget *widget, gpointer data);
 static void HEditFindNextCB(GtkWidget *widget, gpointer data);
-static void HEditEditModeCB(GtkWidget *widget, gpointer data);
+static void HEditEditModeHexCB(GtkWidget *widget, gpointer data);
+static void HEditEditModeASCIICB(GtkWidget *widget, gpointer data);
 static void HEditCalculateSelectedCB(GtkWidget *widget, gpointer data);
+static void HEditASCIIChartCB(GtkWidget *widget, gpointer data);
 static void HEditAboutCB(GtkWidget *widget, gpointer data);
 
+static gint HEditHViewOpenProgressCB(
+	hview_struct *hview, gulong i, gulong m, gpointer data
+);
+static gint HEditHViewSaveProgressCB(
+	hview_struct *hview, gulong i, gulong m, gpointer data
+);
+
 static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent);
 static void HEditUpdate(hedit_struct *he);
 
@@ -184,6 +212,43 @@ static void HEditHViewChangedCB(hview_struct *hv, gpointer data)
 	if(he == NULL)
 	    return;
 
+	if(he->freeze_count > 0)
+	    return;
+
+	HEditUpdate(he);
+}
+
+/*
+ *	Hex View select callback.
+ */
+static void HEditHViewSelectCB(
+	hview_struct *hv, int start_pos, int end_pos, gpointer data
+)
+{
+	hedit_struct *he = HEDIT(data);
+	if(he == NULL)
+	    return;
+
+	if(he->freeze_count > 0)
+	    return;
+
+	HEditUpdate(he);
+}
+
+/*
+ *	Hex View edit mode changed callback.
+ */
+static void HEditHViewEditModeChangedCB(
+	hview_struct *hv, hview_edit_mode edit_mode, gpointer data  
+)
+{
+	hedit_struct *he = HEDIT(data); 
+	if(he == NULL)
+	    return;
+
+	if(he->freeze_count > 0)
+	    return;
+
 	HEditUpdate(he);
 }
 
@@ -248,7 +313,10 @@ static void HEditDNDDragReceivedCB(
 		{
 		    g_free(he->filename);
 		    he->filename = STRDUP(path);
-		    HViewOpenFile(hv, he->filename);
+		    HViewOpenFileProgress(
+			hv, he->filename,
+			HEditHViewOpenProgressCB, he
+		    );
 
 		    g_free(path);
 		}
@@ -270,6 +338,9 @@ static void HEditNewCB(GtkWidget *widget, gpointer data)
 	if(he == NULL)
 	    return;
 
+	if(he->freeze_count > 0)
+	    return;
+
 	toplevel = he->toplevel;
 	hv = he->hv;
 	if(hv == NULL)
@@ -306,6 +377,9 @@ static void HEditOpenCB(GtkWidget *widget, gpointer data)
 	if((he == NULL) || FileBrowserIsQuery())
 	    return;
 
+	if(he->freeze_count > 0)
+	    return;
+
 	toplevel = he->toplevel;
 	hv = he->hv;
 	if(hv == NULL)
@@ -326,7 +400,7 @@ static void HEditOpenCB(GtkWidget *widget, gpointer data)
 	status = FileBrowserGetResponse(
 	    "Open File",
 	    "Open", "Cancel",
-	    NULL,		/* Use last path */
+	    NULL,
 	    ftype, total_ftypes,
 	    &path_rtn, &total_path_rtns,
 	    &ftype_rtn
@@ -341,10 +415,13 @@ static void HEditOpenCB(GtkWidget *widget, gpointer data)
 
 	    g_free(he->filename);
 	    he->filename = STRDUP(new_path);
-	    HViewOpenFile(hv, he->filename);
+	    HViewOpenFileProgress(
+		hv, he->filename,
+		HEditHViewOpenProgressCB, he
+	    );
 	}
 
-	/* Delete file types list */
+	/* Delete the file types list */
 	FileBrowserDeleteTypeList(ftype, total_ftypes);
 
 	HEditUpdate(he);
@@ -362,6 +439,9 @@ static void HEditSaveCB(GtkWidget *widget, gpointer data)
 	if(he == NULL)
 	    return;
 
+	if(he->freeze_count > 0)
+	    return;
+
 	toplevel = he->toplevel;
 	hv = he->hv;
 	if(hv == NULL)
@@ -378,12 +458,15 @@ static void HEditSaveCB(GtkWidget *widget, gpointer data)
 
 	HViewSetBusy(hv, TRUE);
 
-	/* Save data to file */
-	if(HViewSaveFile(hv, he->filename))
+	/* Save the data to file */
+	if(HViewSaveFileProgress(
+	    hv, he->filename,
+	    HEditHViewSaveProgressCB, he
+	))
 	{
 	    /* Error occured while saving file */
 	    gchar *buf = g_strdup_printf(
-"Error occured while saving file:\n\n    %s\n",
+"An error occured while saving the file:\n\n    %s",
 		he->filename
 	    );
 	    EDVPlaySoundError(he->ctx);
@@ -432,6 +515,9 @@ static void HEditSaveAsCB(GtkWidget *widget, gpointer data)
 	if((he == NULL) || FileBrowserIsQuery())
 	    return;
 
+	if(he->freeze_count > 0)
+	    return;
+
 	toplevel = he->toplevel;
 	hv = he->hv;
 	if(hv == NULL)
@@ -450,7 +536,7 @@ static void HEditSaveAsCB(GtkWidget *widget, gpointer data)
 	status = FileBrowserGetResponse(
 	    "Save File As",
 	    "Save", "Cancel",
-	    NULL,               /* Use last path */
+	    NULL,
 	    ftype, total_ftypes,
 	    &path_rtn, &total_path_rtns,
 	    &ftype_rtn
@@ -509,11 +595,14 @@ static void HEditSaveAsCB(GtkWidget *widget, gpointer data)
 		    he->filename = STRDUP(new_path);
 
 		    /* Save data to new file name */
-		    if(HViewSaveFile(hv, he->filename))
+		    if(HViewSaveFileProgress(
+			hv, he->filename,
+			HEditHViewSaveProgressCB, he
+		    ))
 		    {
 			/* Error occured while saving file */
 			gchar *buf = g_strdup_printf(
-"Error occured while saving file:\n\n    %s\n",
+"An error occured while saving the file:\n\n    %s",
 			    he->filename
 			);
 			EDVPlaySoundError(he->ctx);
@@ -571,6 +660,9 @@ static void HEditExitCB(GtkWidget *widget, gpointer data)
 	if(he == NULL)
 	    return;
 
+	if(he->freeze_count > 0)
+	    return;
+
 	toplevel = he->toplevel;
 	hv = he->hv;
 	if(hv == NULL)
@@ -590,6 +682,9 @@ static void HEditCutCB(GtkWidget *widget, gpointer data)
 	if(he == NULL)
 	    return;
 
+	if(he->freeze_count > 0)
+	    return;
+
 	HViewCut(he->hv);
 }
 
@@ -602,6 +697,9 @@ static void HEditCopyCB(GtkWidget *widget, gpointer data)
 	if(he == NULL)
 	    return;
 
+	if(he->freeze_count > 0)
+	    return;
+
 	HViewCopy(he->hv);
 }
 
@@ -614,6 +712,9 @@ static void HEditPasteCB(GtkWidget *widget, gpointer data)
 	if(he == NULL)
 	    return;
 
+	if(he->freeze_count > 0)
+	    return;
+
 	HViewPaste(he->hv);
 }
 
@@ -626,6 +727,9 @@ static void HEditInsertCB(GtkWidget *widget, gpointer data)
 	if(he == NULL)
 	    return;
 
+	if(he->freeze_count > 0)
+	    return;
+
 	HViewInsert(he->hv);
 }
 
@@ -638,9 +742,42 @@ static void HEditDeleteCB(GtkWidget *widget, gpointer data)
 	if(he == NULL)
 	    return;
 
+	if(he->freeze_count > 0)
+	    return;
+
 	HViewDeleteSelected(he->hv);
 }
 
+/*
+ *	Select All callback.
+ */
+static void HEditSelectAllCB(GtkWidget *widget, gpointer data)
+{
+	hedit_struct *he = HEDIT(data);
+	if(he == NULL)
+	    return;
+
+	if(he->freeze_count > 0)
+	    return;
+
+	HViewSelectAll(he->hv);
+}
+
+/*
+ *	Unselect All callback.
+ */
+static void HEditUnselectAllCB(GtkWidget *widget, gpointer data)
+{
+	hedit_struct *he = HEDIT(data);
+	if(he == NULL)
+	    return;
+
+	if(he->freeze_count > 0)
+	    return;
+
+	HViewUnselectAll(he->hv);
+}
+
 /*
  *	Find callback.
  */
@@ -654,6 +791,9 @@ static void HEditFindCB(GtkWidget *widget, gpointer data)
 	if((he == NULL) || PDialogIsQuery())
 	    return;
 
+	if(he->freeze_count > 0)
+	    return;
+
 	toplevel = he->toplevel;
 	hv = he->hv;
 	if(hv == NULL)
@@ -681,7 +821,7 @@ static void HEditFindCB(GtkWidget *widget, gpointer data)
 	PDialogSetSize(320, -1);
 	PDialogSetTransientFor(toplevel);
 	strv = PDialogGetResponse(
-	    "Find:", NULL, NULL,
+	    "Find", NULL, NULL,
 	    PDIALOG_ICON_SEARCH,
 	    "Find", "Cancel",
 	    PDIALOG_BTNFLAG_SUBMIT | PDIALOG_BTNFLAG_CANCEL,
@@ -771,6 +911,9 @@ static void HEditFindNextCB(GtkWidget *widget, gpointer data)
 	if(he == NULL)
 	    return;
 
+	if(he->freeze_count > 0)
+	    return;
+
 	toplevel = he->toplevel;
 	hv = he->hv;
 	if(hv == NULL)
@@ -840,9 +983,9 @@ static void HEditFindNextCB(GtkWidget *widget, gpointer data)
 }
 
 /*
- *	Change edit mode callback.
+ *	Edit mode hex callback.
  */
-static void HEditEditModeCB(GtkWidget *widget, gpointer data)
+static void HEditEditModeHexCB(GtkWidget *widget, gpointer data)
 {
 	GtkWidget *toplevel;
 	hview_struct *hv;
@@ -850,17 +993,37 @@ static void HEditEditModeCB(GtkWidget *widget, gpointer data)
 	if(he == NULL)
 	    return;
 
+	if(he->freeze_count > 0)
+	    return;
+
 	toplevel = he->toplevel;
 	hv = he->hv;
 	if(hv == NULL)
 	    return;
 
-	if(hv->edit_mode == HVIEW_EDIT_MODE_HEX)
-	    HViewSetEditMode(hv, HVIEW_EDIT_MODE_ASCII);
-	else
-	    HViewSetEditMode(hv, HVIEW_EDIT_MODE_HEX);
+	HViewSetEditMode(hv, HVIEW_EDIT_MODE_HEX);
+}
 
-	HEditUpdate(he);
+/*
+ *	Edit mode ASCII callback.
+ */
+static void HEditEditModeASCIICB(GtkWidget *widget, gpointer data)
+{
+	GtkWidget *toplevel;
+	hview_struct *hv;
+	hedit_struct *he = HEDIT(data);
+	if(he == NULL)
+	    return;
+
+	if(he->freeze_count > 0)
+	    return;
+
+	toplevel = he->toplevel;
+	hv = he->hv;
+	if(hv == NULL)
+	    return;
+
+	HViewSetEditMode(hv, HVIEW_EDIT_MODE_ASCII);
 }
 
 /*
@@ -1023,6 +1186,21 @@ Swapped Values:\n\
 	HEditUpdate(he);
 }
 
+/*
+ *	ASCII Chart callback.
+ */
+static void HEditASCIIChartCB(GtkWidget *widget, gpointer data)
+{
+	hedit_struct *he = HEDIT(data);
+	if(he == NULL)
+	    return;
+
+	if(he->ac_dlg == NULL)
+	    he->ac_dlg = ASCIIChartDlgNew(he->toplevel);
+
+	ASCIIChartDlgMap(he->ac_dlg);
+}
+
 /*
  *	About callback.
  */
@@ -1037,6 +1215,37 @@ static void HEditAboutCB(GtkWidget *widget, gpointer data)
 }
 
 
+/*
+ *	HView open file progress callback.
+ */
+static gint HEditHViewOpenProgressCB(
+	hview_struct *hview, gulong i, gulong m, gpointer data
+)
+{
+	hedit_struct *he = HEDIT(data);
+	if(he == NULL)                 
+	    return(1);
+
+
+	return(0);
+}
+
+/*
+ *	HView save file progress callback.
+ */
+static gint HEditHViewSaveProgressCB(
+	hview_struct *hview, gulong i, gulong m, gpointer data
+)
+{
+	hedit_struct *he = HEDIT(data);
+	if(he == NULL)                 
+	    return(1);
+
+
+	return(0);
+}
+
+
 /*
  *	Builds the menu bar.
  */
@@ -1050,14 +1259,13 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 	gpointer mclient_data = he;
 	void (*func_cb)(GtkWidget *w, gpointer);
 
-
 	if((he == NULL) || (parent == NULL))
 	    return;
 
-	/* Get keyboard accelerator group */
+	/* Get the keyboard accelerator group */
 	accelgrp = he->accelgrp;
 
-	/* Create menu bar */
+	/* Create the menu bar */
 	menu_bar = GUIMenuBarCreate(NULL);
 	if(GTK_IS_BOX(parent))
 	    gtk_box_pack_start(GTK_BOX(parent), menu_bar, FALSE, FALSE, 0);
@@ -1087,7 +1295,9 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
  );						\
 }
 
-	/* Create file menu */
+	/* Create each menu */
+
+	/* File menu */
 	menu = GUIMenuCreateTearOff();
 	if(menu != NULL)
 	{
@@ -1111,7 +1321,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 "New"
 #endif
 	    ;
-	    accel_key = 'n';
+	    accel_key = GDK_n;
 	    accel_mods = GDK_CONTROL_MASK;
 	    func_cb = HEditNewCB;
 	    DO_ADD_MENU_ITEM_LABEL
@@ -1136,7 +1346,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 "Open..."
 #endif
 	    ;
-	    accel_key = 'o';
+	    accel_key = GDK_o;
 	    accel_mods = GDK_CONTROL_MASK;
 	    func_cb = HEditOpenCB;
 	    DO_ADD_MENU_ITEM_LABEL
@@ -1161,7 +1371,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 "Save"
 #endif
 	    ;
-	    accel_key = 's';
+	    accel_key = GDK_s;
 	    accel_mods = GDK_CONTROL_MASK;
 	    func_cb = HEditSaveCB;
 	    DO_ADD_MENU_ITEM_LABEL
@@ -1186,34 +1396,26 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 "Save As..."
 #endif
 	    ;
-	    accel_key = 'a';
+	    accel_key = GDK_a;
 	    accel_mods = GDK_CONTROL_MASK;
 	    func_cb = HEditSaveAsCB;
 	    DO_ADD_MENU_ITEM_LABEL
 
 	    DO_ADD_MENU_SEP
 
-	    icon = (guint8 **)icon_exit_20x20_xpm;
+	    icon = (guint8 **)icon_close_20x20_xpm;
 	    label =
 #if defined(PROG_LANGUAGE_SPANISH)
-"La Salida"
+		"Cierre"
 #elif defined(PROG_LANGUAGE_FRENCH)
-"Quitter"
-#elif defined(PROG_LANGUAGE_GERMAN)
-"Ausgang"
-#elif defined(PROG_LANGUAGE_ITALIAN)
-"L'Uscita"
-#elif defined(PROG_LANGUAGE_DUTCH)
-"Uitgang"
-#elif defined(PROG_LANGUAGE_PORTUGUESE)
-"A Sada"
-#elif defined(PROG_LANGUAGE_NORWEGIAN)
-"Utgang"
+		"Proche"
+#elif defined(PROG_LANGUAGE_POLISH)
+		"Zamknij"
 #else
-"Exit"
+		"Close"
 #endif
 	    ;
-	    accel_key = 'q';
+	    accel_key = GDK_w;
 	    accel_mods = GDK_CONTROL_MASK;
 	    func_cb = HEditExitCB;
 	    DO_ADD_MENU_ITEM_LABEL
@@ -1241,7 +1443,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 	    , GUI_MENU_BAR_ALIGN_LEFT
 	);
 
-	/* Create edit menu */
+	/* Edit menu */
 	menu = GUIMenuCreateTearOff();
 	if(menu != NULL)
 	{
@@ -1265,7 +1467,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 "Cut"
 #endif
 	    ;
-	    accel_key = 'x';
+	    accel_key = GDK_x;
 	    accel_mods = GDK_CONTROL_MASK;
 	    func_cb = HEditCutCB;
 	    DO_ADD_MENU_ITEM_LABEL
@@ -1291,7 +1493,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 "Copy"
 #endif
 	    ;
-	    accel_key = 'c';
+	    accel_key = GDK_c;
 	    accel_mods = GDK_CONTROL_MASK;
 	    func_cb = HEditCopyCB;
 	    DO_ADD_MENU_ITEM_LABEL
@@ -1317,7 +1519,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 "Paste"
 #endif
 	    ;
-	    accel_key = 'v';
+	    accel_key = GDK_v;
 	    accel_mods = GDK_CONTROL_MASK;
 	    func_cb = HEditPasteCB;
 	    DO_ADD_MENU_ITEM_LABEL
@@ -1378,29 +1580,38 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 	    DO_ADD_MENU_SEP
 
 	    icon = NULL;
-	    label =
-#if defined(PROG_LANGUAGE_SPANISH)
-"El Cambio Redacta El Modo"
-#elif defined(PROG_LANGUAGE_FRENCH)
-"Mode Edition"
-#elif defined(PROG_LANGUAGE_GERMAN)
-"nderung Redigiert Modus"
-#elif defined(PROG_LANGUAGE_ITALIAN)
-"Il Cambiamento Redige Il Modo"
-#elif defined(PROG_LANGUAGE_DUTCH)
-"Verandeer Bewerking Modus"
-#elif defined(PROG_LANGUAGE_PORTUGUESE)
-"A Mudana Edita Modo"
-#elif defined(PROG_LANGUAGE_NORWEGIAN)
-"Forandr Edit Mode"
-#else
-"Change Edit Mode"
-#endif
-	    ;
-	    accel_key = GDK_F4;
+	    label = "Hex Edit Mode";
+	    accel_key = GDK_F7;
 	    accel_mods = 0;
-	    func_cb = HEditEditModeCB;
+	    func_cb = HEditEditModeHexCB;
+	    DO_ADD_MENU_ITEM_CHECK
+	    he->edit_mode_hex_mi = w;
+
+	    icon = NULL;
+	    label = "ASCII Edit Mode";
+	    accel_key = GDK_F8;
+	    accel_mods = 0;
+	    func_cb = HEditEditModeASCIICB;
+	    DO_ADD_MENU_ITEM_CHECK
+	    he->edit_mode_ascii_mi = w;
+
+	    DO_ADD_MENU_SEP
+
+	    icon = NULL;
+	    label = "Select All";
+	    accel_key = GDK_a;
+	    accel_mods = GDK_CONTROL_MASK;
+	    func_cb = HEditSelectAllCB;
 	    DO_ADD_MENU_ITEM_LABEL
+	    he->select_all_mi = w;
+
+	    icon = NULL;
+	    label = "Unselect All";
+	    accel_key = GDK_u;
+	    accel_mods = GDK_CONTROL_MASK;
+	    func_cb = HEditUnselectAllCB;
+	    DO_ADD_MENU_ITEM_LABEL
+	    he->unselect_all_mi = w;
 
 	    DO_ADD_MENU_SEP
 
@@ -1424,10 +1635,11 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 "Find..."
 #endif
 	    ;
-	    accel_key = 'f';
+	    accel_key = GDK_f;
 	    accel_mods = GDK_CONTROL_MASK;
 	    func_cb = HEditFindCB;
 	    DO_ADD_MENU_ITEM_LABEL
+	    he->find_mi = w;
 
 	    icon = NULL;
 	    label =
@@ -1453,6 +1665,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 	    accel_mods = 0;
 	    func_cb = HEditFindNextCB;
 	    DO_ADD_MENU_ITEM_LABEL
+	    he->find_next_mi = w;
 
 	}
 	GUIMenuAddToMenuBar(
@@ -1477,11 +1690,11 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 	    , GUI_MENU_BAR_ALIGN_LEFT
 	);
 
-	/* Create tools menu */
+	/* Tools menu */
 	menu = GUIMenuCreateTearOff();
 	if(menu != NULL)
 	{
-	    icon = NULL;
+	    icon = (guint8 **)icon_calculator_20x20_xpm;
 	    label =
 #if defined(PROG_LANGUAGE_SPANISH)
 "Calcule Escogido"
@@ -1506,6 +1719,12 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 	    func_cb = HEditCalculateSelectedCB;
 	    DO_ADD_MENU_ITEM_LABEL
 
+	    icon = NULL;
+	    label = "ASCII Chart";
+	    accel_key = GDK_F10;
+	    accel_mods = 0;
+	    func_cb = HEditASCIIChartCB;
+	    DO_ADD_MENU_ITEM_LABEL
 	}
 	GUIMenuAddToMenuBar(
 	    menu_bar, menu,
@@ -1531,7 +1750,7 @@ static void HEditBuildMenuBar(hedit_struct *he, GtkWidget *parent)
 
 
 
-	/* Create help menu */
+	/* Help menu */
 	menu = GUIMenuCreateTearOff();
 	if(menu != NULL)
 	{
@@ -1600,10 +1819,11 @@ static void HEditUpdate(hedit_struct *he)
 	GtkWidget *w;
 	hview_struct *hv;
 
-
 	if(he == NULL)
 	    return;
 
+	he->freeze_count++;
+
 	hv = he->hv;
 	if(hv == NULL)
 	    return;
@@ -1614,7 +1834,7 @@ static void HEditUpdate(hedit_struct *he)
 	    const gchar *s = (he->filename != NULL) ?
 		strrchr(he->filename, DIR_DELIMINATOR) : NULL;
 	    gchar *title = g_strdup_printf(
-		PROG_NAME ": %s%s",
+		PROG_NAME_FULL ": %s%s",
 		(s != NULL) ? s + 1 :
 		    ((he->filename != NULL) ? he->filename : "Untitled"),
 		hv->modified ? " (*)" : ""
@@ -1625,17 +1845,23 @@ static void HEditUpdate(hedit_struct *he)
 
 	sensitive = ((hv->buf_sel_start >= 0) && (hv->buf_sel_end >= 0)) ?
 	    TRUE : FALSE;
-#if 0
 	w = he->cut_mi;
 	if(w != NULL)
 	    gtk_widget_set_sensitive(w, sensitive);
 	w = he->copy_mi;
 	if(w != NULL)
 	    gtk_widget_set_sensitive(w, sensitive);
-	w = he->delete_mi;
-	if(w != NULL)
-	    gtk_widget_set_sensitive(w, sensitive);
-#endif
+
+	GTK_CHECK_MENU_ITEM_SET_ACTIVE(
+	    he->edit_mode_hex_mi,
+	    (hv->edit_mode == HVIEW_EDIT_MODE_HEX) ? TRUE : FALSE
+	);
+	GTK_CHECK_MENU_ITEM_SET_ACTIVE(
+	    he->edit_mode_ascii_mi,
+	    (hv->edit_mode == HVIEW_EDIT_MODE_ASCII) ? TRUE : FALSE
+	);
+
+	he->freeze_count--;
 }
 
 
@@ -1643,7 +1869,7 @@ int main(int argc, char *argv[])
 {
 	gboolean initialized_gtk = FALSE;
 	gint i;
-	gint		scroll_pos = 0;
+	gint		cursor_pos = 0;
 	const gchar	*arg,
 			*filename = NULL;
 	GdkWindow *window;
@@ -1652,9 +1878,8 @@ int main(int argc, char *argv[])
 	hview_struct *hv;
 	edv_context_struct *ctx;
 
-
-	/* Set up time zone */
-	tzset();
+#define DO_FREE_LOCALS	{		\
+}
 
 	/* Set up signal callbacks */
 #ifdef SIGINT
@@ -1692,6 +1917,7 @@ int main(int argc, char *argv[])
 	    )
 	    {
 		g_print(PROG_HELP_MESG);
+		DO_FREE_LOCALS
 		return(0);
 	    }
 	    /* Version? */
@@ -1701,11 +1927,12 @@ int main(int argc, char *argv[])
 	    {
 		g_print(
 		    "%s %s\n%s",
-		    PROG_NAME, PROG_VERSION, PROG_COPYRIGHT
+		    PROG_NAME_FULL, PROG_VERSION, PROG_COPYRIGHT
 		);
+		DO_FREE_LOCALS
 		return(0);
 	    }
-	    /* Scroll to position */
+	    /* Initial cursor position? */
 	    else if(!strcasecmp(arg, "--address") ||
 		    !strcasecmp(arg, "-address") ||
 		    !strcasecmp(arg, "--a") ||
@@ -1716,7 +1943,7 @@ int main(int argc, char *argv[])
 		arg = (i < argc) ? argv[i] : NULL;
 		if(arg != NULL)
 		{
-		    scroll_pos = ATOI(arg);
+		    cursor_pos = ATOI(arg);
 		}
 		else
 		{
@@ -1724,13 +1951,58 @@ int main(int argc, char *argv[])
 			"%s: Requires argument\n",
 			argv[i - 1]
 		    );
+		    DO_FREE_LOCALS
+		    return(2);
 		}
 	    }
-	    /* All other non-options assume file to open at start up */ 
-	    else if(*arg != '-')
+	    /* Skip these arguments so that gtk_window_apply_args()
+	     * handles them
+	     */
+	    else if(gtk_is_window_arg(arg))
+	    {
+		i++;
+	    }
+	    /* Single character argument? */
+	    else if((*arg == '-') ? (arg[1] != '-') : FALSE)
+	    {
+		const gchar *v = arg + 1;
+/*		gchar c; */
+
+		while(*v != '\0')
+		{
+#if 0
+		    c = *v;
+		    if(c == 's')
+		    {
+
+		    }
+		    else
+		    {
+			g_printerr(
+"-%c: Unsupported argument.\n",
+			    c
+			);
+			DO_FREE_LOCALS
+			return(2);
+		    }
+#endif
+		    v++;
+		}
+	    }
+	    /* Non-option argument? */
+	    else if((*arg != '-') && (*arg != '+'))
 	    {
 		filename = arg;
 	    }
+	    else
+	    {
+		g_printerr(
+"%s: Unsupported argument.\n",
+		    arg
+		);
+		DO_FREE_LOCALS
+		return(2);
+	    }
 	}
 
 	/* Set GTK+ locale */
@@ -1742,6 +2014,7 @@ int main(int argc, char *argv[])
 	    if(!gtk_init_check(&argc, &argv))
 	    {
 		g_printerr("Unable to initialize GTK.\n");
+		DO_FREE_LOCALS
 		return(1);
 	    }
 	    initialized_gtk = TRUE;
@@ -1760,18 +2033,20 @@ int main(int argc, char *argv[])
 	EDVContextLoadConfigurationFile(ctx, NULL);
 
 
-	/* Begin creating hex edit window */
+	/* Begin creating the HEdit window */
 	he = HEDIT(
 	    g_malloc0(sizeof(hedit_struct))
 	);
 	he->accelgrp = gtk_accel_group_new();
+	he->freeze_count = 0;
+	he->ac_dlg = NULL;
 	he->ctx = ctx;
 
 	/* Toplevel */
 	he->toplevel = w = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_widget_set_usize(w, HEDIT_WIDTH, HEDIT_HEIGHT);
 	gtk_window_set_wmclass(
-	    GTK_WINDOW(w), "hex_editor", PROG_NAME
+	    GTK_WINDOW(w), "hexeditor", PROG_NAME
 	);
 	gtk_window_set_policy(
 	    GTK_WINDOW(w),
@@ -1816,6 +2091,7 @@ int main(int argc, char *argv[])
 	}
 	gtk_container_border_width(GTK_CONTAINER(w), 0);
 	gtk_window_add_accel_group(GTK_WINDOW(w), he->accelgrp);
+	gtk_window_apply_args(GTK_WINDOW(w), argc, argv);
 
 	he->main_vbox = w = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(he->toplevel), w);
@@ -1828,14 +2104,15 @@ int main(int argc, char *argv[])
 	HEditBuildMenuBar(he, he->menu_bar_handle);
 
 	he->hv = hv = HViewNew(he->main_vbox);
-	gtk_window_apply_args(GTK_WINDOW(he->toplevel), argc, argv);
 	HViewSetChangedCB(hv, HEditHViewChangedCB, he);
+	HViewSetSelectCB(hv, HEditHViewSelectCB, he);
+	HViewSetEditModeChangedCB(hv, HEditHViewEditModeChangedCB, he);
 	HViewMap(hv);
 	gtk_signal_connect(
 	    GTK_OBJECT(he->toplevel), "delete_event",
 	    GTK_SIGNAL_FUNC(HEditCloseCB), he
 	);
-	/* Set up hv for DND */
+	/* Set up the HexView for DND */
 	w = hv->view_da;
 	if(w != NULL)
 	{
@@ -1859,7 +2136,8 @@ int main(int argc, char *argv[])
 	    );
 	}
 	HEditUpdate(he);
-	gtk_widget_show(he->toplevel);
+	gtk_widget_show_raise(he->toplevel);
+	gtk_widget_grab_focus(hv->view_da);
 
 	if(filename != NULL)
 	{
@@ -1867,14 +2145,24 @@ int main(int argc, char *argv[])
 
 	    g_free(he->filename);
 	    he->filename = STRDUP(filename);
-	    HViewOpenFile(hv, he->filename);
+	    HViewOpenFileProgress(
+		hv, he->filename,
+		HEditHViewOpenProgressCB, he
+	    );
 
-	    if(scroll_pos > 0)
+	    /* Set cursor position at startup? */
+	    if(cursor_pos > 0)
 	    {
-		if(scroll_pos >= hv->buf_len)
-		    scroll_pos = MAX(hv->buf_len - 1, 0);
-		HViewSetPosition(hv, scroll_pos);
-		HViewScrollTo(hv, scroll_pos, 0.5f);
+		if(cursor_pos >= hv->buf_len)
+		    cursor_pos = MAX((hv->buf_len - 1), 0);
+		HViewSetPosition(hv, cursor_pos);
+		HViewScrollTo(hv, cursor_pos, 0.5f);
+	    }
+	    else if(cursor_pos == -1)
+	    {
+		cursor_pos = MAX((hv->buf_len - 1), 0);
+		HViewSetPosition(hv, cursor_pos);
+		HViewScrollTo(hv, cursor_pos, 0.5f);
 	    }
 
 	    HEditUpdate(he);
@@ -1885,7 +2173,11 @@ int main(int argc, char *argv[])
 
 	gtk_main();
 
-	/* Delete hex edit window */
+
+	/* Delete the HEdit window */
+	ASCIIChartDlgDelete(he->ac_dlg);
+	he->ac_dlg = NULL;
+
 	HViewClear(hv);
 	HViewDelete(hv);
 	he->hv = hv = NULL;
@@ -1904,7 +2196,7 @@ int main(int argc, char *argv[])
 	he = NULL;
 
 
-	/* Delete Endeavour context */
+	/* Delete the Endeavour context */
 	EDVContextSync(ctx);
 	EDVContextDelete(ctx);
 	ctx = NULL;
@@ -1917,5 +2209,8 @@ int main(int argc, char *argv[])
 	/* Reset the DND Icon */
 	GUIDNDSetDragIcon(NULL, NULL, 0, 0);
 
+	DO_FREE_LOCALS
+
 	return(0);
+#undef DO_FREE_LOCALS
 }
