@@ -1371,7 +1371,7 @@ void EDVHistoryWinUpdateDisplay(
 		mask = lw->object_chmod_mask;
 		break;
 	      case EDV_HISTORY_DISK_OBJECT_CHTIME:
-		s = "Set Date";
+		s = "Change Time Stamps";
 		pixmap = lw->object_chtime_pixmap;
 		mask = lw->object_chtime_mask;
 		break;
@@ -2259,7 +2259,7 @@ static void EDVHistoryWinSetRow(
 	    mask = lw->object_chmod_mask;
 	    break;
 	  case EDV_HISTORY_DISK_OBJECT_CHTIME:
-	    type_name = "Set Date";
+	    type_name = "Change Time Stamps";
 	    pixmap = lw->object_chtime_pixmap;
 	    mask = lw->object_chtime_mask;
 	    break;
