@@ -6,7 +6,6 @@
 
 #include <gtk/gtk.h>
 
-#include "../include/fio.h"
 #include "guiutils.h"
 #include "cdialog.h"
 
@@ -27,17 +26,34 @@ gint HViewPositionXYToBuffer(hview_struct *hv, gint x, gint y);
 void HViewScrollTo(hview_struct *hv, gint pos, gfloat ycoeff);
 GtkVisibility HViewIsBufferPositionVisible(hview_struct *hv, gint i);
 
+gint HViewOpenFileProgress(
+	hview_struct *hv, const gchar *path,
+	gint (*progress_cb)(
+	    hview_struct *, gulong, gulong, gpointer
+	),
+	gpointer progress_data
+);
 gint HViewOpenFile(hview_struct *hv, const gchar *path);
+gint HViewSaveFileProgress(
+	hview_struct *hv, const gchar *path,
+	gint (*progress_cb)(
+	    hview_struct *, gulong, gulong, gpointer
+	),
+	gpointer progress_data
+);
 gint HViewSaveFile(hview_struct *hv, const gchar *path);
-gint HViewOpenData(hview_struct *hv, const guint8 *data, gint data_len);
+gint HViewOpenData(hview_struct *hv, const guint8 *data, const gint data_len);
 void HViewClear(hview_struct *hv);
 
-void HViewSetEditMode(hview_struct *hv, hview_edit_mode edit_mode);
-void HViewSetSelected(hview_struct *hv, guint8 v);
-void HViewSetPosition(hview_struct *hv, gint pos);
+void HViewSetEditMode(hview_struct *hv, const hview_edit_mode edit_mode);
+void HViewSetSelected(hview_struct *hv, const guint8 v);
+void HViewSetPosition(hview_struct *hv, const gint position);
 void HViewSelect(
-	hview_struct *hv, gint start_pos, gint end_pos
+	hview_struct *hv,
+	const gint start_position, const gint end_position
 );
+void HViewSelectAll(hview_struct *hv);
+void HViewUnselectAll(hview_struct *hv);
 void HViewCut(hview_struct *hv);
 void HViewCopy(hview_struct *hv);
 void HViewPaste(hview_struct *hv);
@@ -65,6 +81,24 @@ void HViewSetChangedCB(
 	void (*changed_cb)(hview_struct *, gpointer),
 	gpointer data
 );
+void HViewSetSelectCB(
+	hview_struct *hv,
+	void (*select_cb)(
+		hview_struct *,
+		int, int,
+		gpointer
+	),
+	gpointer data
+);
+void HViewSetEditModeChangedCB(
+	hview_struct *hv,
+	void (*edit_mode_changed_cb)(
+		hview_struct *,
+		hview_edit_mode,                               
+		gpointer                        
+	), 
+	gpointer data 
+); 
 void HViewUpdate(hview_struct *hv);
 void HViewDraw(hview_struct *hv);
 void HViewQueueDraw(hview_struct *hv);  
@@ -257,48 +291,174 @@ GtkVisibility HViewIsBufferPositionVisible(hview_struct *hv, gint i)
 	    return(GTK_VISIBILITY_NONE);
 }
 
+
 /*
- *	Opens the file specified by path and loads it into the buffer.
+ *	Opens the data from the file to the HView.
  *
- *	This function will automatically call HViewClear().
+ *	Any existing data in the HView will be cleared first.
+ *
+ *	The path specifies the file to open.
+ *
+ *	The progress_cb specifies the function to call to report the
+ *	progress of the loading. If it returns non-zero then this
+ *	operation be aborted and this function will return -4.
  *
  *	Returns 0 on success or non-zero on error.
  */
-gint HViewOpenFile(hview_struct *hv, const gchar *path)
+gint HViewOpenFileProgress(
+	hview_struct *hv, const gchar *path,
+	gint (*progress_cb)(
+	    hview_struct *, gulong, gulong, gpointer
+	),
+	gpointer progress_data
+)
 {
+	gboolean read_error = FALSE;
+	gint interrupted = 0;
 	FILE *fp;
-	struct stat stat_buf;
 	GtkAdjustment *adj;
 	GtkWidget *w;
 
 	if((hv == NULL) || STRISEMPTY(path))
 	    return(-1);
 
-	/* Clear buffer and reset scroll position */
-	HViewClear(hv);
-
-	/* Open file for reading */
-	fp = FOpen(path, "rb");
-	if(fp != NULL)
+	/* Report the initial progress */
+	if(progress_cb != NULL)
 	{
-	    if(!fstat(fileno(fp), &stat_buf))
-	    {
-		hv->buf_len = stat_buf.st_size;
-		if(hv->buf_len > 0)
-		    hv->buf = (guint8 *)g_malloc(hv->buf_len * sizeof(guint8));
-		if(hv->buf == NULL)
-		{
-		    hv->buf_len = 0;
-		}
-		else
-		{
-		    fread(hv->buf, sizeof(guint8), hv->buf_len, fp);
-		}
-	    }
-	    FClose(fp);
+	    interrupted = progress_cb(
+		hv, 0l, 0l, progress_data
+	    );
+	    if(interrupted)
+		return(-4);
 	}
 
-	/* Update adjustment */
+	/* Clear the buffer and reset the scroll positions */
+	HViewClear(hv);
+
+	/* Open the file for reading */
+	fp = fopen(path, "rb");
+	if(fp != NULL)
+	{
+	    struct stat stat_buf;
+	    gulong read_buf_len, size;
+	    guint8 *read_buf;
+
+	    /* Get the file's stats */
+	    if(fstat(fileno(fp), &stat_buf))
+	    {
+		read_buf_len = 0l;
+		size = 0l;
+	    }
+	    else
+	    {
+		read_buf_len = (gulong)stat_buf.st_blksize;
+		size = (gulong)stat_buf.st_size;
+	    }
+
+	    /* Allocate the read buffer */
+	    read_buf = (read_buf_len > 0l) ?
+		(guint8 *)g_malloc(read_buf_len * sizeof(guint8)) : NULL;
+
+	    /* Read one block at a time? */
+	    if(read_buf != NULL)
+	    {
+		gint bytes_read, buf_pos;
+
+		while(!feof(fp))
+		{
+		    /* Report the current progress */
+		    if(progress_cb != NULL)
+		    {
+			interrupted = progress_cb(
+			    hv, (gulong)hv->buf_len, size, progress_data
+			);
+			if(interrupted)
+			    break;
+		    }
+
+		    /* Read this block */
+		    bytes_read = (gint)fread(
+			read_buf,
+			sizeof(guint8),
+			(size_t)read_buf_len,
+			fp
+		    );
+		    if(bytes_read <= 0)
+		    {
+			read_error = TRUE;
+			break;
+		    }
+
+		    /* Append this block to the HView's buffer */
+		    buf_pos = hv->buf_len;
+		    hv->buf_len += bytes_read;
+		    hv->buf = (guint8 *)g_realloc(
+			hv->buf,
+			hv->buf_len * sizeof(guint8)
+		    );
+		    if(hv->buf == NULL)
+		    {
+			hv->buf_len = 0;
+			read_error = TRUE;
+			break;
+		    }
+		    memcpy(
+			hv->buf + buf_pos,
+			read_buf,
+			bytes_read * sizeof(guint8)
+		    );
+		}
+
+		/* Delete the read buffer */
+		g_free(read_buf);
+	    }
+	    else
+	    {
+		/* Read one character at a time */
+		gint c, buf_pos;
+
+		while(!feof(fp))
+		{
+		    /* Report the current progress */
+		    if(progress_cb != NULL)
+		    {
+			interrupted = progress_cb(
+			    hv, (gulong)hv->buf_len, size, progress_data
+			);
+			if(interrupted)
+			    break;
+		    }
+
+		    /* Read this character */
+		    c = (gint)fgetc(fp);
+		    if((int)c == EOF)
+		    {
+			read_error = TRUE;
+			break;
+		    }
+
+		    /* Append this character to the HView's buffer */
+		    buf_pos = hv->buf_len;
+		    hv->buf_len++;
+		    hv->buf = (guint8 *)g_realloc(
+			hv->buf,
+			hv->buf_len * sizeof(guint8)
+		    );
+		    if(hv->buf == NULL)
+		    {
+			hv->buf_len = 0;
+			read_error = TRUE;
+			break;
+		    }
+		    hv->buf[buf_pos] = (guint8)c;
+		}
+	    }
+
+	    /* Close the file */
+	    fclose(fp);
+	}
+
+	/* Update the scroll adjustment bounds */
 	w = hv->view_da;
 	adj = hv->vadj;
 	if((w != NULL) && (adj != NULL) &&
@@ -325,44 +485,169 @@ gint HViewOpenFile(hview_struct *hv, const gchar *path)
 	HViewUpdate(hv);
 	HViewSetStatusMessage(hv, NULL, FALSE);
 
-	return(0);
+	/* Report the final progress */
+	if((progress_cb != NULL) && !interrupted)
+	    interrupted = progress_cb(
+		hv, (gulong)hv->buf_len, (gulong)hv->buf_len, progress_data
+	    );
+
+	return(interrupted ? -4 : (read_error ? -1 : 0));
 }
 
 /*
- *	Saves the data to the file specified by path.
+ *	Opens the data from the file to the HView.
+ *
+ *	Any existing data in the HView will be cleared first.
+ *
+ *	The path specifies the file to open.
+ *
+ *	Returns 0 on success or non-zero on error.
+ */
+gint HViewOpenFile(hview_struct *hv, const gchar *path)
+{
+	return(HViewOpenFileProgress(hv, path, NULL, NULL));
+}
+
+/*
+ *	Saves the data in the HView to the file.
+ *
+ *	The path specifies the file to write to, if it exists then it
+ *	will be automatically overwritten.
  *
  *      Returns 0 on success or non-zero on error.
  */
-gint HViewSaveFile(hview_struct *hv, const gchar *path)
+gint HViewSaveFileProgress(
+	hview_struct *hv, const gchar *path,
+	gint (*progress_cb)(
+	    hview_struct *, gulong, gulong, gpointer
+	),
+	gpointer progress_data
+)
 {
+	gboolean write_error = FALSE;
+	int interrupted = 0;
 	FILE *fp;
 
 	if((hv == NULL) || STRISEMPTY(path))
 	    return(-1);
 
-	/* Open file for writing */
-	fp = FOpen(path, "wb");
+	/* Report the initial progress */
+	if(progress_cb != NULL)
+	{
+	    interrupted = progress_cb(
+		hv, 0l, 0l, progress_data
+	    );
+	    if(interrupted)
+		return(-4);
+	}
+
+	/* Open the file for writing */
+	fp = fopen(path, "wb");
 	if(fp != NULL)
 	{
-	    gint i;
+	    struct stat stat_buf;
+	    gulong write_buf_len, size;
 
-	    for(i = 0; i < hv->buf_len; i++)
+	    /* Get the file's stats */
+	    if(fstat(fileno(fp), &stat_buf))
 	    {
-		if(fputc((gint)hv->buf[i], fp) == EOF)
-		    break;
+		write_buf_len = 0l;
+		size = 0l;
+	    }
+	    else
+	    {
+		write_buf_len = (gulong)stat_buf.st_blksize;
+		size = (gulong)stat_buf.st_size;
 	    }
 
-	    FClose(fp);
+	    /* Write one block at a time? */
+	    if(write_buf_len > 0l)
+	    {
+		gint bytes_written, buf_pos = 0, len;
 
-	    /* Write error? */
-	    if(i < hv->buf_len)
-		return(-1);
+		while(buf_pos < hv->buf_len)
+		{
+		    /* Report the current progress */
+		    if(progress_cb != NULL)
+		    {
+			interrupted = progress_cb(
+			    hv, (gulong)buf_pos, (gulong)hv->buf_len, progress_data
+			);
+			if(interrupted)
+			    break;
+		    }
+
+		    /* Calculate the minimum length of this block */
+		    len = MIN(
+			(hv->buf_len - buf_pos),
+			write_buf_len
+		    );
+
+		    /* Write this block */
+		    bytes_written = (gint)fwrite(
+			hv->buf + buf_pos,
+			sizeof(guint8),
+			(size_t)len,
+			fp
+		    );
+		    if(bytes_written <= 0)
+		    {
+			write_error = TRUE;
+			break;
+		    }
+
+		    buf_pos += bytes_written;
+		}
+	    }
+	    else
+	    {
+		/* Write one character at a time */
+		gint buf_pos = 0;
+
+		while(buf_pos < hv->buf_len)
+		{
+		    /* Report the current progress */
+		    if(progress_cb != NULL)
+		    {
+			interrupted = progress_cb(
+			    hv, (gulong)buf_pos, (gulong)hv->buf_len, progress_data
+			);
+			if(interrupted)
+			    break;
+		    }
+
+		    /* Write this character */
+		    if(fputc((int)hv->buf[buf_pos], fp) == EOF)
+		    {
+			write_error = TRUE;
+			break;
+		    }
+
+		    buf_pos++;
+		}
+	    }
+
+	    /* Close the file */
+	    fclose(fp);
 	}
 
 	HViewUpdate(hv);
 	HViewSetStatusMessage(hv, NULL, FALSE);
 
-	return(0);
+	return(interrupted ? -4 : (write_error ? -1 : 0));
+}
+
+/*
+ *	Saves the data in the HView to the file.
+ *
+ *	The path specifies the file to write to, if it exists then it
+ *	will be automatically overwritten.
+ *
+ *      Returns 0 on success or non-zero on error.
+ */
+gint HViewSaveFile(hview_struct *hv, const gchar *path)
+{
+	return(HViewSaveFileProgress(hv, path, NULL, NULL));
 }
 
 /*
@@ -372,7 +657,7 @@ gint HViewSaveFile(hview_struct *hv, const gchar *path)
  *
  *	Returns 0 on success or non-zero on error.
  */
-gint HViewOpenData(hview_struct *hv, const guint8 *data, gint data_len)
+gint HViewOpenData(hview_struct *hv, const guint8 *data, const gint data_len)
 {
 	GtkAdjustment *adj;
 	GtkWidget *w;
@@ -405,7 +690,7 @@ gint HViewOpenData(hview_struct *hv, const guint8 *data, gint data_len)
 	   (hv->cells_per_row > 0) && (hv->cell_height > 0)
 	)
 	{
-            const gint height = w->allocation.height;
+	    const gint height = w->allocation.height;
 
 	    adj->lower = 0.0f;
 	    adj->upper = (gfloat)(
@@ -451,8 +736,8 @@ void HViewClear(hview_struct *hv)
 	hv->buf_len = 0;
 	hv->buf_sel_start = -1;
 	hv->buf_sel_end = -1;
-	hv->buf_hex_edit = 0;
-	*hv->buf_hex_edit_buf = '\0';
+	hv->edit_buf_i = 0;
+	*hv->edit_buf = '\0';
 	changed = (hv->modified != FALSE) ? TRUE : FALSE;
 	hv->modified = FALSE;
 
@@ -462,7 +747,7 @@ void HViewClear(hview_struct *hv)
 	w = hv->view_da;
 	if((w != NULL) && (hv->cells_per_row > 0) && (hv->cell_height > 0))
 	{
-            const gint height = w->allocation.height;
+	    const gint height = w->allocation.height;
 
 	    adj->lower = 0.0f;
 	    adj->upper = (gfloat)(
@@ -482,13 +767,21 @@ void HViewClear(hview_struct *hv)
 
 	if(changed && (hv->changed_cb != NULL))
 	    hv->changed_cb(hv, hv->changed_data);
+	if(hv->select_cb != NULL)
+	    hv->select_cb(
+		hv,
+		hv->buf_sel_start, hv->buf_sel_end,
+		hv->select_data
+	    );
 }
 
 /*
- *	Sets the edit mode, where edit_mode can be either
- *	HVIEW_EDIT_MODE_HEX or HVIEW_EDIT_MODE_ASCII.
+ *	Sets the edit mode.
+ *
+ *	The edit_mode must be either HVIEW_EDIT_MODE_HEX or
+ *	HVIEW_EDIT_MODE_ASCII.
  */
-void HViewSetEditMode(hview_struct *hv, hview_edit_mode edit_mode)
+void HViewSetEditMode(hview_struct *hv, const hview_edit_mode edit_mode)
 {
 	if(hv == NULL)
 	    return;
@@ -498,6 +791,12 @@ void HViewSetEditMode(hview_struct *hv, hview_edit_mode edit_mode)
 	    hv->edit_mode = edit_mode;
 	    HViewUpdate(hv);
 	    HViewSetStatusMessage(hv, NULL, FALSE);
+	    if(hv->edit_mode_changed_cb != NULL)
+		hv->edit_mode_changed_cb(
+		    hv,
+		    edit_mode,
+		     hv->edit_mode_changed_data
+		);
 	}
 }
 
@@ -508,7 +807,7 @@ void HViewSetEditMode(hview_struct *hv, hview_edit_mode edit_mode)
  *	Note that this function will not redraw the view, the calling
  *	function must call HViewDraw().
  */
-void HViewSetSelected(hview_struct *hv, guint8 v)
+void HViewSetSelected(hview_struct *hv, const guint8 v)
 {
 	gint i, n;
 
@@ -545,21 +844,33 @@ void HViewSetSelected(hview_struct *hv, guint8 v)
 
 	/* Set the selected buffer region */
 	memset(&hv->buf[i], v, n * sizeof(guint8));
+
+	if(hv->select_cb != NULL)
+	    hv->select_cb(
+		hv,
+		hv->buf_sel_start, hv->buf_sel_end,
+		hv->select_data
+	    );
 }
 
 /*
  * 	Sets the new cursor position.
  */
-void HViewSetPosition(hview_struct *hv, gint pos)
+void HViewSetPosition(hview_struct *hv, const gint position)
 {
+	gint pos;
+
 	if(hv == NULL)
 	    return;
 
 	/* Sanitize the specified position */
-	if(pos < 0)
+	if(position < 0)
 	    pos = hv->buf_len - 1;
-	if(pos >= hv->buf_len)
+	else if(position >= hv->buf_len)
 	    pos = hv->buf_len - 1;
+	else
+	    pos = position;
+
 	if(pos < 0)
 	    pos = 0;
 
@@ -576,44 +887,88 @@ void HViewSetPosition(hview_struct *hv, gint pos)
 /*
  *	Select the given region.
  *
- *	If either start_pos or end_pos is < 0 then the hv will be
- *	unselected.
+ *	If both start_position and end_position are < 0 then all
+ *	the data will be unselected.
+ *
+ *	If end_position is -1 then it be interpreted as the last
+ *	position in the data.
  */
 void HViewSelect(
-	hview_struct *hv, gint start_pos, gint end_pos
+	hview_struct *hv,
+	const gint start_position, const gint end_position
 )
 {
+	gint start_pos, end_pos;
+
 	if(hv == NULL)
 	    return;
 
-	/* Unselect? */
-	if((start_pos < 0) || (end_pos < 0))
+
+	/* Unselect all? */
+	if((start_position < 0) && (end_position < 0))
 	{
-	    hv->buf_sel_start = -1;
-	    hv->buf_sel_end = -1;
+	    start_pos = -1;
+	    end_pos = -1;
 	}
 	else
 	{
+	    start_pos = start_position;
+	    end_pos = end_position;
+
+	    /* If end_pos is -1 then set it to the end of the data */
+	    if(end_pos < 0)
+		end_pos = hv->buf_len - 1;
+
 	    if(start_pos < end_pos)
 	    {
-		hv->buf_sel_start = start_pos;
-		hv->buf_sel_end = end_pos;
-	    }
-	    else
-	    {
-		hv->buf_sel_start = end_pos;
-		hv->buf_sel_end = start_pos;
+		const gint i = end_pos;
+		end_pos = start_pos;
+		start_pos = i;
+
 	    }
 
-	    if(hv->buf_sel_start >= hv->buf_len)
-		hv->buf_sel_start = hv->buf_len - 1;
-	    if(hv->buf_sel_end >= hv->buf_len)
-		hv->buf_sel_end = hv->buf_len - 1;
+	    if(start_pos >= hv->buf_len)
+		start_pos = hv->buf_len - 1;
+	    if(end_pos >= hv->buf_len)
+		end_pos = hv->buf_len - 1;
 	}
 
+	/* No change in selection? */
+	if((start_pos == hv->buf_sel_start) &&
+	   (end_pos == hv->buf_sel_end)
+	)
+	    return;
+
+	/* Set the selection */
+	hv->buf_sel_start = start_pos;
+	hv->buf_sel_end = end_pos;
+
 	HViewQueueDraw(hv);
 	HViewUpdate(hv);
 	HViewSetStatusMessage(hv, NULL, FALSE);
+
+	if(hv->select_cb != NULL)
+	    hv->select_cb(
+		hv,
+		hv->buf_sel_start, hv->buf_sel_end,
+		hv->select_data
+	    );
+}
+
+/*
+ *	Select all.
+ */
+void HViewSelectAll(hview_struct *hv)
+{
+	HViewSelect(hv, 0, -1);
+}
+
+/*
+ *	Unselect all.
+ */
+void HViewUnselectAll(hview_struct *hv)
+{
+	HViewSelect(hv, -1, -1);
 }
 
 /*
@@ -790,11 +1145,15 @@ hview_struct *HViewNew(GtkWidget *parent)
 	hv->buf_sel_end = -1;
 	hv->read_only = FALSE;
 	hv->edit_mode = HVIEW_EDIT_MODE_HEX;
-	hv->buf_hex_edit = 0;
-	*hv->buf_hex_edit_buf = '\0';
+	hv->edit_buf_i = 0;
+	*hv->edit_buf = '\0';
 	hv->modified = FALSE;
 	hv->changed_cb = NULL;
 	hv->changed_data = NULL;
+	hv->select_cb = NULL;
+	hv->select_data = NULL;
+	hv->edit_mode_changed_cb = NULL;
+	hv->edit_mode_changed_data = NULL;
 
 	/* Load cursors */
 	hv->busy_cur = gdk_cursor_new(GDK_WATCH);
@@ -1392,6 +1751,47 @@ void HViewSetChangedCB(
 	hv->changed_data = data;
 }
 
+/*
+ *	Sets the Hex View's select callback.
+ */
+void HViewSetSelectCB(
+	hview_struct *hv,
+	void (*select_cb)(
+		hview_struct *,
+		int, int,
+		gpointer
+	),
+	gpointer data
+)
+{
+	if(hv == NULL)
+	    return;
+
+	hv->select_cb = select_cb;
+	hv->select_data = data;
+}
+
+/*
+ *	Sets the Hex View's edit mode changed callback.
+ */
+void HViewSetEditModeChangedCB(
+	hview_struct *hv,
+	void (*edit_mode_changed_cb)(
+		hview_struct *,
+		hview_edit_mode,
+		gpointer
+	),
+	gpointer data
+)
+{
+	if(hv == NULL)
+	    return;
+
+	hv->edit_mode_changed_cb = edit_mode_changed_cb;
+	hv->edit_mode_changed_data = data;
+}
+
+
 /*
  *	Updates the Hex View's widgets to reflect current values.
  */
@@ -1435,22 +1835,22 @@ void HViewUpdate(hview_struct *hv)
 	}
 	else
 	{
-            gtk_widget_show(hv->edit_mode_msep);
-            gtk_widget_show(hv->edit_mode_hex_mi);
-            gtk_widget_show(hv->edit_mode_ascii_mi);
+	    gtk_widget_show(hv->edit_mode_msep);
+	    gtk_widget_show(hv->edit_mode_hex_mi);
+	    gtk_widget_show(hv->edit_mode_ascii_mi);
 	}
 	GUIMenuItemSetCheck(
 	    hv->edit_mode_hex_mi,
-            (hv->edit_mode == HVIEW_EDIT_MODE_HEX) ? TRUE : FALSE,
+	    (hv->edit_mode == HVIEW_EDIT_MODE_HEX) ? TRUE : FALSE,
 	    TRUE
-        );
+	);
 	GUIMenuItemSetCheck(
 	    hv->edit_mode_ascii_mi,
 	    (hv->edit_mode == HVIEW_EDIT_MODE_ASCII) ? TRUE : FALSE,
 	    TRUE
 	);
 
-        hv->freeze_count--;
+	hv->freeze_count--;
 }
 
 /* 
@@ -1497,7 +1897,8 @@ void HViewSetStatusMessage(
 	    gint i = hv->buf_pos;
 	    gchar *buf;
 
-	    if(hv->buf_hex_edit > 0)
+	    /* Is a value being edited? */
+	    if((hv->edit_buf_i > 0) && (sizeof(hv->edit_buf) >= 2))
 	    {
 		buf = g_strdup_printf(
 "Address: 0x%.8X - Position: %i - Size: %i -\
@@ -1506,10 +1907,10 @@ void HViewSetStatusMessage(
 		    hv->buf_len,
 		    (hv->edit_mode == HVIEW_EDIT_MODE_HEX) ?
 			"Hex" : "ASCII",
-		    hv->buf_hex_edit_buf[0],
-		    (hv->buf_hex_edit > 1) ?
-			hv->buf_hex_edit_buf[1] : '_',
-		    (hv->buf_hex_edit > 2) ? '_' : '\0'
+		    hv->edit_buf[0],
+		    (hv->edit_buf_i > 1) ?
+			hv->edit_buf[1] : '_',
+		    (hv->edit_buf_i > 2) ? '_' : '\0'
 		);
 	    }
 	    else
@@ -1644,8 +2045,8 @@ void HViewDelete(hview_struct *hv)
 	hv->buf_len = 0;
 	hv->buf_sel_start = -1;
 	hv->buf_sel_end = -1;
-	hv->buf_hex_edit = 0;
-	*hv->buf_hex_edit_buf = '\0';
+	hv->edit_buf_i = 0;
+	*hv->edit_buf = '\0';
 
 	GTK_WIDGET_DESTROY(hv->menu)
 	GTK_WIDGET_DESTROY(hv->status_bar_label)
