@@ -1,5 +1,5 @@
 /*
-				   Hex View
+				    Hex View
  */
 
 #ifndef HVIEW_H
@@ -8,6 +8,11 @@
 #include <gtk/gtk.h>
 
 
+typedef struct _hview_struct		hview_struct;
+#define HVIEW(p)			((hview_struct *)(p))
+
+
+
 /*
  *	Edit Modes:
  */
@@ -20,7 +25,6 @@ typedef enum {
 /*
  *	Hex View:
  */
-typedef struct _hview_struct		hview_struct;
 struct _hview_struct {
 
 	GtkWidget 	*toplevel;
@@ -76,27 +80,41 @@ struct _hview_struct {
 	/* Edit mode */
 	hview_edit_mode	edit_mode;
 
-	/* If not 0, indicates the hex is being edited. When this is
-	 * 1 then it means the user pressed one key to indicate the
-	 * first character of the hex value, pressing another key
-	 * finishes the editing
+	/* Edit buffer
+	 *
+	 * If edit_buf_i is not 0 then it indicates the value is being
+	 * edited and what position in edit_buf should the next value
+	 * be entered to
 	 */
-	gint		buf_hex_edit;
-	/* Tempory buffer for holding the user typed hex characters */
-	gchar		buf_hex_edit_buf[3];
-
+	gint		edit_buf_i;
+	gchar		edit_buf[4];
 
 	gboolean	modified;
 
 	/* Changed callback */
 	void		(*changed_cb)(
-		hview_struct *hv,		/* Hex View */
+		hview_struct *,			/* Hex View */
 		gpointer			/* Data */
 	);
 	gpointer	changed_data;
 
+	/* Select callback */
+	void		(*select_cb)(
+		hview_struct *,			/* Hex View */
+		int, int,			/* Start, End */
+		gpointer			/* Data */
+	);
+	gpointer	select_data;
+
+	/* Edit mode changed callback */
+	void		(*edit_mode_changed_cb)(
+		hview_struct *,			/* Hex View */
+		hview_edit_mode,		/* Edit mode */
+		gpointer			/* Data */
+	);
+	gpointer	edit_mode_changed_data;
+
 };
-#define HVIEW(p)	((hview_struct *)(p))
 
 /* Returns TRUE if the buffer is selected (not nessisarly has selection)
  * or FALSE if the buffer is not selected
@@ -121,17 +139,34 @@ extern GtkVisibility HViewIsBufferPositionVisible(
 	hview_struct *hv, gint i
 );
 
+extern gint HViewOpenFileProgress(
+        hview_struct *hv, const gchar *path,
+        gint (*progress_cb)(
+            hview_struct *, gulong, gulong, gpointer
+        ),
+        gpointer progress_data
+);
 extern gint HViewOpenFile(hview_struct *hv, const gchar *path);
+extern gint HViewSaveFileProgress(
+        hview_struct *hv, const gchar *path,
+        gint (*progress_cb)(
+            hview_struct *, gulong, gulong, gpointer
+        ),
+        gpointer progress_data
+);
 extern gint HViewSaveFile(hview_struct *hv, const gchar *path);
 extern gint HViewOpenData(hview_struct *hv, const guint8 *data, gint data_len);
 extern void HViewClear(hview_struct *hv);
 
-extern void HViewSetEditMode(hview_struct *hv, hview_edit_mode edit_mode);
-extern void HViewSetSelected(hview_struct *hv, guint8 v);
-extern void HViewSetPosition(hview_struct *hv, gint pos);
+extern void HViewSetEditMode(hview_struct *hv, const hview_edit_mode edit_mode);
+extern void HViewSetSelected(hview_struct *hv, const guint8 v);
+extern void HViewSetPosition(hview_struct *hv, const gint position);
 extern void HViewSelect(
-	hview_struct *hv, gint start_pos, gint end_pos
+	hview_struct *hv,
+	const gint start_position, const gint end_position
 );
+extern void HViewSelectAll(hview_struct *hv);
+extern void HViewUnselectAll(hview_struct *hv);
 extern void HViewCut(hview_struct *hv);
 extern void HViewCopy(hview_struct *hv);
 extern void HViewPaste(hview_struct *hv);
@@ -159,6 +194,25 @@ extern void HViewSetChangedCB(
 	void (*changed_cb)(hview_struct *, gpointer),
 	gpointer data
 );
+extern void HViewSetSelectCB(
+	hview_struct *hv,
+	void (*select_cb)(
+		hview_struct *,
+		int, int,
+		gpointer
+	),
+	gpointer data
+);
+extern void HViewSetEditModeChangedCB(
+	hview_struct *hv,
+	void (*edit_mode_changed_cb)(
+		hview_struct *,
+		hview_edit_mode,
+		gpointer
+	),
+	gpointer data
+);
+
 extern void HViewUpdate(hview_struct *hv);
 extern void HViewDraw(hview_struct *hv);
 extern void HViewQueueDraw(hview_struct *hv);
