@@ -1350,44 +1350,8 @@ gint HViewButtonCB(
 
 	switch(button->button)
 	{
-	  case 3:
-	    if(button_press)
-	    {
-		/* Map right click menu */
-		GtkMenu *menu = (GtkMenu *)hv->menu;
-		if(menu != NULL)
-		    gtk_menu_popup(
-			menu, NULL, NULL,
-			NULL, NULL,
-			button->button, button->time
-		    );
-	    }
-	    status = TRUE;
-	    break;
-
-	  case 2:
-	    if(button_press)
-	    {
-		GtkWidget *w = hv->view_da;
-
-		hv->dragging_scroll = TRUE;
-		hv->last_motion_x = (gint)button->x;
-		hv->last_motion_y = (gint)button->y;
-		if(w != NULL)
-		    gdk_window_set_cursor(w->window, hv->translate_cur);
-	    }
-	    else
-	    {
-		GtkWidget *w = hv->view_da;
-
-		hv->dragging_scroll = FALSE;
-		if(w != NULL)
-		    gdk_window_set_cursor(w->window, NULL);
-	    }
-	    status = TRUE;
-	    break;
-
-	  case 1:
+	  case GDK_BUTTON1:
+	    /* Position cursor or select */
 	    if(button_press)
 	    {
 		const gint	x = (gint)button->x,
@@ -1495,6 +1459,82 @@ gint HViewButtonCB(
 	    status = TRUE;
 	    break;
 
+	  case GDK_BUTTON2:
+	    /* Translate */
+	    if(button_press)
+	    {
+		GtkWidget *w = hv->view_da;
+
+		hv->dragging_scroll = TRUE;
+		hv->last_motion_x = (gint)button->x;
+		hv->last_motion_y = (gint)button->y;
+		if(w != NULL)
+		    gdk_window_set_cursor(w->window, hv->translate_cur);
+	    }
+	    else
+	    {
+		GtkWidget *w = hv->view_da;
+
+		hv->dragging_scroll = FALSE;
+		if(w != NULL)
+		    gdk_window_set_cursor(w->window, NULL);
+	    }
+	    status = TRUE;
+	    break;
+
+	  case GDK_BUTTON3:
+	    /* Popup menu */
+	    if(button_press)
+	    {
+		/* Map right click menu */
+		GtkMenu *menu = (GtkMenu *)hv->menu;
+		if(menu != NULL)
+		    gtk_menu_popup(
+			menu, NULL, NULL,
+			NULL, NULL,
+			button->button, button->time
+		    );
+	    }
+	    status = TRUE;
+	    break;
+
+	  case GDK_BUTTON4:
+	    /* Scroll up */
+	    if(button_press && (hv->vadj != NULL))
+	    {
+		GtkAdjustment *adj = hv->vadj;
+		const gfloat inc = MAX(
+		    (0.25f * adj->page_size),
+		    adj->step_increment
+		);
+		gfloat v = adj->value - inc;
+		if(v > (adj->upper - adj->page_size))
+		    v = adj->upper - adj->page_size;
+		if(v < adj->lower)
+		    v = adj->lower;
+		gtk_adjustment_set_value(adj, v);
+	    }
+	    status = TRUE;
+	    break;
+
+	  case GDK_BUTTON5:
+	    /* Scroll down */
+	    if(button_press && (hv->vadj != NULL))
+	    {
+		GtkAdjustment *adj = hv->vadj;
+		const gfloat inc = MAX(
+		    (0.25f * adj->page_size),
+		    adj->step_increment
+		);
+		gfloat v = adj->value + inc;
+		if(v > (adj->upper - adj->page_size))
+		    v = adj->upper - adj->page_size;
+		if(v < adj->lower)
+		    v = adj->lower;
+		gtk_adjustment_set_value(adj, v);
+	    }
+	    status = TRUE;
+	    break;
 	}
 
 	return(status);
