@@ -1,5 +1,6 @@
 #include <stdlib.h>
 #include <string.h>
+#include <errno.h>
 #include <sys/stat.h>
 #include <gtk/gtk.h>
 
@@ -241,14 +242,15 @@ static void EDVImbrDragDataReceivedNexus(
 	GtkWidget *toplevel = imbr->toplevel;
 	const url_struct *url;
 
-#define DO_FREE_LOCALS	{				\
- g_free(parent_path);					\
- parent_path = NULL;					\
-							\
- /* Delete URL list */					\
- g_list_foreach(url_list, (GFunc)URLDelete, NULL);	\
- g_list_free(url_list);					\
- url_list = NULL;					\
+#define DO_FREE_LOCALS	{		\
+ g_free(parent_path);			\
+					\
+ if(url_list != NULL) {			\
+  g_list_foreach(			\
+   url_list, (GFunc)URLDelete, NULL	\
+  );					\
+  g_list_free(url_list);		\
+ }					\
 }
 
 	/* Get copy of parent_path as the object's full path if the
@@ -277,11 +279,11 @@ static void EDVImbrDragDataReceivedNexus(
 	    parent_path = s;
 	}
 
-	/* Decode the DDE buffer into a list of URLs */  
+	/* Decode the DDE buffer into a list of URLs */
 	url_list = URLDecode(
 	    (const guint8 *)selection_data->data,
 	    selection_data->length
-	);                        
+	);
 	nurls = g_list_length(url_list);
 
 	/* External drag source checks go here, for example sources
@@ -327,7 +329,7 @@ static void EDVImbrDragDataReceivedNexus(
 	    gboolean yes_to_all = FALSE;
 	    gint objects_processed = 0;
 	    gchar *new_path;
-	    const gchar *error_title, *error_msg;
+	    const gchar *path, *error_title, *error_msg;
 	    GList *glist;
 	    struct stat lstat_buf;
 
@@ -344,8 +346,9 @@ static void EDVImbrDragDataReceivedNexus(
 		if(url == NULL)
 		    continue;
 
-		if(STRISEMPTY(parent_path) || STRISEMPTY(url->path))
-		    continue;  
+		path = url->path;
+		if(STRISEMPTY(path))
+		    continue;
 
 		/* Handle by drag action type */
 		status = -1;
@@ -355,7 +358,7 @@ static void EDVImbrDragDataReceivedNexus(
 		{
 		  case GDK_ACTION_COPY:
 		    status = EDVObjectOPCopy(
-			core, url->path, parent_path,
+			core, path, parent_path,
 			&new_path, toplevel,
 			TRUE, TRUE,
 			&yes_to_all
@@ -364,7 +367,7 @@ static void EDVImbrDragDataReceivedNexus(
 		    break;
 		  case GDK_ACTION_MOVE:
 		    status = EDVObjectOPMove(
-			core, url->path, parent_path,
+			core, path, parent_path,
 			&new_path, toplevel,
 			TRUE, TRUE,
 			&yes_to_all
@@ -373,7 +376,7 @@ static void EDVImbrDragDataReceivedNexus(
 		    break;
 		  case GDK_ACTION_LINK:
 		    status = EDVObjectOPLink(
-			core, parent_path, url->path,
+			core, parent_path, path,
 			&new_path, toplevel,
 			TRUE, TRUE,
 			&yes_to_all
@@ -386,9 +389,7 @@ static void EDVImbrDragDataReceivedNexus(
 		    break;
 		}
 
-		/* Get error message (if any) describing the error that
-		 * might have occured in the above operation
-		 */
+		/* Check for and report any errors */
 		if(error_msg == NULL)
 		    error_msg = EDVObjectOPGetError();
 		if(!STRISEMPTY(error_msg))
@@ -397,27 +398,44 @@ static void EDVImbrDragDataReceivedNexus(
 		    EDVMessageObjectOPError(
 			error_title,
 			error_msg,
-			url->path,
+			path,
 			toplevel
 		    );
 		}
 
-		/* Report the new object being added? */
-		if((new_path != NULL) ?
-		    !lstat(new_path, &lstat_buf) : FALSE
-		)
+		/* Get the source object's statistics for reporting */
+		if(lstat(path, &lstat_buf))
 		{
-		    objects_processed++;
-
-		    imbr->processing = FALSE;
-		    EDVObjectAddedEmit(
-			core, new_path, &lstat_buf
-		    );
-		    imbr->processing = TRUE;
+#ifdef ENOENT
+		    /* Report the object being removed */
+		    const gint error_code = (gint)errno;
+		    if(error_code == ENOENT)
+		    {
+			imbr->processing = FALSE;
+			EDVObjectRemovedEmit(core, path);
+			imbr->processing = TRUE;
+		    }
+#endif
 		}
 
-		/* Delete the path of the new object */
-		g_free(new_path);
+		/* Report the new object being added? */
+		if(new_path != NULL)
+		{
+		    if(!lstat(new_path, &lstat_buf))
+		    {
+			objects_processed++;
+
+			imbr->processing = FALSE;
+			EDVObjectAddedEmit(
+			    core,
+			    new_path,
+			    &lstat_buf
+			);
+			imbr->processing = TRUE;
+		    }
+
+		    g_free(new_path);
+		}
 
 		/* User aborted? */
 		if(status == -4)
@@ -469,8 +487,7 @@ static void EDVImbrDragDataReceivedNexus(
 		if(url == NULL)
 		    continue;
 
-		if(STRISEMPTY(url->path))
-		    continue;
+		index = (guint)ATOI(url->path);
 
 		/* Handle by drag action type */
 		status = -1;
@@ -482,7 +499,6 @@ static void EDVImbrDragDataReceivedNexus(
 		    error_msg = "Recycled objects may not be coppied";
 		    break;
 		  case GDK_ACTION_MOVE:
-		    index = (guint)ATOI(url->path);
 		    status = EDVRecBinRecover(
 			core,
 			index,		/* Recycled object to recover */
@@ -517,22 +533,25 @@ static void EDVImbrDragDataReceivedNexus(
 		}
 
 		/* Object recovered? */
-		if((new_path != NULL) ?
-		    !lstat(new_path, &lstat_buf) : FALSE
-		)
+		if(new_path != NULL)
 		{
-		    objects_recovered++;
+		    if(!lstat(new_path, &lstat_buf))
+		    {
+			objects_recovered++;
 
-		    imbr->processing = FALSE;
-		    EDVObjectAddedEmit(
-			core, new_path, &lstat_buf
-		    );
-		    imbr->processing = TRUE;
+			imbr->processing = FALSE;
+			EDVRecycledObjectRemovedEmit(core, index);
+			EDVObjectAddedEmit(
+			    core,
+			    new_path,
+			    &lstat_buf
+			);
+			imbr->processing = TRUE;
+		    }
+
+		    g_free(new_path);
 		}
 
-		/* Delete the path of the new object */
-		g_free(new_path);
-
 		/* User aborted? */
 		if(status == -4)
 		    break;
@@ -638,9 +657,7 @@ static void EDVImbrDragDataReceivedNexus(
 		preserve_timestamps
 	    );
 
-	    /* Get error message (if any) describing the error that
-	     * might have occured in the above operation
-	     */
+	    /* Check for and report any errors */
 	    error_msg = EDVArchExtractGetError();
 	    if(!STRISEMPTY(error_msg))
 	    {
@@ -678,12 +695,10 @@ static void EDVImbrDragDataReceivedNexus(
 		}
 
 		imbr->processing = TRUE;
-	    }
 
-	    /* Delete the list of extracted object paths */
-	    g_list_foreach(new_paths_list, (GFunc)g_free, NULL);
-	    g_list_free(new_paths_list);
-	    new_paths_list = NULL;                
+		g_list_foreach(new_paths_list, (GFunc)g_free, NULL);
+		g_list_free(new_paths_list);
+	    }
 
 	    /* Update the status bar message */
 	    EDVImbrDNDUpdateStatusBar(
@@ -885,7 +900,7 @@ void EDVImbrTListDragDataGetCB(
 
 	/* Delete URL list */
 	g_list_foreach(url_list, (GFunc)URLDelete, NULL);
-	g_list_free(url_list);  
+	g_list_free(url_list);
 
 	/* If failed to send out data then respond with error */
 	if(!data_sent)
@@ -960,63 +975,10 @@ void EDVImbrTListDragDataDeleteCB(
 	GtkWidget *widget, GdkDragContext *dc, gpointer data
 )
 {
-	const gchar *path;
-	gchar **strv;
-	gint i, thumb_num, strc;
-	struct stat lstat_buf;
-	GList *glist;
-	tlist_struct *tlist;
-	edv_object_struct *obj;
-	edv_core_struct *core;
-	edv_imbr_struct *imbr = EDV_IMBR(data);
-	if((dc == NULL) || (imbr == NULL))
-	    return;
 
-	tlist = imbr->tlist;
-	core = imbr->core;
-	if((tlist == NULL) || (core == NULL))
-	    return;
-
-	/* Iterate through selected thumbs, getting a list of paths */
-	strv = NULL;
-	strc = 0;
-	for(glist = tlist->selection;
-	    glist != NULL;
-	    glist = g_list_next(glist)
-	)
-	{
-	    thumb_num = (gint)glist->data;
-	    obj = EDV_OBJECT(TListGetThumbData(tlist, thumb_num));
-	    if((obj != NULL) ? !STRISEMPTY(obj->full_path) : FALSE)
-	    {
-		i = strc;
-		strc = i + 1;
-		strv = (gchar **)g_realloc(
-		    strv, strc * sizeof(gchar *)
-		);
-		if(strv == NULL)
-		{
-		    strc = 0;
-		    break;
-		}
-		strv[i] = STRDUP(obj->full_path);
-	    }
-	}
-
-	/* Emit object removed signal and delete each path in the list */
-	for(i = 0; i < strc; i++)
-	{
-	    path = strv[i];
-	    if(!STRISEMPTY(path))
-	    {
-		if(lstat(path, &lstat_buf))
-		    EDVObjectRemovedEmit(core, path);
-	    }
-	    g_free(strv[i]);
-	}
-	g_free(strv);
 }
 
+
 /*
  *	Image Browser ImgView "drag_data_received" signal callback.
  */
