@@ -1,5 +1,7 @@
 #include <stdlib.h>
 #include <string.h>
+#include <errno.h>
+#include <ctype.h>
 #include <gtk/gtk.h>
 
 #include "../include/string.h"
@@ -1703,13 +1705,11 @@ void EDVImbrOPChTime(edv_imbr_struct *imbr)
  */
 void EDVImbrOPDelete(edv_imbr_struct *imbr)
 {
+	struct stat lstat_buf;
 	gboolean yes_to_all = FALSE;
-	gint i, status;
-	const gchar *path;
-	gchar **object_path = NULL;
-	gint total_object_paths = 0, objects_deleted = 0;
-	GList *index_list;
-	const gchar *error_msg;
+	gint status, npaths, objects_deleted = 0;
+	const gchar *path, *error_msg;
+	GList *glist, *paths_list = NULL, *index_list;
 	GtkWidget *toplevel;
 	edv_core_struct *core;
 
@@ -1717,9 +1717,12 @@ void EDVImbrOPDelete(edv_imbr_struct *imbr)
 	    return;
 
 #define DO_FREE_LOCALS	{			\
- strlistfree(object_path, total_object_paths);	\
- object_path = NULL;				\
- total_object_paths = 0;			\
+ if(paths_list != NULL) {			\
+  g_list_foreach(				\
+   paths_list, (GFunc)g_free, NULL		\
+  );						\
+  g_list_free(paths_list);			\
+ }						\
 }
 
 	toplevel = imbr->toplevel;
@@ -1744,52 +1747,41 @@ void EDVImbrOPDelete(edv_imbr_struct *imbr)
 	 */
 	if(TRUE)
 	{
-	    gint i, thumb_num;
-	    GList *glist;
 	    tlist_struct *tlist = imbr->tlist;
+	    gint thumb_num;
 	    edv_object_struct *obj;
 
-
-	    glist = (tlist != NULL) ? tlist->selection : NULL;
-	    while(glist != NULL)
+	    for(glist = tlist->selection;
+		glist != NULL;
+	        glist = g_list_next(glist)
+	    )
 	    {
 		thumb_num = (gint)glist->data;
 		obj = EDV_OBJECT(
 		    TListGetThumbData(tlist, thumb_num)
 		);
 		if((obj != NULL) ? (obj->full_path != NULL) : FALSE)
-		{
-		    i = total_object_paths;
-		    total_object_paths = i + 1;
-		    object_path = (gchar **)g_realloc(
-			object_path,
-			total_object_paths * sizeof(gchar *)
+		    paths_list = g_list_append(
+			paths_list,
+			STRDUP(obj->full_path)
 		    );
-		    if(object_path == NULL)
-		    {
-			total_object_paths = 0;
-			break;
-		    }
-
-		    object_path[i] = STRDUP(obj->full_path);
-		}
-
-		glist = g_list_next(glist);
 	    }
 	}
 
-	/* No disk objects selected? */
-	if(total_object_paths <= 0)
+	/* No objects selected? */
+	if(paths_list == NULL)
 	{
 	    DO_FREE_LOCALS
 	    return;
 	}
 
+	npaths = g_list_length(paths_list);
+
 	/* Confirm delete */
 	status = EDVConfirmDelete(
 	    core, toplevel,
-	    (total_object_paths == 1) ? object_path[0] : NULL,
-	    total_object_paths
+	    (npaths == 1) ? (const gchar *)paths_list->data : NULL,
+	    npaths
 	);
 	switch(status)
 	{
@@ -1810,9 +1802,12 @@ void EDVImbrOPDelete(edv_imbr_struct *imbr)
 
 	/* Iterate through the list of object paths */
 	status = 0;
-	for(i = 0; i < total_object_paths; i++)
+	for(glist = paths_list;
+	    glist != NULL;
+	    glist = g_list_next(glist)
+	)
 	{
-	    path = object_path[i];
+	    path = (const gchar *)glist->data;
 	    if(path == NULL)
 		continue;
 
@@ -1825,9 +1820,7 @@ void EDVImbrOPDelete(edv_imbr_struct *imbr)
 		TRUE, TRUE, &yes_to_all
 	    );
 
-	    /* Get error message (if any) describing the error that
-	     * might have occured in the above operation
-	     */
+	    /* Check for and report any errors */
 	    error_msg = EDVRecBinDeleteObjectGetError();
 	    if(!STRISEMPTY(error_msg))
 	    {
@@ -1840,10 +1833,20 @@ void EDVImbrOPDelete(edv_imbr_struct *imbr)
 		);
 	    }
 
+	    /* Check if the object still exists */
+	    if(lstat(path, &lstat_buf))
+	    {
+#ifdef ENOENT
+		/* Report the object being removed */
+		const gint error_code = (gint)errno;
+		if(error_code == ENOENT)
+		    EDVObjectRemovedEmit(core, path); 
+#endif
+	    }
+
 	    /* Any objects deleted? */
 	    if(index_list != NULL)
 	    {
-		struct stat lstat_buf;
 		guint index;
 		GList *glist;
 
@@ -1855,10 +1858,6 @@ void EDVImbrOPDelete(edv_imbr_struct *imbr)
 
 		    objects_deleted++;
 		}
-
-		/* Report the object removed? */
-		if(lstat(path, &lstat_buf))
-		    EDVObjectRemovedEmit(core, path);
 	    }
 
 	    /* Delete the recycle objects index list */
@@ -1886,7 +1885,7 @@ void EDVImbrOPDelete(edv_imbr_struct *imbr)
 	    else
 		s = g_strdup_printf(
 		    "Unable to delete %s",
-		    (total_object_paths == 1) ? "object" : "objects"
+		    (npaths == 1) ? "object" : "objects"
 		);
 	    EDVStatusBarMessage(imbr->status_bar, s, FALSE);
 	    g_free(s);
