@@ -85,6 +85,10 @@ static gint EDVImbrTListAppendObject(
 );
 
 /* Finding */
+gint EDVImbrTListFindThumbByIndex(
+	edv_imbr_struct *imbr,
+	const gulong device_index, const gulong index
+);
 gint EDVImbrTListFindThumbByPath(
 	edv_imbr_struct *imbr, const gchar *path
 );
@@ -814,10 +818,57 @@ static gint EDVImbrTListAppendObject(
 }
 
 /*
- *	Returns the thumb index number who's disk object data structure's
- *	full path matches the given path.
+ *	Finds the thumb who's object matches the location index.
  *
- *	Can return -1 on error or failed match.
+ *	The device_index specifies the index of the device that the
+ *	object resides on.
+ *
+ *	The index specifies the index on the device that the object
+ *	resides at.
+ *
+ *	Returns the matched thumb or -1 on error.
+ */
+gint EDVImbrTListFindThumbByIndex(
+	edv_imbr_struct *imbr, 
+	const gulong device_index, const gulong index
+)
+{
+	gint i;
+	tlist_struct *tlist;
+	edv_object_struct *obj;
+
+	if(imbr == NULL)
+	    return(-1);
+
+	tlist = imbr->tlist;
+	if(tlist == NULL)
+	    return(-1);
+
+	/* Iterate through the thumbs list and look for a thumb
+	 * who's object matches the specified location index
+	 */
+	for(i = 0; i < tlist->total_thumbs; i++)
+	{
+	    obj = EDV_OBJECT(TListGetThumbData(tlist, i));
+	    if(obj == NULL)
+		continue;
+
+	    /* Location indices match? */
+	    if((obj->device_index == device_index) &&
+	       (obj->index == index)
+	    )
+		return(i);
+	}
+
+	return(-1);
+}
+
+/*
+ *	Finds the thumb who's object matches the path.
+ *
+ *	The path specifies the full path of the object.
+ *
+ *	Returns the matched thumb or -1 on error.
  */
 gint EDVImbrTListFindThumbByPath(
 	edv_imbr_struct *imbr, const gchar *path
@@ -834,7 +885,9 @@ gint EDVImbrTListFindThumbByPath(
 	if(tlist == NULL)
 	    return(-1);
 
-	/* Iterate through all thumbs */
+	/* Iterate through the thumbs list and look for a thumb
+	 * who's object matches the specified path
+	 */
 	for(i = 0; i < tlist->total_thumbs; i++)
 	{
 	    obj = EDV_OBJECT(TListGetThumbData(tlist, i));
@@ -1731,16 +1784,19 @@ static void EDVImbrTListFPromptRenameApplyCB(
 	    /* Check if the selected object is valid */
 	    if((obj != NULL) ? !STRISEMPTY(obj->full_path) : FALSE)
 	    {
-		gchar *old_full_path = STRDUP(obj->full_path);
-		gchar *new_obj = NULL;
-		const gchar *error_msg;
 		gboolean yes_to_all = FALSE;
+		const gchar *error_msg;
+		gchar *old_full_path = STRDUP(obj->full_path);
+		GList *modified_paths_list;
 
-		/* Perform rename */
+		/* Rename */
 		EDVObjectOPRename(
-		    core, old_full_path, value,
-		    &new_obj, toplevel,
-		    FALSE, TRUE,
+		    core,
+		    old_full_path, value,
+		    &modified_paths_list,
+		    toplevel,
+		    FALSE,			/* Do not show progress */
+		    TRUE,			/* Interactive */
 		    &yes_to_all
 		);
 
@@ -1765,49 +1821,56 @@ static void EDVImbrTListFPromptRenameApplyCB(
 		    );
 		}
 
-		/* Got new object full path name (implying success)? */
-		if((new_obj != NULL) && (old_full_path != NULL))
+		/* Report the modified objects */
+		if(modified_paths_list != NULL)
 		{
 		    struct stat lstat_buf;
-		    const gchar	*new_child = g_basename(new_obj),
-				*old_child = g_basename(old_full_path);
+		    const gchar *modified_path;
+		    GList *glist;
 
-		    /* Get new local statistics for the renamed object */
-		    if(!lstat(new_obj, &lstat_buf))
+		    for(glist = modified_paths_list;
+			glist != NULL;
+			glist = g_list_next(glist)
+		    )
 		    {
-			gchar *buf = g_strdup_printf(
-			    "Object \"%s\" renamed to \"%s\"",
-			    old_child, new_child
-			);
-			EDVStatusBarMessage(
-			    imbr->status_bar, buf, FALSE
-			);
-			g_free(buf);
+			modified_path = (const gchar *)glist->data;
+			if(modified_path == NULL)
+			    continue;
 
-			/* Emit object modified signal to all windows */
-			EDVObjectModifiedEmit(
-			    core, old_full_path,
-			    new_obj, &lstat_buf
-			);
+			if(!lstat(modified_path, &lstat_buf))
+			{
+			    gchar *s = g_strdup_printf(
+				"Object \"%s\" renamed to \"%s\"",
+				g_basename(old_full_path),
+				g_basename(modified_path)
+			    );
+			    EDVStatusBarMessage(imbr->status_bar, s, FALSE);
+			    g_free(s);
+
+			    EDVObjectModifiedEmit(
+				core,
+				old_full_path,
+				modified_path,
+				&lstat_buf
+			    );
+			}
 		    }
+
+		    g_list_foreach(modified_paths_list, (GFunc)g_free, NULL);
+		    g_list_free(modified_paths_list);
 		}
 		else
 		{
-		    /* Did not get new object path new_obj, this
+		    /* Did not get the modified object path so this
 		     * implies failure
 		     */
 		    EDVStatusBarMessage(
-			imbr->status_bar, "Rename object failed", FALSE
+			imbr->status_bar,
+			"Rename object failed",
+			FALSE
 		    );
 		}
 
-		/* The object may now be invalid if the object modified
-		 * signal was emitted
-		 */
-		obj = NULL;
-
-		/* Delete coppies of paths */
-		g_free(new_obj);
 		g_free(old_full_path);
 	    }
 	}
@@ -1962,11 +2025,15 @@ void EDVImbrTListObjectAddedNotify(
 	    return;
 	}
 
-	/* Check if the added path refers to an object that is already
-	 * in the list
+	/* Check if the added object refers to an object that is
+	 * already listed
 	 */
-	thumb_num = EDVImbrTListFindThumbByPath(imbr, path);
-	if((thumb_num >= 0) && (thumb_num < tlist->total_thumbs))
+	thumb_num = EDVImbrTListFindThumbByIndex(
+	    imbr,
+	    (gulong)lstat_buf->st_dev,
+	    (gulong)lstat_buf->st_ino
+	);
+	if(thumb_num > -1)
 	{
 	    /* Update the existing object */
 	    obj = EDV_OBJECT(TListGetThumbData(tlist, thumb_num));
@@ -2023,7 +2090,6 @@ void EDVImbrTListObjectModifiedNotify(
 	const gchar *cur_path;
 	gchar *parent_path;
 	tlist_struct *tlist;
-	edv_object_struct *obj;
 	edv_core_struct *core;
 
 	if((imbr == NULL) || (path == NULL) || (lstat_buf == NULL))
@@ -2054,10 +2120,16 @@ void EDVImbrTListObjectModifiedNotify(
 	else if(!strcmp(parent_path, cur_path))
 	{
 	    /* Update the existing object */
-	    const gint thumb_num = EDVImbrTListFindThumbByPath(imbr, path);
-	    if((thumb_num >= 0) && (thumb_num < tlist->total_thumbs))
+	    const gint thumb_num = EDVImbrTListFindThumbByIndex(
+		imbr,
+		(gulong)lstat_buf->st_dev,
+		(gulong)lstat_buf->st_ino
+	    );
+	    if(thumb_num > -1)
 	    {
-		obj = EDV_OBJECT(TListGetThumbData(tlist, thumb_num));
+		edv_object_struct *obj = EDV_OBJECT(
+		    TListGetThumbData(tlist, thumb_num)
+		);
 		if(obj != NULL)
 		{
 		    EDVObjectSetPath(obj, new_path);		/* Use new_path */
@@ -2112,8 +2184,11 @@ void EDVImbrTListObjectRemovedNotify(
 	else if(!strcmp(parent_path, cur_path))
 	{
 	    /* Remove the existing object */
-	    const gint thumb_num = EDVImbrTListFindThumbByPath(imbr, path);
-	    if((thumb_num >= 0) && (thumb_num < tlist->total_thumbs))
+	    const gint thumb_num = EDVImbrTListFindThumbByPath(
+		imbr,
+		path
+	    );
+	    if(thumb_num > -1)
 	    {
 		TListFreeze(tlist);
 		TListRemove(tlist, thumb_num);
