@@ -11,23 +11,23 @@
 #include <endeavour2.h>
 
 
-void print_device_info(edv_device_struct *d);
+static void print_device_info(edv_device_struct *d);
 
-edv_device_struct *match_device(
+static edv_device_struct *match_device(
 	edv_context_struct *ctx, const gchar *path
 );
 
-void list_devices(edv_context_struct *ctx);
+static void list_devices(edv_context_struct *ctx);
 
-void mount_device(edv_context_struct *ctx, edv_device_struct *d);
-void unmount_device(edv_context_struct *ctx, edv_device_struct *d);
-void eject_device(edv_context_struct *ctx, edv_device_struct *d);
+static void mount_device(edv_context_struct *ctx, edv_device_struct *d);
+static void unmount_device(edv_context_struct *ctx, edv_device_struct *d);
+static void eject_device(edv_context_struct *ctx, edv_device_struct *d);
 
 
 /*
  *	Prints information about the specified Device.
  */
-void print_device_info(edv_device_struct *d)
+static void print_device_info(edv_device_struct *d)
 {
 	gulong used;
 
@@ -64,7 +64,7 @@ void print_device_info(edv_device_struct *d)
 /*
  *	Matches a Device by the specified mount path or device path.
  */
-edv_device_struct *match_device(
+static edv_device_struct *match_device(
 	edv_context_struct *ctx, const gchar *path
 )
 {
@@ -91,7 +91,7 @@ edv_device_struct *match_device(
 /*
  *	Prints a list of all Devices.
  */
-void list_devices(edv_context_struct *ctx)
+static void list_devices(edv_context_struct *ctx)
 {
 	gint i, total;
 	edv_device_struct **list = EDVDevicesList(ctx, &total);
@@ -109,27 +109,27 @@ void list_devices(edv_context_struct *ctx)
 /*
  *	Mounts the specified Device.
  */
-void mount_device(edv_context_struct *ctx, edv_device_struct *d)
+static void mount_device(edv_context_struct *ctx, edv_device_struct *d)
 {
-	if(EDVMount(ctx, d, TRUE))
+	if(EDVDeviceMount(ctx, d, TRUE))
 	    g_printerr("%s\n", EDVMountGetError());
 }
 
 /*
  *	Unmounts the specified Device.
  */
-void unmount_device(edv_context_struct *ctx, edv_device_struct *d)
+static void unmount_device(edv_context_struct *ctx, edv_device_struct *d)
 {
-	if(EDVUnmount(ctx, d, TRUE))
+	if(EDVDeviceUnmount(ctx, d, TRUE))
 	    g_printerr("%s\n", EDVMountGetError());
 }
 
 /*
  *	Ejects the specified Device.
  */
-void eject_device(edv_context_struct *ctx, edv_device_struct *d)
+static void eject_device(edv_context_struct *ctx, edv_device_struct *d)
 {
-	if(EDVEject(ctx, d))
+	if(EDVDeviceEject(ctx, d))
 	    g_printerr("%s\n", EDVMountGetError());
 }
 
