@@ -3,7 +3,6 @@
  *	with EDVGet*() functions.
  */
 
-#include <stdio.h>
 #include <glib.h>
 #include <endeavour2.h>
 
@@ -29,12 +28,12 @@ int main(int argc, char *argv[])
 	params = EDVGetConfigurationParameters(ctx, &total);
 	for(i = 0; i < total; i++)
 	{
-	    printf("%s\n", params[i]);
+	    g_print("%s\n", params[i]);
 	    g_free(params[i]);
 	}
 	g_free(params);
 
-	printf("%i parameters found\n", i);
+	g_print("%i parameters found\n", i);
 
 	EDVContextSync(ctx);
 	EDVContextDelete(ctx);
