@@ -113,7 +113,14 @@ static gint EDVContextMimeTypeAppend(
 
 
 /*
- *	Allocates a new Endeavour Context.
+ *	Creates a new Endeavour 2 Context.
+ *
+ *	The function EDVContextLoadConfigurationFile() should be
+ *	called after this call in order to set up the Endeavour 2
+ *	Context.
+ *
+ *	Returns the Endeavour 2 Context or NULL on error. To delete
+ *	the returned Endeavour 2 Context, call EDVContextDelete().
  */
 edv_context_struct *EDVContextNew(void)
 {
@@ -142,20 +149,17 @@ edv_context_struct *EDVContextNew(void)
 }
 
 /*
- *	Loads the configuration from the specified Endeavour 
- *	configuration file.
+ *	Opens the configuration and sets up the Endeavour 2 Context.
  *
- *	If path is NULL then the default configuration file found in the
- *	user's home directory will be used:
+ *	The ctx specifies the Endeavour 2 Context. This should be
+ *	called right after EDVContextNew() to ensure that the context
+ *	ctx is set up properly before passing to any other function.
+ *
+ *	The path specifies the full path to the alternate configuration
+ *	file. If path is NULL then the default configuration file found
+ *	in the user's home directory will be used:
  *
  *		$HOME/.endeavour2/endeavour2.ini
- *
- *	Additional configuration file loading and set up will also be
- *	performed during this call.
- *
- *      This should be called right after EDVContextNew() to ensure
- *      that the context ctx is set up properly before passing to any
- *	other function.
  */
 void EDVContextLoadConfigurationFile(
 	edv_context_struct *ctx,
@@ -601,7 +605,9 @@ static void EDVContextLoadMimeTypes(edv_context_struct *ctx)
 
 
 /*
- *      Returns the number of queued commands on the context ctx.
+ *	Returns the number of queued commands.
+ *
+ *	The ctx specifies the Endeavour 2 Context.
  */
 gint EDVContextCommandsPending(edv_context_struct *ctx)
 {
@@ -609,14 +615,16 @@ gint EDVContextCommandsPending(edv_context_struct *ctx)
 }
 
 /*
- *	Appends the given cmd to the list of queued commands on the
- *	context ctx.
+ *	Appends a command to the queued commands list.
  *
- *	The command is queued and will not actually be sent until
- *	EDVContextFlush() is called.
+ *	The ctx specifies the Endeavour 2 Context.
+ *
+ *	The cmd specifies the command. This command will be queued, to
+ *	actually execute it, call EDVContextFlush() or EDVContextSync().
  */
 void EDVContextQueueCommand(
-	edv_context_struct *ctx, const gchar *cmd
+	edv_context_struct *ctx,
+	const gchar *cmd
 )
 {
 	gint i;
@@ -642,14 +650,15 @@ void EDVContextQueueCommand(
 }
 
 /*
- *	Processes and flushes all pending operations and resources on
- *      the given context ctx.
+ *	Processes and flushes all pending operations and resources.
  *
  *	All queued commands will be sent (regardless if Endeavour is
  *	running or not).
  *
- *      This call will not block/wait for Endeavour to acknowlage
- *      the request, for that use EDVContextWait();
+ *	This call will not block/wait for Endeavour to acknowlage
+ *	the request, for that use EDVContextWait();
+ *
+ *	The ctx specifies the Endeavour 2 Context.
  */
 void EDVContextFlush(edv_context_struct *ctx)
 {
@@ -687,11 +696,14 @@ void EDVContextFlush(edv_context_struct *ctx)
 }
 
 /*
- *	Waits for a response from Endeavour (if it is running) to
+ *	Waits for a response from Endeavour 2 (if it is running) to
  *	indicate that it has processed all the commands sent to it
  *	from a prior call to EDVContextFlush() (if any).
  *
- *	If Endeavour is not running then this call returns immediately.
+ *	If Endeavour 2 is not running then this call returns
+ *	immediately.
+ *
+ *	The ctx specifies the Endeavour 2 Context.
  */
 void EDVContextWait(edv_context_struct *ctx)
 {
@@ -709,10 +721,11 @@ void EDVContextWait(edv_context_struct *ctx)
 }
 
 /*
- *	Deletes the Endeavour Context and all it's resources.
+ *	Deletes the Endeavour 2 Context and closes to "connection"
+ *	to Endeavour 2 (if it was running). Any pending operations
+ *	will not be performed and will be discarded.
  *
- *	Any pending operations will not be performed and will be
- *	discarded.
+ *	The ctx specifies the Endeavour 2 Context.
  */
 void EDVContextDelete(edv_context_struct *ctx)
 {
