@@ -13,21 +13,35 @@ typedef enum {
 
 /*
  *	Returns a statically allocated string describing the date &
- *	time specified by t in systime seconds.
+ *	time.
  *
  *	The format and relativity of the date & time is specified by    
  *	the configuration on the context.
+ *
+ *	The ctx specifies the Endeavour 2 Context.
+ *
+ *	The t specifies the time in seconds since EPOCH.
  */
-extern const gchar *EDVDateString(edv_context_struct *ctx, gulong t);
+extern const gchar *EDVDateString(
+	edv_context_struct *ctx,
+	const gulong t
+);
 
 /*
- *	Returns a statically allocated string describing the time that
- *	has been lapsed specified by dt in seconds.
+ *	Returns a statically allocated string describing the duration
+ *	(delta time or time lapsed).
  *
  *	The format and relativity of the date & time is specified by
  *	the configuration on the context.
+ *
+ *	The ctx specifies the Endeavour 2 Context.
+ *
+ *	The dt specifies the delta time in seconds.
  */
-extern const gchar *EDVDateStringDuration(edv_context_struct *ctx, gulong dt);
+extern const gchar *EDVDateStringDuration(
+	edv_context_struct *ctx,
+	const gulong dt
+);
 
 
 #endif	/* EDV_DATE_H */
