@@ -6,7 +6,8 @@
 
 
 void EDVHelpSubject(
-	edv_context_struct *ctx, const gchar *subject
+	edv_context_struct *ctx,
+	const gchar *subject
 );
 
 
@@ -24,10 +25,16 @@ void EDVHelpSubject(
 
 /*
  *	Maps the help browser and displays the help file specified by
- *	the given subject.
+ *	subject.
+ *
+ *	The ctx specifies the Endeavour 2 Context.
+ *
+ *	The subject tspecifies the subject. If subject is NULL then the
+ *	contents will be displayed.
  */
 void EDVHelpSubject(
-	edv_context_struct *ctx, const gchar *subject
+	edv_context_struct *ctx,
+	const gchar *subject
 )
 {
 	gchar *cmd;
