@@ -10,11 +10,18 @@
 
 /*
  *	Maps the help browser and displays the help file specified by
- *	the given subject.
+ *	subject.
+ *
+ *	The ctx specifies the Endeavour 2 Context.
+ *
+ *	The subject tspecifies the subject. If subject is NULL then the
+ *	contents will be displayed.
  */
 extern void EDVHelpSubject(
-	edv_context_struct *ctx, const gchar *subject
+	edv_context_struct *ctx,
+	const gchar *subject
 );
+
 #define EDVHelpContents(ctx)	EDVHelpSubject(ctx, NULL)
 #define EDVHelp(ctx)		EDVHelpSubject(ctx, NULL)
 
