@@ -12,17 +12,28 @@
 
 
 /*
- *	Returns a list of MIME Types.
+ *	Gets the MIME Types list.
+ *
+ *	The ctx specifies the Endeavour 2 Context.
+ *
+ *	The total specifies the return value for the total number of MIME Types
+ *	in the list.
  *
  *	The returned list must not be modified or deleted.
  */
 extern edv_mime_type_struct **EDVMimeTypeList(
-	edv_context_struct *ctx, gint *total
+	edv_context_struct *ctx,
+	gint *total
 );
 
 /*
- *	Matches the object specified by path and lstat_buf with a
- *	MIME Type.
+ *	Matches the MIME Type by path and object statistics.
+ *
+ *	The ctx specifies the Endeavour 2 Context.
+ *
+ *	The path specifies the full path or name of the object.
+ *
+ *	The lstat_buf specifies the local statistics of the object.
  *
  *	Returns the matched MIME Type or NULL on error, the returned
  *	MIME Type must not be modified or deleted.
@@ -33,7 +44,11 @@ extern edv_mime_type_struct *EDVMimeTypeMatch(
 );
 
 /*
- *	Matches the MIME Type by the specified type string.
+ *	Matches the MIME Type by type string.
+ *
+ *	The ctx specifies the Endeavour 2 Context.
+ *
+ *	The type specifies the type string.
  *
  *	Returns the matched MIME Type or NULL on error, the returned
  *	MIME Type must not be modified or deleted.
