@@ -196,7 +196,12 @@ int main(int argc, char *argv[])
 #endif  /* HAVE_IMLIB */
 
 	/* Initialize the dialogs */
-	ConMsgInit(PROG_NAME_FULL, 0, 0, show_stdout_dialog, show_stderr_dialog);
+	ConMsgInit(
+	    PROG_NAME_FULL,
+	    0, 0,
+	    show_stdout_dialog,
+	    show_stderr_dialog
+	);
 	CDialogInit();
 	FileBrowserInit();
 	CSDInit();
@@ -205,20 +210,22 @@ int main(int argc, char *argv[])
 	PDialogInit();
 	ProgressDialogInit();
 
-	/* Create the Endeavour core */
+	/* Create the Endeavour 2 core */
 	edv_core = core = EDVNew(argc, argv, &err_rtn);
 	if(core == NULL)
-	    return((err_rtn != 0) ? -err_rtn : 0);
+	    return((err_rtn < 0) ? -err_rtn : err_rtn);
 
-	/* Enter the first GTK main loop */
+	/* Push the first GTK main loop */
 	gtk_main();
 
-	/* Save the configuration and then delete the Endeavour core */
+	/* Save the configuration and then delete the Endeavour 2
+	 * core
+	 */
 	edv_core = NULL;
 	EDVDelete(core, TRUE);
 	core = NULL;
 
-	/* Shutdown Dialogs */
+	/* Shutdown the dialogs */
 	ProgressDialogShutdown();
 	PDialogShutdown();
 	FPromptShutdown();
