@@ -228,6 +228,7 @@ static void EDVObjOpDlgBrowseCB(GtkWidget *widget, gpointer data)
  */
 static void EDVObjOpDlgOwnerMapPUListCB(GtkWidget *widget, gpointer data)
 {
+	gint nitems, nitems_visible;
 	const gchar *value;
 	GtkEntry *entry;
 	pulist_struct *pulist;
@@ -245,11 +246,14 @@ static void EDVObjOpDlgOwnerMapPUListCB(GtkWidget *widget, gpointer data)
 	if(PUListIsQuery(pulist))
 	    return;
 
+	nitems = PUListGetTotalItems(pulist);
+	nitems_visible = MIN(15, nitems);
+
 	/* Block input and get value */
 	value = PUListMapQuery(
 	    pulist,			/* Popup List */
 	    gtk_entry_get_text(entry),	/* Initial Value */
-	    15,				/* Lines Visible */
+	    nitems_visible,
 	    PULIST_RELATIVE_BELOW,	/* Popup Relativity */
 	    GTK_WIDGET(entry),		/* Relative Widget */
 	    widget			/* Map Trigger Widget */
@@ -264,6 +268,7 @@ static void EDVObjOpDlgOwnerMapPUListCB(GtkWidget *widget, gpointer data)
  */
 static void EDVObjOpDlgGroupMapPUListCB(GtkWidget *widget, gpointer data)
 {
+	gint nitems, nitems_visible;
 	const gchar *value;
 	GtkEntry *entry;
 	pulist_struct *pulist;
@@ -281,11 +286,14 @@ static void EDVObjOpDlgGroupMapPUListCB(GtkWidget *widget, gpointer data)
 	if(PUListIsQuery(pulist))
 	    return;
 
+        nitems = PUListGetTotalItems(pulist);
+        nitems_visible = MIN(15, nitems);
+
 	/* Block input and get value */
 	value = PUListMapQuery(
 	    pulist,			/* Popup List */
 	    gtk_entry_get_text(entry),	/* Initial Value */
-	    15,				/* Lines Visible */
+	    nitems_visible,
 	    PULIST_RELATIVE_BELOW,	/* Popup Relativity */
 	    GTK_WIDGET(entry),		/* Relative Widget */
 	    widget			/* Map Trigger Widget */
@@ -466,10 +474,12 @@ static void EDVObjOpDlgMTimeCurrentTimeCB(
 static void EDVObjOpDlgProcess(edv_obj_op_dlg_struct *d)
 {
 	const gboolean show_progress = TRUE;
-	gint i, nobjs;
+	gboolean	recursive = FALSE,
+			dereference_links = FALSE;
+	gint status, nobjs;
 	gchar *tar_path;
 	edv_obj_op_dlg_op op;
-	edv_object_struct **objs_list, *obj;
+	edv_object_struct **objs_list;
 	GtkWidget *w, *toplevel;
 	edv_core_struct *core;
 
@@ -498,19 +508,28 @@ static void EDVObjOpDlgProcess(edv_obj_op_dlg_struct *d)
 	 */
 	toplevel = d->ref_toplevel;
 
-	/* Get source list of disk object structures */
+	/* Get the list of objects to operate on */
 	nobjs = d->src_obj_total;
 	objs_list = d->src_obj;
 
-	/* Get copy of parsed and simplified target path */
+	/* Get the target value */
 	w = d->target_entry;
-	tar_path = (w != NULL) ?
-	    EDVEvaluatePath(d->src_dir, gtk_entry_get_text(GTK_ENTRY(w))) :
-	    NULL;
+	if((w != NULL) ? GTK_WIDGET_MAPPED(w) : FALSE)
+	{
+	    tar_path = EDVEvaluatePath(
+		d->src_dir, gtk_entry_get_text(GTK_ENTRY(w))
+	    );
+	}
+	else
+	{
+	    tar_path = NULL;
+	}
 
-	/* Get permissions */
+	/* Get the permission values if the operation is Change
+	 * Permissions
+	 */
 	w = d->target_chmod_parent;
-	if(w != NULL)
+	if((w != NULL) ? GTK_WIDGET_MAPPED(w) : FALSE)
 	{
 	    if(GTK_TOGGLE_BUTTON_GET_ACTIVE(d->target_ur_check))
 		permissions |= EDV_PERMISSION_UREAD;
@@ -541,9 +560,11 @@ static void EDVObjOpDlgProcess(edv_obj_op_dlg_struct *d)
 		permissions |= EDV_PERMISSION_STICKY;
 	}
 
-	/* Get owner and group */
+	/* Get the owner & group values if the operation is Change
+	 * Ownership
+	 */
 	w = d->target_chown_parent;
-	if(w != NULL)
+	if((w != NULL) ? GTK_WIDGET_MAPPED(w) : FALSE)
 	{
 	    /* Get user id from user entry */
 	    w = d->target_owner_entry;
@@ -562,9 +583,11 @@ static void EDVObjOpDlgProcess(edv_obj_op_dlg_struct *d)
 		);
 	}
 
-	/* Get time */
+	/* Get the time values if the operation is Change Time
+	 * Stamps
+	 */
 	w = d->target_time_parent;
-	if(w != NULL)
+	if((w != NULL) ? GTK_WIDGET_MAPPED(w) : FALSE)
 	{
 	    /* Access time */
 	    struct tm *tm_buf = (struct tm *)g_malloc0(sizeof(struct tm));
@@ -647,23 +670,44 @@ static void EDVObjOpDlgProcess(edv_obj_op_dlg_struct *d)
 	    }
 	}
 
+	/* Get the options if they are specified */
+	w = d->opt_parent;
+	if((w != NULL) ? GTK_WIDGET_MAPPED(w) : FALSE)
+	{
+	    w = d->opt_recursive_check;
+	    if(GTK_WIDGET_MAPPED(w) && GTK_WIDGET_SENSITIVE(w))
+		recursive = GTK_TOGGLE_BUTTON_GET_ACTIVE(
+		    d->opt_recursive_check
+		);
+	    w = d->opt_dereference_links_check;
+	    if(GTK_WIDGET_MAPPED(w) && GTK_WIDGET_SENSITIVE(w))
+		dereference_links = GTK_TOGGLE_BUTTON_GET_ACTIVE(
+		    d->opt_dereference_links_check
+		);
+	}
+
+
 	/* Unmap the Object Operations Dialog */
 	EDVObjOpDlgUnmap(d);
 
 
-	/* Perform the operation */
-	if(TRUE)
+	status = 0;
+
+	/* Perform the operation
+	 *
+	 * Copy?
+	 */
+	if(op == EDV_OBJ_OP_DLG_OP_COPY)
 	{
-	    gboolean	yes_to_all = FALSE,
-			need_emit_modified = FALSE;
-	    gint status = -1;
+	    struct stat lstat_buf;
+	    gboolean yes_to_all = FALSE;
+	    gint i;
 	    const gchar *src_path;
 	    gchar *new_path;
-	    const gchar *error_title, *error_msg;
-	    struct stat lstat_buf;
-	    gint src_lstat_result;
+	    const gchar *error_msg;
+	    edv_object_struct *obj;
 
-	    /* Iterate through the list of objects */
+	    /* Iterate through the objects list and copy each object */
 	    for(i = 0; i < nobjs; i++)
 	    {
 		obj = objs_list[i];
@@ -674,319 +718,487 @@ static void EDVObjOpDlgProcess(edv_obj_op_dlg_struct *d)
 		if(STRISEMPTY(src_path))
 		    continue;
 
-		/* Handle by the specified operation */
-		status = -1;
-		new_path = NULL;
-		error_title = NULL;
-		error_msg = NULL;
-		switch(op)
-		{
-		  case EDV_OBJ_OP_DLG_OP_COPY:
-		    error_title = "Copy Error";
-		    status = EDVObjectOPCopy(
-			core, src_path, tar_path,
-			&new_path, toplevel,
-			show_progress, TRUE,
-			&yes_to_all
-		    );
-		    break;
+		/* Copy this object */
+		status = EDVObjectOPCopy(
+		    core,
+		    src_path, tar_path,
+		    &new_path,
+		    toplevel,
+		    show_progress,
+		    TRUE,			/* Interactive */
+		    &yes_to_all
+		);
 
-		  case EDV_OBJ_OP_DLG_OP_MOVE:
-		    error_title = "Move Error";
-		    status = EDVObjectOPMove(
-			core, src_path, tar_path,
-			&new_path, toplevel,
-			show_progress, TRUE,
-			&yes_to_all
-		    );
-		    break;
-
-		  case EDV_OBJ_OP_DLG_OP_LINK:
-		    error_title = "Link Error";
-		    status = EDVObjectOPLink(
-			core, tar_path, src_path,
-			&new_path, toplevel,
-			show_progress, TRUE,
-			&yes_to_all
-		    );
-		    break;
-
-		  case EDV_OBJ_OP_DLG_OP_CHMOD:
-		    error_title = "Change Permissions Error";
-
-		    /* Report progress */
-		    if(show_progress)
-		    {
-			const gfloat progress = (nobjs > 0) ?
-			    ((gfloat)i / (gfloat)nobjs) : 0.0f;
-			gchar *p1 = EDVShortenPath(
-			    src_path, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
-			);
-			gchar *msg = g_strdup_printf(
-"Changing permissions of:\n\
-\n\
-    %s\n",
-			    p1
-			);
-			g_free(p1);
-		        if(ProgressDialogIsQuery())
-			{
-			    ProgressDialogUpdate(
-				NULL, msg, NULL, NULL,
-				progress, EDV_DEF_PROGRESS_BAR_TICKS, TRUE
-			    );
-			}
-			else
-			{
-			    ProgressDialogSetTransientFor(toplevel);
-			    ProgressDialogMap(
-				"Changing Permissions",
-				msg,
-				(const guint8 **)icon_chmod_32x32_xpm,
-				"Stop"
-			    );
-			    ProgressDialogUpdate(
-				NULL, NULL, NULL, NULL,
-				progress, EDV_DEF_PROGRESS_BAR_TICKS, TRUE
-			    );
-			    gdk_flush();
-			}
-			g_free(msg);
-		    }
-
-		    /* Change the permissions */
-		    status = EDVObjectOPChmod(
-			core, src_path,
-			permissions,
-			toplevel,
-			FALSE,			/* Do not show progress */
-			TRUE,			/* Interactive */
-			&yes_to_all,
-			FALSE			/* Not recursive */
-		    );
-		    need_emit_modified = TRUE;
-
-		    /* Report progress */
-		    if(show_progress && ProgressDialogIsQuery())
-		    {
-			const gfloat progress = (nobjs > 0) ?
-			    ((gfloat)(i + 1) / (gfloat)nobjs) : 0.0f;
-			ProgressDialogUpdate(
-			    NULL, NULL, NULL, NULL,
-			    progress, EDV_DEF_PROGRESS_BAR_TICKS, TRUE
-			);
-		    }     
-		    break;
-
-		  case EDV_OBJ_OP_DLG_OP_CHOWN:
-		    error_title = "Change Ownership Error";
-		    /* Report progress */
-		    if(show_progress)
-		    {
-			const gfloat progress = (nobjs > 0) ?
-			    ((gfloat)i / (gfloat)nobjs) : 0.0f;
-			gchar *p1 = EDVShortenPath(
-			    src_path, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
-			);
-			gchar *msg = g_strdup_printf(
-"Changing ownership of:\n\
-\n\
-    %s\n",
-			    p1
-			);
-			g_free(p1);
-			if(ProgressDialogIsQuery())
-			{
-			    ProgressDialogUpdate(
-				NULL, msg, NULL, NULL,
-				progress, EDV_DEF_PROGRESS_BAR_TICKS, TRUE
-			    );
-			}
-			else
-			{
-			    ProgressDialogSetTransientFor(toplevel);
-			    ProgressDialogMap(
-				"Changing Ownership",
-				msg,
-				(const guint8 **)icon_owned_32x32_xpm,
-				"Stop"
-			    );
-			    ProgressDialogUpdate(
-				NULL, NULL, NULL, NULL,
-				progress, EDV_DEF_PROGRESS_BAR_TICKS, TRUE
-			    );
-			    gdk_flush();
-			}
-			g_free(msg);
-		    }
-
-		    /* Change the ownership */
-		    status = EDVObjectOPChOwn(
-			core, src_path,
-			owner_id, group_id,
-			toplevel,
-			FALSE,			/* Do not show progress */
-			TRUE,			/* Interactive */
-			&yes_to_all,
-			FALSE			/* Not recursive */
-		    );
-		    need_emit_modified = TRUE;
-
-		    /* Report progress */
-		    if(show_progress && ProgressDialogIsQuery())
-		    {
-			const gfloat progress = (nobjs > 0) ?
-			    ((gfloat)(i + 1) / (gfloat)nobjs) : 0.0f;
-			ProgressDialogUpdate(
-			    NULL, NULL, NULL, NULL,
-			    progress, EDV_DEF_PROGRESS_BAR_TICKS, TRUE
-			);
-		    }     
-		    break;
-
-		  case EDV_OBJ_OP_DLG_OP_CHTIME:
-		    error_title = "Change Time Stamps Error";
-
-		    /* Report progress */
-		    if(show_progress)
-		    {
-			const gfloat progress = (nobjs > 0) ?
-			    ((gfloat)i / (gfloat)nobjs) : 0.0f;
-			gchar *p1 = EDVShortenPath(
-			    src_path, EDV_DEF_PROGRESS_BAR_PATH_DISPLAY_MAX
-			);
-			gchar *msg = g_strdup_printf(
-"Changing time stamps of:\n\
-\n\
-    %s\n",
-			    p1
-			);
-			g_free(p1);
-			if(ProgressDialogIsQuery())
-			{
-			    ProgressDialogUpdate(
-				NULL, msg, NULL, NULL,
-				progress, EDV_DEF_PROGRESS_BAR_TICKS, TRUE
-			    );
-			}
-			else
-			{
-			    ProgressDialogSetTransientFor(toplevel);
-			    ProgressDialogMap(
-				"Changing Time Stamps",
-				msg,
-				(const guint8 **)icon_time_stamp_32x32_xpm,
-				"Stop"
-			    );
-			    ProgressDialogUpdate(
-				NULL, NULL, NULL, NULL,
-				progress, EDV_DEF_PROGRESS_BAR_TICKS, TRUE
-			    );
-			    gdk_flush();
-			}
-			g_free(msg);
-		    }
-
-		    /* Change the time stamps */
-		    status = EDVObjectOPChTime(
-			core, src_path,
-			atime, mtime,
-			toplevel,
-			FALSE,			/* Do not show progress */
-			TRUE,			/* Interactive */
-			&yes_to_all,
-			FALSE			/* Not recursive */
-		    );
-		    need_emit_modified = TRUE;
-
-		    /* Report progress */
-		    if(show_progress && ProgressDialogIsQuery())
-		    {
-			const gfloat progress = (nobjs > 0) ?
-			    ((gfloat)(i + 1) / (gfloat)nobjs) : 0.0f;
-			ProgressDialogUpdate(
-			    NULL, NULL, NULL, NULL,
-			    progress, EDV_DEF_PROGRESS_BAR_TICKS, TRUE
-			);
-		    }     
-		    break;
-
-		  default:
-		    error_title = "Operation Error";
-		    error_msg = "Unsupported operation";
- 		    break;
-		}
-
-		/* Get the error message (if any) describing any
-		 * possible error tha tmight have occured during
-		 * the operation
-		 */   
-		if(error_msg == NULL)
-		    error_msg = EDVObjectOPGetError();
-
-		/* Got an error message? */
+		/* Check for and report any errors */
+		error_msg = EDVObjectOPGetError();
 		if(!STRISEMPTY(error_msg))
 		{
-		    /* Display the error message */
 		    EDVPlaySoundError(core);
 		    EDVMessageObjectOPError(
-			error_title,
+			"Copy Error",
 			error_msg,
 			src_path,
 			toplevel
 		    );
 		}
 
+		/* Get the source object's statistics */
+                if(lstat(src_path, &lstat_buf))
+                {
+#ifdef ENOENT
+		    /* Report the source object being removed */
+                    const gint error_code = (gint)errno;
+                    if(error_code == ENOENT)
+                        EDVObjectRemovedEmit(core, src_path);
+#endif
+                }
+
 		/* Report a new object being added? */
-		if((new_path != NULL) ?
-		    !lstat(new_path, &lstat_buf) : FALSE
-		)
-		    EDVObjectAddedEmit(
-			core, new_path, &lstat_buf
-		    );
-
-		/* Get the local stats for the source object */
-		src_lstat_result = lstat(src_path, &lstat_buf);
-
-		/* Need to emit an object modified signal? (For cases of
-		 * chmod or chown operations?
-		 */
-		if(need_emit_modified)
+		if(new_path != NULL)
 		{
-		    if(src_lstat_result == 0)
-			EDVObjectModifiedEmit(
-			    core, src_path, src_path,
+		    if(!lstat(new_path, &lstat_buf))
+			EDVObjectAddedEmit(
+			    core,
+			    new_path,
 			    &lstat_buf
 			);
+
+		    /* Delete the new object path */
+		    g_free(new_path);
 		}
 
-		/* Check if the object no longer exists locally, if it
-		 * no longer exists then emit an object removed signal to
-		 * all of endeavour's resources
-		 *
-		 * Note that this will work out if the operation was a
-		 * copy, link, chmod, or chown since it dosen't emit an
-		 * object removed signal if the object still exists
-		 */
-		if(src_lstat_result != 0)
-		    EDVObjectRemovedEmit(core, src_path);
-
-		/* Delete the path of the new object */
-		g_free(new_path);
-
 		/* User aborted? */
 		if(status == -4)
 		    break;
 	    }
-
-	    /* Unmap the progress dialog */
-	    ProgressDialogBreakQuery(TRUE);
-	    ProgressDialogSetTransientFor(NULL);
-
-	    /* Play the completed sound on success */
-	    if(status == 0)
-		EDVPlaySoundCompleted(core);
 	}
+	/* Move? */
+	else if(op == EDV_OBJ_OP_DLG_OP_MOVE)
+	{
+	    struct stat lstat_buf;
+	    gboolean yes_to_all = FALSE;
+	    gint i;
+	    const gchar *src_path;
+	    gchar *new_path;
+	    const gchar *error_msg;
+	    edv_object_struct *obj;
+
+	    /* Iterate through the objects list and move each object */
+	    for(i = 0; i < nobjs; i++)
+	    {
+		obj = objs_list[i];
+		if(obj == NULL)
+		    continue;
+
+		src_path = obj->full_path;
+		if(STRISEMPTY(src_path))
+		    continue;
+
+		/* Move this object */
+		status = EDVObjectOPMove(
+		    core,
+		    src_path, tar_path,
+		    &new_path,
+		    toplevel,
+		    show_progress,
+		    TRUE,			/* Interactive */
+		    &yes_to_all
+		);
+
+		/* Check for and report any errors */
+		error_msg = EDVObjectOPGetError();
+		if(!STRISEMPTY(error_msg))
+		{
+		    EDVPlaySoundError(core);
+		    EDVMessageObjectOPError(
+			"Move Error",
+			error_msg,
+			src_path,
+			toplevel
+		    );
+		}
+
+		/* Get the source object's statistics */
+                if(lstat(src_path, &lstat_buf))
+                {
+#ifdef ENOENT
+		    /* Report the source object being removed */
+                    const gint error_code = (gint)errno;
+                    if(error_code == ENOENT)
+                        EDVObjectRemovedEmit(core, src_path);
+#endif
+                }
+
+		/* Report a new object being added? */
+		if(new_path != NULL)
+		{
+		    if(!lstat(new_path, &lstat_buf))
+			EDVObjectAddedEmit(
+			    core,
+			    new_path,
+			    &lstat_buf
+			);
+
+		    /* Delete the new object path */
+		    g_free(new_path);
+		}
+
+		/* User aborted? */
+		if(status == -4)
+		    break;
+	    }
+	}
+	/* Link? */
+	else if(op == EDV_OBJ_OP_DLG_OP_LINK)
+	{
+	    struct stat lstat_buf;
+	    gboolean yes_to_all = FALSE;
+	    gint i;
+	    const gchar *src_path;
+	    gchar *new_path;
+	    const gchar *error_msg;
+	    edv_object_struct *obj;
+
+	    /* Iterate through the objects list and link each object */
+	    for(i = 0; i < nobjs; i++)
+	    {
+		obj = objs_list[i];
+		if(obj == NULL)
+		    continue;
+
+		src_path = obj->full_path;
+		if(STRISEMPTY(src_path))
+		    continue;
+
+		/* Link this object */
+		status = EDVObjectOPLink(
+		    core,
+		    tar_path,			/* New link */
+		    src_path,			/* Destination value */
+		    &new_path,
+		    toplevel,
+		    show_progress,
+		    TRUE,			/* Interactive */
+		    &yes_to_all
+		);
+
+		/* Check for and report any errors */
+		error_msg = EDVObjectOPGetError();
+		if(!STRISEMPTY(error_msg))
+		{
+		    EDVPlaySoundError(core);
+		    EDVMessageObjectOPError(
+			"Link Error",
+			error_msg,
+			src_path,
+			toplevel
+		    );
+		}
+
+		/* Get the source object's statistics */
+                if(lstat(src_path, &lstat_buf))
+                {
+#ifdef ENOENT
+		    /* Report the source object being removed */
+                    const gint error_code = (gint)errno;
+                    if(error_code == ENOENT)
+                        EDVObjectRemovedEmit(core, src_path);
+#endif
+                }
+
+		/* Report a new object being added? */
+		if(new_path != NULL)
+		{
+		    if(!lstat(new_path, &lstat_buf))
+			EDVObjectAddedEmit(
+			    core,
+			    new_path,
+			    &lstat_buf
+			);
+
+		    /* Delete the new object path */
+		    g_free(new_path);
+		}
+
+		/* User aborted? */
+		if(status == -4)
+		    break;
+	    }
+	}
+	/* Change permissions? */
+	else if(op == EDV_OBJ_OP_DLG_OP_CHMOD)
+	{
+	    gboolean yes_to_all = FALSE;
+	    gint i;
+	    const gchar *error_msg;
+	    GList *paths_list = NULL, *modified_paths_list;
+	    edv_object_struct *obj;
+
+	    /* Create the paths list */
+	    for(i = 0; i < nobjs; i++)
+	    {
+		obj = objs_list[i];
+		if(obj == NULL)
+		    continue;
+
+		paths_list = g_list_append(
+		    paths_list,
+		    STRDUP(obj->full_path)
+		);
+	    }
+
+	    /* Change the permissions */
+	    status = EDVObjectOPChMod(
+		core,
+		paths_list, permissions,
+		&modified_paths_list,
+		toplevel,
+		show_progress,
+		TRUE,			/* Interactive */
+		&yes_to_all,
+		recursive,
+		!dereference_links	/* Archive */
+	    );
+
+	    /* Check for error */
+	    error_msg = EDVObjectOPGetError();
+	    if(!STRISEMPTY(error_msg))
+	    {
+		EDVPlaySoundError(core);
+		EDVMessageError(
+		    "Change Permissions Error",
+		    error_msg,
+		    NULL,
+		    toplevel
+		);
+	    }
+
+	    /* Report the modified objects */
+	    if(modified_paths_list != NULL)
+	    {
+		struct stat lstat_buf;
+		const gchar *modified_path;
+		GList *glist;
+
+		for(glist = modified_paths_list;
+		    glist != NULL;
+		    glist = g_list_next(glist)
+		)
+		{
+		    modified_path = (const gchar *)glist->data;
+		    if(modified_path == NULL)
+			continue;
+
+		    if(!lstat(modified_path, &lstat_buf))
+			EDVObjectModifiedEmit(
+			    core,
+			    modified_path,
+			    modified_path,
+			    &lstat_buf
+			);
+		}
+
+		/* Delete the modified paths list */
+		g_list_foreach(modified_paths_list, (GFunc)g_free, NULL);
+		g_list_free(modified_paths_list);
+	    }
+
+	    /* Delete the paths list */
+	    if(paths_list != NULL)
+	    {
+		g_list_foreach(paths_list, (GFunc)g_free, NULL);
+		g_list_free(paths_list);
+	    }
+	}
+	/* Change ownership? */
+	else if(op == EDV_OBJ_OP_DLG_OP_CHOWN)
+	{
+	    gboolean yes_to_all = FALSE;
+	    gint i;
+	    const gchar *error_msg;
+	    GList *paths_list = NULL, *modified_paths_list;
+	    edv_object_struct *obj;
+
+	    /* Create the paths list */
+	    for(i = 0; i < nobjs; i++)
+	    {
+		obj = objs_list[i];
+		if(obj == NULL)
+		    continue;
+
+		paths_list = g_list_append(
+		    paths_list,
+		    STRDUP(obj->full_path)
+		);
+	    }
+
+	    /* Change the ownership */
+	    status = EDVObjectOPChOwn(
+		core,
+		paths_list,
+		owner_id, group_id,
+		&modified_paths_list,
+		toplevel,
+		show_progress,
+		TRUE,			/* Interactive */
+		&yes_to_all,
+		recursive,
+		!dereference_links	/* Archive */
+	    );
+
+	    /* Check for error */
+	    error_msg = EDVObjectOPGetError();
+	    if(!STRISEMPTY(error_msg))
+	    {
+		EDVPlaySoundError(core);
+		EDVMessageError(
+		    "Change Ownership Error",
+		    error_msg,
+		    NULL,
+		    toplevel
+		);
+	    }
+
+	    /* Report the modified objects */
+	    if(modified_paths_list != NULL)
+	    {
+		struct stat lstat_buf;
+		const gchar *modified_path;
+		GList *glist;
+
+		for(glist = modified_paths_list;
+		    glist != NULL;
+		    glist = g_list_next(glist)
+		)
+		{
+		    modified_path = (const gchar *)glist->data;
+		    if(modified_path == NULL)
+			continue;
+
+		    if(!lstat(modified_path, &lstat_buf))
+			EDVObjectModifiedEmit(
+			    core,
+			    modified_path,
+			    modified_path,
+			    &lstat_buf
+			);
+		}
+
+		/* Delete the modified paths list */
+		g_list_foreach(modified_paths_list, (GFunc)g_free, NULL);
+		g_list_free(modified_paths_list);
+	    }
+
+	    /* Delete the paths list */
+	    if(paths_list != NULL)
+	    {
+		g_list_foreach(paths_list, (GFunc)g_free, NULL);
+		g_list_free(paths_list);
+	    }
+	}
+	/* Change time stamps? */
+	else if(op == EDV_OBJ_OP_DLG_OP_CHTIME)
+	{
+	    gboolean yes_to_all = FALSE;
+	    gint i;
+	    const gchar *error_msg;
+	    GList *paths_list = NULL, *modified_paths_list;
+	    edv_object_struct *obj;
+
+	    /* Create the paths list */
+	    for(i = 0; i < nobjs; i++)
+	    {
+		obj = objs_list[i];
+		if(obj == NULL)
+		    continue;
+
+		paths_list = g_list_append(
+		    paths_list,
+		    STRDUP(obj->full_path)
+		);
+	    }
+
+	    /* Change the time stamps */
+	    status = EDVObjectOPChTime(
+		core,
+		paths_list,
+		atime, mtime,
+		&modified_paths_list,
+		toplevel,
+		show_progress,
+		TRUE,			/* Interactive */
+		&yes_to_all,
+		recursive,
+		!dereference_links	/* Archive */
+	    );
+
+	    /* Check for error */
+	    error_msg = EDVObjectOPGetError();
+	    if(!STRISEMPTY(error_msg))
+	    {
+		EDVPlaySoundError(core);
+		EDVMessageError(
+		    "Change Time Stamps Error",
+		    error_msg,
+		    NULL,
+		    toplevel
+		);
+	    }
+
+	    /* Report the modified objects */
+	    if(modified_paths_list != NULL)
+	    {
+		struct stat lstat_buf;
+		const gchar *modified_path;
+		GList *glist;
+
+		for(glist = modified_paths_list;
+		    glist != NULL;
+		    glist = g_list_next(glist)
+		)
+		{
+		    modified_path = (const gchar *)glist->data;
+		    if(modified_path == NULL)
+			continue;
+
+		    if(!lstat(modified_path, &lstat_buf))
+			EDVObjectModifiedEmit(
+			    core,
+			    modified_path,
+			    modified_path,
+			    &lstat_buf
+			);
+		}
+
+		/* Delete the modified paths list */
+		g_list_foreach(modified_paths_list, (GFunc)g_free, NULL);
+		g_list_free(modified_paths_list);
+	    }
+
+	    /* Delete the paths list */
+	    if(paths_list != NULL)
+	    {
+		g_list_foreach(paths_list, (GFunc)g_free, NULL);
+		g_list_free(paths_list);
+	    }
+	}
+	else
+	{
+	    g_printerr(
+"EDVObjOpDlgProcess(): Operation %i: Unsupported operation.\n",
+		op
+	    );
+	    status = -2;
+	}
+
+	/* Unmap the progress dialog */
+	ProgressDialogBreakQuery(TRUE);
+	ProgressDialogSetTransientFor(NULL);
+
+	/* Play the completed sound on success */
+	if(status == 0)
+	    EDVPlaySoundCompleted(core);
+
 
 	/* Delete the copy of the target path */
 	g_free(tar_path);
@@ -1424,52 +1636,57 @@ edv_obj_op_dlg_struct *EDVObjOpDlgNew(edv_core_struct *core)
 	parent = w;
 
 
-	/* Main vbox */
+	/* Main GtkVBox */
 	d->main_vbox = w = gtk_vbox_new(FALSE, 0);
 	gtk_container_add(GTK_CONTAINER(parent), w);
 	gtk_widget_show(w);
 	parent = w;
 
 
-	/* Hbox to hold icon and message label */
+	/* Icon & Label GtkHBox */
 	w = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent), w, TRUE, TRUE, border_major);
 	gtk_widget_show(w);
 	parent2 = w;
 
 
-	/* Vbox to hold icon fixed */
+	/* Icon GtkVBox */
 	w = gtk_vbox_new(TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(parent2), w, FALSE, FALSE, border_major);
 	gtk_widget_show(w);
 	parent3 = w;
 
+	/* Icon GtkFixed */
 	d->icon_fixed = w = gtk_fixed_new();
-	d->icon_pm = NULL;
 	gtk_box_pack_start(GTK_BOX(parent3), w, TRUE, FALSE, 0);
 	gtk_widget_realize(w);
 	gtk_widget_show(w);
 
+	/* Icon GtkPixmap will be created later */
+	d->icon_pm = NULL;
 
-	/* Vbox for label and entry */
+
+	/* Label & Operation-Specific Widgets GtkVBox */
 	w = gtk_vbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent2), w, TRUE, TRUE, border_major);
 	gtk_widget_show(w);
 	parent3 = w;
 
-	/* Label hbox */
+
+	/* Label GtkHBox */
 	w = gtk_hbox_new(FALSE, 0);
 	gtk_box_pack_start(GTK_BOX(parent3), w, TRUE, TRUE, 0);
 	gtk_widget_show(w);
 	parent4 = w;
-	/* Label */
-	d->label = w = gtk_label_new("Are you sure?");
+
+	/* GtkLabel */
+	d->label = w = gtk_label_new("");
 	gtk_label_set_justify(GTK_LABEL(w), GTK_JUSTIFY_LEFT);
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 
 
-	/* Hbox for target widgets */
+	/* Operation-Specific GtkHBox */
 	w = gtk_hbox_new(FALSE, border_minor);
 	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
@@ -1486,7 +1703,7 @@ edv_obj_op_dlg_struct *EDVObjOpDlgNew(edv_core_struct *core)
 	gtk_widget_show(w);
 
 
-	/* Target path entry */
+	/* Target GtkEntry */
 	d->target_entry = w = gtk_entry_new();
 	gtk_widget_set_usize(w, 350, -1);
 	GTK_WIDGET_SET_FLAGS(w, GTK_CAN_DEFAULT);
@@ -1498,8 +1715,7 @@ edv_obj_op_dlg_struct *EDVObjOpDlgNew(edv_core_struct *core)
 	EDVEntrySetDND(core, w);
 	EDVEntrySetCompletePath(core, w);
 
-
-	/* Browse button */
+	/* Target Browse GtkButton */
 	d->target_browse_btn = w = GUIButtonPixmap(
 	    (guint8 **)icon_browse_20x20_xpm
 	);
@@ -1510,13 +1726,15 @@ edv_obj_op_dlg_struct *EDVObjOpDlgNew(edv_core_struct *core)
 	);
 
 
-	/* Parent GtkVBox for the permission widgets */
+	/* Create widgets for the Change Permissions operation */
+
+	/* Parent GtkVBox */
 	d->target_chmod_parent = w = gtk_vbox_new(FALSE, border_minor);
 	gtk_widget_set_usize(w, 300, -1);
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
 	parent5 = w;
 
-	/* Create the permission widgets */
+	/* Create the Change Permission widgets */
 	EDVObjOpDlgCreatePermissionWidgets(
 	    parent5, style,
 	    &d->target_ur_check,
@@ -1534,7 +1752,9 @@ edv_obj_op_dlg_struct *EDVObjOpDlgNew(edv_core_struct *core)
 	);
 
 
-	/* Parent GtkVBox for the ownership widgets */
+	/* Create widgets for the Change Ownership operation */
+
+	/* Parent GtkVBox */
 	d->target_chown_parent = w = gtk_vbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);
 	parent5 = w;
@@ -1614,7 +1834,9 @@ edv_obj_op_dlg_struct *EDVObjOpDlgNew(edv_core_struct *core)
 	gtk_widget_show(w);
 
 
-	/* Parent GtkVBox for the time stamp widgets */
+	/* Create widgets for the Change Time Stamps operation */
+
+	/* Parent GtkVBox */
 	d->target_time_parent = w = gtk_vbox_new(FALSE, border_major);
 	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);    
 	parent5 = w;
@@ -1666,19 +1888,55 @@ edv_obj_op_dlg_struct *EDVObjOpDlgNew(edv_core_struct *core)
 	);
 
 
+	/* Create the Options widgets */
+
+	/* Parent GtkVBox */
+	d->opt_parent = w = gtk_vbox_new(FALSE, border_minor);
+	gtk_box_pack_start(GTK_BOX(parent3), w, FALSE, FALSE, 0);
+	parent4 = w;
+
+	w = gtk_hbox_new(FALSE, border_minor);
+	gtk_box_pack_start(GTK_BOX(parent4), w, FALSE, FALSE, 0);    
+	gtk_widget_show(w);
+	parent5 = w;
+
+	/* Recursive */
+	d->opt_recursive_check = w = gtk_check_button_new_with_label(
+	    "Recursive"
+	);
+	gtk_box_pack_start(GTK_BOX(parent5), w, FALSE, FALSE, 0);
+	GTK_TOGGLE_BUTTON_SET_ACTIVE(w, FALSE);
+	GUISetWidgetTip(
+	    w,
+	    "Check this to recurse into subdirectories"
+	);
+
+	/* Dereference Links */
+	d->opt_dereference_links_check = w = gtk_check_button_new_with_label(
+	    "Dereference Links"
+	);
+	gtk_box_pack_start(GTK_BOX(parent5), w, FALSE, FALSE, 0);
+	GTK_TOGGLE_BUTTON_SET_ACTIVE(w, FALSE);
+	GUISetWidgetTip(
+	    w,
+"Check this to operate on the links' destination instead\
+ of the links themselves"
+	);
+
+
 	/* Separator */
 	w = gtk_hseparator_new();
 	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, 0);
 	gtk_widget_show(w);
 
 
-	/* Buttons hbox */
+	/* Buttons GtkHBox */
 	w = gtk_hbox_new(TRUE, 0);
 	gtk_box_pack_start(GTK_BOX(parent), w, FALSE, FALSE, border_major);
 	gtk_widget_show(w);
 	parent2 = w;
 
-	/* Move button */
+	/* Move GtkButton */
 	d->move_btn = w = GUIButtonPixmapLabelH(
 	    (guint8 **)icon_move_file_20x20_xpm,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -1716,7 +1974,7 @@ edv_obj_op_dlg_struct *EDVObjOpDlgNew(edv_core_struct *core)
 	);
 	GUIButtonLabelUnderline(w, GDK_m);
 
-	/* Copy button */
+	/* Copy GtkButton */
 	d->copy_btn = w = GUIButtonPixmapLabelH(
 	    (guint8 **)icon_copy_file_20x20_xpm,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -1754,7 +2012,7 @@ edv_obj_op_dlg_struct *EDVObjOpDlgNew(edv_core_struct *core)
 	);
 	GUIButtonLabelUnderline(w, GDK_o);
 
-	/* Link button */
+	/* Link GtkButton */
 	d->link_btn = w = GUIButtonPixmapLabelH(
 	    (guint8 **)icon_link2_20x20_xpm,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -1792,7 +2050,7 @@ edv_obj_op_dlg_struct *EDVObjOpDlgNew(edv_core_struct *core)
 	);
 	GUIButtonLabelUnderline(w, GDK_l);
 
-	/* Change Permissions button */
+	/* Change Permissions GtkButton */
 	d->chmod_btn = w = GUIButtonPixmapLabelH(
 	    (guint8 **)icon_chmod_20x20_xpm, "ChMod", NULL
 	);
@@ -1812,7 +2070,7 @@ edv_obj_op_dlg_struct *EDVObjOpDlgNew(edv_core_struct *core)
 	);
 	GUIButtonLabelUnderline(w, GDK_h);
 
-	/* Change Ownership button */
+	/* Change Ownership GtkButton */
 	d->chown_btn = w = GUIButtonPixmapLabelH(
 	    (guint8 **)icon_owned_20x20_xpm,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -1850,7 +2108,7 @@ edv_obj_op_dlg_struct *EDVObjOpDlgNew(edv_core_struct *core)
 	);
 	GUIButtonLabelUnderline(w, GDK_h);
 
-	/* Change time stamps button */
+	/* Change Time Stamps GtkButton */
 	d->chtime_btn = w = GUIButtonPixmapLabelH(
 	    (guint8 **)icon_time_stamp_20x20_xpm,
 	    "ChTime",
@@ -1872,7 +2130,7 @@ edv_obj_op_dlg_struct *EDVObjOpDlgNew(edv_core_struct *core)
 	);
 	GUIButtonLabelUnderline(w, GDK_s);
 
-	/* Cancel button */
+	/* Cancel GtkButton */
 	d->cancel_btn = w = GUIButtonPixmapLabelH(
 	    (guint8 **)icon_cancel_20x20_xpm,
 #if defined(PROG_LANGUAGE_SPANISH)
@@ -1916,7 +2174,6 @@ edv_obj_op_dlg_struct *EDVObjOpDlgNew(edv_core_struct *core)
 	gtk_widget_show(w);
 
 
-
 	return(d);
 }
 
@@ -2007,22 +2264,33 @@ gboolean EDVObjOpDlgIsMapped(edv_obj_op_dlg_struct *d)
 }
 
 /*
- *	Maps the Object Operations Dialog with the specified values.
+ *	Maps the Object Operations Dialog.
  *
- *	The given list of src_obj must contain atleast one object, this
- *	list will not be modified by this function.
+ *	The d specifies the Object Operations Dialog.
+ *
+ *	The op specifies the operation.
+ *
+ *	The src_obj and src_obj_total specifies the list of objects
+ *	to be operated on. This list of objects will be coppied and
+ *	stored locally on the Object Operations Dialog.
+ *
+ *	The src_dir specifies the initial target location.
+ *
+ *	The toplevel specifies the relative toplevel GtkWindow.
  */
 void EDVObjOpDlgMapValues(
 	edv_obj_op_dlg_struct *d,
-	const edv_obj_op_dlg_op op,	/* One of EDV_OBJ_OP_DLG_OP_* */
-	edv_object_struct **src_obj,	/* Source list, will be coppied */
+	const edv_obj_op_dlg_op op,
+	edv_object_struct **src_obj,
 	const gint src_obj_total,
 	const gchar *src_dir,
 	GtkWidget *toplevel
 )
 {
 	gint i;
-	gboolean need_warn_chmod_link = FALSE;
+	gboolean	need_warn_chmod_link = FALSE,
+			need_warn_chtime_link = FALSE,
+			map_browse_btn = FALSE;
 	const gchar *title = NULL;
 	gchar *buf = NULL;
 	const gchar *src_obj_full_path, *src_obj_name;
@@ -2030,8 +2298,7 @@ void EDVObjOpDlgMapValues(
 	const gchar *icon_name = NULL;
 	edv_object_struct *obj;
 	edv_core_struct *core;
-	gboolean map_browse_btn = FALSE;
-	GtkWidget *w, *parent, *button = NULL, *target_w = NULL;
+	GtkWidget *w, *parent, *button = NULL, *op_parent = NULL;
 
 	if(d == NULL)
 	    return;
@@ -2067,7 +2334,7 @@ void EDVObjOpDlgMapValues(
 	/* Set operation code */
 	d->op = op;
 
-	/* Update widgets based on operation code */
+	/* Update the widgets based on the operation */
 	switch(op)
 	{
 	  case EDV_OBJ_OP_DLG_OP_MOVE:
@@ -2151,8 +2418,11 @@ void EDVObjOpDlgMapValues(
 		    , src_obj_total
 		);
 	    button = d->move_btn;
-	    target_w = d->target_entry;
+	    op_parent = d->target_entry;
 	    map_browse_btn = TRUE;
+	    gtk_widget_hide(d->opt_parent);
+	    gtk_widget_hide(d->opt_recursive_check);
+	    gtk_widget_hide(d->opt_dereference_links_check);
 	    break;
 
 	  case EDV_OBJ_OP_DLG_OP_COPY:
@@ -2236,8 +2506,11 @@ void EDVObjOpDlgMapValues(
 		    , src_obj_total
 		);
 	    button = d->copy_btn;
-	    target_w = d->target_entry;
+	    op_parent = d->target_entry;
 	    map_browse_btn = TRUE;
+	    gtk_widget_hide(d->opt_parent);
+	    gtk_widget_hide(d->opt_recursive_check);
+	    gtk_widget_hide(d->opt_dereference_links_check);
 	    break;
 
 	  case EDV_OBJ_OP_DLG_OP_LINK:
@@ -2321,8 +2594,11 @@ void EDVObjOpDlgMapValues(
 		    , src_obj_total
 		);
 	    button = d->link_btn;
-	    target_w = d->target_entry;
+	    op_parent = d->target_entry;
 	    map_browse_btn = TRUE;
+	    gtk_widget_hide(d->opt_parent);
+	    gtk_widget_hide(d->opt_recursive_check);
+	    gtk_widget_hide(d->opt_dereference_links_check);
 	    break;
 
 	  case EDV_OBJ_OP_DLG_OP_CHMOD:
@@ -2406,7 +2682,10 @@ void EDVObjOpDlgMapValues(
 		    , src_obj_total
 		);
 	    button = d->chmod_btn;
-	    target_w = d->target_chmod_parent;
+	    op_parent = d->target_chmod_parent;
+	    gtk_widget_show(d->opt_parent);
+	    gtk_widget_show(d->opt_recursive_check);
+	    gtk_widget_show(d->opt_dereference_links_check);
 	    break;
 
 	  case EDV_OBJ_OP_DLG_OP_CHOWN:
@@ -2490,7 +2769,10 @@ void EDVObjOpDlgMapValues(
 		    , src_obj_total
 		);
 	    button = d->chown_btn;
-	    target_w = d->target_chown_parent;
+	    op_parent = d->target_chown_parent;
+	    gtk_widget_show(d->opt_parent);
+	    gtk_widget_show(d->opt_recursive_check);
+	    gtk_widget_show(d->opt_dereference_links_check);
 	    break;
 
 	  case EDV_OBJ_OP_DLG_OP_CHTIME:
@@ -2511,9 +2793,11 @@ void EDVObjOpDlgMapValues(
 		    , src_obj_total
 		);
 	    button = d->chtime_btn;
-	    target_w = d->target_time_parent;
+	    op_parent = d->target_time_parent;
+	    gtk_widget_show(d->opt_parent);
+	    gtk_widget_show(d->opt_recursive_check);
+	    gtk_widget_show(d->opt_dereference_links_check);
 	    break;
-
 	}
 
 	/* Update the icon */
@@ -2571,24 +2855,25 @@ void EDVObjOpDlgMapValues(
 	    if(w != NULL)
 		gtk_label_set_text(GTK_LABEL(w), buf);
 
-	    /* Delete message, it is no longer needed */
 	    g_free(buf);
 	    buf = NULL;
 	}
 
 
-	/* Update the source directory */
+	/* Set the source directory */
 	g_free(d->src_dir);
 	d->src_dir = STRDUP(src_dir);
 
-	/* Update the target entry */
+	/* Set the target GtkEntry's value if it is the operation
+	 * widget?
+	 */
 	w = d->target_entry;
-	if((w != NULL) && (w == target_w))
+	if((w != NULL) && (w == op_parent))
 	{
-	    if(GTK_IS_ENTRY(w))
-		gtk_entry_set_text(
-		    GTK_ENTRY(w), (src_dir != NULL) ? src_dir : ""
-		);
+	    gtk_entry_set_text(
+		GTK_ENTRY(w),
+		(src_dir != NULL) ? src_dir : ""
+	    );
 	    if(GTK_WIDGET_CAN_FOCUS(w))
 		gtk_widget_grab_focus(w);
 	    if(GTK_WIDGET_CAN_DEFAULT(w))
@@ -2623,7 +2908,7 @@ void EDVObjOpDlgMapValues(
 
 	/* Is the operation to change permissions? */
 	w = d->target_chmod_parent;
-	if((w != NULL) && (w == target_w))
+	if((w != NULL) && (w == op_parent))
 	{
 	    /* Set the initial values for the change permission
 	     * widgets
@@ -2722,7 +3007,7 @@ void EDVObjOpDlgMapValues(
 
 	/* Is the operation to change ownership? */
 	w = d->target_chown_parent;
-	if((w != NULL) && (w == target_w))
+	if((w != NULL) && (w == op_parent))
 	{
 	    /* Set the initial values for the owner and group widgets */
 	    edv_object_struct *ref_obj = obj;
@@ -2764,11 +3049,12 @@ void EDVObjOpDlgMapValues(
 
 	/* Is the operation to change time stamps? */
 	w = d->target_time_parent;
-	if((w != NULL) && (w == target_w))
+	if((w != NULL) && (w == op_parent))
 	{
 	    /* Set the initial time stamp widget values to the time
 	     * stamps of the specified object
 	     */
+	    gint i;
 	    edv_object_struct *ref_obj = obj;
 
 	    /* If there was more than one object specified then use the
@@ -2876,6 +3162,17 @@ void EDVObjOpDlgMapValues(
 			);
 		}
 	    }
+
+	    /* Check if we need to warn about links */
+	    for(i = 0; i < d->src_obj_total; i++)
+	    {
+		ref_obj = d->src_obj[i];
+		if(ref_obj == NULL)
+		    continue;
+
+		if(ref_obj->type == EDV_OBJECT_TYPE_LINK)
+		    need_warn_chtime_link = TRUE;
+	    }
 	}
 
 
@@ -2920,8 +3217,8 @@ void EDVObjOpDlgMapValues(
 	    gtk_widget_hide(w);
 
 	/* Check if the target widget to be mapped is valid and map it */
-	if(target_w != NULL)
-	    gtk_widget_show(target_w);
+	if(op_parent != NULL)
+	    gtk_widget_show(op_parent);
 
 	/* Map or unmap the browse button */
 	w = d->target_browse_btn;
@@ -2941,14 +3238,29 @@ void EDVObjOpDlgMapValues(
 	    EDVPlaySoundWarning(core);
 	    EDVMessageWarning(
 "Changing Permissions Warning",
-"Changing the permissions on a symbolic link object\n\
-will effectively change the permissions of its destination\n\
-object.",
+"Changing the permissions on a link will effectively\n\
+change the permissions of its destination object.",
 "One or more of the selected object(s) are of type\n\
-symbolic link. Symbolic links do not have permissions,\n\
-instead their permissions are determined by the permissions\n\
-of the destination object. So changing the permissions on a\n\
-symbolic link will effectively change the permissions of its\n\
+link. Links do not have permissions, instead, their\n\
+permissions are determined by the permissions of the\n\
+destination object. So changing the permissions on a\n\
+link will effectively change the permissions of its\n\
+destination object.",
+		toplevel
+	    );
+	}
+	if(need_warn_chtime_link)
+	{
+	    EDVPlaySoundWarning(core);
+	    EDVMessageWarning(
+"Changing Time Stamps Warning",
+"Changing the time stamps on a link will effectively\n\
+change the time stamps of its destination object.",
+"One or more of the selected object(s) are of type\n\
+link. Links do not have time stamps, instead, their\n\
+time stamps are determined by the time stamps of the\n\
+destination object. So changing the time stamps on a\n\
+link will effectively change the time stamps of its\n\
 destination object.",
 		toplevel
 	    );
@@ -3048,6 +3360,10 @@ void EDVObjOpDlgDelete(edv_obj_op_dlg_struct *d)
 	GTK_WIDGET_DESTROY(d->target_mtime_current_btn);
 	GTK_WIDGET_DESTROY(d->target_time_parent);
 
+	GTK_WIDGET_DESTROY(d->opt_recursive_check);
+	GTK_WIDGET_DESTROY(d->opt_dereference_links_check);
+	GTK_WIDGET_DESTROY(d->opt_parent);
+
 	GTK_WIDGET_DESTROY(d->move_btn)
 	GTK_WIDGET_DESTROY(d->copy_btn)
 	GTK_WIDGET_DESTROY(d->link_btn)
