@@ -1,6 +1,6 @@
 #include <stdlib.h>
 #include <string.h>
-#if defined(WIN32)
+#if defined(_WIN32)
 # include <windows.h>
 #else
 # include <sys/time.h>
@@ -14,7 +14,7 @@
 
 
 /*
- *	Animated Icon structure:
+ *	Animated Icon:
  */
 typedef struct {
 
@@ -26,7 +26,7 @@ typedef struct {
 #define ICON(p)		((icon_struct *)(p))
 
 /*
- *	Progress Dialog structure:
+ *	Progress Dialog:
  */
 typedef struct {
 
@@ -96,6 +96,7 @@ void ProgressDialogSetWMIconData(const guint8 **icon_data);
 gboolean ProgressDialogIsQuery(void);
 void ProgressDialogBreakQuery(gboolean allow_gtk_iteration);
 gint ProgressDialogStopCount(void);
+GtkWidget *ProgressDialogGetToplevel(void);
 void ProgressDialogMap(
 	const gchar *title,
 	const gchar *label,
@@ -487,7 +488,7 @@ static gint ProgressDialogAnimationDrawCB(
  */
 static gulong ProgressDialogCurrentTime(void)
 {
-#if defined(WIN32)
+#if defined(_WIN32)
 	SYSTEMTIME t;   /* Current time of day structure */
 
 	GetSystemTime(&t);
@@ -702,8 +703,8 @@ gint ProgressDialogInit(void)
 
 	    gdk_window_set_decorations(
 		window,
-                GDK_DECOR_BORDER | GDK_DECOR_TITLE | GDK_DECOR_MENU |
-                GDK_DECOR_MINIMIZE
+		GDK_DECOR_BORDER | GDK_DECOR_TITLE | GDK_DECOR_MENU |
+		GDK_DECOR_MINIMIZE
 	    );
 	    gdk_window_set_functions(
 		window,
@@ -920,7 +921,6 @@ void ProgressDialogSetTransientFor(GtkWidget *w)
 {
 	progress_dialog_struct *pd = &progress_dialog;
 
-
 	if(!pd->initialized)
 	    return;
 
@@ -1024,6 +1024,14 @@ gint ProgressDialogStopCount(void)
 	    return(pd->stop_count);
 }
 
+/*
+ *	Gets the progress dialog's toplevel widget.
+ */
+GtkWidget *ProgressDialogGetToplevel(void)
+{
+	return(progress_dialog.toplevel);
+}
+
 /*
  *	Maps the progress dialog for standard progress display.
  *
