@@ -23,6 +23,9 @@ static gint PUListButtonPressEventCB(
 static gint PUListMotionNotifyEventCB(
 	GtkWidget *widget, GdkEventMotion *motion, gpointer data
 );
+static gint PUListCrossingEventCB(
+	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
+);
 static gint PUListMapIdleCB(gpointer data);
 
 /* Shadow Callbacks */
@@ -248,11 +251,11 @@ static gint PUListKeyPressEventCB(
 	if((widget == NULL) || (key == NULL) || (list == NULL))
 	    return(status);
 
-#define BREAK_GTK_MAIN_LOOP	{	\
- while(list->gtk_block_level > 0) {	\
-  list->gtk_block_level--;		\
-  gtk_main_quit();			\
- }					\
+#define BREAK_GTK_MAIN_LOOP(_list_)	{	\
+ while((_list_)->gtk_block_level > 0) {		\
+  (_list_)->gtk_block_level--;			\
+  gtk_main_quit();				\
+ }						\
 }
 
 #define ADJ_CLAMP_EMIT(_adj_)	{		\
@@ -329,7 +332,7 @@ static gint PUListKeyPressEventCB(
 			}
 		    }
 		    /* Break query */
-		    BREAK_GTK_MAIN_LOOP
+		    BREAK_GTK_MAIN_LOOP(list);
 		}
 		STOP_KEY_SIGNAL_EMIT(widget);
 		status = TRUE;
@@ -339,7 +342,7 @@ static gint PUListKeyPressEventCB(
 		if(press)
 		{
 		    /* Break query */
-		    BREAK_GTK_MAIN_LOOP
+		    BREAK_GTK_MAIN_LOOP(list);
 		}
 		STOP_KEY_SIGNAL_EMIT(widget);
 		status = TRUE;
@@ -412,16 +415,16 @@ static gint PUListKeyPressEventCB(
 	    }
 	}
 
-	return(status);
-
 #undef BREAK_GTK_MAIN_LOOP
 #undef ADJ_CLAMP_EMIT
 #undef STOP_KEY_SIGNAL_EMIT
+
+	return(status);
 }
 
 /*
- *	Popup List GtkCList "button_press_event" or
- *	"button_release_event" signal callback.
+ *	Popup List "button_press_event" or "button_release_event"
+ *	signal callback.
  */
 static gint PUListButtonPressEventCB(
 	GtkWidget *widget, GdkEventButton *button, gpointer data
@@ -432,10 +435,10 @@ static gint PUListButtonPressEventCB(
 	if((widget == NULL) || (button == NULL) || (list == NULL))
 	    return(status);
 
-#define BREAK_GTK_MAIN_LOOP	{	\
- while(list->gtk_block_level > 0) {	\
-  list->gtk_block_level--;		\
-  gtk_main_quit();			\
+#define BREAK_GTK_MAIN_LOOP(_list_)	{	\
+ while((_list_)->gtk_block_level > 0) {		\
+  (_list_)->gtk_block_level--;			\
+  gtk_main_quit();				\
 } }
 
 #define RESTORE_MAP_WIDGET(_map_w_)	{	\
@@ -464,7 +467,7 @@ static gint PUListButtonPressEventCB(
 	    gint x, y;
 	    GtkCList *clist = GTK_CLIST(widget);
 
-	    /* Get the widget the event occured over */
+	    /* Get the widget that this event occured over */
 	    GtkWidget *w = gtk_get_event_widget((GdkEvent *)button);
 
 	    switch((gint)button->type)
@@ -472,7 +475,8 @@ static gint PUListButtonPressEventCB(
 	      case GDK_BUTTON_PRESS:
 		x = (gint)button->x;
 		y = (gint)button->y;
-		/* Button pressed outside of the clist? */
+
+		/* Did this event occure outside the clist? */
 		if(w != widget)
 		{
 		    /* Clicked on one of the other GtkWidgets
@@ -484,7 +488,7 @@ static gint PUListButtonPressEventCB(
 		       (w == list->toplevel)
 		    )
 		    {
-			/* Forward event to that GtkWidget */
+			/* Forward event to that widget */
 			gtk_widget_event(w, (GdkEvent *)button);
 		    }
 		    else
@@ -494,7 +498,7 @@ static gint PUListButtonPressEventCB(
 			 * Break out of the block loop and restore the
 			 * map widget
 			 */
-			BREAK_GTK_MAIN_LOOP
+			BREAK_GTK_MAIN_LOOP(list);
 			RESTORE_MAP_WIDGET(list->map_widget);
 		    }
 		}
@@ -515,8 +519,8 @@ static gint PUListButtonPressEventCB(
 		y = (gint)button->y;
 		switch(button->button)
 		{
-		  case 1:
-		    /* Button released inside the clist? */
+		  case GDK_BUTTON1:
+		    /* Did this event occure inside the clist? */
 		    if((w == widget) &&
 		       (x >= 0) && (x < widget->allocation.width) &&
 		       (y >= 0) && (y < widget->allocation.height)
@@ -560,11 +564,11 @@ static gint PUListButtonPressEventCB(
 		        }
 
 			/* Break query */
-			BREAK_GTK_MAIN_LOOP
+			BREAK_GTK_MAIN_LOOP(list);
 		    }
 		    else
 		    {
-			/* Button was released outside of the clist */
+			/* The button was released outside of the clist */
 
 			/* Released over one of the other GtkWidgets
 			 * belonging to the Popup List?
@@ -575,13 +579,13 @@ static gint PUListButtonPressEventCB(
 			   (w == list->toplevel)
 			)
 			{
-			    /* Forward event to that GtkWidget */
+			    /* Forward this event to that widget */
 			    gtk_widget_event(w, (GdkEvent *)button);
 			}
 
 			/* Grab the clist again, since releasing the
 			 * button outside the clist would have
-			 * ungrabbed it and not not unmap it
+			 * ungrabbed it and not unmap it
 			 */
 			if(widget != gtk_grab_get_current())
 			    gtk_grab_add(widget);
@@ -595,14 +599,14 @@ static gint PUListButtonPressEventCB(
 	    }
 	}
 
-	return(status);
-
 #undef RESTORE_MAP_WIDGET
 #undef BREAK_GTK_MAIN_LOOP
+
+	return(status);
 }
 
 /*
- *	Popup List GtkCList "motion_notify_event" signal callback.
+ *	Popup List "motion_notify_event" signal callback.
  */
 static gint PUListMotionNotifyEventCB(
 	GtkWidget *widget, GdkEventMotion *motion, gpointer data
@@ -618,10 +622,9 @@ static gint PUListMotionNotifyEventCB(
 	{
 	    GtkCList *clist = GTK_CLIST(widget);
 
-	    /* Check if the widget that the event occured over was
-	     * the clist
-	     */
+	    /* Get the widget that this event occured over */
 	    GtkWidget *w = gtk_get_event_widget((GdkEvent *)motion);
+
 	    if(widget == w)
 	    {
 		/* Send a "button_press_event" signal to the
@@ -683,6 +686,73 @@ static gint PUListMotionNotifyEventCB(
 	return(status);
 }
 
+/*
+ *	Popup List "button_press_event" or "button_release_event"
+ *	signal callback.
+ */
+static gint PUListCrossingEventCB(
+	GtkWidget *widget, GdkEventCrossing *crossing, gpointer data
+)
+{
+	gint status = FALSE;
+	pulist_struct *list = PULIST(data);
+	if((widget == NULL) || (crossing == NULL) || (list == NULL))
+	    return(status);
+
+	/* See which widget this event is for */
+	if(widget == list->clist)
+	{
+	    /* Get the widget that this event occured over */
+	    GtkWidget *w = gtk_get_event_widget((GdkEvent *)crossing);
+
+	    switch((gint)crossing->type)
+	    {
+	      case GDK_ENTER_NOTIFY:
+		/* Did this event occure outside the clist? */
+		if(w != widget)
+		{
+		    /* Clicked on one of the other GtkWidgets
+		     * belonging to the Popup List?
+		     */
+		    if((w == list->vscrollbar) ||
+		       (w == list->hscrollbar) ||
+		       (w == list->scrolled_window) ||
+		       (w == list->toplevel)
+		    )
+		    {
+			/* Forward event to that widget */
+			gtk_widget_event(w, (GdkEvent *)crossing);
+		    }
+		}
+		status = TRUE;
+		break;
+
+	      case GDK_LEAVE_NOTIFY:
+		/* Did this event occure outside the clist? */
+		if(w != widget)
+		{
+		    /* Clicked on one of the other GtkWidgets
+		     * belonging to the Popup List?
+		     */
+		    if((w == list->vscrollbar) ||
+		       (w == list->hscrollbar) ||
+		       (w == list->scrolled_window) ||
+		       (w == list->toplevel)
+		    )
+		    {
+			/* Forward event to that widget */
+			gtk_widget_event(w, (GdkEvent *)crossing);
+		    }
+		}
+		status = TRUE;
+		break;
+	    }
+	}
+
+	return(status);
+}
+
+
 /*
  *	Popup List's map idle callback.
  *
@@ -950,10 +1020,11 @@ static gint PUListBoxEventCB(
 )
 {
 	gint status = FALSE;
-	gboolean key_press;
+	gboolean press;
 	GdkEventFocus *focus;
 	GdkEventKey *key;
 	GdkEventButton *button;
+	pulist_struct *list;
 	pulistbox_struct *box = PULISTBOX(data);
 	if((widget == NULL) || (event == NULL) || (box == NULL))
 	    return(status);
@@ -984,12 +1055,12 @@ static gint PUListBoxEventCB(
 	  case GDK_KEY_PRESS:
 	  case GDK_KEY_RELEASE:
 	    key = (GdkEventKey *)event;
-	    key_press = (key->type == GDK_KEY_PRESS) ? TRUE : FALSE;
+	    press = (key->type == GDK_KEY_PRESS) ? TRUE : FALSE;
 #define STOP_KEY_SIGNAL_EMIT(_w_)	{	\
 if((_w_) != NULL)				\
  gtk_signal_emit_stop_by_name(			\
   GTK_OBJECT(_w_),				\
-  key_press ?					\
+  press ?					\
    "key_press_event" : "key_release_event"	\
  );						\
 }
@@ -998,7 +1069,7 @@ if((_w_) != NULL)				\
 	      case GDK_Return:
 	      case GDK_KP_Enter:
 	      case GDK_space:
-		if(key_press)
+		if(press)
 		    PUListBoxMapCB(box->map_btn, box);
 		STOP_KEY_SIGNAL_EMIT(widget);
 		status = TRUE; 
@@ -1006,7 +1077,7 @@ if((_w_) != NULL)				\
 
 	      case GDK_Up:
 	      case GDK_KP_Up:
-		if(key_press)
+		if(press)
 		{
 		    pulist_struct *list = PUListBoxGetPUList(box);
 		    GtkCList *clist = (GtkCList *)PUListGetCList(list);
@@ -1041,7 +1112,7 @@ if((_w_) != NULL)				\
 
 	      case GDK_Down:
 	      case GDK_KP_Down:
-		if(key_press)
+		if(press)
 		{
 		    pulist_struct *list = PUListBoxGetPUList(box);
 		    GtkCList *clist = (GtkCList *)PUListGetCList(list);
@@ -1073,6 +1144,156 @@ if((_w_) != NULL)				\
 		STOP_KEY_SIGNAL_EMIT(widget);
 		status = TRUE;
 		break;
+
+	      case GDK_Page_Up:
+	      case GDK_KP_Page_Up:
+		if(press)
+		{
+		    pulist_struct *list = PUListBoxGetPUList(box);
+		    GtkCList *clist = (GtkCList *)PUListGetCList(list);
+		    if(clist != NULL)
+		    {
+			GList *glist = clist->selection_end;
+			const gint sel_row = (glist != NULL) ? (gint)glist->data : -1;
+			gint row = sel_row;
+			if(row < 0)
+			    row = 0;
+			else
+			    row -= MAX((box->nlines_visible / 2), 1);
+			if(row < 0)
+			    row = 0;
+			if((row >= 0) && (row < clist->rows) &&
+			   (row != sel_row)
+			)
+			{
+			    gtk_clist_unselect_all(clist);
+			    gtk_clist_select_row(clist, row, 0);
+
+			    gtk_widget_queue_draw(widget);
+
+			    /* Report new value */
+			    if(box->changed_cb != NULL)
+				box->changed_cb(
+				    box,		/* Popup List Box */
+				    row,		/* Item */
+				    box->changed_data	/* Data */
+				);
+			}
+		    }
+		}
+		STOP_KEY_SIGNAL_EMIT(widget);
+		status = TRUE;
+		break;
+
+	      case GDK_Page_Down:
+	      case GDK_KP_Page_Down:
+		if(press)
+		{
+		    pulist_struct *list = PUListBoxGetPUList(box);
+		    GtkCList *clist = (GtkCList *)PUListGetCList(list);
+		    if(clist != NULL)
+		    {
+			GList *glist = clist->selection_end;
+			const gint sel_row = (glist != NULL) ? (gint)glist->data : -1;
+			gint row = sel_row;
+			if(row < 0)
+			    row = 0;
+			else
+			    row += MAX((box->nlines_visible / 2), 1);
+			if(row >= clist->rows)
+			    row = clist->rows - 1;
+			if((row >= 0) && (row < clist->rows) &&
+			   (row != sel_row)
+			)
+			{
+			    gtk_clist_unselect_all(clist);
+			    gtk_clist_select_row(clist, row, 0);
+
+			    gtk_widget_queue_draw(widget);
+
+			    /* Report new value */
+			    if(box->changed_cb != NULL)
+				box->changed_cb(
+				    box,		/* Popup List Box */
+				    row,		/* Item */
+				    box->changed_data	/* Data */
+				);
+			}
+		    }
+		}
+		STOP_KEY_SIGNAL_EMIT(widget);
+		status = TRUE;
+		break;
+
+	      case GDK_Home:
+	      case GDK_KP_Home:
+		if(press)
+		{
+		    pulist_struct *list = PUListBoxGetPUList(box);
+		    GtkCList *clist = (GtkCList *)PUListGetCList(list);
+		    if(clist != NULL)
+		    {
+			GList *glist = clist->selection_end;
+			const gint sel_row = (glist != NULL) ? (gint)glist->data : -1;
+			gint row = 0;
+			if((row >= 0) && (row < clist->rows) &&
+			   (row != sel_row)
+			)
+			{
+			    gtk_clist_unselect_all(clist);
+			    gtk_clist_select_row(clist, row, 0);
+
+			    gtk_widget_queue_draw(widget);
+
+			    /* Report new value */
+			    if(box->changed_cb != NULL)
+				box->changed_cb(
+				    box,		/* Popup List Box */
+				    row,		/* Item */
+				    box->changed_data	/* Data */
+				);
+			}
+		    }
+		}
+		STOP_KEY_SIGNAL_EMIT(widget);
+		status = TRUE;
+		break;
+
+	      case GDK_End:
+	      case GDK_KP_End:
+		if(press)
+		{
+		    pulist_struct *list = PUListBoxGetPUList(box);
+		    GtkCList *clist = (GtkCList *)PUListGetCList(list);
+		    if(clist != NULL)
+		    {
+			GList *glist = clist->selection_end;
+			const gint sel_row = (glist != NULL) ? (gint)glist->data : -1;
+			gint row = clist->rows - 1;
+			if(row < 0)
+			    row = 0;
+			if((row >= 0) && (row < clist->rows) &&
+			   (row != sel_row)
+			)
+			{
+			    gtk_clist_unselect_all(clist);
+			    gtk_clist_select_row(clist, row, 0);
+
+			    gtk_widget_queue_draw(widget);
+
+			    /* Report new value */
+			    if(box->changed_cb != NULL)
+				box->changed_cb(
+				    box,		/* Popup List Box */
+				    row,		/* Item */
+				    box->changed_data	/* Data */
+				);
+			}
+		    }
+		}
+		STOP_KEY_SIGNAL_EMIT(widget);
+		status = TRUE;
+		break;
 	    }
 	    break;
 
@@ -1080,8 +1301,64 @@ if((_w_) != NULL)				\
 	    button = (GdkEventButton *)event;
 	    if(!GTK_WIDGET_HAS_FOCUS(widget))
 		gtk_widget_grab_focus(widget);
-	    if(button->button == 1)
+	    switch(button->button)
+	    {
+	      case GDK_BUTTON1:
 		PUListBoxMapCB(box->map_btn, box);
+		break;
+
+	      case GDK_BUTTON4:
+		list = PUListBoxGetPUList(box);
+		if(list != NULL)
+		{
+		    const gint	i = PUListGetSelectedLast(list),
+				n = PUListGetTotalItems(list);
+		    GtkCList *clist = (GtkCList *)PUListGetCList(list);
+		    if((i > 0) && (n > 0))
+		    {
+			const gint row = i - 1;
+
+			gtk_clist_unselect_all(clist);
+			gtk_clist_select_row(clist, row, 0);
+
+			gtk_widget_queue_draw(widget);
+
+			if(box->changed_cb != NULL)
+			    box->changed_cb(
+				box,			/* Popup List Box */
+				row,			/* Item */
+				box->changed_data	/* Data */
+			    );
+		    }
+		}
+		break;
+
+	      case GDK_BUTTON5:
+		list = PUListBoxGetPUList(box);
+		if(list != NULL)
+		{
+		    const gint	i = PUListGetSelectedLast(list),
+				n = PUListGetTotalItems(list);
+		    GtkCList *clist = (GtkCList *)PUListGetCList(list);
+		    if((i < (n - 1)) && (n > 0))
+		    {
+			const gint row = i + 1;
+
+			gtk_clist_unselect_all(clist);
+			gtk_clist_select_row(clist, row, 0);
+
+			gtk_widget_queue_draw(widget);
+
+			if(box->changed_cb != NULL)
+			    box->changed_cb(
+				box,			/* Popup List Box */
+				row,			/* Item */
+				box->changed_data	/* Data */
+			    );
+		    }
+		}
+		break;
+	    }
 	    status = TRUE;
 	    break;
 	}
@@ -1096,6 +1373,7 @@ static void PUListBoxMapCB(GtkWidget *widget, gpointer data)
 {
 	gint prev_i;
 	const gchar *v;
+	gchar *prev_v;
 	pulist_struct *list;
 	pulistbox_struct *box = PULISTBOX(data);
 	if((widget == NULL) || (box == NULL))
@@ -1113,16 +1391,22 @@ static void PUListBoxMapCB(GtkWidget *widget, gpointer data)
 	    PUListSelect(list, prev_i);
 	}
 
+	PUListGetItemText(list, prev_i, &prev_v);
+	if(prev_v != NULL)
+	    prev_v = STRDUP(prev_v);
+
 	/* Map the popup list and wait for user response */
 	v = PUListMapQuery(
 	    list,
-	    NULL,			/* No initial value */
+	    prev_v,
 	    box->nlines_visible,
 	    PULIST_RELATIVE_BELOW,
 	    box->frame,			/* Relative widget */
 	    widget			/* Map widget */
 	);
 
+	g_free(prev_v);
+
 	/* Got new value? */
 	if(v != NULL)
 	{
@@ -1766,7 +2050,7 @@ const gchar *PUListMapQuery(
 	}
 	height = (((lines_visible < 0) ?
 	    POPUP_LIST_DEF_NLINES_VISIBLE : lines_visible) *
-	    (POPUP_LIST_ROW_SPACING + 1)) + (6 * 2);
+	    (POPUP_LIST_ROW_SPACING + 1)) + (5 * 2);
 
 	/* If a map widget is specified then we need to restore the
 	 * map widget's state before mapping the popup list
@@ -1800,7 +2084,9 @@ const gchar *PUListMapQuery(
 	    if(sel_item > -1)
 	    {
 		GtkCList *clist = GTK_CLIST(w);
+		gtk_clist_unselect_all(clist);
 		gtk_clist_select_row(clist, sel_item, 0);
+		clist->focus_row = sel_item;
 	    }
 	}
 
@@ -2074,7 +2360,8 @@ pulist_struct *PUListNew(void)
 	    w,
 	    GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK |
 	    GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
-	    GDK_POINTER_MOTION_MASK
+	    GDK_POINTER_MOTION_MASK | GDK_ENTER_NOTIFY_MASK |
+	    GDK_LEAVE_NOTIFY_MASK
 	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "key_press_event",
@@ -2096,6 +2383,14 @@ pulist_struct *PUListNew(void)
 	    GTK_OBJECT(w), "motion_notify_event",
 	    GTK_SIGNAL_FUNC(PUListMotionNotifyEventCB), list
 	);
+	gtk_signal_connect_after(
+	    GTK_OBJECT(w), "enter_notify_event",
+	    GTK_SIGNAL_FUNC(PUListCrossingEventCB), list
+	);
+	gtk_signal_connect_after(
+	    GTK_OBJECT(w), "leave_notify_event",
+	    GTK_SIGNAL_FUNC(PUListCrossingEventCB), list
+	);
 	gtk_container_add(GTK_CONTAINER(parent2), w);
 	gtk_widget_realize(w);
 	gtk_clist_set_shadow_type(clist, GTK_SHADOW_IN);
@@ -2435,13 +2730,13 @@ void PUListBoxSelect(pulistbox_struct *box, const gint i)
 	if(list == NULL)
 	    return;
 
-	/* Is there a change in the selected item? */
-	if(i != PUListGetSelectedLast(list))
-	{
-	    /* Select the item and redraw the popup list box */
-	    PUListSelect(list, i);
-	    gtk_widget_queue_draw(box->da);
-	}
+	/* Do not check for a change in the selected item since
+	 * the item's value may have changed and checking its index
+	 * to be changed is not reliable
+	 */
+
+	PUListSelect(list, i);
+	gtk_widget_queue_draw(box->da);
 }
 
 /*
