@@ -7,19 +7,19 @@
 #include "toolbar.h"
 
 #include "cfg.h"
-#include "edvtypes.h"
-#include "edvlistcb.h"
-#include "statusbar.h"
+#include "edv_types.h"
+#include "edv_list_cb.h"
+#include "edv_status_bar.h"
 #include "recbin.h"
-#include "recbincb.h"
-#include "recbinopcb.h"
-#include "recbincontents.h"
-#include "recbindnd.h"
-#include "endeavour.h"
-#include "edvcb.h"
-#include "edvutils.h"
-#include "edvutilsgtk.h"
-#include "edvcfglist.h"
+#include "recbin_cb.h"
+#include "recbin_op_cb.h"
+#include "recbin_contents_list.h"
+#include "recbin_dnd.h"
+#include "endeavour2.h"
+#include "edv_cb.h"
+#include "edv_utils.h"
+#include "edv_utils_gtk.h"
+#include "edv_cfg_list.h"
 #include "config.h"
 
 #include "images/icon_hsep_20x20.xpm"
@@ -40,6 +40,7 @@
 #include "images/icon_search_20x20.xpm"
 #include "images/icon_tool_bar_20x20.xpm"
 #include "images/icon_status_bar_20x20.xpm"
+#include "images/icon_wildcards_20x20.xpm"
 #include "images/icon_options2_20x20.xpm"
 #include "images/icon_customize_20x20.xpm"
 #include "images/icon_insecure_20x20.xpm"
@@ -84,7 +85,7 @@ cfg_accelkey_list_struct *EDVRecBinAccelkeysListNewDefault(void);
 static void EDVRecBinCreateMenuBar(
 	edv_recbin_struct *recbin, GtkWidget *parent
 );
-edv_recbin_struct *EDVRecBinNew(gpointer core_ptr);
+edv_recbin_struct *EDVRecBinNew(edv_core_struct *core);
 void EDVRecBinSyncData(edv_recbin_struct *recbin);
 void EDVRecBinUpdateMenus(edv_recbin_struct *recbin);
 void EDVRecBinUpdateContentsHeadings(
@@ -155,20 +156,19 @@ void EDVRecBinSetTitle(edv_recbin_struct *recbin)
 	gchar *title;
 	GtkWidget *w;
 	const cfg_item_struct *cfg_list;
-	edv_core_struct *core_ptr;
-
+	edv_core_struct *core;
 
 	if(recbin == NULL)
 	    return;
 
-	core_ptr = EDV_CORE(recbin->core_ptr);
-	if(core_ptr == NULL)
+	core = recbin->core;
+	if(core == NULL)
 	    return;
 
-	cfg_list = core_ptr->cfg_list;
+	cfg_list = core->cfg_list;
 
-	if(!STRISEMPTY(core_ptr->title))
-	    prog_name = core_ptr->title;
+	if(!STRISEMPTY(core->title))
+	    prog_name = core->title;
 
 	w = recbin->toplevel;
 	if(w == NULL)
@@ -180,7 +180,7 @@ void EDVRecBinSetTitle(edv_recbin_struct *recbin)
 	if(include_user_name)
 	    title = g_strdup_printf(
 		"%s: %s",
-		prog_name, core_ptr->effective_user_id_host_str
+		prog_name, core->effective_user_id_host_str
 	    );
 	else
 	    title = STRDUP(prog_name);
@@ -200,16 +200,16 @@ void EDVRecBinAccelkeysRegenerate(edv_recbin_struct *recbin)
 	GtkAccelGroup *accelgrp = NULL; 
 	cfg_accelkey_list_struct *ak_list;
 	const cfg_item_struct *cfg_list;
-	edv_core_struct *core_ptr;
+	edv_core_struct *core;
 
 	if(recbin == NULL)
 	    return;
 		   
-	core_ptr = EDV_CORE(recbin->core_ptr);
-	if(core_ptr == NULL)
+	core = recbin->core;
+	if(core == NULL)
 	    return;
 
-	cfg_list = core_ptr->cfg_list;
+	cfg_list = core->cfg_list;
 
 	ak_list = EDV_GET_ACCELKEY_LIST(EDV_CFG_PARM_RECBIN_ACCELERATOR_KEYS);
 	if(ak_list == NULL)                                                    
@@ -232,10 +232,10 @@ void EDVRecBinAccelkeysRegenerate(edv_recbin_struct *recbin)
     GUIMenuItemSetAccelKey(			\
      (_w_), accelgrp, ak->key, ak->modifiers	\
     );						\
-    break;                                      \
-   }                                            \
-  }                                             \
- }                                              \
+    break;					\
+   }						\
+  }						\
+ }						\
 }
 
 	UPDATE_ACCELKEY(
@@ -292,7 +292,7 @@ void EDVRecBinAccelkeysRegenerate(edv_recbin_struct *recbin)
 	    EDV_RECBIN_OP_UNSELECT_ALL
 	);
 	UPDATE_ACCELKEY(
-	    recbin->invert_selection_mi,   
+	    recbin->invert_selection_mi,
 	    EDV_RECBIN_OP_INVERT_SELECTION
 	);
 	UPDATE_ACCELKEY(
@@ -320,6 +320,10 @@ void EDVRecBinAccelkeysRegenerate(edv_recbin_struct *recbin)
 	    recbin->show_status_bar_micheck,
 	    EDV_RECBIN_OP_SHOW_STATUS_BAR
 	);
+	UPDATE_ACCELKEY(
+	    recbin->contents_list_filter_mi,
+	    EDV_RECBIN_OP_CONTENTS_LIST_FILTER
+	);
 	UPDATE_ACCELKEY(
 	    recbin->mime_types_mi,
 	    EDV_RECBIN_OP_MIME_TYPES
@@ -329,6 +333,14 @@ void EDVRecBinAccelkeysRegenerate(edv_recbin_struct *recbin)
 	    recbin->write_protect_mi,
 	    EDV_RECBIN_OP_WRITE_PROTECT
 	);
+	UPDATE_ACCELKEY(  
+	    recbin->delete_method_recycle_micheck,
+	    EDV_RECBIN_OP_DELETE_METHOD_RECYCLE
+	);
+	UPDATE_ACCELKEY(
+	    recbin->delete_method_purge_micheck,
+	    EDV_RECBIN_OP_DELETE_METHOD_PURGE
+	);
 	UPDATE_ACCELKEY(
 	    recbin->options_mi,
 	    EDV_RECBIN_OP_OPTIONS
@@ -404,17 +416,17 @@ void EDVRecBinToolBarRegenerate(edv_recbin_struct *recbin)
 	edv_recbin_opid_struct *opid;
 	toolbar_struct *toolbar;
 	toolbar_item_struct **item, *item_ptr;
-	edv_core_struct *core_ptr;
+	edv_core_struct *core;
 
 	if(recbin == NULL)
 	    return;
 
 	parent = recbin->tool_bar_handle;
-	core_ptr = EDV_CORE(recbin->core_ptr);
-	if((parent == NULL) || (core_ptr == NULL))
+	core = recbin->core;
+	if((parent == NULL) || (core == NULL))
 	    return;
 
-	cfg_list = core_ptr->cfg_list;
+	cfg_list = core->cfg_list;
 
 	/* Get Tool Bar configuration */
 	tb_display = (toolbar_display)EDV_GET_I(
@@ -455,7 +467,7 @@ void EDVRecBinToolBarRegenerate(edv_recbin_struct *recbin)
 		    glist->data : NULL
 		)
 	    );
-	    glist = g_list_next(glist);    
+	    glist = g_list_next(glist);
 	    if(opid == NULL)
 		continue;
 
@@ -569,18 +581,18 @@ void EDVRecBinContentsMenuRegenerate(edv_recbin_struct *recbin)
 void EDVRecBinSyncConfiguration(edv_recbin_struct *recbin)
 {
 	GtkWidget *w;
-	edv_core_struct *core_ptr;
+	edv_core_struct *core;
 	cfg_item_struct *cfg_list;
 	
 
 	if(recbin == NULL)
 	    return;
 
-	core_ptr = EDV_CORE(recbin->core_ptr);
-	if(core_ptr == NULL)
+	core = recbin->core;
+	if(core == NULL)
 	    return;
 
-	cfg_list = core_ptr->cfg_list;
+	cfg_list = core->cfg_list;
 
 	/* Toplevel geometry */
 	w = recbin->toplevel;
@@ -606,6 +618,22 @@ void EDVRecBinSyncConfiguration(edv_recbin_struct *recbin)
 	/* EDV_CFG_PARM_RECBIN_CONTENTS_COLUMN parameter is updated
 	 * when the configuration list is changed directly
 	 */
+
+	/* Contents list filter */
+	if(STRISEMPTY(recbin->contents_list_filter))
+	{
+	    EDV_SET_S(
+		EDV_CFG_PARM_RECBIN_CONTENTS_LIST_FILTER,
+		"*"
+	    );
+	}
+	else
+	{
+	    EDV_SET_S(
+		EDV_CFG_PARM_RECBIN_CONTENTS_LIST_FILTER,
+		recbin->contents_list_filter
+	    );
+	}
 }
 
 
@@ -620,7 +648,7 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	GList *opid_list = NULL;
 	toolbar_item_type tb_item_type;
 	edv_opid_flags flags;
-	edv_recbin_op op;    
+	edv_recbin_op op;
 	edv_recbin_opid_struct *opid;
 	void (*func_cb)(toolbar_item_struct *, gint, gpointer);
 	void (*enter_func_cb)(toolbar_item_struct *, gint, gpointer);
@@ -754,8 +782,8 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "Flush any pending data transfers to disk";
 #endif
 #ifdef PROG_LANGUAGE_SPANISH
-	button_name = "Discos Sincro";
-	menu_name = "Discos Sincro";
+	button_name = "Sincronizar Discos";
+	menu_name = "Sincronizar Discos";
 	tooltip = "Limpan cualquiera transferencias pendientes de datos al disco";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
@@ -851,8 +879,8 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #endif
 #ifdef PROG_LANGUAGE_SPANISH
 	button_name = "Proteja";
-	menu_name = "Escriba Proteja";
-	tooltip = "Habilite/incapacita escribe protege";
+	menu_name = "Proteja contra escritura";
+	tooltip = "Habilite/inhabilita la proteccion contra escritura";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 	button_name = "Protge";
@@ -863,6 +891,31 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	accel_mods = GDK_CONTROL_MASK;
 	DO_APPEND_OPID
 
+	op = EDV_RECBIN_OP_DELETE_METHOD_RECYCLE;
+	tb_item_type = TOOLBAR_ITEM_TOGGLE_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_trash_20x20_xpm;
+	menu_icon_data = button_icon_data;
+	button_name = "Recycle";
+	menu_name = "Delete Method: Recycle";
+	tooltip = "Set the delete method to recycle";
+	accel_key = 0;
+	accel_mods = 0;
+	DO_APPEND_OPID
+		      
+	op = EDV_RECBIN_OP_DELETE_METHOD_PURGE;
+	tb_item_type = TOOLBAR_ITEM_TOGGLE_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_purge_20x20_xpm;
+	menu_icon_data = button_icon_data;
+	button_name = "Purge";
+	menu_name = "Delete Method: Purge";
+	tooltip = "Set the delete method to purge";
+	accel_key = 0;
+	accel_mods = 0;
+	DO_APPEND_OPID
+
+
 	op = EDV_RECBIN_OP_SYNC_RECYCLE_BIN;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
 	flags = 0;
@@ -919,7 +972,7 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #ifdef PROG_LANGUAGE_SPANISH
 	button_name = "Recupere";
 	menu_name = "Recupere";
-	tooltip = "Recupere escogido se opone(s)";
+	tooltip = "Recupere objetos escogido(s)";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 	button_name = "Retrouver";
@@ -943,7 +996,7 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #ifdef PROG_LANGUAGE_SPANISH
 	button_name = "Purga";
 	menu_name = "Purga";
-	tooltip = "Tira Permanentemente escogido se opone(s)";
+	tooltip = "Tira Permanentemente objetos escogido(s)";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 	button_name = "Purge";
@@ -967,7 +1020,7 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #ifdef PROG_LANGUAGE_SPANISH
 	button_name = "PurgTodo";
 	menu_name = "Purgue Todo";
-	tooltip = "Tira Permanentemente todo recycled se opone";
+	tooltip = "Tira Permanentemente todo el contenido";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 	button_name = "PurgTout";
@@ -992,7 +1045,7 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #ifdef PROG_LANGUAGE_SPANISH
 	button_name = "SelAll";
 	menu_name = "Escoja Todo";
-	tooltip = "Escoge todo se opone";
+	tooltip = "Escoge todo";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 	button_name = "SelAll";
@@ -1016,7 +1069,7 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #ifdef PROG_LANGUAGE_SPANISH
 	button_name = "UnSelAll";
 	menu_name = "Unescoja Todo";
-	tooltip = "Unescoge todo se opone";
+	tooltip = "Unescoge todo";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 	button_name = "UnSelAll";
@@ -1065,9 +1118,9 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	tooltip = "Find object(s) by specific attributes";
 #endif
 #ifdef PROG_LANGUAGE_SPANISH
-	button_name = "Hallazgo";
-	menu_name = "El Hallazgo";
-	tooltip = "El Hallazgo se opone (s) por atributos especificados";
+	button_name = "Buscar";
+	menu_name = "Buscar";
+	tooltip = "Buscar objeto(s) por atributos especificados";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 	button_name = "Find";
@@ -1199,6 +1252,18 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 	accel_mods = 0;
 	DO_APPEND_OPID
 
+	op = EDV_RECBIN_OP_CONTENTS_LIST_FILTER;
+	tb_item_type = TOOLBAR_ITEM_BUTTON;
+	flags = 0;
+	button_icon_data = (guint8 **)icon_wildcards_20x20_xpm;
+	menu_icon_data = button_icon_data;
+	button_name = "Filter";
+	menu_name = "Set Filter...";
+	tooltip = "Set the name filter for listing objects";
+	accel_key = 0;
+	accel_mods = 0;
+	DO_APPEND_OPID
+
 
 	op = EDV_RECBIN_OP_MIME_TYPES;
 	tb_item_type = TOOLBAR_ITEM_BUTTON;
@@ -1237,8 +1302,8 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #endif
 #ifdef PROG_LANGUAGE_SPANISH
 	button_name = "FBrowser";
-	menu_name = "El Examinador Nuevo Del Archivo";
-	tooltip = "Crea a un examinador nuevo del archivo";
+	menu_name = "Nuevo Examinador De Archivos";
+	tooltip = "Muestra un nuevo examinador de archivos";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 	button_name = "Dossier";
@@ -1261,8 +1326,8 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #endif
 #ifdef PROG_LANGUAGE_SPANISH
 	button_name = "IBrowser";
-	menu_name = "El Examinador Nuevo De La Imagen";
-	tooltip = "Crea a un examinador nuevo de la imagen";
+	menu_name = "Nuevo Examinador De Imagenes";
+	tooltip = "Muestra un nuevo examinador de imagenes";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 	button_name = "Galerie";
@@ -1285,8 +1350,8 @@ GList *EDVRecBinOPIDListNew(edv_recbin_struct *recbin)
 #endif
 #ifdef PROG_LANGUAGE_SPANISH
 	button_name = "Archiver";
-	menu_name = "Archiver Nuevo";
-	tooltip = "Crea un archiver nuevo";
+	menu_name = "Nuevo Compresor De Archivos";
+	tooltip = "Muestra un archivo comprimido nuevo";
 #endif
 #ifdef PROG_LANGUAGE_FRENCH
 	button_name = "Archive";
@@ -1737,6 +1802,8 @@ static void EDVRecBinCreateMenuBar(
 	    DO_ADD_MENU_ITEM_LABEL
 	    recbin->invert_selection_mi = w;
 
+	    DO_ADD_MENU_SEP
+
 	    op = EDV_RECBIN_OP_FIND;
 	    DO_ADD_MENU_ITEM_LABEL
 	    recbin->find_mi = w;
@@ -1744,7 +1811,7 @@ static void EDVRecBinCreateMenuBar(
 	GUIMenuAddToMenuBar(
 	    menu_bar, menu,
 #if defined(PROG_LANGUAGE_SPANISH)
-"Redacte"
+"Editar"
 #elif defined(PROG_LANGUAGE_FRENCH)
 "Editer"
 #elif defined(PROG_LANGUAGE_GERMAN)
@@ -1792,6 +1859,12 @@ static void EDVRecBinCreateMenuBar(
 
 	    DO_ADD_MENU_SEP
 
+	    op = EDV_RECBIN_OP_CONTENTS_LIST_FILTER;
+	    DO_ADD_MENU_ITEM_LABEL
+	    recbin->contents_list_filter_mi = w;
+
+	    DO_ADD_MENU_SEP
+
 	    op = EDV_RECBIN_OP_MIME_TYPES;
 	    DO_ADD_MENU_ITEM_LABEL
 	    recbin->mime_types_mi = w;
@@ -1827,6 +1900,15 @@ static void EDVRecBinCreateMenuBar(
 	    DO_ADD_MENU_ITEM_LABEL
 	    recbin->write_protect_mi = w;
 
+	    op = EDV_RECBIN_OP_DELETE_METHOD_RECYCLE;
+	    DO_ADD_MENU_ITEM_CHECK
+	    recbin->delete_method_recycle_micheck = w;
+
+	    op = EDV_RECBIN_OP_DELETE_METHOD_PURGE;
+	    DO_ADD_MENU_ITEM_CHECK
+	    recbin->delete_method_purge_micheck = w;
+
+
 	    DO_ADD_MENU_SEP
 
 	    op = EDV_RECBIN_OP_OPTIONS;
@@ -1840,7 +1922,7 @@ static void EDVRecBinCreateMenuBar(
 	GUIMenuAddToMenuBar(
 	    menu_bar, menu,
 #if defined(PROG_LANGUAGE_SPANISH)
-"Escenarios"
+"Configuracion"
 #elif defined(PROG_LANGUAGE_FRENCH)
 "Rglages"
 #elif defined(PROG_LANGUAGE_GERMAN)
@@ -1955,24 +2037,17 @@ static void EDVRecBinCreateMenuBar(
 /*
  *	Creates a new Recycle Bin.
  */
-edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
+edv_recbin_struct *EDVRecBinNew(edv_core_struct *core)
 {
-	gint	toplevel_x = 0,
-		toplevel_y = 0,
-		toplevel_width = EDV_DEF_RECBIN_WIDTH,
-		toplevel_height = EDV_DEF_RECBIN_HEIGHT;
-	gboolean	tool_bar_map_state = TRUE,
-			find_bar_map_state = TRUE,
-			status_bar_map_state = TRUE;
+	gint	toplevel_x, toplevel_y,
+		toplevel_width, toplevel_height;
+	gboolean	tool_bar_map_state,
+			find_bar_map_state,
+			status_bar_map_state;
 	gint i;
-	edv_statusbar_struct *status_bar;
-	const gchar	*wm_name = NULL,
-			*wm_class = NULL;
-	const cfg_item_struct *cfg_list = (core_ptr != NULL) ?
-	    EDV_CORE(core_ptr)->cfg_list : NULL;
+	const gchar *wm_name, *wm_class;
 	GdkWindow *window;
-	GtkRcStyle	*standard_rcstyle = NULL,
-			*lists_rcstyle = NULL;
+	GtkRcStyle *standard_rcstyle, *lists_rcstyle;
 	GtkStyle *style;
 	GtkWidget *w, *parent, *parent2;
 	GtkCList *clist;
@@ -1984,55 +2059,58 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 	const GtkTargetEntry dnd_src_types[] = {
 {EDV_DND_TYPE_STRING_RECYCLED_OBJECT,	0,	EDV_DND_TYPE_INFO_RECYCLED_OBJECT}
 	};
+	const cfg_item_struct *cfg_list;
+	edv_status_bar_struct *status_bar;
 	edv_recbin_struct *recbin = EDV_RECBIN(
 	    g_malloc0(sizeof(edv_recbin_struct))
 	);
-	if(recbin == NULL)
-	    return(recbin);
-
-
-	/* Get configuration */
-	if(cfg_list != NULL)
+	if((recbin == NULL) || (core == NULL))
 	{
-	    edv_core_struct *c_ptr = EDV_CORE(core_ptr);
-
-	    standard_rcstyle = c_ptr->standard_rcstyle;
-	    lists_rcstyle = c_ptr->lists_rcstyle;
-
-	    wm_name = c_ptr->wm_name;
-	    wm_class = c_ptr->wm_class;
-
-	    if(c_ptr->geometry_set)
-	    {
-		GdkRectangle *rect = &c_ptr->geometry;
-		toplevel_x = rect->x;
-		toplevel_y = rect->y;
-		toplevel_width = rect->width;
-		toplevel_height = rect->height;
-	    }
-	    else
-	    {
-		toplevel_x = EDV_GET_I(EDV_CFG_PARM_RECBIN_X);
-		toplevel_y = EDV_GET_I(EDV_CFG_PARM_RECBIN_Y);
-		toplevel_width = EDV_GET_I(EDV_CFG_PARM_RECBIN_WIDTH);
-		toplevel_height = EDV_GET_I(EDV_CFG_PARM_RECBIN_HEIGHT);
-	    }
-
-	    tool_bar_map_state = EDV_GET_B(EDV_CFG_PARM_RECBIN_SHOW_TOOL_BAR);
-	    find_bar_map_state = EDV_GET_B(EDV_CFG_PARM_RECBIN_SHOW_FIND_BAR);
-	    status_bar_map_state = EDV_GET_B(EDV_CFG_PARM_RECBIN_SHOW_STATUS_BAR);
+	    g_free(recbin);
+	    return(NULL);
 	}
 
+	cfg_list = core->cfg_list;
+
+	standard_rcstyle = core->standard_rcstyle;
+	lists_rcstyle = core->lists_rcstyle;
+
+	wm_name = core->wm_name;
+	wm_class = core->wm_class;
+
+	if(core->geometry_set)
+	{
+	    const GdkRectangle *rect = &core->geometry;
+	    toplevel_x = rect->x;
+	    toplevel_y = rect->y;
+	    toplevel_width = rect->width;
+	    toplevel_height = rect->height;
+	}
+	else
+	{
+	    toplevel_x = EDV_GET_I(EDV_CFG_PARM_RECBIN_X);
+	    toplevel_y = EDV_GET_I(EDV_CFG_PARM_RECBIN_Y);
+	    toplevel_width = EDV_GET_I(EDV_CFG_PARM_RECBIN_WIDTH);
+	    toplevel_height = EDV_GET_I(EDV_CFG_PARM_RECBIN_HEIGHT);
+	}
+
+	tool_bar_map_state = EDV_GET_B(EDV_CFG_PARM_RECBIN_SHOW_TOOL_BAR);
+	find_bar_map_state = EDV_GET_B(EDV_CFG_PARM_RECBIN_SHOW_FIND_BAR);
+	status_bar_map_state = EDV_GET_B(EDV_CFG_PARM_RECBIN_SHOW_STATUS_BAR);
+
 	recbin->processing = FALSE;
 	recbin->busy_count = 0;
 	recbin->freeze_count = 0;
-	recbin->core_ptr = core_ptr;
+	recbin->core = core;
 
 	recbin->opid_list = EDVRecBinOPIDListNew(recbin);
 
 	recbin->tool_bar_map_state = tool_bar_map_state;
 	recbin->find_bar_map_state = find_bar_map_state;
 	recbin->status_bar_map_state = status_bar_map_state;
+	recbin->contents_list_filter = STRDUP(EDV_GET_S(
+	    EDV_CFG_PARM_RECBIN_CONTENTS_LIST_FILTER
+	));
 	recbin->contents_clist_selected_row = -1;
 	recbin->last_recbin_items = -1;
 	recbin->last_write_protect_state = -1;
@@ -2163,7 +2241,7 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 
 	/* Create the Find Bar */
 	recbin->find_bar = EDVFindBarNew(
-	    core_ptr, parent2,
+	    core, parent2,
 	    EDV_FINDBAR_ROLE_RECYCLED_OBJECT,
 	    NULL,
 	    EDVRecBinFindBarStartCB,
@@ -2201,23 +2279,23 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "key_press_event",
-	    GTK_SIGNAL_FUNC(EDVCListKeyEventCB), core_ptr
+	    GTK_SIGNAL_FUNC(EDVCListKeyEventCB), core
 	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "key_release_event",
-	    GTK_SIGNAL_FUNC(EDVCListKeyEventCB), core_ptr
+	    GTK_SIGNAL_FUNC(EDVCListKeyEventCB), core
 	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "button_press_event",
-	    GTK_SIGNAL_FUNC(EDVCListButtonEventCB), core_ptr
+	    GTK_SIGNAL_FUNC(EDVCListButtonEventCB), core
 	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "button_release_event",
-	    GTK_SIGNAL_FUNC(EDVCListButtonEventCB), core_ptr
+	    GTK_SIGNAL_FUNC(EDVCListButtonEventCB), core
 	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "motion_notify_event",
-	    GTK_SIGNAL_FUNC(EDVCListMotionEventCB), core_ptr
+	    GTK_SIGNAL_FUNC(EDVCListMotionEventCB), core
 	);
 	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "key_press_event",
@@ -2272,8 +2350,8 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 	    dnd_tar_types,
 	    sizeof(dnd_tar_types) / sizeof(GtkTargetEntry),
 	    GDK_ACTION_MOVE,			/* Actions */
-	    GDK_ACTION_MOVE,                    /* Default action if same */
-	    GDK_ACTION_MOVE,                    /* Default action */
+	    GDK_ACTION_MOVE,			/* Default action if same */
+	    GDK_ACTION_MOVE,			/* Default action */
 	    EDVRecBinContentsDragDataReceivedCB,
 	    recbin
 	);
@@ -2294,7 +2372,7 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 
 	/* Create the Status Bar */
 	recbin->status_bar = status_bar = EDVStatusBarNew(
-	    core_ptr, recbin->main_vbox
+	    core, recbin->main_vbox
 	);
 	if(status_bar != NULL)
 	{
@@ -2329,8 +2407,8 @@ edv_recbin_struct *EDVRecBinNew(gpointer core_ptr)
 }
 
 /*
- *      Syncronizes all data in the recycle bin's widgets to internal data
- *      on the recycle bin.
+ *	Syncronizes all data in the recycle bin's widgets to internal data
+ *	on the recycle bin.
  */
 void EDVRecBinSyncData(edv_recbin_struct *recbin)
 {
@@ -2343,15 +2421,16 @@ void EDVRecBinSyncData(edv_recbin_struct *recbin)
 }
 
 /*
- *      Updates all widgets on the given recycle bin to reflect the current
- *      data.
+ *	Updates all widgets on the given recycle bin to reflect the current
+ *	data.
  */
 void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 {
 	gboolean	write_protect,
-			write_protect_changed = FALSE;
-	gboolean	sensitive,
+			write_protect_changed = FALSE,
+			sensitive,
 			state;
+	edv_delete_method delete_method;
 	const cfg_item_struct *cfg_list;
 	guint8		**recbin_icon_data,
 			**recbin_icon_large_data;
@@ -2359,17 +2438,16 @@ void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 	GtkCList *clist;
 	gint selected_obj_row = -1;
 	toolbar_struct *tb;
-	edv_core_struct *core_ptr;
-
+	edv_core_struct *core;
 
 	if(recbin == NULL)
 	    return;
 
-	core_ptr = EDV_CORE(recbin->core_ptr);
-	if(core_ptr == NULL)
+	core = recbin->core;
+	if(core == NULL)
 	    return;
 
-	cfg_list = core_ptr->cfg_list;
+	cfg_list = core->cfg_list;
 
 	tb = recbin->tool_bar;
 
@@ -2395,6 +2473,11 @@ void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 	}
 	recbin->last_write_protect_state = write_protect ? 1 : 0;
 
+	/* Delete method */
+	delete_method = (edv_delete_method)EDV_GET_I(
+	    EDV_CFG_PARM_DELETE_METHOD
+	);
+
 	/* Get last selected row on the contents clist */
 	clist = (GtkCList *)recbin->contents_clist;
 	selected_obj_row = EDVCListGetSelectedLast(clist, NULL);
@@ -2407,7 +2490,7 @@ void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 	recbin_icon_large_data = NULL;
 	if(recbin->last_recbin_items < 0)
 	{
-	    if(core_ptr->last_recbin_items > 0)
+	    if(core->last_recbin_items > 0)
 	    {
 		recbin_icon_data = (guint8 **)icon_trash_20x20_xpm;
 		recbin_icon_large_data = (guint8 **)icon_trash_48x48_xpm;
@@ -2421,21 +2504,21 @@ void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 	else
 	{
 	    if(!recbin->last_recbin_items &&
-	       core_ptr->last_recbin_items
+	       core->last_recbin_items
 	    )
 	    {
 		recbin_icon_data = (guint8 **)icon_trash_20x20_xpm;
 		recbin_icon_large_data = (guint8 **)icon_trash_48x48_xpm;
 	    }
 	    else if(recbin->last_recbin_items &&
-		    !core_ptr->last_recbin_items
+		    !core->last_recbin_items
 	    )
 	    {
 		recbin_icon_data = (guint8 **)icon_trash_empty_20x20_xpm;
 		recbin_icon_large_data = (guint8 **)icon_trash_empty_48x48_xpm;
 	    }
 	}
-	recbin->last_recbin_items = core_ptr->last_recbin_items;
+	recbin->last_recbin_items = core->last_recbin_items;
 
 
 	/* Begin updating menu items and tool bar items */
@@ -2511,6 +2594,29 @@ void EDVRecBinUpdateMenus(edv_recbin_struct *recbin)
 	    );
 	}
 
+	/* Delete Method: Recycle */
+	w = recbin->delete_method_recycle_micheck;
+	GUIMenuItemSetPixmap(w, recbin_icon_data);
+	state = (delete_method == EDV_DELETE_METHOD_RECYCLE) ?
+	    TRUE : FALSE;
+	DO_SET_CHECK_STATE
+	ToolBarItemUpdateByID(
+	    tb, EDV_RECBIN_OP_DELETE_METHOD_RECYCLE,
+	    NULL, recbin_icon_data, NULL                              
+	);
+	ToolBarItemSetToggleID(
+	    tb, EDV_RECBIN_OP_DELETE_METHOD_RECYCLE, state
+	);
+
+	/* Delete Method: Purge */
+	w = recbin->delete_method_purge_micheck;
+	state = (delete_method == EDV_DELETE_METHOD_PURGE) ?
+	    TRUE : FALSE;
+	DO_SET_CHECK_STATE
+	ToolBarItemSetToggleID(
+	    tb, EDV_RECBIN_OP_DELETE_METHOD_PURGE, state
+	);
+
 
 	/* Windows */
 
@@ -2551,14 +2657,14 @@ void EDVRecBinSetBusy(edv_recbin_struct *recbin, gboolean busy)
 {
 	GdkCursor *cur;
 	GtkWidget *w;
-	edv_core_struct *core_ptr;
+	edv_core_struct *core;
 
 	if(recbin == NULL)
 	    return;
 
 	w = recbin->toplevel;
-	core_ptr = EDV_CORE(recbin->core_ptr);
-	if((w == NULL) || (core_ptr == NULL))
+	core = recbin->core;
+	if((w == NULL) || (core == NULL))
 	    return;
 
 	if(busy)
@@ -2566,7 +2672,7 @@ void EDVRecBinSetBusy(edv_recbin_struct *recbin, gboolean busy)
 	    recbin->busy_count++;
 	    if(recbin->busy_count > 1)
 		return;
-	    cur = EDVGetCursor(core_ptr, EDV_CURSOR_CODE_BUSY);
+	    cur = EDVGetCursor(core, EDV_CURSOR_CODE_BUSY);
 	}
 	else
 	{
@@ -2710,5 +2816,7 @@ void EDVRecBinDelete(edv_recbin_struct *recbin)
 	/* Delete all Operation IDs */
 	EDVRecBinOPIDListDelete(recbin->opid_list);
 
+	g_free(recbin->contents_list_filter);
+
 	g_free(recbin);
 }
