@@ -7,14 +7,16 @@
 
 #include <gtk/gtk.h>
 #include "cfg.h"
-#include "edvtypes.h"
+#include "edv_types.h"
 #include "toolbar.h"
-#include "findbar.h"
-#include "statusbar.h"
+#include "edv_find_bar.h"
+#include "edv_status_bar.h"
 
 
-typedef struct _edv_recbin_struct		edv_recbin_struct;
-typedef struct _edv_recbin_opid_struct		edv_recbin_opid_struct;
+typedef struct _edv_recbin_struct	edv_recbin_struct;
+#define EDV_RECBIN(p)			((edv_recbin_struct *)(p))
+typedef struct _edv_recbin_opid_struct	edv_recbin_opid_struct;
+#define EDV_RECBIN_OPID(p)		((edv_recbin_opid_struct *)(p))
 
 
 /*
@@ -34,11 +36,12 @@ typedef enum {
 	EDV_RECBIN_COLUMN_TYPE_DATE_DELETED		= 9,
 	EDV_RECBIN_COLUMN_TYPE_LINKED_TO		= 10,
 	EDV_RECBIN_COLUMN_TYPE_ORIGINAL_LOCATION	= 11,
-	EDV_RECBIN_COLUMN_TYPE_INDEX			= 12
+	EDV_RECBIN_COLUMN_TYPE_INDEX			= 12,
+	EDV_RECBIN_COLUMN_TYPE_CAPACITY_USED		= 13
 
 } edv_recbin_column_type;
 /* Total number of column types */
-#define EDV_RECBIN_CONTENTS_CLIST_COLUMNS_MAX		13
+#define EDV_RECBIN_CONTENTS_CLIST_COLUMNS_MAX		14
 
 
 /*
@@ -56,6 +59,8 @@ typedef enum {
 	EDV_RECBIN_OP_RUN			= 31,
 	EDV_RECBIN_OP_RUN_TERMINAL		= 32,
 	EDV_RECBIN_OP_WRITE_PROTECT		= 35,
+	EDV_RECBIN_OP_DELETE_METHOD_RECYCLE	= 38,
+	EDV_RECBIN_OP_DELETE_METHOD_PURGE	= 39,
 
 	EDV_RECBIN_OP_SYNC_RECYCLE_BIN		= 40,
 
@@ -75,6 +80,8 @@ typedef enum {
 	EDV_RECBIN_OP_SHOW_FIND_BAR		= 91,
 	EDV_RECBIN_OP_SHOW_STATUS_BAR		= 92,
 
+	EDV_RECBIN_OP_CONTENTS_LIST_FILTER	= 97,
+
 	EDV_RECBIN_OP_MIME_TYPES		= 100,
 
 	EDV_RECBIN_OP_NEW_BROWSER		= 110,
@@ -136,7 +143,6 @@ struct _edv_recbin_opid_struct {
 			**menu_icon_data;	/* Shared */
 
 };
-#define EDV_RECBIN_OPID(p)	((edv_recbin_opid_struct *)(p))
 
 /*
  *	Recycle Bin:
@@ -147,7 +153,7 @@ struct _edv_recbin_struct {
 	gboolean	processing;
 	gint		busy_count,
 			freeze_count;
-	gpointer	core_ptr;
+	edv_core_struct *core;
 
 	GList		*opid_list;
 
@@ -194,9 +200,12 @@ struct _edv_recbin_struct {
 			*show_tool_bar_micheck,
 			*show_find_bar_micheck,
 			*show_status_bar_micheck,
+			*contents_list_filter_mi,
 			*mime_types_mi,
 
 			*write_protect_mi,
+			*delete_method_recycle_micheck,
+			*delete_method_purge_micheck,
 			*options_mi,
 			*customize_mi,
 
@@ -216,6 +225,8 @@ struct _edv_recbin_struct {
 			*contents_clist_purge_mi,
 			*contents_clist_purge_all_mi;
 
+	gchar		*contents_list_filter;
+
 	/* Last selected row on the clist (can be -1 for none)
 	 *
 	 * Note that this does not reflect other selected rows since
@@ -238,10 +249,9 @@ struct _edv_recbin_struct {
 
 
 	/* Status Bar */
-	edv_statusbar_struct	*status_bar;
+	edv_status_bar_struct	*status_bar;
 
 };
-#define EDV_RECBIN(p)	((edv_recbin_struct *)(p))
 
 
 extern edv_recbin_opid_struct *EDVRecBinMatchOPID(
@@ -263,7 +273,7 @@ extern void EDVRecBinOPIDListDelete(GList *glist);
 
 extern cfg_accelkey_list_struct *EDVRecBinAccelkeysListNewDefault(void);
 
-extern edv_recbin_struct *EDVRecBinNew(gpointer core_ptr);
+extern edv_recbin_struct *EDVRecBinNew(edv_core_struct *core);
 extern void EDVRecBinSyncData(edv_recbin_struct *recbin);
 extern void EDVRecBinUpdateMenus(edv_recbin_struct *recbin);
 extern void EDVRecBinUpdateContentsHeadings(
