@@ -734,7 +734,7 @@ void EDVRecBinClickColumnCB(
 	    GtkCListCompareFunc cmp_func_str =
 		 (GtkCListCompareFunc)EDVCListColumnSortStringCB;
 	    GtkCListCompareFunc cmp_func_num =
-		(GtkCListCompareFunc)EDVCListColumnSortNumericCB;
+		(GtkCListCompareFunc)EDVCListColumnSortNumberCB;
 
 
 	    EDVRecBinSetBusy(recbin, TRUE);
