@@ -1,5 +1,6 @@
 #include <stdlib.h>
 #include <string.h>
+#include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <gtk/gtk.h>
@@ -283,11 +284,12 @@ static void EDVRecBinDragDataReceivedNexus(
 	   )
 	)
 	{
+	    struct stat lstat_buf;
 	    gint status = -1;
 	    gboolean yes_to_all = FALSE;
 	    gint objects_deleted = 0;
+	    const gchar *path, *error_msg;
 	    GList *glist, *index_list;
-	    const gchar *error_msg;
 
 	    if(recbin != NULL)
 	    {
@@ -305,7 +307,8 @@ static void EDVRecBinDragDataReceivedNexus(
 		if(url == NULL)
 		    continue;
 
-		if(STRISEMPTY(url->path))
+		path = url->path;
+		if(STRISEMPTY(path))
 		    continue;
 
 		/* Handle by drag action type */
@@ -320,7 +323,7 @@ static void EDVRecBinDragDataReceivedNexus(
 		  case GDK_ACTION_MOVE:
 		    status = EDVRecBinDeleteObject(
 			core,
-			url->path,
+			path,
 			&index_list,
 			toplevel,
 			TRUE, TRUE, &yes_to_all
@@ -334,9 +337,7 @@ static void EDVRecBinDragDataReceivedNexus(
 		    break;
 		}
 
-		/* Get error message (if any) that might have occured
-		 * in the above operation
-		 */
+		/* Check for and report any errors */
 		if(error_msg == NULL)
 		    error_msg = EDVRecBinDeleteObjectGetError();
 		if(!STRISEMPTY(error_msg))
@@ -345,11 +346,22 @@ static void EDVRecBinDragDataReceivedNexus(
 		    EDVMessageObjectOPError(
 			"Delete Object Error",
 			error_msg,
-			url->path,
+			path,
 			toplevel
 		    );
 		}
 
+		/* Check if the object still exists */
+		if(lstat(path, &lstat_buf))
+		{
+#ifdef ENOENT
+		    /* Report the object being removed */
+		    const gint error_code = (gint)errno;
+		    if(error_code == ENOENT)
+			EDVObjectRemovedEmit(core, path);
+#endif
+		}
+
 		/* Any objects deleted? */
 		if(index_list != NULL)
 		{
@@ -381,7 +393,7 @@ static void EDVRecBinDragDataReceivedNexus(
 		    break;
 	    }
 
-	    /* Update status bar message */
+	    /* Update the status bar message */
 	    if(recbin != NULL)
 		EDVRecBinDNDUpdateStatusBar(
 		    recbin, (gint)dc->action, info,
@@ -699,78 +711,5 @@ void EDVRecBinContentsDragDataDeleteCB(
 	GtkWidget *widget, GdkDragContext *dc, gpointer data
 )
 {
-	guint *index;
-	gint i, row, total_indices;
-	edv_core_struct *core;
-	GList *glist;
-	GtkWidget *w;
-	GtkCList *clist;
-	const gchar *recycled_index_file;
-	edv_recycled_object_struct *obj;
-	edv_recbin_struct *recbin = EDV_RECBIN(data);
-	if((dc == NULL) || (recbin == NULL))
-	    return;
 
-	w = recbin->contents_clist;
-	core = recbin->core;
-	if((w == NULL) || (core == NULL))
-	    return;
-
-	clist = GTK_CLIST(w);
-
-	/* Get path to recycled objects index file */
-	recycled_index_file = CFGItemListGetValueS(
-	    core->cfg_list, EDV_CFG_PARM_FILE_RECYCLE_BIN_INDEX
-	);
-	if(STRISEMPTY(recycled_index_file))
-	    return;
-
-	/* Generate a list of recycled object indices based on the
-	 * selected rows
-	 */
-	index = NULL;
-	total_indices = 0;
-	for(glist = clist->selection;
-	    glist != NULL;
-	    glist = g_list_next(glist)
-	)
-	{
-	    row = (gint)glist->data;
-	    obj = EDV_RECYCLED_OBJECT(
-		gtk_clist_get_row_data(clist, row)
-	    );
-	    if(obj != NULL)
-	    {
-		i = total_indices;
-		total_indices = i + 1;
-		index = (guint *)g_realloc(
-		    index, total_indices * sizeof(guint)
-		);
-		if(index == NULL)
-		{
-		    total_indices = 0;
-		    break;
-		}
-		index[i] = obj->index;
-	    }
-	}
-
-	/* Emit recycled object removed signal for each recycled
-	 * object index
-	 */
-	for(i = 0; i < total_indices; i++)
-	{
-	    /* Get recycled object to check if it does not exist */
-	    obj = EDVRecBinObjectStat(recycled_index_file, index[i]);
-	    if(obj != NULL)
-	    {
-		/* Recycled object still exists, skip it */
-		EDVRecycledObjectDelete(obj);
-		continue;
-	    }
-
-	    /* Emit recycled object removed signal */
-	    EDVRecycledObjectRemovedEmit(core, index[i]);
-	}
-	g_free(index);
 }
