@@ -1,5 +1,6 @@
 #include <stdlib.h>
 #include <string.h>
+#include <errno.h>
 #include <gtk/gtk.h>
 
 #include "../include/disk.h"
@@ -680,6 +681,7 @@ void EDVRecBinOPRecover(edv_recbin_struct *recbin)
 	gboolean yes_to_all = FALSE;
 	struct stat stat_buf;
 	gint row, status, nobjs, nobjs_recovered = 0;
+	guint index;
 	gchar *new_path;
 	const gchar *error_msg;
 	GList *glist, *obj_list = NULL;
@@ -702,18 +704,21 @@ void EDVRecBinOPRecover(edv_recbin_struct *recbin)
 	    return;
 
 #define DO_FREE_LOCALS	{				\
- g_list_foreach(					\
-  obj_list, (GFunc)EDVRecycledObjectDelete, NULL		\
- );							\
- g_list_free(obj_list);					\
- obj_list = NULL;					\
+ if(obj_list != NULL) {					\
+  g_list_foreach(					\
+   obj_list, (GFunc)EDVRecycledObjectDelete, NULL	\
+  );							\
+  g_list_free(obj_list);				\
+ }							\
 }
 
 	EDVRecBinSetBusy(recbin, TRUE);
 
 	/* Get the list of selected recycled objects */
-	glist = clist->selection;
-	while(glist != NULL)
+	for(glist = clist->selection;
+            glist != NULL;
+            glist = g_list_next(glist)
+	)
 	{
 	    row = (gint)glist->data;
 	    obj = EDV_RECYCLED_OBJECT(
@@ -724,8 +729,6 @@ void EDVRecBinOPRecover(edv_recbin_struct *recbin)
 		    obj_list,
 		    EDVRecycledObjectCopy(obj)
 		);
-
-	    glist = g_list_next(glist);
 	}
 
 	/* No recycled objects to recover? */
@@ -762,12 +765,17 @@ void EDVRecBinOPRecover(edv_recbin_struct *recbin)
 	 * one
 	 */
 	status = 0;
-	for(glist = obj_list; glist != NULL; glist = g_list_next(glist))
+	for(glist = obj_list;
+            glist != NULL;
+            glist = g_list_next(glist)
+	)
 	{
 	    obj = EDV_RECYCLED_OBJECT(glist->data);
 	    if(obj == NULL)
 		continue;
 
+	    index = obj->index;
+
 	    /* Check if this object's original path no longer exists */
 	    if((obj->original_path != NULL) ?
 		stat((const char *)obj->original_path, &stat_buf) : FALSE
@@ -834,7 +842,7 @@ No longer exists, create it?",
 	    new_path = NULL;
 	    status = EDVRecBinRecover(
 		core,
-		obj->index,	/* Recycled object to recover */
+		index,		/* Recycled object to recover */
 		NULL,		/* Use the original location as the
 				 * recovery path */
 		&new_path,
@@ -864,19 +872,20 @@ No longer exists, create it?",
 
 		nobjs_recovered++;
 
+		/* Report this recycled object removed */
+		EDVRecycledObjectRemovedEmit(core, index);
+
 		/* Report the recovered object */
 		if(!lstat(new_path, &lstat_buf))
 		    EDVObjectAddedEmit(
-			core, new_path, &lstat_buf
+			core,
+			new_path,
+			&lstat_buf
 		    );
 
-		/* Report this recycled object removed */
-		EDVRecycledObjectRemovedEmit(core, obj->index);
+		g_free(new_path);
 	    }
 
-	    /* Delete the path of the recovered object */
-	    g_free(new_path);
-
 	    /* User aborted? */
 	    if(status == -4)
 		break;
@@ -928,6 +937,7 @@ void EDVRecBinOPPurge(edv_recbin_struct *recbin)
 {
 	gboolean yes_to_all = FALSE;
 	gint row, status, nobjs, nobjs_purged = 0;
+	guint index;
 	const gchar *error_msg;
 	GtkWidget *toplevel;
 	GList *glist, *obj_list = NULL;
@@ -1017,10 +1027,12 @@ void EDVRecBinOPPurge(edv_recbin_struct *recbin)
 	    if(obj == NULL)
 		continue;
 
+	    index = obj->index;
+
 	    /* Purge this recycled object */
 	    status = EDVRecBinPurge(
 		core,
-		obj->index,		/* Recycled object to purge */
+		index,
 		toplevel,
 		(nobjs > 0) ?
 		    ((gfloat)nobjs_purged / (gfloat)nobjs) : -1.0f,
@@ -1046,7 +1058,7 @@ void EDVRecBinOPPurge(edv_recbin_struct *recbin)
 	    if(status == 0)
 	    {
 		nobjs_purged++;
-		EDVRecycledObjectRemovedEmit(core, obj->index);
+		EDVRecycledObjectRemovedEmit(core, index);
 	    }
 
 	    /* User aborted? */
@@ -1128,7 +1140,6 @@ void EDVRecBinOPPurgeAll(edv_recbin_struct *recbin)
 
 #define DO_FREE_LOCALS	{	\
  g_list_free(index_list);	\
- index_list = NULL;		\
 }
 
 	/* Get a list of all recycled object indices */
