@@ -25,6 +25,9 @@ static void StackListShiftDownCB(GtkWidget *widget, gpointer data);
 static gint StackListCListEventCB(
 	GtkWidget *widget, GdkEvent *event, gpointer data
 );
+static gint StackListCListButtonEventMapMenuCB(
+	GtkWidget *widget, GdkEventButton *button, gpointer data
+);
 static void StackListSelectRowCB(
 	GtkCList *clist, gint row, gint column, GdkEvent *event,
 	gpointer data
@@ -674,7 +677,6 @@ static gint StackListCListEventCB(
 	GdkEventCrossing *crossing;
 	GdkEventButton *button;
 	GdkEventMotion *motion;
-	GtkWidget *w;
 	GtkCList *clist;
 	stack_list_flags flags;
 	stack_list_struct *slist = STACK_LIST(data);
@@ -790,6 +792,7 @@ g_print(
 	    button = (GdkEventButton *)event;
 	    x = (gint)button->x;
 	    y = (gint)button->y;
+	    slist->button = button->button;
 	    if(!gtk_clist_get_selection_info(
 		clist, x, y, &row, &column
 	    ))
@@ -797,18 +800,203 @@ g_print(
 		row = -1;
 		column = 0;
 	    }
-#if (DEBUG_LEVEL >= 1)
-g_print(
- "StackListCListEventCB(): slist=0x%.8x button_press_event\
- x=%i y=%i clist=0x%.8x row=%i column=%i\n",
- (guint32)slist, (guint32)clist, x, y, row, column
-);
-#endif
 
 	    /* Handle by button number */
 	    switch(button->button)
 	    {
-	      case 3:
+	      case GDK_BUTTON2:
+		gdk_pointer_grab(
+		    button->window,
+		    FALSE,
+		    GDK_BUTTON_PRESS_MASK |
+		    GDK_BUTTON_RELEASE_MASK |
+		    GDK_POINTER_MOTION_MASK |
+		    GDK_POINTER_MOTION_HINT_MASK,
+		    NULL,
+		    slist->translate_cur,
+		    button->time
+		);
+		slist->drag_last_x = (gint)button->x;
+		slist->drag_last_y = (gint)button->y;
+		status = TRUE;
+		break;
+	    }
+	    break;
+
+	  case GDK_BUTTON_RELEASE:
+	    button = (GdkEventButton *)event;
+	    switch(button->button)
+	    {
+	      case GDK_BUTTON2:
+		if(slist->button > 0)
+		    status = TRUE;
+		if(gdk_pointer_is_grabbed())
+		    gdk_pointer_ungrab(button->time);
+		break;
+	    }
+	    slist->button = 0;
+	    slist->drag_last_x = 0;
+	    slist->drag_last_y = 0;
+	    break;
+
+	  case GDK_MOTION_NOTIFY:
+	    motion = (GdkEventMotion *)event;
+	    x = (gint)motion->x;
+	    y = (gint)motion->y;
+
+	    /* Get row and column */
+	    if(!gtk_clist_get_selection_info(
+		clist, x, y, &row, &column
+	    ))
+	    {
+		row = -1;
+		column = 0;
+	    }
+
+#define DO_SCROLL(adj,d)	{			\
+ if((d) != 0) {						\
+  if(((adj)->upper - (adj)->page_size) > (adj)->lower) {\
+   gtk_adjustment_set_value(				\
+    adj,						\
+    CLIP(						\
+     (adj)->value - (d),				\
+     (adj)->lower, ((adj)->upper - (adj)->page_size)	\
+    )							\
+   );							\
+  }							\
+ }							\
+}
+
+	    /* Check which widget this event is for */
+	    if((widget == slist->src_clist) &&
+	       (flags & STACK_LIST_SHOW_DESCRIPTION_SOURCE)
+	    )
+	    {
+		if(slist->button == GDK_BUTTON2)
+		{
+		    gint dx, dy;
+		    GtkCList *clist = GTK_CLIST(slist->src_clist);
+		    GtkAdjustment *hadj = clist->hadjustment,
+				  *vadj = clist->vadjustment;
+		    if(motion->is_hint)
+		    {
+			gint x, y;
+			GdkModifierType mask;
+			gdk_window_get_pointer(
+			    motion->window, &x, &y, &mask
+			);
+			dx = x - slist->drag_last_x;
+			dy = y - slist->drag_last_y;
+			slist->drag_last_x = x;
+			slist->drag_last_y = y;
+		    }
+		    else
+		    {
+			dx = (gint)(motion->x - slist->drag_last_x);
+			slist->drag_last_x = (gint)motion->x;
+			dy = (gint)(motion->y - slist->drag_last_y);
+			slist->drag_last_y = (gint)motion->y;
+		    }
+		    DO_SCROLL(hadj, dx);
+		    DO_SCROLL(vadj, dy);
+		}
+		else
+		{
+		    /* Get item (if any) from row data */
+		    stack_list_item_struct *item = STACK_LIST_ITEM(
+			gtk_clist_get_row_data(clist, row)
+		    );
+		    /* Set description from item (if any) */
+		    StackListSetDescriptionFromItem(slist, item);
+		}
+		status = TRUE;
+	    }
+	    else if((widget == slist->tar_clist) &&  
+		    (flags & STACK_LIST_SHOW_DESCRIPTION_TARGET)
+	    )
+	    {
+		if(slist->button == GDK_BUTTON2)
+		{
+		    gint dx, dy;
+		    GtkCList *clist = GTK_CLIST(slist->tar_clist);
+		    GtkAdjustment *hadj = clist->hadjustment,
+				  *vadj = clist->vadjustment;
+		    if(motion->is_hint)
+		    {
+			gint x, y;
+			GdkModifierType mask;
+			gdk_window_get_pointer(
+			    motion->window, &x, &y, &mask
+			);
+			dx = x - slist->drag_last_x;
+			dy = y - slist->drag_last_y;
+			slist->drag_last_x = x;
+			slist->drag_last_y = y;
+		    }
+		    else
+		    {
+			dx = (gint)(motion->x - slist->drag_last_x);
+			slist->drag_last_x = (gint)motion->x;
+			dy = (gint)(motion->y - slist->drag_last_y);
+			slist->drag_last_y = (gint)motion->y;
+		    }
+		    DO_SCROLL(hadj, dx);
+		    DO_SCROLL(vadj, dy);
+		}
+		else
+		{
+		    /* Get item (if any) from row data */
+		    stack_list_item_struct *item = STACK_LIST_ITEM( 
+			gtk_clist_get_row_data(clist, row)
+		    );
+		    /* Set description from item (if any) */
+		    StackListSetDescriptionFromItem(slist, item);
+		}
+		status = TRUE;
+	    }
+
+#undef DO_SCROLL
+	    break;
+	}
+
+	return(status);
+}
+
+/*
+ *	GtkCList "button_press_event" signal callback for mapping
+ *	the popup menus.
+ */
+static gint StackListCListButtonEventMapMenuCB(
+	GtkWidget *widget, GdkEventButton *button, gpointer data
+)
+{
+	gint status = FALSE;
+	gint x, y, row, column;
+	GtkWidget *w;
+	GtkCList *clist;
+	stack_list_struct *slist = STACK_LIST(data);
+	if((widget == NULL) || (button == NULL) || (slist == NULL))
+	    return(status);
+
+	clist = GTK_CLIST(widget);
+
+	switch((gint)button->type)
+	{
+	  case GDK_BUTTON_PRESS:
+	    switch(button->button)
+	    {
+	      case GDK_BUTTON3:
+		/* Get the row and column */
+		x = (gint)button->x;
+		y = (gint)button->y;
+		if(!gtk_clist_get_selection_info(
+		    clist, x, y, &row, &column
+		))
+		{
+		    row = -1;
+		    column = 0;
+		}
+
 		gtk_clist_freeze(clist);
 		if(!(button->state & GDK_CONTROL_MASK) &&
 		   !(button->state & GDK_SHIFT_MASK)
@@ -832,79 +1020,9 @@ g_print(
 			NULL, NULL,
 			button->button, button->time
 		    );
+		status = TRUE;
 		break;
 	    }
-	    status = TRUE;
-	    break;
-
-	  case GDK_BUTTON_RELEASE:
-	    button = (GdkEventButton *)event;
-	    x = (gint)button->x;
-	    y = (gint)button->y;
-	    if(!gtk_clist_get_selection_info(
-		clist, x, y, &row, &column
-	    ))
-	    {
-		row = -1;
-		column = 0;
-	    }
-#if (DEBUG_LEVEL >= 1)
-g_print(
- "StackListCListEventCB(): slist=0x%.8x button_release_event\
- x=%i y=%i clist=0x%.8x row=%i column=%i\n",
- (guint32)slist, (guint32)clist, x, y, row, column
-);
-#endif
-
-	    status = TRUE;
-	    break;
-
-	  case GDK_MOTION_NOTIFY:
-	    motion = (GdkEventMotion *)event;
-	    x = (gint)motion->x;
-	    y = (gint)motion->y;
-
-	    /* Get row and column */
-	    if(!gtk_clist_get_selection_info(
-		clist, x, y, &row, &column
-	    ))
-	    {
-		row = -1;
-		column = 0;
-	    }
-#if (DEBUG_LEVEL >= 2)
-g_print(
- "StackListCListEventCB(): slist=0x%.8x motion_notify_event\
- x=%i y=%i clist=0x%.8x row=%i column=%i\n",
- (guint32)slist, (guint32)clist, x, y, row, column
-);
-#endif
-
-	    /* Check which widget this event is for */
-	    if((widget == slist->src_clist) &&
-	       (flags & STACK_LIST_SHOW_DESCRIPTION_SOURCE)
-	    )
-	    {
-		/* Get item (if any) from row data */
-		stack_list_item_struct *item = STACK_LIST_ITEM(
-		    gtk_clist_get_row_data(clist, row)
-		);
-		/* Set description from item (if any) */
-		StackListSetDescriptionFromItem(slist, item);
-	    }
-	    else if((widget == slist->tar_clist) &&  
-		    (flags & STACK_LIST_SHOW_DESCRIPTION_TARGET)
-	    )
-	    {
-		/* Get item (if any) from row data */
-		stack_list_item_struct *item = STACK_LIST_ITEM( 
-		    gtk_clist_get_row_data(clist, row)
-		);
-		/* Set description from item (if any) */
-		StackListSetDescriptionFromItem(slist, item);
-	    }
-
-	    status = TRUE;
 	    break;
 	}
 
@@ -1644,12 +1762,17 @@ stack_list_struct *StackListNew(
 	slist->freeze_count = 0;
 	slist->busy_count = 0;
 	slist->flags = 0;
+	slist->translate_cur = gdk_cursor_new(GDK_FLEUR);
 	slist->src_last_selected = -1;
 	slist->tar_last_selected = -1;
 	slist->item = NULL;
 	slist->total_items = 0;
 	slist->last_description_item = NULL;
 
+	slist->button = 0;
+	slist->drag_last_x = 0;
+	slist->drag_last_y = 0;
+
 	slist->changed_cb = NULL;
 	slist->changed_data = NULL;
 	slist->added_cb = NULL;
@@ -1708,7 +1831,8 @@ stack_list_struct *StackListNew(
 	    w,
 	    GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK |
 	    GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK |
-	    GDK_BUTTON_PRESS_MASK | GDK_POINTER_MOTION_MASK
+	    GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
+	    GDK_POINTER_MOTION_MASK
 	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "key_press_event",
@@ -1728,6 +1852,14 @@ stack_list_struct *StackListNew(
 	);
 	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "button_press_event",
+	    GTK_SIGNAL_FUNC(StackListCListButtonEventMapMenuCB), slist
+	);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "button_press_event",
+	    GTK_SIGNAL_FUNC(StackListCListEventCB), slist
+	);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "button_release_event",
 	    GTK_SIGNAL_FUNC(StackListCListEventCB), slist
 	);
 	gtk_signal_connect(
@@ -1872,7 +2004,8 @@ stack_list_struct *StackListNew(
 	    w,
 	    GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK |
 	    GDK_ENTER_NOTIFY_MASK | GDK_LEAVE_NOTIFY_MASK |
-	    GDK_BUTTON_PRESS_MASK | GDK_POINTER_MOTION_MASK
+	    GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK |
+	    GDK_POINTER_MOTION_MASK
 	);
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "key_press_event",
@@ -1892,6 +2025,14 @@ stack_list_struct *StackListNew(
 	);
 	gtk_signal_connect_after(
 	    GTK_OBJECT(w), "button_press_event",
+	    GTK_SIGNAL_FUNC(StackListCListButtonEventMapMenuCB), slist
+	);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "button_press_event",
+	    GTK_SIGNAL_FUNC(StackListCListEventCB), slist
+	);
+	gtk_signal_connect(
+	    GTK_OBJECT(w), "button_release_event",
 	    GTK_SIGNAL_FUNC(StackListCListEventCB), slist
 	);
 	gtk_signal_connect(
@@ -2300,5 +2441,7 @@ void StackListDelete(stack_list_struct *slist)
 
 	GTK_WIDGET_DESTROY(slist->toplevel)
 
+	GDK_CURSOR_DESTROY(slist->translate_cur);
+
 	g_free(slist);
 }
