@@ -3,8 +3,6 @@
 #include <stdlib.h>
 #include <ctype.h>
 
-extern char *tzname[2];
-
 #include <time.h>
 #include "../include/os.h"
 
@@ -174,9 +172,9 @@ int strlines(const char *s)
 {
 	int lines = 0;
 
-
 	if(s == NULL)
 	    return(lines);
+
 	if(*s == '\0')
 	    return(lines);
 
@@ -205,7 +203,7 @@ int strcasecmp(const char *s1, const char *s2)
 
 	while(*s1 && *s2)
 	{
-	    if(toupper(*s1) != toupper(*s2))
+	    if(toupper((int)(*s1)) != toupper((int)(*s2)))
 		return(1);	/* False */
 
 	    s1++;
@@ -238,7 +236,7 @@ char *strcasestr(const char *haystack, const char *needle)
 	    /* Character in needle and haystack at same position the
 	     * same (case insensitive)
 	     */
-	    if(toupper(*sh) == toupper(*sn))
+	    if(toupper((int)(*sh)) == toupper((int)(*sn)))
 	    {
 		const char *sh_needle_start = sh;
 
@@ -254,7 +252,7 @@ char *strcasestr(const char *haystack, const char *needle)
 			return((char *)sh_needle_start);
 		    }
 		    /* Characters differ (case insensitive)? */
-		    else if(toupper(*sh) != toupper(*sn))
+		    else if(toupper((int)(*sh)) != toupper((int)(*sn)))
 		    {
 			sh++;
 			break;
@@ -283,7 +281,8 @@ char *strcasestr(const char *haystack, const char *needle)
 #endif	/* NEED_STRCASESTR */
 
 /*
- *	Checks if string pfx is a prefix of string s.
+ *	Checks if the string specified pfx is a prefix of the string
+ *	specified by s.
  */
 int strpfx(const char *s, const char *pfx)
 {
@@ -315,7 +314,7 @@ int strcasepfx(const char *s, const char *pfx)
 	 */
 	while(*pfx != '\0')
 	{
-	    if(toupper(*s) != toupper(*pfx))
+	    if(toupper((int)(*s)) != toupper((int)(*pfx)))
 		return(0);
 
 	    s++;
@@ -336,9 +335,12 @@ char *strinsstr(char *s, int i, const char *s2)
 	char *ps, *pt, *pend;
 	const char *ps2;
 
-	if((s == NULL) || (dlen <= 0))
+	if(dlen <= 0)
 	    return(s);
 
+	if(s == NULL)
+	    s = STRDUP("");
+
 	slen = STRLEN(s);
 
 	/* Append? */
@@ -383,7 +385,7 @@ char *strinschr(char *s, int i, char c)
 	char *ps, *pt, *pend;
 
 	if(s == NULL)
-	    return(s);
+	    s = STRDUP("");
 
 	slen = STRLEN(s);
 
@@ -483,8 +485,8 @@ void strtoupper(char *s)
 	if(s == NULL)
 	    return;
 
-	while(*s != '\0')
-	    *s++ = toupper(*s);
+	for(; *s != '\0'; s++)
+	    *s = (char)toupper((int)(*s));
 }
 
 /*
@@ -495,8 +497,8 @@ void strtolower(char *s)
 	if(s == NULL)
 	    return;
 
-	while(*s != '\0')
-	    *s++ = tolower(*s);
+	for(; *s != '\0'; s++)
+	    *s = (char)tolower((int)(*s));
 }
 
 /*
@@ -1605,7 +1607,8 @@ char *StringFormatTimePeriod(time_t seconds)
 
 	if(seconds < 60)
 	{
-	    sprintf(s, "%ld sec%s",
+	    sprintf(
+		s, "%ld sec%s",
 		seconds,
 		((seconds > 1) ? "s" : "")
 	    );
@@ -1613,7 +1616,8 @@ char *StringFormatTimePeriod(time_t seconds)
 	else if(seconds < 3600)
 	{
 	    seconds = seconds / 60;
-	    sprintf(s, "%ld min%s",
+	    sprintf(
+		s, "%ld min%s",
 		seconds,
 		((seconds > 1) ? "s" : "")
 	    );
@@ -1621,19 +1625,49 @@ char *StringFormatTimePeriod(time_t seconds)
 	else if(seconds < 86400)
 	{
 	    seconds = seconds / 3600;
-	    sprintf(s, "%ld hour%s",
+	    sprintf(
+		s, "%ld hour%s",
 		seconds,
 		((seconds > 1) ? "s" : "")
 	    );
 	}
-	else
+	else if(seconds < (7 * 86400))
 	{
 	    seconds = seconds / 86400;
-	    sprintf(s, "%ld day%s",
+	    sprintf(
+		s, "%ld day%s",
 		seconds,
-		((seconds > 1) ? "s" : "")
+		((seconds != 1) ? "s" : "")
 	    );
 	}
+	else if(seconds < (28 * 86400))
+	{
+	    seconds = seconds / (7 * 86400);
+	    sprintf(
+		s, "%ld week%s",
+		seconds,
+		((seconds != 1) ? "s" : "")
+	    );
+	}
+        else if(seconds < (365 * 86400))
+        {
+            seconds = seconds / (28 * 86400);
+            sprintf(
+                s, "%ld month%s",
+                seconds,
+                ((seconds != 1) ? "s" : "")
+            );
+        }     
+	else
+	{
+	    seconds = seconds / (365 * 86400);
+	    sprintf(
+		s, "%ld year%s",
+		seconds,
+		((seconds != 1) ? "s" : "")
+	    );
+	}     
+
 
 	s[sizeof(s) - 1] = '\0';
 
