@@ -80,6 +80,9 @@ typedef struct {
 			*popup_replace_mi,
 			*popup_insert_file_mi;
 
+	GtkAdjustment	*hadj,
+			*vadj;
+
 	gboolean	modified;
 
 	gchar		*filename;
@@ -453,18 +456,77 @@ static gint TEditTextEventCB(
 	    switch(button->button)
 	    {
 	      case GDK_BUTTON3:
-		gtk_signal_emit_stop_by_name(
-		    GTK_OBJECT(widget),
-		    "button_press_event"
-		);
+		/* Popup menu */
 		gtk_menu_popup(
 		    GTK_MENU(te->popup_menu),
 		    NULL, NULL,
 		    NULL, NULL,
 		    button->button, button->time
 		);
+                /* Need to mark the GtkText button as 0 or else it will
+                 * keep marking
+                 */
+                GTK_TEXT(widget)->button = 0;
+                gtk_grab_remove(widget);
+		gtk_signal_emit_stop_by_name(
+		    GTK_OBJECT(widget), "button_press_event"
+		);
 		status = TRUE;
 		break;
+
+              case GDK_BUTTON4:
+                /* Scroll up */
+                if(te->vadj != NULL)
+                {
+                    GtkAdjustment *adj = te->vadj;
+                    const gfloat inc = MAX(
+                        (0.25f * adj->page_size),
+                        adj->step_increment
+                    );
+                    gfloat v = adj->value - inc;
+                    if(v > (adj->upper - adj->page_size))
+                        v = adj->upper - adj->page_size;
+                    if(v < adj->lower)
+                        v = adj->lower;
+                    gtk_adjustment_set_value(adj, v);
+                }
+                /* Need to mark the GtkText button as 0 or else it will
+                 * keep marking
+                 */
+                GTK_TEXT(widget)->button = 0;
+                gtk_grab_remove(widget);
+                gtk_signal_emit_stop_by_name(
+                    GTK_OBJECT(widget), "button_press_event"
+                );
+                status = TRUE;
+                break;
+
+              case GDK_BUTTON5:
+                /* Scroll down */
+                if(te->vadj != NULL)
+                {
+                    GtkAdjustment *adj = te->vadj;
+                    const gfloat inc = MAX(
+                        (0.25f * adj->page_size),
+                        adj->step_increment
+                    );
+                    gfloat v = adj->value + inc;
+                    if(v > (adj->upper - adj->page_size))
+                        v = adj->upper - adj->page_size;
+                    if(v < adj->lower)
+                        v = adj->lower;
+                    gtk_adjustment_set_value(adj, v);
+                }
+                /* Need to mark the GtkText button as 0 or else it will
+                 * keep marking
+                 */
+                GTK_TEXT(widget)->button = 0;
+                gtk_grab_remove(widget);
+                gtk_signal_emit_stop_by_name(
+                    GTK_OBJECT(widget), "button_press_event"
+                );
+                status = TRUE;
+                break;
 	    }
 	    /* Update the widgets based on any button press which
 	     * may have changed the GtkText selection state
@@ -477,9 +539,37 @@ static gint TEditTextEventCB(
 	    switch(button->button)
 	    {
 	      case GDK_BUTTON3:
+                /* Need to mark the GtkText button as 0 or else it will
+                 * keep marking
+                 */
+                GTK_TEXT(widget)->button = 0;
+                gtk_grab_remove(widget);
 		gtk_signal_emit_stop_by_name(
-		    GTK_OBJECT(widget),
-		    "button_release_event"
+		    GTK_OBJECT(widget), "button_release_event"
+		);
+		status = TRUE;
+		break;
+
+	      case GDK_BUTTON4:
+                /* Need to mark the GtkText button as 0 or else it will
+                 * keep marking
+                 */
+                GTK_TEXT(widget)->button = 0;
+                gtk_grab_remove(widget);
+		gtk_signal_emit_stop_by_name(
+		    GTK_OBJECT(widget), "button_release_event"
+		);
+		status = TRUE;
+		break;
+
+	      case GDK_BUTTON5:
+                /* Need to mark the GtkText button as 0 or else it will
+                 * keep marking
+                 */
+                GTK_TEXT(widget)->button = 0;
+                gtk_grab_remove(widget);
+		gtk_signal_emit_stop_by_name(
+		    GTK_OBJECT(widget), "button_release_event"
 		);
 		status = TRUE;
 		break;
@@ -1310,7 +1400,7 @@ static gint TEditFindReplace(
 
 	toplevel = te->toplevel;
 	text = GTK_TEXT(te->text);
-	editable = GTK_EDITABLE(text);  
+	editable = GTK_EDITABLE(text);
 
 	/* Get the lengths of the needle and replace strings */
 	needle_len = STRLEN(needle_str);
@@ -4001,6 +4091,8 @@ static tedit_struct *TEditNew(
 	gdk_window_set_cursor(text->text_area, te->text_cur);
 	gtk_widget_show(w);
 	GTK_RC_STYLE_UNREF(rcstyle);
+	te->hadj = text->hadj;
+	te->vadj = text->vadj;
 	/* Vertical GtkScrollBar */
 	sb = gtk_vscrollbar_new(text->vadj);
 	gtk_table_attach(
