@@ -9,9 +9,19 @@
 
 
 typedef struct _tlist_struct		tlist_struct;
+#define TLIST(p)	((tlist_struct *)(p))
 typedef struct _tlist_thumb_struct	tlist_thumb_struct;
+#define TLIST_THUMB(p)		((tlist_thumb_struct *)(p))
 
 
+/*
+ *	Thumbs List Thumb Flags:
+ */
+typedef enum {
+	TLIST_THUMB_SENSITIVE		= (1 << 0),
+	TLIST_THUMB_SELECTABLE		= (1 << 1)
+} tlist_thumb_flags;
+
 /*
  *	Thumbs List Flags:
  */
@@ -20,9 +30,12 @@ typedef enum {
 	TLIST_DOUBLE_BUFFER		= (1 << 1),	/* Use double buffer */
 	TLIST_SHOW_THUMB_FRAMES		= (1 << 2),	/* Show Thumb Frames */
  	TLIST_SHOW_THUMB_LABELS		= (1 << 3),	/* Show Thumb Labels */
-	TLIST_SHOW_TEXTTIPS		= (1 << 4)	/* Show Texttips */
+	TLIST_SHOW_TEXTTIPS		= (1 << 4),	/* Show Texttips */
+	TLIST_DRAG_ACTIVE		= (1 << 16),	/* A drag is in progress */
+	TLIST_DRAG_ACTIVE_MOVE		= (1 << 17)	/* A drag move is in progress */
 } tlist_flags;
 
+
 /*
  *	Thumb Load States:
  */
@@ -38,8 +51,8 @@ typedef enum {
  */
 struct _tlist_thumb_struct {
 
+	tlist_thumb_flags	flags;
 	tlist_load_state	load_state;
-	GtkStateType	state;
 	GdkColormap	*colormap;
 
 	GdkPixmap	*pixmap;
@@ -60,7 +73,10 @@ struct _tlist_thumb_struct {
 	);
 
 };
-#define TLIST_THUMB(p)		((tlist_thumb_struct *)(p))
+#define TLIST_THUMB_IS_SELECTABLE(_thumb_)			\
+ (((_thumb_) != NULL) ?						\
+  ((_thumb_)->flags & TLIST_THUMB_SELECTABLE) : FALSE		\
+ )
 
 
 /*
@@ -85,6 +101,8 @@ struct _tlist_struct {
 	GtkAdjustment	*vadj,		/* Scroll adjustments */
 			*hadj;
 
+	GdkBitmap	*transparent_stipple_bm;
+
 	/* Thumbs */
 	tlist_thumb_struct	**thumb;
 	gint			total_thumbs;
@@ -124,7 +142,6 @@ struct _tlist_struct {
 	);
 
 };
-#define TLIST(p)	((tlist_struct *)(p))
 
 
 /* Utils */
@@ -150,26 +167,30 @@ extern void TListThaw(tlist_struct *tlist);
 
 
 /* Thumbs Add, Set, and Delete */
-extern gint TListInsert(tlist_struct *tlist, gint thumb_num, const gchar *text);
-extern gint TListAppend(tlist_struct *tlist, const gchar *text);
+extern gint TListInsert(
+	tlist_struct *tlist, const gint thumb_num, const gchar *text
+);
+extern gint TListAppend(
+	tlist_struct *tlist, const gchar *text
+);
 extern void TListSetLoadState(
-	tlist_struct *tlist, gint thumb_num,
-	tlist_load_state load_state
+	tlist_struct *tlist, const gint thumb_num,
+	const tlist_load_state load_state
 );
 extern void TListSetText(
-	tlist_struct *tlist, gint thumb_num,
+	tlist_struct *tlist, const gint thumb_num,
 	const gchar *text
 );
 extern void TListSetTextColor(
-        tlist_struct *tlist, gint thumb_num,
+        tlist_struct *tlist, const gint thumb_num,
         GdkColor *fg, GdkColor *bg
 );
 extern void TListSetPixmap(
-	tlist_struct *tlist, gint thumb_num,
+	tlist_struct *tlist, const gint thumb_num,
 	GdkPixmap *pixmap, GdkBitmap *mask
 );
 extern void TListSetRGBA(
-	tlist_struct *tlist, gint thumb_num,
+	tlist_struct *tlist, const gint thumb_num,
 	gint width, gint height,        /* Of image data */
 	gint bpl,                       /* Bytes per line, can be -1 */
 	GdkRgbDither dith,
@@ -178,20 +199,22 @@ extern void TListSetRGBA(
 					 * than thumb */
 );
 extern void TListSetThumbData(
-	tlist_struct *tlist, gint thumb_num,
+	tlist_struct *tlist, const gint thumb_num,
 	gpointer data
 );
 extern void TListSetThumbDataFull(
-	tlist_struct *tlist, gint thumb_num,
+	tlist_struct *tlist, const gint thumb_num,
 	gpointer data,
 	void (*destroy_cb)(gpointer)
 );
 
-extern void TListRemove(tlist_struct *tlist, gint thumb_num);
+extern void TListRemove(tlist_struct *tlist, const gint thumb_num);
 extern void TListClear(tlist_struct *tlist);
 
 /* Thumbs Get */
-extern tlist_load_state TListGetLoadState(tlist_struct *tlist, gint thumb_num);
+extern tlist_load_state TListGetLoadState(
+	tlist_struct *tlist, const gint thumb_num
+);
 extern gboolean TListGetText(
 	tlist_struct *tlist, gint thumb_num, gchar **text
 );
