@@ -1,6 +1,6 @@
+#include <stdio.h>
 #include <sys/stat.h>
 #include <gtk/gtk.h>
-#include "../include/fio.h"
 #include "guiutils.h"
 #include "tview.h"
 #include "tviewcb.h"
@@ -143,7 +143,7 @@ GtkVisibility TViewIsLineVisible(tview_struct *tv, gint n)
 	    return(GTK_VISIBILITY_NONE);
 
 	font = tv->text_font;
-	adj = tv->vadj;      
+	adj = tv->vadj;
 	if((font == NULL) || (adj == NULL))
 	    return(GTK_VISIBILITY_NONE);
 
@@ -173,13 +173,13 @@ GtkVisibility TViewIsLineVisible(tview_struct *tv, gint n)
  */
 gint TViewOpenFile(tview_struct *tv, const gchar *path)
 {
-	gchar *buf = NULL;
-	gint len = 0;
 	FILE *fp;
 	GtkWidget *w;
+	GtkEditable *editable;
+	GtkText *text;
 
 	if(tv == NULL)             
-	    return(-1);
+	    return(-2);
 
 	/* Delete all text */                        
 	TViewClear(tv);
@@ -188,46 +188,98 @@ gint TViewOpenFile(tview_struct *tv, const gchar *path)
 	if(tv->has_changes)
 	    tv->has_changes = FALSE;
 
-	w = tv->text;
-	if((w == NULL) || STRISEMPTY(path))
-	    return(0);
+	if(STRISEMPTY(path))
+	    return(2);
 
-	/* Open file for reading */
-	fp = FOpen(path, "rb");
+	w = tv->text;
+	if(w == NULL)
+	    return(-1);
+
+	editable = GTK_EDITABLE(w);
+	text = GTK_TEXT(w);
+
+	/* Open the file for reading */
+	fp = fopen(path, "rb");
 	if(fp != NULL)
 	{
 	    struct stat stat_buf;
 
+	    /* Get the file's statistics */
 	    if(!fstat(fileno(fp), &stat_buf))
 	    {
-		len = stat_buf.st_size;
-		if(len > 0)
-		    buf = (gchar *)g_malloc(len * sizeof(gchar));
-		if(buf != NULL)
-		    fread(buf, sizeof(gchar), len, fp);
+		gint units_read;
+		gchar *read_buf;
+		const gulong read_buf_len = (gulong)stat_buf.st_blksize;
+
+		gtk_text_freeze(text);
+
+		/* Set the GtkText's insert position to the beginning */
+		gtk_text_set_point(GTK_TEXT(w), 0);
+
+		/* Allocate the read buffer */
+		if(read_buf_len > 0)
+		    read_buf = (gchar *)g_malloc(read_buf_len * sizeof(gchar));
 		else
-		    len = 0;
-	    }    
-	    FClose(fp);
+		    read_buf = NULL;
+
+		if(read_buf != NULL)
+		{
+		    /* Begin reading the file */
+		    clearerr(fp);
+		    while(!feof(fp))
+		    {
+			/* Read this block */
+			units_read = (gint)fread(
+			    read_buf, sizeof(guint8), (size_t)read_buf_len, fp
+			);
+			if(units_read <= 0)
+			    break;
+
+			/* Append this block to the GtkText */
+			gtk_text_insert(
+			    text,
+			    tv->text_font,
+			    NULL, NULL,
+			    read_buf, units_read
+			);
+		    }
+
+		    /* Delete the read buffer */
+		    g_free(read_buf);
+		}
+		else
+		{
+		    /* No read buffer, open one character at a time */
+		    gint c;
+		    gchar buf[1];
+
+		    /* Begin reading the file */
+		    clearerr(fp);
+		    while(!feof(fp))
+		    {
+			c = (gint)fgetc(fp);
+			if(c == EOF)
+			    break;
+
+			buf[0] = (gchar)c;
+
+			/* Append this character to the GtkText */
+			gtk_text_insert(
+			    text,
+			    tv->text_font,
+			    NULL, NULL,
+			    buf, 1
+			);
+		    }
+		}
+
+		gtk_text_thaw(text);
+	    }
+
+	    fclose(fp);
 	}
 
-	/* Got data from file? */
-	if(buf != NULL)
-	{
-	    /* Insert text from file data */
-	    gtk_text_freeze(GTK_TEXT(w));
-	    gtk_text_set_point(GTK_TEXT(w), 0);
-	    gtk_text_insert(
-		GTK_TEXT(w),
-		tv->text_font,
-		NULL, NULL,
-		buf, len
-	    );
-	    gtk_text_thaw(GTK_TEXT(w));
-	    TViewUpdate(tv);
-
-	    g_free(buf);
-	}
+	TViewUpdate(tv);
 
 	return(0);
 }
@@ -237,10 +289,10 @@ gint TViewOpenFile(tview_struct *tv, const gchar *path)
  */
 gint TViewSaveFile(tview_struct *tv, const gchar *path)
 {
-	gchar *buf;
+	gchar *buf, *buf_end;
 	gint len;
 	FILE *fp;
-	GtkWidget *w;                
+	GtkWidget *w;
 
 	if(tv == NULL)             
 	    return(-1);
@@ -252,19 +304,51 @@ gint TViewSaveFile(tview_struct *tv, const gchar *path)
 	/* Get copy of data from text */
 	len = (gint)gtk_text_get_length(GTK_TEXT(w));
 	buf = gtk_editable_get_chars(GTK_EDITABLE(w), 0, len);
+	if(buf == NULL)
+	    return(-1);
 
-	/* Open file for writing */
-	fp = FOpen(path, "wb");
-	if((fp != NULL) && (buf != NULL) && (len > 0))
+	buf_end = buf + len;
+
+	/* Open the file for writing */
+	fp = fopen(path, "wb");
+	if(fp != NULL)
 	{
-	    gint i;
+	    struct stat stat_buf;
 
-	    for(i = 0; i < len; i++)
-		fputc(buf[i], fp);
+	    /* Get the file's statistics */
+	    if(!fstat(fileno(fp), &stat_buf))
+	    {
+		gint cur_len, units_written;
+		const gulong write_buf_len = MAX(
+		    (gulong)stat_buf.st_blksize,
+		    1l
+		);
+		gchar *buf_ptr = buf;
+
+		/* Begin writing the file */
+		while(buf_ptr < buf_end)
+		{
+		    cur_len = MIN(
+			(gint)(buf_end - buf_ptr),
+			(gint)write_buf_len
+		    );
+		    if(cur_len <= 0)
+			break;
+
+		    /* Write this block */
+		    units_written = (gint)fwrite(
+			buf_ptr, sizeof(gchar), (size_t)cur_len, fp
+		    );
+		    if(units_written <= 0)
+			break;
+
+		    buf_ptr += units_written;
+		}
+	    }
 	}
 
-	/* Close file and delete copy of data */
-	FClose(fp);
+	/* Close the file and delete the copy of the text */
+	fclose(fp);
 	g_free(buf);
 
 	/* Reset has changes mark */
@@ -406,7 +490,7 @@ void TViewCopy(tview_struct *tv)
 	/* Delete coppied buffer */
 	g_free(buf);
 
-	gtk_text_thaw(GTK_TEXT(w));                                   
+	gtk_text_thaw(GTK_TEXT(w));
 }
 
 /*
@@ -437,8 +521,8 @@ void TViewPaste(tview_struct *tv)
 	    GTK_EDITABLE(w), 
 	    0,     
 	    (gint)gtk_text_get_length(GTK_TEXT(w))     
-	);     
-	gtk_text_thaw(GTK_TEXT(w));                      
+	);
+	gtk_text_thaw(GTK_TEXT(w));
 #endif
 
 	/* Delete coppied data from clipboard */
@@ -619,7 +703,7 @@ tview_struct *TViewNew(GtkWidget *parent)
 	parent2 = w;
 	/* Text */
 	tv->text = w = gtk_text_new(NULL, NULL);
-	editable = GTK_EDITABLE(w);                    
+	editable = GTK_EDITABLE(w);
 	text = GTK_TEXT(w);
 	gtk_widget_add_events(
 	    w,
@@ -697,21 +781,21 @@ tview_struct *TViewNew(GtkWidget *parent)
   menu, GUI_MENU_ITEM_TYPE_LABEL, accelgrp,     \
   icon, label, accel_key, accel_mods, NULL,     \
   mclient_data, func_cb                         \
- );                                             \
+ );						\
 }
 #define DO_ADD_MENU_ITEM_CHECK  {               \
  w = GUIMenuItemCreate(                         \
   menu, GUI_MENU_ITEM_TYPE_CHECK, accelgrp,     \
   icon, label, accel_key, accel_mods, NULL,     \
   mclient_data, func_cb                         \
- );                                             \
+ );						\
 }
 #define DO_ADD_MENU_SEP         {               \
  w = GUIMenuItemCreate(                         \
   menu, GUI_MENU_ITEM_TYPE_SEPARATOR, NULL,     \
   NULL, NULL, 0, 0, NULL,                       \
   NULL, NULL                                    \
- );                                             \
+ );						\
 }
 	    GtkWidget *menu = GUIMenuCreate();
 	    guint8 **icon;
@@ -795,7 +879,7 @@ tview_struct *TViewNew(GtkWidget *parent)
 #else
 "Paste"
 #endif
-	    ;  
+	    ;
 	    accel_key = 0;
 	    accel_mods = 0;
 	    func_cb = TViewPasteCB;
@@ -903,7 +987,7 @@ tview_struct *TViewNewWithToplevel(
 	gtk_signal_connect(
 	    GTK_OBJECT(w), "delete_event",
 	    GTK_SIGNAL_FUNC(TViewDeleteEventCB), tv
-	);                                         
+	);
 
 	return(tv);
 }
@@ -941,7 +1025,7 @@ void TViewSetChangedCB(
 )
 {
 	if(tv == NULL)
-	    return;   
+	    return;
 
 	tv->changed_cb = changed_cb;
 	tv->changed_data = data;
@@ -1020,7 +1104,7 @@ void TViewSetBusy(tview_struct *tv, gboolean is_busy)
 
 	    /* If already busy then don't change anything */
 	    if(tv->busy_count > 1)
-		return;      
+		return;
 
 	    SET_CURSOR(tv->toplevel, tv->busy_cur)
 	    SET_CURSOR(tv->text, tv->busy_cur)
