@@ -4,16 +4,16 @@
 #include "url.h"
 
 
-static gchar *STRNDUP(const gchar *s, gint len);
+static gchar *STRNDUP(const gchar *s, const gint len);
 
 url_struct *URLNew(void);
 url_struct *URLNewWithValues(
-	url_flags flags,
+	const url_flags flags,
 	const gchar *protocol,
 	const gchar *user,
 	const gchar *password,
 	const gchar *host,
-	gint port,
+	const gint port,
 	const gchar *path,
 	const gchar *path_arg
 );
@@ -21,8 +21,8 @@ url_struct *URLNewFromURLString(const gchar *url_str);
 url_struct *URLCopy(const url_struct *url);
 void URLDelete(url_struct *url);
 
-guint8 *URLEncode(GList *glist, gint *buf_len);
-GList *URLDecode(const guint8 *buf, gint buf_len);
+guint8 *URLEncode(GList *url_list, gint *buf_len);
+GList *URLDecode(const guint8 *buf, const gint buf_len);
 GList *URLDecodeString(const gchar *s);
 
 gchar *URLTokenize(const gchar *url_str);
@@ -51,7 +51,7 @@ gchar *URLDetokenize(const gchar *url_str);
  *	The returned string may be shorter if a null terminating byte
  *	is encountered in s before len bytes is reached.
  */
-static gchar *STRNDUP(const gchar *s, gint len)
+static gchar *STRNDUP(const gchar *s, const gint len)
 {
 	const gchar *src, *src_end;
 	gchar *tar, *s2 = ((s != NULL) && (len > 0)) ?
@@ -75,15 +75,15 @@ static gchar *STRNDUP(const gchar *s, gint len)
 		const gint tar_len = (gint)(tar - s2);
 
 		/* Null terminate the target string, shorten its
-		 * allocation, then return
+		 * allocation, and then return
 		 */
 		*tar = '\0';
-		s2 = g_realloc(s2, (tar_len + 1) * sizeof(gchar));
-		return(s2);
+		return(g_realloc(s2, (tar_len + 1) * sizeof(gchar)));
 	    }
 
 	    *tar++ = *src++;
 	}
+
 	*tar = '\0';
 
 	return(s2);
@@ -102,12 +102,12 @@ url_struct *URLNew(void)
  *	Creates a new URL from the specified values.
  */
 url_struct *URLNewWithValues(
-	url_flags flags,
+	const url_flags flags,
 	const gchar *protocol,
 	const gchar *user,    
 	const gchar *password,
 	const gchar *host,
-	gint port,
+	const gint port,
 	const gchar *path,
 	const gchar *path_arg
 )
@@ -163,7 +163,7 @@ url_struct *URLNewFromURLString(const gchar *url_str)
 	}
 	url->protocol = STRNDUP(s, (gint)(s2 - s));
 
-	/* Seek s past protocol deliminator characters */
+	/* Seek s past the protocol deliminator characters */
 	if(*s2 == ':')
 	    s2++;
 	if(*s2 == '/')
@@ -174,9 +174,10 @@ url_struct *URLNewFromURLString(const gchar *url_str)
 
 	/* Path
 	 *
-	 * Now s is past the protocol deliminator characters, seek path
-	 * to the start of the path or marker, if there is no path or
-	 * marker then path will point ot the end of the URL string
+	 * Now s is past the protocol deliminator characters, seek
+	 * path to the start of the path or marker, if there is no
+	 * path or marker then path will point ot the end of the URL
+	 * string
 	 */
 	for(path = s; *path != '\0'; path++)
 	{
@@ -406,7 +407,7 @@ void URLDelete(url_struct *url)
  *	Encodes the specified list of URLs into a buffer of null byte
  *	separated URL strings.
  */
-guint8 *URLEncode(GList *glist, gint *buf_len)
+guint8 *URLEncode(GList *url_list, gint *buf_len)
 {
 	gint len = 0, cur_pos, url_len;
 	const gchar	*protocol,
@@ -414,18 +415,19 @@ guint8 *URLEncode(GList *glist, gint *buf_len)
 			*password,
 			*host,
 			*path;
-	gchar *url_str, port[40];
+	gchar *url_str, port_str[40];
 	guint8 *buf = NULL, *buf_ptr;
+	GList *glist;
 	const url_struct *url;
 
 	if(buf_len != NULL)
 	    *buf_len = len;
 
-	if(glist == NULL)
+	if(url_list == NULL)
 	    return(buf);
 
 	/* Iterate through each URL */
-	for(;
+	for(glist = url_list;
 	    glist != NULL;
 	    glist = g_list_next(glist)
 	)
@@ -434,7 +436,7 @@ guint8 *URLEncode(GList *glist, gint *buf_len)
 	    if(url == NULL)
 		continue;
 
-	    /* Get strings */
+	    /* Get the URL values and use defaults as needed */
 	    protocol = (url->protocol != NULL) ?
 			url->protocol : "file";
 	    user = url->user;
@@ -442,15 +444,17 @@ guint8 *URLEncode(GList *glist, gint *buf_len)
 	    host = (url->host != NULL) ? url->host : "";
 	    if(url->port > 0)
 		g_snprintf(
-		    port, sizeof(port),
+		    port_str, sizeof(port_str),
 		    ":%i",
 		    url->port
 		);
 	    else
-		*port = '\0';
+		*port_str = '\0';
 	    path = url->path;
 
-	    /* Must have a path */
+	    /* If there is no path specified then it is not possible
+	     * to encode this URL
+	     */
 	    if(STRISEMPTY(path))
 		continue;
 
@@ -460,25 +464,49 @@ guint8 *URLEncode(GList *glist, gint *buf_len)
 	     * character will be used to deliminate the host address
 	     * and path
 	     */
-	    if(!STRISEMPTY(user))
-		url_str = g_strdup_printf(
-		    "%s://%s%s%s@%s%s%s%s",
+	    if(!STRISEMPTY(user) && !STRISEMPTY(password))
+		url_str = g_strconcat(
 		    protocol,
+		    "://",
 		    user,
-		    STRISEMPTY(password) ? "" : ":",
+		    ":",
 		    password,
-		    host, port,
+		    "@",
+		    host,
+		    port_str,
 		    URLPATHISABSOLUTE(path) ? "" : "#",
-		    path
+		    path,
+		    NULL
 		);
-	    else 
-		url_str = g_strdup_printf(
-		    "%s://%s%s%s%s",
+	    else if(!STRISEMPTY(user))
+		url_str = g_strconcat(
 		    protocol,
-		    host, port,
+		    "://",
+		    user,
+		    "@",
+		    host,
+		    port_str,
 		    URLPATHISABSOLUTE(path) ? "" : "#",
-		    path
+		    path,
+		    NULL
 		);
+	    else
+		url_str = g_strconcat(
+		    protocol,
+		    "://",
+		    host,
+		    port_str,
+		    URLPATHISABSOLUTE(path) ? "" : "#",
+		    path,
+		    NULL
+		);
+
+	    if(url->path_arg != NULL)
+	    {
+		gchar *s = g_strconcat(url_str, "?", url->path_arg, NULL);
+		g_free(url_str);
+		url_str = s;
+	    }
 
 	    /* Calculate length of this url string (including the null
 	     * terminating character) and increase buffer allocation to
@@ -489,7 +517,7 @@ guint8 *URLEncode(GList *glist, gint *buf_len)
 	    url_len = STRLEN(url_str) + 1;	/* Length of URL string plus null char */
  	    len += url_len;			/* Increase total buffer length */
 
-	    /* Increase buffer allocation */
+	    /* Increase the buffer allocation */
 	    buf = (guint8 *)g_realloc(buf, len * sizeof(guint8));
 	    if(buf == NULL)
 	    {
@@ -498,7 +526,9 @@ guint8 *URLEncode(GList *glist, gint *buf_len)
 		break;
 	    }
 
-	    /* Get pointer to position of current buffer segment */
+	    /* Get the pointer to the position of the current buffer
+	     * segment
+	     */
 	    buf_ptr = (guint8 *)(buf + cur_pos);
 
 	    /* Copy the URL to the current buffer segment, including
@@ -520,16 +550,16 @@ guint8 *URLEncode(GList *glist, gint *buf_len)
  *	Decodes the specified buffer containing null byte separated URL
  *	strings into a list of URLs.
  */
-GList *URLDecode(const guint8 *buf, gint buf_len)
+GList *URLDecode(const guint8 *buf, const gint buf_len)
 {
 	gint url_len;
 	gchar *url_str;
 	const guint8 *buf_ptr, *buf_end;
-	GList *glist = NULL;
+	GList *url_list = NULL;
 	url_struct *url;
 
 	if((buf == NULL) || (buf_len <= 0))
-	    return(glist);
+	    return(url_list);
 
 	/* Iterate through buffer */
 	buf_ptr = buf;
@@ -543,21 +573,23 @@ GList *URLDecode(const guint8 *buf, gint buf_len)
 	    if(url_str == NULL)
 		break;
 
-	    /* Get length of this URL string segment */
+	    /* Get the length of this URL string segment */
 	    url_len = STRLEN(url_str);
 
-	    /* Create a new URL and append it to the list */
+	    /* Create a new URL from this URL string segment and
+	     * append it to the list
+	     */
 	    url = URLNewFromURLString(url_str);
-	    glist = g_list_append(glist, url);
+	    url_list = g_list_append(url_list, url);
 
-	    /* Delete the copy of the URL string segment */
+	    /* Delete this URL string segment */
 	    g_free(url_str);
 
-	    /* Seek buffer position to start of next URL string */
+	    /* Seek to the next URL string segment */
 	    buf_ptr += url_len + 1;
 	}
 
-	return(glist);
+	return(url_list);
 }
 
 
@@ -569,16 +601,16 @@ GList *URLDecodeString(const gchar *s)
 {
 	gchar *url_str;
 	const gchar *s_next;
-	GList *glist = NULL;
+	GList *url_list = NULL;
 	url_struct *url;
 
 	if(s == NULL)
-	    return(glist);
+	    return(url_list);
 
 	/* Iterate through string */
 	while(*s != '\0')
 	{
-	    /* Seek s past deliminators */
+	    /* Seek s past the deliminator(s) */
 	    while((*s == ' ') || (*s == '\t'))
 		s++;
 
@@ -596,7 +628,7 @@ GList *URLDecodeString(const gchar *s)
 
 	    /* Create a new URL and append it to the list */
 	    url = URLNewFromURLString(url_str);
-	    glist = g_list_append(glist, url);
+	    url_list = g_list_append(url_list, url);
 
 	    /* Delete the copy of the URL string segment */
 	    g_free(url_str);
@@ -605,7 +637,7 @@ GList *URLDecodeString(const gchar *s)
 	    s = s_next;
 	}
 
-	return(glist);
+	return(url_list);
 }
 
 
