@@ -8,19 +8,20 @@
 #include <glib.h>
 
 
+typedef struct _url_struct		url_struct;
+#define URL(p)				((url_struct *)(p))
+
+
 /*
  *	URL Flags:
  */
 typedef enum {
-
 	URL_PATH_RELATIVE		= (1 << 0)
-
 } url_flags;
 
 /*
  *	URL:
  */
-typedef struct _url_struct		url_struct;
 struct _url_struct {
 
 	url_flags	flags;
@@ -38,7 +39,11 @@ struct _url_struct {
 	gchar		*host;
 	gint		port;
 
-	/* Path or Marker (may be NULL for none) */
+	/* Path or Marker (may be NULL for none)
+	 *
+	 * For recycled objects, this contains the recycled object's
+	 * index value as a string
+	 */
 	gchar		*path;
 
 	/* Path argument, after the '?' character (may be NULL for
@@ -47,17 +52,16 @@ struct _url_struct {
 	gchar		*path_arg;
 
 };
-#define URL(p)	((url_struct *)(p))
 
 
 extern url_struct *URLNew(void);
 extern url_struct *URLNewWithValues(
-	url_flags flags,
+	const url_flags flags,
 	const gchar *protocol,
 	const gchar *user,
 	const gchar *password,
 	const gchar *host,
-	gint port,
+	const gint port,
 	const gchar *path,
 	const gchar *path_arg
 );
@@ -65,8 +69,8 @@ extern url_struct *URLNewFromURLString(const gchar *url_str);
 extern url_struct *URLCopy(const url_struct *url);
 extern void URLDelete(url_struct *url);
 
-extern guint8 *URLEncode(GList *glist, gint *buf_len);
-extern GList *URLDecode(const guint8 *buf, gint buf_len);
+extern guint8 *URLEncode(GList *url_list, gint *buf_len);
+extern GList *URLDecode(const guint8 *buf, const gint buf_len);
 extern GList *URLDecodeString(const gchar *s);
 
 extern gchar *URLTokenize(const gchar *url_str);
