@@ -33,15 +33,15 @@
 #define PROG_HELP_MESG  "\
 Usage: ziptool.front [device] [options] [GUI_options]\n\
 \n\
-    [device] specifies the device to select at startup.\n\
+    The [device] specifies the device to select at startup.\n\
 \n\
-    [options] can be any of the following:\n\
+    The [options] can be any of the following:\n\
 \n\
 	--help                  Prints (this) help screen and exits.\n\
 	--version               Prints version information and exits.\n\
 \n\
-    [GUI_options] can be any options standard to your GUI, consult\n\
-    your GUI's manual for available options.\n\
+    The [GUI_options] can be any options standard to your GUI,\n\
+    consult your GUI's manual for available options.\n\
 \n"
 #endif
 #ifdef PROG_LANGUAGE_SPANISH
