@@ -6,12 +6,12 @@
 #include <gdk/gdkkeysyms.h>
 
 #include "../guiutils.h"
-#include "../piechart.h"
+#include "../pie_chart.h"
 #include "../toolbar.h"
 
-#include "../edvtypes.h"
-#include "../edvid.h"
-#include "../edvutils.h"
+#include "../edv_types.h"
+#include "../edv_id.h"
+#include "../edv_utils.h"
 #include "../lib/endeavour2.h"
 
 #include "ziptoolio.h"
