@@ -6,9 +6,9 @@
 #define ZIPTOOL_H
 
 #include <gtk/gtk.h>
-#include "../piechart.h"
-#include "../edvtypes.h"
-#include "../edvid.h"
+#include "../pie_chart.h"
+#include "../edv_types.h"
+#include "../edv_id.h"
 #include "../toolbar.h"
 #include "../lib/endeavour2.h"
 #include "ziptoolio.h"
